@@ -12,6 +12,7 @@
 #include "dfvm.h"
 
 #include <ftypes/ftypes.h>
+#include <wsutil/array.h>
 #include <wsutil/ws_assert.h>
 
 static void
@@ -21,6 +22,7 @@ const char *
 dfvm_opcode_tostr(dfvm_opcode_t code)
 {
 	switch (code) {
+		case DFVM_NULL:			return "(DFVM_NULL)";
 		case DFVM_IF_TRUE_GOTO:		return "IF_TRUE_GOTO";
 		case DFVM_IF_FALSE_GOTO:	return "IF_FALSE_GOTO";
 		case DFVM_CHECK_EXISTS:		return "CHECK_EXISTS";
@@ -57,6 +59,7 @@ dfvm_opcode_tostr(dfvm_opcode_t code)
 		case DFVM_SET_CLEAR:		return "SET_CLEAR";
 		case DFVM_SLICE:		return "SLICE";
 		case DFVM_LENGTH:		return "LENGTH";
+		case DFVM_VALUE_STRING:		return "VALUE_STRING";
 		case DFVM_BITWISE_AND:		return "BITWISE_AND";
 		case DFVM_UNARY_MINUS:		return "UNARY_MINUS";
 		case DFVM_ADD:			return "ADD";
@@ -68,23 +71,11 @@ dfvm_opcode_tostr(dfvm_opcode_t code)
 		case DFVM_STACK_PUSH:		return "STACK_PUSH";
 		case DFVM_STACK_POP:		return "STACK_POP";
 		case DFVM_NOT_ALL_ZERO:		return "NOT_ALL_ZERO";
+		case DFVM_NO_OP:		return "NO_OP";
 	}
 	return "(fix-opcode-string)";
 }
 
-dfvm_insn_t*
-dfvm_insn_new(dfvm_opcode_t op)
-{
-	dfvm_insn_t	*insn;
-
-	insn = g_new(dfvm_insn_t, 1);
-	insn->op = op;
-	insn->arg1 = NULL;
-	insn->arg2 = NULL;
-	insn->arg3 = NULL;
-	return insn;
-}
-
 static void
 dfvm_value_free(dfvm_value_t *v)
 {
@@ -129,6 +120,37 @@ dfvm_value_unref(dfvm_value_t *v)
 	dfvm_value_free(v);
 }
 
+dfvm_insn_t*
+dfvm_insn_new(dfvm_opcode_t op)
+{
+	dfvm_insn_t	*insn;
+
+	insn = g_new(dfvm_insn_t, 1);
+	insn->op = op;
+	insn->arg1 = NULL;
+	insn->arg2 = NULL;
+	insn->arg3 = NULL;
+	return insn;
+}
+
+void
+dfvm_insn_replace_no_op(dfvm_insn_t *insn)
+{
+	if (insn->arg1) {
+		dfvm_value_unref(insn->arg1);
+		insn->arg1 = NULL;
+	}
+	if (insn->arg2) {
+		dfvm_value_unref(insn->arg2);
+		insn->arg2 = NULL;
+	}
+	if (insn->arg3) {
+		dfvm_value_unref(insn->arg3);
+		insn->arg3 = NULL;
+	}
+	insn->op = DFVM_NO_OP;
+}
+
 void
 dfvm_insn_free(dfvm_insn_t *insn)
 {
@@ -221,7 +243,7 @@ dfvm_value_new_guint(unsigned num)
 static char *
 dfvm_value_tostr(dfvm_value_t *v)
 {
-	char *s;
+	char *s = NULL;
 
 	if (!v)
 		return NULL;
@@ -251,8 +273,12 @@ dfvm_value_tostr(dfvm_value_t *v)
 		case INTEGER:
 			s = ws_strdup_printf("%"G_GUINT32_FORMAT, v->value.numeric);
 			break;
-		default:
-			s = ws_strdup("FIXME");
+		case EMPTY:
+			s = ws_strdup("EMPTY");
+			break;
+		case INSN_NUMBER:
+			s = ws_strdup_printf("INSN(%"PRIu32")", v->value.numeric);
+			break;
 	}
 	return s;
 }
@@ -275,6 +301,12 @@ value_type_tostr(dfvm_value_t *v, bool show_ftype)
 		case FVALUE:
 			s = fvalue_type_name(dfvm_value_get_fvalue(v));
 			break;
+		case FUNCTION_DEF:
+			if (v->value.funcdef->return_ftype != FT_NONE)
+				s = ftype_name(v->value.funcdef->return_ftype);
+			else
+				s = "***";
+			break;
 		default:
 			return ws_strdup("");
 			break;
@@ -283,15 +315,22 @@ value_type_tostr(dfvm_value_t *v, bool show_ftype)
 }
 
 static GSList *
-dump_str_stack_push(GSList *stack, const char *str)
+dump_str_stack_push(GSList *stack, const char *arg, const char *arg_type)
 {
-	return g_slist_prepend(stack, g_strdup(str));
+	stack = g_slist_prepend(stack, g_strdup(arg));
+	stack = g_slist_prepend(stack, g_strdup(arg_type));
+	return stack;
 }
 
 static GSList *
 dump_str_stack_pop(GSList *stack, uint32_t count)
 {
 	while (stack && count-- > 0) {
+		/* For each argument count we need to pop two elements from the stack,
+		 * the argument string itself and the argument type string.
+		 * They always come in pairs. */
+		g_free(stack->data);
+		stack = g_slist_delete_link(stack, stack);
 		g_free(stack->data);
 		stack = g_slist_delete_link(stack, stack);
 	}
@@ -299,8 +338,8 @@ dump_str_stack_pop(GSList *stack, uint32_t count)
 }
 
 static void
-append_call_function(wmem_strbuf_t *buf, const char *func, uint32_t nargs,
-					GSList *stack_print)
+append_call_function(wmem_strbuf_t *buf, const char *func, const char *func_type,
+			uint32_t nargs, GSList *stack_print)
 {
 	uint32_t idx;
 	GString	*gs;
@@ -311,14 +350,18 @@ append_call_function(wmem_strbuf_t *buf, const char *func, uint32_t nargs,
 	if (nargs > 0) {
 		gs = g_string_new(NULL);
 		for (l = stack_print, idx = 0; l != NULL && idx < nargs; idx++, l = l->next) {
+			/* Argument strings always come in pairs, string + type string. Type comes first
+			 * (top to bottom). */
 			g_string_prepend(gs, sep);
 			g_string_prepend(gs, l->data);
+			l = l->next;
+			g_string_prepend(gs, l->data);
 			sep = ", ";
 		}
 		wmem_strbuf_append(buf, gs->str);
-		g_string_free(gs, true);
+		g_string_free(gs, TRUE);
 	}
-	wmem_strbuf_append(buf, ")");
+	wmem_strbuf_append_printf(buf, ")%s", func_type);
 }
 
 static void
@@ -406,18 +449,19 @@ append_op_args(wmem_strbuf_t *buf, dfvm_insn_t *insn, GSList **stack_print,
 			break;
 
 		case DFVM_CALL_FUNCTION:
-			append_call_function(buf, arg1_str, arg3->value.numeric, *stack_print);
+			append_call_function(buf, arg1_str, arg1_str_type,
+						arg3->value.numeric, *stack_print);
 			indent2(buf, col_start);
 			append_to_register(buf, arg2_str);
 			break;
 
 		case DFVM_STACK_PUSH:
-			wmem_strbuf_append_printf(buf, "%s", arg1_str);
-			*stack_print = dump_str_stack_push(*stack_print, arg1_str);
+			wmem_strbuf_append_printf(buf, "%s%s", arg1_str, arg1_str_type);
+			*stack_print = dump_str_stack_push(*stack_print, arg1_str, arg1_str_type);
 			break;
 
 		case DFVM_STACK_POP:
-			wmem_strbuf_append_printf(buf, "%s", arg1_str);
+			wmem_strbuf_append_printf(buf, "[%s]", arg1_str);
 			*stack_print = dump_str_stack_pop(*stack_print, arg1->value.numeric);
 			break;
 
@@ -435,6 +479,13 @@ append_op_args(wmem_strbuf_t *buf, dfvm_insn_t *insn, GSList **stack_print,
 			append_to_register(buf, arg2_str);
 			break;
 
+		case DFVM_VALUE_STRING:
+			wmem_strbuf_append_printf(buf, "%s::VS(%s%s)",
+						arg1_str, arg2_str, arg2_str_type);
+			indent2(buf, col_start);
+			append_to_register(buf, arg3_str);
+			break;
+
 		case DFVM_ALL_EQ:
 			wmem_strbuf_append_printf(buf, "%s%s === %s%s",
 						arg1_str, arg1_str_type, arg2_str, arg2_str_type);
@@ -567,10 +618,17 @@ append_op_args(wmem_strbuf_t *buf, dfvm_insn_t *insn, GSList **stack_print,
 			wmem_strbuf_append_printf(buf, "%u", arg1->value.numeric);
 			break;
 
-		case DFVM_NOT:
 		case DFVM_RETURN:
+			if (arg1_str) {
+				wmem_strbuf_append_printf(buf, "%s%s", arg1_str, arg1_str_type);
+			}
+			break;
+
+		case DFVM_NOT:
 		case DFVM_SET_CLEAR:
-			ws_assert_not_reached();
+		case DFVM_NULL:
+		case DFVM_NO_OP:
+			ASSERT_DFVM_OP_NOT_REACHED(insn->op);
 	}
 
 	g_free(arg1_str);
@@ -655,8 +713,8 @@ dfvm_dump_str(wmem_allocator_t *alloc, dfilter_t *df, uint16_t flags)
 
 		switch (insn->op) {
 			case DFVM_NOT:
-			case DFVM_RETURN:
 			case DFVM_SET_CLEAR:
+			case DFVM_NO_OP:
 				/* Nothing here */
 				break;
 			default:
@@ -679,7 +737,7 @@ dfvm_dump(FILE *f, dfilter_t *df, uint16_t flags)
 }
 
 static int
-compare_finfo_layer(gconstpointer _a, gconstpointer _b)
+compare_finfo_layer(const void *_a, const void *_b)
 {
 	const field_info *a = *(const field_info **)_a;
 	const field_info *b = *(const field_info **)_b;
@@ -1241,6 +1299,85 @@ mk_length(dfilter_t *df, dfvm_value_t *from_arg, dfvm_value_t *to_arg)
 	}
 }
 
+static const char *
+try_value_string(const header_field_info *hfinfo, fvalue_t *fv_num, char *buf)
+{
+	uint64_t val;
+
+	/* XXX - What about BASE_UNIT_STRING? Should we guarantee that we
+	 * don't get here for unit strings in semcheck.c (currently we
+	 * do for OP_MATCHES instead of disallowing it, which will result
+	 * in a legal filter that always compares false as this returns NULL.)
+	 */
+	if (fvalue_to_uinteger64(fv_num, &val) != FT_OK)
+		return NULL;
+
+	/* XXX We should find or create instead a suitable function in proto.h
+	 * to perform this mapping. hf_try_val[64]_to_str are similar, though
+	 * don't handle BASE_CUSTOM but do handle BASE_UNIT_STRING */
+
+	if (hfinfo->display & BASE_RANGE_STRING) {
+		return try_rval_to_str((uint32_t)val, hfinfo->strings);
+	}
+	else if (hfinfo->display & BASE_EXT_STRING) {
+		if (hfinfo->display & BASE_VAL64_STRING) {
+			return try_val64_to_str_ext(val, (val64_string_ext *)hfinfo->strings);
+		} else {
+			return try_val_to_str_ext((uint32_t)val, (value_string_ext *)hfinfo->strings);
+		}
+	}
+	else if (hfinfo->display & BASE_VAL64_STRING) {
+		return try_val64_to_str(val, hfinfo->strings);
+	}
+	else if (hfinfo->display == BASE_CUSTOM) {
+		if (FT_IS_INT32(hfinfo->type) || FT_IS_UINT32(hfinfo->type))
+			((custom_fmt_func_t)hfinfo->strings)(buf, (uint32_t)val);
+		else if (FT_IS_INT64(hfinfo->type) || FT_IS_UINT64(hfinfo->type))
+			((custom_fmt_func_64_t)hfinfo->strings)(buf, val);
+		else
+			ws_assert_not_reached();
+	}
+	else {
+		return try_val_to_str((uint32_t)val, hfinfo->strings);
+	}
+	ws_assert_not_reached();
+}
+
+static bool
+mk_value_string(dfilter_t *df, dfvm_value_t *vs_arg, dfvm_value_t *from_arg, dfvm_value_t *to_arg)
+{
+	df_cell_t *from_rp, *to_rp;
+	df_cell_iter_t from_iter;
+	const header_field_info *hfinfo;
+	const char *str;
+	fvalue_t *old_fv;
+	fvalue_t *new_fv;
+	char label_buf[ITEM_LABEL_LENGTH];
+
+	hfinfo = vs_arg->value.hfinfo;
+
+	to_rp = &df->registers[to_arg->value.numeric];
+	df_cell_init(to_rp, true);
+	from_rp = &df->registers[from_arg->value.numeric];
+
+	df_cell_iter_init(from_rp, &from_iter);
+	while ((old_fv = df_cell_iter_next(&from_iter)) != NULL) {
+		str = try_value_string(hfinfo, old_fv, label_buf);
+		if (str) {
+			new_fv = fvalue_new(FT_STRING);
+			fvalue_set_string(new_fv, str);
+			df_cell_append(to_rp, new_fv);
+		}
+		/* XXX - If there's no match we could have a NULL result
+		 * as now (and return false), or use a string like "Unknown"
+		 * the way columns do. We could fall back to a string
+		 * representation of the value if BASE_SPECIAL_VALS if set.
+		 */
+	}
+
+	return !df_cell_is_empty(to_rp);
+}
+
 static bool
 call_function(dfilter_t *df, dfvm_value_t *arg1, dfvm_value_t *arg2,
 							dfvm_value_t *arg3)
@@ -1514,7 +1651,7 @@ check_exists(proto_tree *tree, dfvm_value_t *arg1, dfvm_value_t *arg2)
 }
 
 bool
-dfvm_apply(dfilter_t *df, proto_tree *tree)
+dfvm_apply_full(dfilter_t *df, proto_tree *tree, GPtrArray **fvals)
 {
 	int		id, length;
 	bool	accum = true;
@@ -1584,6 +1721,10 @@ dfvm_apply(dfilter_t *df, proto_tree *tree)
 				mk_length(df, arg1, arg2);
 				break;
 
+			case DFVM_VALUE_STRING:
+				accum = mk_value_string(df, arg1, arg2, arg3);
+				break;
+
 			case DFVM_ALL_EQ:
 				accum = all_test(df, fvalue_eq, arg1, arg2);
 				break;
@@ -1713,9 +1854,18 @@ dfvm_apply(dfilter_t *df, proto_tree *tree)
 				break;
 
 			case DFVM_RETURN:
+				if (fvals && arg1) {
+					*fvals = df_cell_ref(&df->registers[arg1->value.numeric]);
+					if (*fvals == NULL) {
+						*fvals = g_ptr_array_new();
+					}
+				}
 				free_register_overhead(df);
 				return accum;
 
+			case DFVM_NO_OP:
+				break;
+
 			case DFVM_IF_TRUE_GOTO:
 				if (accum) {
 					id = arg1->value.numeric;
@@ -1729,12 +1879,21 @@ dfvm_apply(dfilter_t *df, proto_tree *tree)
 					goto AGAIN;
 				}
 				break;
+
+			case DFVM_NULL:
+				ASSERT_DFVM_OP_NOT_REACHED(insn->op);
 		}
 	}
 
 	ws_assert_not_reached();
 }
 
+bool
+dfvm_apply(dfilter_t *df, proto_tree *tree)
+{
+	return dfvm_apply_full(df, tree, NULL);
+}
+
 /*
  * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
