@@ -46,7 +46,7 @@
 void proto_register_h245(void);
 void proto_reg_handoff_h245(void);
 
-static dissector_handle_t rtcp_handle=NULL;
+static dissector_handle_t rtcp_handle;
 static dissector_table_t nsp_object_dissector_table;
 static dissector_table_t nsp_h221_dissector_table;
 static dissector_table_t gef_name_dissector_table;
@@ -55,22 +55,22 @@ static dissector_handle_t h245_handle;
 static dissector_handle_t nsp_handle;
 static dissector_handle_t data_handle;
 static dissector_handle_t MultimediaSystemControlMessage_handle;
-static dissector_handle_t h263_handle = NULL;
-static dissector_handle_t amr_handle = NULL;
+static dissector_handle_t h263_handle;
+static dissector_handle_t amr_handle;
 
 static void init_h245_packet_info(h245_packet_info *pi);
-static int hf_h245_pdu_type = -1;
-static int hf_h245Manufacturer = -1;
-static int hf_h245_subMessageIdentifier_standard = -1;
-static int h245_tap = -1;
-static int h245dg_tap = -1;
-static int hf_h245_debug_dissector_try_string = -1;
+static int hf_h245_pdu_type;
+static int hf_h245Manufacturer;
+static int hf_h245_subMessageIdentifier_standard;
+static int h245_tap;
+static int h245dg_tap;
+static int hf_h245_debug_dissector_try_string;
 
 h245_packet_info *h245_pi=NULL;
 
-static gboolean h245_reassembly = TRUE;
-static gboolean h245_shorttypes = FALSE;
-static gboolean info_col_fmt_prepend = FALSE;
+static bool h245_reassembly = true;
+static bool h245_shorttypes;
+static bool info_col_fmt_prepend;
 
 #include "packet-h245-val.h"
 
@@ -196,42 +196,42 @@ static const value_string h245_AudioCapability_short_vals[] = {
 
 /* To put the codec type only in COL_INFO when
    an OLC is read */
-const char* codec_type = NULL;
-static guint32 rfc_number;
+const char* codec_type;
+static uint32_t rfc_number;
 
 typedef struct _unicast_addr_t {
   address addr;
-  guint8 addr_buf[16];
-  guint32 port;
+  uint8_t addr_buf[16];
+  uint32_t port;
 } unicast_addr_t;
 
 typedef struct _channel_info_t {
-  gchar data_type_str[32];
+  char data_type_str[32];
   unicast_addr_t *upcoming_addr;
   unicast_addr_t media_addr;
   unicast_addr_t media_control_addr;
   unsigned int rfc2198;
-  gboolean srtp_flag;
-  gboolean is_video;
+  bool srtp_flag;
+  bool is_video;
 } channel_info_t;
 
 typedef struct _olc_info_t {
-  guint16 fwd_lc_num;
+  uint16_t fwd_lc_num;
   channel_info_t fwd_lc;
   channel_info_t rev_lc;
 } olc_info_t;
 
-static wmem_map_t* h245_pending_olc_reqs = NULL;
-static gboolean fast_start = FALSE;
-static olc_info_t *upcoming_olc = NULL;
-static channel_info_t *upcoming_channel = NULL;
+static wmem_map_t* h245_pending_olc_reqs;
+static bool fast_start;
+static olc_info_t *upcoming_olc;
+static channel_info_t *upcoming_channel;
 
 /* NonStandardParameter */
 static const char *nsiOID;
-static guint32 h221NonStandard;
-static guint32 t35CountryCode;
-static guint32 t35Extension;
-static guint32 manufacturerCode;
+static uint32_t h221NonStandard;
+static uint32_t t35CountryCode;
+static uint32_t t35Extension;
+static uint32_t manufacturerCode;
 
 static const value_string h245_RFC_number_vals[] = {
 	{  2190,	"RFC 2190 - H.263 Video Streams" },
@@ -256,9 +256,9 @@ static const value_string h245_h239subMessageIdentifier_vals[] = {
 
 
 /* h223 multiplex codes */
-static h223_set_mc_handle_t h223_set_mc_handle = NULL;
+static h223_set_mc_handle_t h223_set_mc_handle;
 h223_mux_element *h223_me=NULL;
-guint8 h223_mc=0;
+uint8_t h223_mc=0;
 void h245_set_h223_set_mc_handle( h223_set_mc_handle_t handle )
 {
 	h223_set_mc_handle = handle;
@@ -270,15 +270,15 @@ typedef struct {
 	h223_lc_params *rev_channel_params;
 } h223_pending_olc;
 
-static wmem_map_t*          h223_pending_olc_reqs[] = { NULL, NULL };
+static wmem_map_t*          h223_pending_olc_reqs[2];
 static dissector_handle_t   h245_lc_dissector;
-static guint16              h245_lc_temp;
-static guint16              h223_fw_lc_num;
-static guint16              h223_rev_lc_num;
+static uint16_t             h245_lc_temp;
+static uint16_t             h223_fw_lc_num;
+static uint16_t             h223_rev_lc_num;
 static h223_lc_params      *h223_lc_params_temp;
 static h223_lc_params      *h223_fw_lc_params;
 static h223_lc_params      *h223_rev_lc_params;
-static h223_add_lc_handle_t h223_add_lc_handle = NULL;
+static h223_add_lc_handle_t h223_add_lc_handle;
 
 static void h223_lc_init( void )
 {
@@ -292,7 +292,7 @@ void h245_set_h223_add_lc_handle( h223_add_lc_handle_t handle )
 	h223_add_lc_handle = handle;
 }
 
-static const gchar *gen_olc_key(guint16 lc_num, address *dst_addr, address *src_addr, wmem_allocator_t *scope)
+static const char *gen_olc_key(uint16_t lc_num, address *dst_addr, address *src_addr, wmem_allocator_t *scope)
 {
   return wmem_strdup_printf(scope, "%s/%s/%u",
           address_to_str(scope, dst_addr),
@@ -329,7 +329,7 @@ static void h245_setup_channels(packet_info *pinfo, channel_info_t *upcoming_cha
 	/* (S)RTP, (S)RTCP */
 	if (upcoming_channel_lcl->rfc2198 > 0) {
 		rtp_dyn_payload = rtp_dyn_payload_new();
-		rtp_dyn_payload_insert(rtp_dyn_payload, upcoming_channel_lcl->rfc2198, "red", 8000);
+		rtp_dyn_payload_insert(rtp_dyn_payload, upcoming_channel_lcl->rfc2198, "red", 8000, 1);
 	}
 
 	if (upcoming_channel_lcl->srtp_flag) {
@@ -352,31 +352,31 @@ static void h245_setup_channels(packet_info *pinfo, channel_info_t *upcoming_cha
 
 /* Prints formated information column of h245 messages. Note that global variables
  * "h245_shorttypes" and "info_col_fmt_prepend" are used to decide formating preferences */
-static void print_info_column(column_info *cinfo, const gint32 *value,
+static void print_info_column(column_info *cinfo, const int32_t *value,
     const value_string *msg_vals, const value_string *short_msg_vals)
 {
   const value_string *vals;
 
-  if (h245_shorttypes == FALSE || short_msg_vals == NULL) {
+  if (h245_shorttypes == false || short_msg_vals == NULL) {
     vals = msg_vals;
   } else {
     vals = short_msg_vals;
   }
 
-  if (info_col_fmt_prepend == FALSE) {
-    col_append_fstr(cinfo, COL_INFO, "%s ", val_to_str(*value, vals, "<unknown>"));
+  if (info_col_fmt_prepend == false) {
+    col_append_fstr(cinfo, COL_INFO, "%s ", val_to_str_const(*value, vals, "<unknown>"));
   } else {
-    col_prepend_fstr(cinfo, COL_INFO, "%s ", val_to_str(*value, vals, "<unknown>"));
+    col_prepend_fstr(cinfo, COL_INFO, "%s ", val_to_str_const(*value, vals, "<unknown>"));
   }
 }
 
 /* Initialize the protocol and registered fields */
-static int proto_h245 = -1;
+static int proto_h245;
 #include "packet-h245-hf.c"
 
 /* Initialize the subtree pointers */
-static int ett_h245 = -1;
-static int ett_h245_returnedFunction = -1;
+static int ett_h245;
+static int ett_h245_returnedFunction;
 #include "packet-h245-ett.c"
 
 /* Forward declarations */
@@ -405,10 +405,10 @@ dissect_h245_h245(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, vo
 {
 	proto_item *it;
 	proto_tree *tr;
-	guint32 offset=0;
+	uint32_t offset=0;
 	asn1_ctx_t asn1_ctx;
 
-	fast_start = FALSE;
+	fast_start = false;
 	/* Clean up from any previous packet dissection */
 	upcoming_olc = NULL;
 	upcoming_channel = NULL;
@@ -424,7 +424,7 @@ dissect_h245_h245(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, vo
 		CLEANUP_PUSH(reset_h245_pi, NULL);
 		h245_pi=wmem_new(pinfo->pool, h245_packet_info);
 		init_h245_packet_info(h245_pi);
-		asn1_ctx_init(&asn1_ctx, ASN1_ENC_PER, TRUE, pinfo);
+		asn1_ctx_init(&asn1_ctx, ASN1_ENC_PER, true, pinfo);
 		offset = dissect_h245_MultimediaSystemControlMessage(tvb, offset, &asn1_ctx, tr, hf_h245_pdu_type);
 		tap_queue_packet(h245dg_tap, pinfo, h245_pi);
 		offset = (offset+0x07) & 0xfffffff8;
@@ -436,7 +436,7 @@ dissect_h245_h245(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, vo
 void
 dissect_h245_FastStart_OLC(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, char *codec_str) {
 
-  fast_start = TRUE;
+  fast_start = true;
   /* Clean up from any previous packet dissection */
   upcoming_olc = NULL;
   upcoming_channel = NULL;
@@ -476,7 +476,7 @@ void proto_register_h245(void) {
   };
 
   /* List of subtrees */
-  static gint *ett[] = {
+  static int *ett[] = {
 	  &ett_h245,
 	  &ett_h245_returnedFunction,
 #include "packet-h245-ettarr.c"
@@ -513,10 +513,10 @@ void proto_register_h245(void) {
   MultimediaSystemControlMessage_handle = register_dissector("h245dg", dissect_h245_h245, proto_h245);
   h245_handle = register_dissector("h245", dissect_h245, proto_h245);
 
-  nsp_object_dissector_table = register_dissector_table("h245.nsp.object", "H.245 NonStandardParameter (object)", proto_h245, FT_STRING, BASE_NONE);
+  nsp_object_dissector_table = register_dissector_table("h245.nsp.object", "H.245 NonStandardParameter (object)", proto_h245, FT_STRING, STRING_CASE_SENSITIVE);
   nsp_h221_dissector_table = register_dissector_table("h245.nsp.h221", "H.245 NonStandardParameter (h221)", proto_h245, FT_UINT32, BASE_HEX);
-  gef_name_dissector_table = register_dissector_table("h245.gef.name", "H.245 Generic Extensible Framework Name", proto_h245, FT_STRING, BASE_NONE);
-  gef_content_dissector_table = register_dissector_table("h245.gef.content", "H.245 Generic Extensible Framework Content", proto_h245, FT_STRING, BASE_NONE);
+  gef_name_dissector_table = register_dissector_table("h245.gef.name", "H.245 Generic Extensible Framework Name", proto_h245, FT_STRING, STRING_CASE_SENSITIVE);
+  gef_content_dissector_table = register_dissector_table("h245.gef.content", "H.245 Generic Extensible Framework Content", proto_h245, FT_STRING, STRING_CASE_SENSITIVE);
 
   h245_tap = register_tap("h245");
   h245dg_tap = register_tap("h245dg");
@@ -593,6 +593,6 @@ static void init_h245_packet_info(h245_packet_info *pi)
 
         pi->msg_type = H245_OTHER;
 		pi->frame_label[0] = '\0';
-		g_snprintf(pi->comment, sizeof(pi->comment), "H245 ");
+		snprintf(pi->comment, sizeof(pi->comment), "H245 ");
 }
 
