@@ -28,15 +28,18 @@ void proto_register_h460(void);
 void proto_reg_handoff_h460(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_h460 = -1;
+static int proto_h460;
 #include "packet-h460-hf.c"
 
 /* Initialize the subtree pointers */
 #include "packet-h460-ett.c"
 
+/* Main dissector handle */
+static dissector_handle_t h460_name_handle;
+
 /* Subdissectors */
-static dissector_handle_t q931_ie_handle = NULL;
-static dissector_handle_t h225_ras_handle = NULL;
+static dissector_handle_t q931_ie_handle;
+static dissector_handle_t h225_ras_handle;
 
 #include "packet-h460-fn.c"
 
@@ -63,15 +66,15 @@ dissect_ras(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 }
 
 typedef struct _h460_feature_t {
-  guint32 opt;
-  const gchar *id;
-  const gchar *name;
+  uint32_t opt;
+  const char *id;
+  const char *name;
   dissector_t content_pdu;
   /*---*/
-  const gchar *key_gd;
-  const gchar *key_fd;
-  const gchar *key_gm;
-  const gchar *key_gi;
+  const char *key_gd;
+  const char *key_fd;
+  const char *key_gm;
+  const char *key_gi;
   dissector_handle_t content_hnd;
 } h460_feature_t;
 
@@ -187,7 +190,7 @@ static h460_feature_t h460_feature_tab[] = {
   { 0, NULL, NULL, NULL, FFILL },
 };
 
-static h460_feature_t *find_ftr(const gchar *key) {
+static h460_feature_t *find_ftr(const char *key) {
   h460_feature_t *ftr = NULL;
   h460_feature_t *f;
 
@@ -236,7 +239,7 @@ void proto_register_h460(void) {
   };
 
   /* List of subtrees */
-  static gint *ett[] = {
+  static int *ett[] = {
 #include "packet-h460-ettarr.c"
   };
 
@@ -247,6 +250,7 @@ void proto_register_h460(void) {
   proto_register_field_array(proto_h460, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
+  h460_name_handle = register_dissector(PFNAME, dissect_h460_name, proto_h460);
   for (ftr=h460_feature_tab; ftr->id; ftr++) {
     if (ftr->opt & GD) ftr->key_gd = wmem_strdup_printf(wmem_epan_scope(), "GenericData/%s", ftr->id);
     if (ftr->opt & FD) ftr->key_fd = wmem_strdup_printf(wmem_epan_scope(), "FeatureDescriptor/%s", ftr->id);
@@ -260,12 +264,10 @@ void proto_register_h460(void) {
 void proto_reg_handoff_h460(void)
 {
   h460_feature_t *ftr;
-  dissector_handle_t h460_name_handle;
 
   q931_ie_handle = find_dissector_add_dependency("q931.ie", proto_h460);
   h225_ras_handle = find_dissector_add_dependency("h225.ras", proto_h460);
 
-  h460_name_handle = create_dissector_handle(dissect_h460_name, proto_h460);
   for (ftr=h460_feature_tab; ftr->id; ftr++) {
     if (ftr->key_gd) dissector_add_string("h225.gef.name", ftr->key_gd, h460_name_handle);
     if (ftr->key_fd) dissector_add_string("h225.gef.name", ftr->key_fd, h460_name_handle);
