@@ -38,7 +38,7 @@ void proto_reg_handoff_inap(void);
 
 
 /* Initialize the protocol and registered fields */
-static int proto_inap = -1;
+static int proto_inap;
 
 /* include constants */
 #include "packet-inap-val.h"
@@ -51,9 +51,10 @@ static range_t *global_ssn_range;
 static dissector_handle_t	inap_handle;
 
 /* Global variables */
-static guint32 opcode=0;
-static guint32 errorCode=0;
-static const char *obj_id = NULL;
+static uint32_t opcode=0;
+static uint32_t errorCode=0;
+static const char *obj_id;
+static bool is_ExtensionField;
 
 static int inap_opcode_type;
 #define INAP_OPCODE_INVOKE        1
@@ -61,47 +62,49 @@ static int inap_opcode_type;
 #define INAP_OPCODE_RETURN_ERROR  3
 #define INAP_OPCODE_REJECT        4
 
-static int hf_inap_cause_indicator = -1;
+static int hf_inap_cause_indicator;
 
 /* Initialize the subtree pointers */
-static gint ett_inap = -1;
-static gint ett_inapisup_parameter = -1;
-static gint ett_inap_RedirectionInformation = -1;
-static gint ett_inap_HighLayerCompatibility = -1;
-static gint ett_inap_extension_data = -1;
-static gint ett_inap_cause = -1;
-static gint ett_inap_calledAddressValue = -1;
-static gint ett_inap_callingAddressValue = -1;
-static gint ett_inap_additionalCallingPartyNumber = -1;
-static gint ett_inap_assistingSSPIPRoutingAddress = -1;
-static gint ett_inap_correlationID = -1;
-static gint ett_inap_number = -1;
-static gint ett_inap_dialledNumber = -1;
-static gint ett_inap_callingLineID = -1;
-static gint ett_inap_iNServiceControlCode = -1;
-static gint ett_inap_iNServiceControlCodeLow = -1;
-static gint ett_inap_iNServiceControlCodeHigh = -1;
-static gint ett_inap_lineID = -1;
-static gint ett_inap_prefix = -1;
-static gint ett_inap_iPAddressValue = -1;
-static gint ett_inap_digitsResponse = -1;
+static int ett_inap;
+static int ett_inapisup_parameter;
+static int ett_inap_RedirectionInformation;
+static int ett_inap_HighLayerCompatibility;
+static int ett_inap_extension_data;
+static int ett_inap_cause;
+static int ett_inap_calledAddressValue;
+static int ett_inap_callingAddressValue;
+static int ett_inap_additionalCallingPartyNumber;
+static int ett_inap_assistingSSPIPRoutingAddress;
+static int ett_inap_correlationID;
+static int ett_inap_number;
+static int ett_inap_dialledNumber;
+static int ett_inap_callingLineID;
+static int ett_inap_iNServiceControlCode;
+static int ett_inap_iNServiceControlCodeLow;
+static int ett_inap_iNServiceControlCodeHigh;
+static int ett_inap_lineID;
+static int ett_inap_prefix;
+static int ett_inap_iPAddressValue;
+static int ett_inap_digitsResponse;
 
 #include "packet-inap-ett.c"
 
-static expert_field ei_inap_unknown_invokeData = EI_INIT;
-static expert_field ei_inap_unknown_returnResultData = EI_INIT;
-static expert_field ei_inap_unknown_returnErrorData = EI_INIT;
+static expert_field ei_inap_unknown_invokeData;
+static expert_field ei_inap_unknown_returnResultData;
+static expert_field ei_inap_unknown_returnErrorData;
 
 #include "packet-inap-table.c"
 
-const value_string inap_general_problem_strings[] = {
-{0,"General Problem Unrecognized Component"},
-{1,"General Problem Mistyped Component"},
-{3,"General Problem Badly Structured Component"},
-{0, NULL}
+#if 0
+static const value_string inap_general_problem_strings[] = {
+  {0,"General Problem Unrecognized Component"},
+  {1,"General Problem Mistyped Component"},
+  {3,"General Problem Badly Structured Component"},
+  {0, NULL}
 };
+#endif
 
-/* Forvard declarations */
+/* Forward declarations */
 static int dissect_invokeData(proto_tree *tree, tvbuff_t *tvb, int offset, asn1_ctx_t *actx _U_);
 static int dissect_returnResultData(proto_tree *tree, tvbuff_t *tvb, int offset, asn1_ctx_t *actx _U_);
 static int dissect_returnErrorData(proto_tree *tree, tvbuff_t *tvb, int offset, asn1_ctx_t *actx);
@@ -130,8 +133,8 @@ TC-Invokable OPERATION ::=
 #include "packet-inap-table2.c"
 
 
-static guint8 inap_pdu_type = 0;
-static guint8 inap_pdu_size = 0;
+static uint8_t inap_pdu_type;
+static uint8_t inap_pdu_size;
 
 
 static int
@@ -141,7 +144,7 @@ dissect_inap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void *d
   proto_tree		*tree=NULL;
   int				offset = 0;
   asn1_ctx_t asn1_ctx;
-  asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, TRUE, pinfo);
+  asn1_ctx_init(&asn1_ctx, ASN1_ENC_BER, true, pinfo);
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, "INAP");
 
@@ -150,24 +153,25 @@ dissect_inap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void *d
     item = proto_tree_add_item(parent_tree, proto_inap, tvb, 0, -1, ENC_NA);
     tree = proto_item_add_subtree(item, ett_inap);
   }
-  inap_pdu_type = tvb_get_guint8(tvb, offset)&0x0f;
+  inap_pdu_type = tvb_get_uint8(tvb, offset)&0x0f;
   /* Get the length and add 2 */
-  inap_pdu_size = tvb_get_guint8(tvb, offset+1)+2;
+  inap_pdu_size = tvb_get_uint8(tvb, offset+1)+2;
   opcode = 0;
-  dissect_inap_ROS(TRUE, tvb, offset, &asn1_ctx, tree, -1);
+  is_ExtensionField =false;
+  dissect_inap_ROS(true, tvb, offset, &asn1_ctx, tree, -1);
 
   return inap_pdu_size;
 }
 
 /*--- proto_reg_handoff_inap ---------------------------------------*/
-static void range_delete_callback(guint32 ssn, gpointer ptr _U_)
+static void range_delete_callback(uint32_t ssn, void *ptr _U_)
 {
   if (ssn) {
     delete_itu_tcap_subdissector(ssn, inap_handle);
   }
 }
 
-static void range_add_callback(guint32 ssn, gpointer ptr _U_)
+static void range_add_callback(uint32_t ssn, void *ptr _U_)
 {
   if (ssn) {
   add_itu_tcap_subdissector(ssn, inap_handle);
@@ -176,11 +180,11 @@ static void range_add_callback(guint32 ssn, gpointer ptr _U_)
 
 void proto_reg_handoff_inap(void) {
 
-  static gboolean inap_prefs_initialized = FALSE;
+  static bool inap_prefs_initialized = false;
   static range_t *ssn_range;
 
   if (!inap_prefs_initialized) {
-    inap_prefs_initialized = TRUE;
+    inap_prefs_initialized = true;
     oid_add_from_string("Core-INAP-CS1-Codes","0.4.0.1.1.0.3.0");
     oid_add_from_string("iso(1) identified-organization(3) icd-ecma(12) member-company(2) 1107 oen(3) inap(3) extensions(2)","1.3.12.2.1107.3.3.2");
     oid_add_from_string("alcatel(1006)","1.3.12.2.1006.64");
@@ -219,7 +223,7 @@ void proto_register_inap(void) {
 
 
   /* List of subtrees */
-  static gint *ett[] = {
+  static int *ett[] = {
     &ett_inap,
     &ett_inapisup_parameter,
     &ett_inap_RedirectionInformation,
