@@ -1,8 +1,8 @@
 /* packet-nr-rrc-template.c
  * NR;
  * Radio Resource Control (RRC) protocol specification
- * (3GPP TS 38.331 V16.8.0 Release 16) packet dissection
- * Copyright 2018-2022, Pascal Quantin
+ * (3GPP TS 38.331 V18.2.0 Release 18) packet dissection
+ * Copyright 2018-2024, Pascal Quantin
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -46,116 +46,123 @@
 void proto_register_nr_rrc(void);
 void proto_reg_handoff_nr_rrc(void);
 
-static dissector_handle_t nas_5gs_handle = NULL;
-static dissector_handle_t lte_rrc_conn_reconf_handle = NULL;
-static dissector_handle_t lte_rrc_conn_reconf_compl_handle = NULL;
-static dissector_handle_t lte_rrc_ul_dcch_handle = NULL;
-static dissector_handle_t lte_rrc_dl_dcch_handle = NULL;
+static dissector_handle_t nas_5gs_handle;
+static dissector_handle_t lte_rrc_conn_reconf_handle;
+static dissector_handle_t lte_rrc_conn_reconf_compl_handle;
+static dissector_handle_t lte_rrc_ul_dcch_handle;
+static dissector_handle_t lte_rrc_dl_dcch_handle;
 
-static wmem_map_t *nr_rrc_etws_cmas_dcs_hash = NULL;
+static wmem_map_t *nr_rrc_etws_cmas_dcs_hash;
 
 static reassembly_table nr_rrc_sib7_reassembly_table;
 static reassembly_table nr_rrc_sib8_reassembly_table;
 
-static gboolean nr_rrc_nas_in_root_tree;
+static bool nr_rrc_nas_in_root_tree;
 
 extern int proto_mac_nr;
+extern int proto_rlc_nr;
 extern int proto_pdcp_nr;
 
 /* Include constants */
 #include "packet-nr-rrc-val.h"
 
 /* Initialize the protocol and registered fields */
-static int proto_nr_rrc = -1;
+static int proto_nr_rrc;
 #include "packet-nr-rrc-hf.c"
-static int hf_nr_rrc_serialNumber_gs = -1;
-static int hf_nr_rrc_serialNumber_msg_code = -1;
-static int hf_nr_rrc_serialNumber_upd_nb = -1;
-static int hf_nr_rrc_warningType_value = -1;
-static int hf_nr_rrc_warningType_emergency_user_alert = -1;
-static int hf_nr_rrc_warningType_popup = -1;
-static int hf_nr_rrc_warningMessageSegment_nb_pages = -1;
-static int hf_nr_rrc_warningMessageSegment_decoded_page = -1;
-static int hf_nr_rrc_sib7_fragments = -1;
-static int hf_nr_rrc_sib7_fragment = -1;
-static int hf_nr_rrc_sib7_fragment_overlap = -1;
-static int hf_nr_rrc_sib7_fragment_overlap_conflict = -1;
-static int hf_nr_rrc_sib7_fragment_multiple_tails = -1;
-static int hf_nr_rrc_sib7_fragment_too_long_fragment = -1;
-static int hf_nr_rrc_sib7_fragment_error = -1;
-static int hf_nr_rrc_sib7_fragment_count = -1;
-static int hf_nr_rrc_sib7_reassembled_in = -1;
-static int hf_nr_rrc_sib7_reassembled_length = -1;
-static int hf_nr_rrc_sib7_reassembled_data = -1;
-static int hf_nr_rrc_sib8_fragments = -1;
-static int hf_nr_rrc_sib8_fragment = -1;
-static int hf_nr_rrc_sib8_fragment_overlap = -1;
-static int hf_nr_rrc_sib8_fragment_overlap_conflict = -1;
-static int hf_nr_rrc_sib8_fragment_multiple_tails = -1;
-static int hf_nr_rrc_sib8_fragment_too_long_fragment = -1;
-static int hf_nr_rrc_sib8_fragment_error = -1;
-static int hf_nr_rrc_sib8_fragment_count = -1;
-static int hf_nr_rrc_sib8_reassembled_in = -1;
-static int hf_nr_rrc_sib8_reassembled_length = -1;
-static int hf_nr_rrc_sib8_reassembled_data = -1;
-static int hf_nr_rrc_utc_time = -1;
-static int hf_nr_rrc_local_time = -1;
-static int hf_nr_rrc_absolute_time = -1;
+static int hf_nr_rrc_serialNumber_gs;
+static int hf_nr_rrc_serialNumber_msg_code;
+static int hf_nr_rrc_serialNumber_upd_nb;
+static int hf_nr_rrc_warningType_value;
+static int hf_nr_rrc_warningType_emergency_user_alert;
+static int hf_nr_rrc_warningType_popup;
+static int hf_nr_rrc_warningMessageSegment_nb_pages;
+static int hf_nr_rrc_warningMessageSegment_decoded_page;
+static int hf_nr_rrc_sib7_fragments;
+static int hf_nr_rrc_sib7_fragment;
+static int hf_nr_rrc_sib7_fragment_overlap;
+static int hf_nr_rrc_sib7_fragment_overlap_conflict;
+static int hf_nr_rrc_sib7_fragment_multiple_tails;
+static int hf_nr_rrc_sib7_fragment_too_long_fragment;
+static int hf_nr_rrc_sib7_fragment_error;
+static int hf_nr_rrc_sib7_fragment_count;
+static int hf_nr_rrc_sib7_reassembled_in;
+static int hf_nr_rrc_sib7_reassembled_length;
+static int hf_nr_rrc_sib7_reassembled_data;
+static int hf_nr_rrc_sib8_fragments;
+static int hf_nr_rrc_sib8_fragment;
+static int hf_nr_rrc_sib8_fragment_overlap;
+static int hf_nr_rrc_sib8_fragment_overlap_conflict;
+static int hf_nr_rrc_sib8_fragment_multiple_tails;
+static int hf_nr_rrc_sib8_fragment_too_long_fragment;
+static int hf_nr_rrc_sib8_fragment_error;
+static int hf_nr_rrc_sib8_fragment_count;
+static int hf_nr_rrc_sib8_reassembled_in;
+static int hf_nr_rrc_sib8_reassembled_length;
+static int hf_nr_rrc_sib8_reassembled_data;
+static int hf_nr_rrc_utc_time;
+static int hf_nr_rrc_local_time;
+static int hf_nr_rrc_absolute_time;
 
 /* Initialize the subtree pointers */
-static gint ett_nr_rrc = -1;
+static int ett_nr_rrc;
 #include "packet-nr-rrc-ett.c"
-static gint ett_nr_rrc_DedicatedNAS_Message = -1;
-static gint ett_nr_rrc_targetRAT_MessageContainer = -1;
-static gint ett_nr_rrc_nas_Container = -1;
-static gint ett_nr_rrc_serialNumber = -1;
-static gint ett_nr_rrc_warningType = -1;
-static gint ett_nr_rrc_dataCodingScheme = -1;
-static gint ett_nr_rrc_sib7_fragment = -1;
-static gint ett_nr_rrc_sib7_fragments = -1;
-static gint ett_nr_rrc_sib8_fragment = -1;
-static gint ett_nr_rrc_sib8_fragments = -1;
-static gint ett_nr_rrc_warningMessageSegment = -1;
-static gint ett_nr_rrc_timeInfo = -1;
-static gint ett_nr_rrc_capabilityRequestFilter = -1;
-static gint ett_nr_rrc_sourceSCG_EUTRA_Config = -1;
-static gint ett_nr_rrc_scg_CellGroupConfigEUTRA = -1;
-static gint ett_nr_rrc_candidateCellInfoListSN_EUTRA = -1;
-static gint ett_nr_rrc_candidateCellInfoListMN_EUTRA = -1;
-static gint ett_nr_rrc_sourceConfigSCG_EUTRA = -1;
-static gint ett_nr_rrc_eutra_SCG = -1;
-static gint ett_nr_rrc_nr_SCG_Response = -1;
-static gint ett_nr_rrc_eutra_SCG_Response = -1;
-static gint ett_nr_rrc_measResultSCG_FailureMRDC = -1;
-static gint ett_nr_rrc_ul_DCCH_MessageNR = -1;
-static gint ett_nr_rrc_ul_DCCH_MessageEUTRA = -1;
-static gint ett_rr_rrc_nas_SecurityParamFromNR = -1;
-static gint ett_nr_rrc_sidelinkUEInformationNR = -1;
-static gint ett_nr_rrc_sidelinkUEInformationEUTRA = -1;
-static gint ett_nr_rrc_ueAssistanceInformationEUTRA = -1;
-static gint ett_nr_rrc_dl_DCCH_MessageNR = -1;
-static gint ett_nr_rrc_dl_DCCH_MessageEUTRA = -1;
-static gint ett_nr_rrc_sl_ConfigDedicatedEUTRA = -1;
-static gint ett_nr_rrc_sl_CapabilityInformationSidelink = -1;
-static gint ett_nr_rrc_measResult_RLF_Report_EUTRA = -1;
-static gint ett_nr_rrc_locationTimestamp_r16 = -1;
-static gint ett_nr_rrc_locationCoordinate_r16 = -1;
-static gint ett_nr_rrc_locationError_r16 = -1;
-static gint ett_nr_rrc_locationSource_r16 = -1;
-static gint ett_nr_rrc_velocityEstimate_r16 = -1;
-static gint ett_nr_rrc_sensor_MeasurementInformation_r16 = -1;
-static gint ett_nr_rrc_sensor_MotionInformation_r16 = -1;
-static gint ett_nr_rrc_bandParametersSidelinkEUTRA1_r16 = -1;
-static gint ett_nr_rrc_bandParametersSidelinkEUTRA2_r16 = -1;
-static gint ett_nr_rrc_sl_ParametersEUTRA1_r16 = -1;
-static gint ett_nr_rrc_sl_ParametersEUTRA2_r16 = -1;
-static gint ett_nr_rrc_sl_ParametersEUTRA3_r16 = -1;
-static gint ett_nr_rrc_absTimeInfo = -1;
-static gint ett_nr_rrc_assistanceDataSIB_Element_r16 = -1;
-static gint ett_nr_sl_V2X_ConfigCommon_r16 = -1;
-static gint ett_nr_tdd_Config_r16 = -1;
+static int ett_nr_rrc_DedicatedNAS_Message;
+static int ett_nr_rrc_targetRAT_MessageContainer;
+static int ett_nr_rrc_nas_Container;
+static int ett_nr_rrc_serialNumber;
+static int ett_nr_rrc_warningType;
+static int ett_nr_rrc_dataCodingScheme;
+static int ett_nr_rrc_sib7_fragment;
+static int ett_nr_rrc_sib7_fragments;
+static int ett_nr_rrc_sib8_fragment;
+static int ett_nr_rrc_sib8_fragments;
+static int ett_nr_rrc_warningMessageSegment;
+static int ett_nr_rrc_timeInfo;
+static int ett_nr_rrc_capabilityRequestFilter;
+static int ett_nr_rrc_sourceSCG_EUTRA_Config;
+static int ett_nr_rrc_scg_CellGroupConfigEUTRA;
+static int ett_nr_rrc_candidateCellInfoListSN_EUTRA;
+static int ett_nr_rrc_candidateCellInfoListMN_EUTRA;
+static int ett_nr_rrc_sourceConfigSCG_EUTRA;
+static int ett_nr_rrc_eutra_SCG;
+static int ett_nr_rrc_nr_SCG_Response;
+static int ett_nr_rrc_eutra_SCG_Response;
+static int ett_nr_rrc_measResultSCG_FailureMRDC;
+static int ett_nr_rrc_ul_DCCH_MessageNR;
+static int ett_nr_rrc_ul_DCCH_MessageEUTRA;
+static int ett_rr_rrc_nas_SecurityParamFromNR;
+static int ett_nr_rrc_sidelinkUEInformationNR;
+static int ett_nr_rrc_sidelinkUEInformationEUTRA;
+static int ett_nr_rrc_ueAssistanceInformationEUTRA;
+static int ett_nr_rrc_dl_DCCH_MessageNR;
+static int ett_nr_rrc_dl_DCCH_MessageEUTRA;
+static int ett_nr_rrc_sl_ConfigDedicatedEUTRA;
+static int ett_nr_rrc_sl_CapabilityInformationSidelink;
+static int ett_nr_rrc_measResult_RLF_Report_EUTRA;
+static int ett_nr_rrc_measResult_RLF_Report_EUTRA_v1690;
+static int ett_nr_rrc_locationTimestamp_r16;
+static int ett_nr_rrc_locationCoordinate_r16;
+static int ett_nr_rrc_locationError_r16;
+static int ett_nr_rrc_locationSource_r16;
+static int ett_nr_rrc_velocityEstimate_r16;
+static int ett_nr_rrc_sensor_MeasurementInformation_r16;
+static int ett_nr_rrc_sensor_MotionInformation_r16;
+static int ett_nr_rrc_bandParametersSidelinkEUTRA1_r16;
+static int ett_nr_rrc_bandParametersSidelinkEUTRA2_r16;
+static int ett_nr_rrc_sl_ParametersEUTRA1_r16;
+static int ett_nr_rrc_sl_ParametersEUTRA2_r16;
+static int ett_nr_rrc_sl_ParametersEUTRA3_r16;
+static int ett_nr_rrc_absTimeInfo;
+static int ett_nr_rrc_assistanceDataSIB_Element_r16;
+static int ett_nr_rrc_sl_V2X_ConfigCommon_r16;
+static int ett_nr_rrc_tdd_Config_r16;
+static int ett_nr_rrc_coarseLocationInfo_r17;
+static int ett_nr_rrc_sl_MeasResultsCandRelay_r17;
+static int ett_nr_rrc_sl_MeasResultServingRelay_r17;
+static int ett_nr_rrc_ReferenceLocation_r17;
+static int ett_nr_rrc_wayPointLocation_r18;
 
-static expert_field ei_nr_rrc_number_pages_le15 = EI_INIT;
+static expert_field ei_nr_rrc_number_pages_le15;
 
 /* Forward declarations */
 static int dissect_UECapabilityInformationSidelink_PDU(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree *tree _U_, void *data _U_);
@@ -163,23 +170,48 @@ static int dissect_DL_DCCH_Message_PDU(tvbuff_t *tvb _U_, packet_info *pinfo _U_
 static int dissect_DL_CCCH_Message_PDU(tvbuff_t* tvb _U_, packet_info* pinfo _U_, proto_tree* tree _U_, void* data _U_);
 static int dissect_UL_CCCH_Message_PDU(tvbuff_t* tvb _U_, packet_info* pinfo _U_, proto_tree* tree _U_, void* data _U_);
 static int dissect_UERadioAccessCapabilityInformation_PDU(tvbuff_t* tvb _U_, packet_info* pinfo _U_, proto_tree* tree _U_, void* data _U_);
+static int dissect_SL_MeasResultListRelay_r17_PDU(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree *tree _U_, void *data _U_);
+static int dissect_SL_MeasResultRelay_r17_PDU(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree *tree _U_, void *data _U_);
 
 static const unit_name_string units_periodicities = { " periodicity", " periodicities" };
 static const unit_name_string units_prbs = { " PRB", " PRBs" };
 static const unit_name_string units_slots = { " slot", " slots" };
 
 typedef struct {
-  guint8 rat_type;
-  guint8 target_rat_type;
-  guint16 message_identifier;
-  guint8 warning_message_segment_type;
-  guint8 warning_message_segment_number;
+  uint8_t rat_type;
+  uint8_t target_rat_type;
+  uint16_t message_identifier;
+  uint8_t warning_message_segment_type;
+  uint8_t warning_message_segment_number;
   nr_drb_mac_rlc_mapping_t drb_rlc_mapping;
   nr_drb_rlc_pdcp_mapping_t drb_pdcp_mapping;
   lpp_pos_sib_type_t pos_sib_type;
   pdcp_nr_security_info_t pdcp_security;
 } nr_rrc_private_data_t;
 
+/* Helper function to get UE identifier from lower layers (in order MAC, RLC, PDCP) */
+static uint16_t*
+nr_rrc_get_ueid_from_lower_layers(wmem_allocator_t *scope, struct _packet_info* pinfo)
+{
+  /* Try MAC first */
+  mac_nr_info *p_mac_nr_info = (mac_nr_info *)p_get_proto_data(scope, pinfo, proto_mac_nr, 0);
+  if (p_mac_nr_info != NULL) {
+    return &p_mac_nr_info->ueid;
+  }
+  /* Not found, try RLC */
+  rlc_nr_info *p_rlc_nr_info = (rlc_nr_info *)p_get_proto_data(scope, pinfo, proto_rlc_nr, 0);
+  if (p_rlc_nr_info != NULL) {
+    return &p_rlc_nr_info->ueid;
+  }
+  /* Not found, try PDCP */
+  pdcp_nr_info *p_pdcp_nr_info = (pdcp_nr_info *)p_get_proto_data(scope, pinfo, proto_pdcp_nr, 0);
+  if (p_pdcp_nr_info != NULL) {
+    return &p_pdcp_nr_info->ueid;
+  }
+  /* Nothing found, give up */
+  return NULL;
+}
+
 /* Helper function to get or create a struct that will be actx->private_data */
 static nr_rrc_private_data_t*
 nr_rrc_get_private_data(asn1_ctx_t *actx)
@@ -204,9 +236,9 @@ nr_rrc_call_dissector(dissector_handle_t handle, tvbuff_t *tvb, packet_info *pin
 }
 
 static void
-nr_rrc_q_RxLevMin_fmt(gchar *s, guint32 v)
+nr_rrc_q_RxLevMin_fmt(char *s, uint32_t v)
 {
-  gint32 d = (gint32)v;
+  int32_t d = (int32_t)v;
 
   snprintf(s, ITEM_LABEL_LENGTH, "%d dB (%d)", 2*d, d);
 }
@@ -263,15 +295,15 @@ static const fragment_items nr_rrc_sib8_frag_items = {
 };
 
 static void
-dissect_nr_rrc_warningMessageSegment(tvbuff_t *warning_msg_seg_tvb, proto_tree *tree, packet_info *pinfo, guint8 dataCodingScheme)
+dissect_nr_rrc_warningMessageSegment(tvbuff_t *warning_msg_seg_tvb, proto_tree *tree, packet_info *pinfo, uint8_t dataCodingScheme)
 {
-  guint32 offset;
-  guint8 nb_of_pages, length, *str;
+  uint32_t offset;
+  uint8_t nb_of_pages, length, *str;
   proto_item *ti;
   tvbuff_t *cb_data_page_tvb, *cb_data_tvb;
   int i;
 
-  nb_of_pages = tvb_get_guint8(warning_msg_seg_tvb, 0);
+  nb_of_pages = tvb_get_uint8(warning_msg_seg_tvb, 0);
   ti = proto_tree_add_uint(tree, hf_nr_rrc_warningMessageSegment_nb_pages, warning_msg_seg_tvb, 0, 1, nb_of_pages);
   if (nb_of_pages > 15) {
     expert_add_info_format(pinfo, ti, &ei_nr_rrc_number_pages_le15,
@@ -279,7 +311,7 @@ dissect_nr_rrc_warningMessageSegment(tvbuff_t *warning_msg_seg_tvb, proto_tree *
     nb_of_pages = 15;
   }
   for (i = 0, offset = 1; i < nb_of_pages; i++) {
-    length = tvb_get_guint8(warning_msg_seg_tvb, offset+82);
+    length = tvb_get_uint8(warning_msg_seg_tvb, offset+82);
     cb_data_page_tvb = tvb_new_subset_length(warning_msg_seg_tvb, offset, length);
     cb_data_tvb = dissect_cbs_data(dataCodingScheme, cb_data_page_tvb, tree, pinfo, 0);
     if (cb_data_tvb) {
@@ -300,9 +332,9 @@ static const value_string nr_rrc_daylightSavingTime_vals[] = {
 };
 
 static void
-nr_rrc_localTimeOffset_fmt(gchar *s, guint32 v)
+nr_rrc_localTimeOffset_fmt(char *s, uint32_t v)
 {
-  gint32 time_offset = (gint32) v;
+  int32_t time_offset = (int32_t) v;
 
   snprintf(s, ITEM_LABEL_LENGTH, "UTC time %c %dhr %dmin (%d)",
              (time_offset < 0) ? '-':'+', abs(time_offset) >> 2,
@@ -310,35 +342,35 @@ nr_rrc_localTimeOffset_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_drx_SlotOffset_fmt(gchar *s, guint32 v)
+nr_rrc_drx_SlotOffset_fmt(char *s, uint32_t v)
 {
   snprintf(s, ITEM_LABEL_LENGTH, "%g ms (%u)", 1./32 * v, v);
 }
 
 static void
-nr_rrc_Hysteresis_fmt(gchar *s, guint32 v)
+nr_rrc_Hysteresis_fmt(char *s, uint32_t v)
 {
   snprintf(s, ITEM_LABEL_LENGTH, "%gdB (%u)", 0.5 * v, v);
 }
 
 static void
-nr_rrc_msg3_DeltaPreamble_fmt(gchar *s, guint32 v)
+nr_rrc_msg3_DeltaPreamble_fmt(char *s, uint32_t v)
 {
-  gint32 d = (gint32)v;
+  int32_t d = (int32_t)v;
 
   snprintf(s, ITEM_LABEL_LENGTH, "%ddB (%d)", 2 * d, d);
 }
 
 static void
-nr_rrc_Q_RxLevMin_fmt(gchar *s, guint32 v)
+nr_rrc_Q_RxLevMin_fmt(char *s, uint32_t v)
 {
-  gint32 d = (gint32)v;
+  int32_t d = (int32_t)v;
 
   snprintf(s, ITEM_LABEL_LENGTH, "%ddBm (%d)", 2 * d, d);
 }
 
 static void
-nr_rrc_RSRP_RangeEUTRA_fmt(gchar *s, guint32 v)
+nr_rrc_RSRP_RangeEUTRA_fmt(char *s, uint32_t v)
 {
   if (v == 0) {
     snprintf(s, ITEM_LABEL_LENGTH, "RSRP < -140dBm (0)");
@@ -350,7 +382,7 @@ nr_rrc_RSRP_RangeEUTRA_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_RSRQ_RangeEUTRA_fmt(gchar *s, guint32 v)
+nr_rrc_RSRQ_RangeEUTRA_fmt(char *s, uint32_t v)
 {
   if (v == 0) {
     snprintf(s, ITEM_LABEL_LENGTH, "RSRQ < -19.5dB (0)");
@@ -362,7 +394,7 @@ nr_rrc_RSRQ_RangeEUTRA_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_SINR_RangeEUTRA_fmt(gchar *s, guint32 v)
+nr_rrc_SINR_RangeEUTRA_fmt(char *s, uint32_t v)
 {
   if (v == 0) {
     snprintf(s, ITEM_LABEL_LENGTH, "SINR < -23dB (0)");
@@ -374,13 +406,13 @@ nr_rrc_SINR_RangeEUTRA_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_ReselectionThreshold_fmt(gchar *s, guint32 v)
+nr_rrc_ReselectionThreshold_fmt(char *s, uint32_t v)
 {
   snprintf(s, ITEM_LABEL_LENGTH, "%udB (%u)", 2 * v, v);
 }
 
 static void
-nr_rrc_RSRP_Range_fmt(gchar *s, guint32 v)
+nr_rrc_RSRP_Range_fmt(char *s, uint32_t v)
 {
   if (v == 0) {
     snprintf(s, ITEM_LABEL_LENGTH, "SS-RSRP < -156dBm (0)");
@@ -394,19 +426,19 @@ nr_rrc_RSRP_Range_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_RSRQ_Range_fmt(gchar *s, guint32 v)
+nr_rrc_RSRQ_Range_fmt(char *s, uint32_t v)
 {
   if (v == 0) {
     snprintf(s, ITEM_LABEL_LENGTH, "SS-RSRQ < -43dB (0)");
   } else if (v < 127) {
     snprintf(s, ITEM_LABEL_LENGTH, "%.1fdB <= SS-RSRQ < %.1fdB (%u)", (((float)v-1)/2)-43, ((float)v/2)-43, v);
   } else {
-    snprintf(s, ITEM_LABEL_LENGTH, "-20dB <= SS-RSRQ (127)");
+    snprintf(s, ITEM_LABEL_LENGTH, "20dB <= SS-RSRQ (127)");
   }
 }
 
 static void
-nr_rrc_SINR_Range_fmt(gchar *s, guint32 v)
+nr_rrc_SINR_Range_fmt(char *s, uint32_t v)
 {
   if (v == 0) {
     snprintf(s, ITEM_LABEL_LENGTH, "SS-SINR < -23dB (0)");
@@ -418,19 +450,19 @@ nr_rrc_SINR_Range_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_dl_1024QAM_TotalWeightedLayers_fmt(gchar *s, guint32 v)
+nr_rrc_dl_1024QAM_TotalWeightedLayers_fmt(char *s, uint32_t v)
 {
   snprintf(s, ITEM_LABEL_LENGTH, "%u (%u)", 10+(2*v), v);
 }
 
 static void
-nr_rrc_timeConnFailure_r16_fmt(gchar *s, guint32 v)
+nr_rrc_timeConnFailure_r16_fmt(char *s, uint32_t v)
 {
   snprintf(s, ITEM_LABEL_LENGTH, "%ums (%u)", 100*v, v);
 }
 
 static void
-nr_rrc_RSSI_Range_r16_fmt(gchar *s, guint32 v)
+nr_rrc_RSSI_Range_r16_fmt(char *s, uint32_t v)
 {
   if (v == 0) {
     snprintf(s, ITEM_LABEL_LENGTH, "RSSI < -100dBm (0)");
@@ -442,9 +474,9 @@ nr_rrc_RSSI_Range_r16_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_RSRQ_RangeEUTRA_r16_fmt(gchar *s, guint32 v)
+nr_rrc_RSRQ_RangeEUTRA_r16_fmt(char *s, uint32_t v)
 {
-  gint32 d = (gint32)v;
+  int32_t d = (int32_t)v;
 
   if (d == -34) {
     snprintf(s, ITEM_LABEL_LENGTH, "RSRQ < -36dB (-34)");
@@ -464,9 +496,9 @@ nr_rrc_RSRQ_RangeEUTRA_r16_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_utra_FDD_RSCP_r16_fmt(gchar *s, guint32 v)
+nr_rrc_utra_FDD_RSCP_r16_fmt(char *s, uint32_t v)
 {
-  gint32 d = (gint32)v;
+  int32_t d = (int32_t)v;
 
   if (d == -5) {
     snprintf(s, ITEM_LABEL_LENGTH, "RSCP < -120dBm (-5)");
@@ -478,7 +510,7 @@ nr_rrc_utra_FDD_RSCP_r16_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_utra_FDD_EcN0_r16_fmt(gchar *s, guint32 v)
+nr_rrc_utra_FDD_EcN0_r16_fmt(char *s, uint32_t v)
 {
   if (v == 0) {
     snprintf(s, ITEM_LABEL_LENGTH, "Ec/No < -24dB (0)");
@@ -490,27 +522,27 @@ nr_rrc_utra_FDD_EcN0_r16_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_averageDelay_r16_fmt(gchar *s, guint32 v)
+nr_rrc_averageDelay_r16_fmt(char *s, uint32_t v)
 {
   snprintf(s, ITEM_LABEL_LENGTH, "%.1fms (%u)", (float)v/10, v);
 }
 
 static void
-nr_rrc_measTriggerQuantity_utra_FDD_RSCP_r16_fmt(gchar *s, guint32 v)
+nr_rrc_measTriggerQuantity_utra_FDD_RSCP_r16_fmt(char *s, uint32_t v)
 {
-  gint32 d = (gint32)v;
+  int32_t d = (int32_t)v;
 
   snprintf(s, ITEM_LABEL_LENGTH, "%ddBm (%d)", d-115, d);
 }
 
 static void
-nr_rrc_measTriggerQuantity_utra_FDD_EcN0_r16_fmt(gchar *s, guint32 v)
+nr_rrc_measTriggerQuantity_utra_FDD_EcN0_r16_fmt(char *s, uint32_t v)
 {
   snprintf(s, ITEM_LABEL_LENGTH, "%.1fdB (%u)", (float)v/2-24.5, v);
 }
 
 static void
-nr_rrc_SRS_RSRP_r16_fmt(gchar *s, guint32 v)
+nr_rrc_SRS_RSRP_r16_fmt(char *s, uint32_t v)
 {
   if (v == 0) {
     snprintf(s, ITEM_LABEL_LENGTH, "SRS-RSRP < -140dBm (0)");
@@ -524,13 +556,25 @@ nr_rrc_SRS_RSRP_r16_fmt(gchar *s, guint32 v)
 }
 
 static void
-nr_rrc_MeasTriggerQuantityOffset_fmt(gchar *s, guint32 v)
+nr_rrc_MeasTriggerQuantityOffset_fmt(char *s, uint32_t v)
 {
-  gint32 d = (gint32)v;
+  int32_t d = (int32_t)v;
 
   snprintf(s, ITEM_LABEL_LENGTH, "%.1fdB (%d)", (float)d/2, d);
 }
 
+static void
+nr_rrc_TimeSinceCHO_Reconfig_r17_fmt(char *s, uint32_t v)
+{
+  snprintf(s, ITEM_LABEL_LENGTH, "%.1fs (%u)", (float)v/10, v);
+}
+
+static void
+nr_rrc_FlightPathUpdateDistanceThr_r18_fmt(char *s, uint32_t v)
+{
+  snprintf(s, ITEM_LABEL_LENGTH, "%um (%u)", v*5, v);
+}
+
 static int
 dissect_nr_rrc_cg_configinfo_msg(tvbuff_t* tvb _U_, packet_info* pinfo _U_, proto_tree* tree _U_, void* data _U_)
 {
@@ -707,7 +751,7 @@ dissect_nr_rrc_handoverpreparationinformation_msg(tvbuff_t* tvb _U_, packet_info
     proto_tree* sub_tree;
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "NR RRC");
-    col_set_str(pinfo->cinfo, COL_INFO, "MeasGapConfig");
+    col_set_str(pinfo->cinfo, COL_INFO, "HandoverPreparationInformation");
 
     ti = proto_tree_add_item(tree, proto_nr_rrc, tvb, 0, -1, ENC_NA);
     sub_tree = proto_item_add_subtree(ti, ett_nr_rrc);
@@ -731,6 +775,21 @@ dissect_nr_rrc_rrcreconfiguration_msg(tvbuff_t* tvb _U_, packet_info* pinfo _U_,
 }
 
 
+static int
+dissect_nr_rrc_rrcreconfigurationcomplete_msg(tvbuff_t* tvb _U_, packet_info* pinfo _U_, proto_tree* tree _U_, void* data _U_)
+{
+    proto_item* ti;
+    proto_tree* sub_tree;
+
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "NR RRC");
+    col_set_str(pinfo->cinfo, COL_INFO, "RRCReconfigurationComplete");
+
+    ti = proto_tree_add_item(tree, proto_nr_rrc, tvb, 0, -1, ENC_NA);
+    sub_tree = proto_item_add_subtree(ti, ett_nr_rrc);
+    return dissect_nr_rrc_RRCReconfigurationComplete_PDU(tvb, pinfo, sub_tree, NULL);
+}
+
+
 static int
 dissect_nr_rrc_ue_capabilityrat_containerlist_msg(tvbuff_t* tvb _U_, packet_info* pinfo _U_, proto_tree* tree _U_, void* data _U_)
 {
@@ -768,7 +827,7 @@ dissect_nr_rrc_nr_RLF_Report_r16_PDU(tvbuff_t *tvb _U_, packet_info *pinfo _U_,
   proto_item_set_hidden(prot_ti);
   int offset = 0;
   asn1_ctx_t asn1_ctx;
-  asn1_ctx_init(&asn1_ctx, ASN1_ENC_PER, FALSE, pinfo);
+  asn1_ctx_init(&asn1_ctx, ASN1_ENC_PER, false, pinfo);
   offset = dissect_nr_rrc_T_nr_RLF_Report_r16(tvb, offset, &asn1_ctx, tree, hf_nr_rrc_BCCH_DL_SCH_Message_PDU);
   offset += 7; offset >>= 3;
   return offset;
@@ -780,12 +839,24 @@ dissect_nr_rrc_subCarrierSpacingCommon_PDU(tvbuff_t *tvb _U_, packet_info *pinfo
   proto_item_set_hidden(prot_ti);
   int offset = 0;
   asn1_ctx_t asn1_ctx;
-  asn1_ctx_init(&asn1_ctx, ASN1_ENC_PER, FALSE, pinfo);
+  asn1_ctx_init(&asn1_ctx, ASN1_ENC_PER, false, pinfo);
   offset = dissect_nr_rrc_T_subCarrierSpacingCommon(tvb, offset, &asn1_ctx, tree, hf_nr_rrc_BCCH_DL_SCH_Message_PDU);
   offset += 7; offset >>= 3;
   return offset;
 }
 
+int
+dissect_nr_rrc_rach_ConfigCommonIAB_r16_PDU(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree *tree _U_, void *data _U_) {
+  proto_item *prot_ti = proto_tree_add_item(tree, proto_nr_rrc, tvb, 0, -1, ENC_NA);
+  proto_item_set_hidden(prot_ti);
+  int offset = 0;
+  asn1_ctx_t asn1_ctx;
+  asn1_ctx_init(&asn1_ctx, ASN1_ENC_PER, false, pinfo);
+  offset = dissect_nr_rrc_T_rach_ConfigCommonIAB_r16(tvb, offset, &asn1_ctx, tree, hf_nr_rrc_BCCH_DL_SCH_Message_PDU);
+  offset += 7; offset >>= 3;
+  return offset;
+}
+
 void
 proto_register_nr_rrc(void) {
 
@@ -928,7 +999,7 @@ proto_register_nr_rrc(void) {
         NULL, HFILL }},
   };
 
-  static gint *ett[] = {
+  static int *ett[] = {
     &ett_nr_rrc,
 #include "packet-nr-rrc-ettarr.c"
     &ett_nr_rrc_DedicatedNAS_Message,
@@ -964,6 +1035,7 @@ proto_register_nr_rrc(void) {
     &ett_nr_rrc_sl_ConfigDedicatedEUTRA,
     &ett_nr_rrc_sl_CapabilityInformationSidelink,
     &ett_nr_rrc_measResult_RLF_Report_EUTRA,
+    &ett_nr_rrc_measResult_RLF_Report_EUTRA_v1690,
     &ett_nr_rrc_locationTimestamp_r16,
     &ett_nr_rrc_locationCoordinate_r16,
     &ett_nr_rrc_locationError_r16,
@@ -978,8 +1050,13 @@ proto_register_nr_rrc(void) {
     &ett_nr_rrc_sl_ParametersEUTRA3_r16,
     &ett_nr_rrc_absTimeInfo,
     &ett_nr_rrc_assistanceDataSIB_Element_r16,
-    &ett_nr_sl_V2X_ConfigCommon_r16,
-    &ett_nr_tdd_Config_r16
+    &ett_nr_rrc_sl_V2X_ConfigCommon_r16,
+    &ett_nr_rrc_tdd_Config_r16,
+    &ett_nr_rrc_coarseLocationInfo_r17,
+    &ett_nr_rrc_sl_MeasResultsCandRelay_r17,
+    &ett_nr_rrc_sl_MeasResultServingRelay_r17,
+    &ett_nr_rrc_ReferenceLocation_r17,
+    &ett_nr_rrc_wayPointLocation_r18
   };
 
   static ei_register_info ei[] = {
@@ -1002,6 +1079,7 @@ proto_register_nr_rrc(void) {
   register_dissector("nr-rrc.cg_configinfo", dissect_nr_rrc_cg_configinfo_msg, proto_nr_rrc);
   register_dissector("nr-rrc.radiobearerconfig", dissect_nr_rrc_radiobearerconfig_msg, proto_nr_rrc);
   register_dissector("nr-rrc.rrc_reconf_msg", dissect_nr_rrc_rrcreconfiguration_msg, proto_nr_rrc);
+  register_dissector("nr-rrc.rrc_reconf_compl_msg", dissect_nr_rrc_rrcreconfigurationcomplete_msg, proto_nr_rrc);
   register_dissector("nr-rrc.ue_capabilityrat_containerlist", dissect_nr_rrc_ue_capabilityrat_containerlist_msg, proto_nr_rrc);
   register_dissector("nr-rrc.ue_mrdc_cap_msg", dissect_nr_rrc_ue_mrdc_capability_msg, proto_nr_rrc);
   register_dissector("nr-rrc.ue_nr_cap_msg", dissect_nr_rrc_ue_nr_capability_msg, proto_nr_rrc);
@@ -1015,7 +1093,7 @@ proto_register_nr_rrc(void) {
   register_dissector("nr-rrc.measgapconfig_msg", dissect_nr_rrc_measgapconfig_msg, proto_nr_rrc);
   register_dissector("nr-rrc.handoverpreparationinformation_msg", dissect_nr_rrc_handoverpreparationinformation_msg, proto_nr_rrc);
   register_dissector("nr-rrc.handovercommand_msg", dissect_nr_rrc_handovercommand_msg, proto_nr_rrc);
-
+ /*#include "packet-nr-rrc-dis-reg.c" */
 #include "packet-nr-rrc-dis-reg.c"
 
   nr_rrc_etws_cmas_dcs_hash = wmem_map_new_autoreset(wmem_epan_scope(), wmem_file_scope(),
