@@ -11,7 +11,7 @@
  *
  * Based on the RANAP dissector
  *
- * References: ETSI TS 125 453 V7.9.0 (2008-02)
+ * References: ETSI TS 125 453 V17.0.0 (2022-04)
  */
 
 #include "config.h"
@@ -42,22 +42,22 @@ void proto_reg_handoff_pcap(void);
 
 #include "packet-pcap-val.h"
 
-static dissector_handle_t pcap_handle = NULL;
+static dissector_handle_t pcap_handle;
 
 /* Initialize the protocol and registered fields */
-static int proto_pcap = -1;
+static int proto_pcap;
 
 #include "packet-pcap-hf.c"
 
 /* Initialize the subtree pointers */
-static int ett_pcap = -1;
+static int ett_pcap;
 
 #include "packet-pcap-ett.c"
 
 /* Global variables */
-static guint32 ProcedureCode;
-static guint32 ProtocolIE_ID;
-/*static guint32 ProtocolExtensionID;*/
+static uint32_t ProcedureCode;
+static uint32_t ProtocolIE_ID;
+/*static uint32_t ProtocolExtensionID;*/
 
 /* Dissector tables */
 static dissector_table_t pcap_ies_dissector_table;
@@ -144,7 +144,7 @@ void proto_register_pcap(void) {
   };
 
   /* List of subtrees */
-  static gint *ett[] = {
+  static int *ett[] = {
 		  &ett_pcap,
 #include "packet-pcap-ettarr.c"
   };
