@@ -14,12 +14,12 @@
 
 /* Depending on what ASN.1 specification is used you may have to change
  * the preference setting regarding Pre-Corrigendum ASN.1 specification:
- * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/1998/T38.html  (Pre-Corrigendum=TRUE)
- * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/2003/T38(1998).html (Pre-Corrigendum=TRUE)
+ * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/1998/T38.html  (Pre-Corrigendum=true)
+ * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/2003/T38(1998).html (Pre-Corrigendum=true)
  *
- * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/2003/T38(2002).html (Pre-Corrigendum=FALSE)
- * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/2002/t38.html  (Pre-Corrigendum=FALSE)
- * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/2002-Amd1/T38.html (Pre-Corrigendum=FALSE)
+ * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/2003/T38(2002).html (Pre-Corrigendum=false)
+ * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/2002/t38.html  (Pre-Corrigendum=false)
+ * http://www.itu.int/ITU-T/asn1/database/itu-t/t/t38/2002-Amd1/T38.html (Pre-Corrigendum=false)
  */
 
 /* TO DO:
@@ -50,20 +50,20 @@
 
 void proto_register_t38(void);
 
-static int t38_tap = -1;
+static int t38_tap;
 
 /* dissect using the Pre Corrigendum T.38 ASN.1 specification (1998) */
-static gboolean use_pre_corrigendum_asn1_specification = TRUE;
+static bool use_pre_corrigendum_asn1_specification = true;
 
 /* dissect packets that looks like RTP version 2 packets as RTP     */
 /* instead of as T.38. This may result in that some T.38 UPTL       */
 /* packets with sequence number values higher than 32767 may be     */
 /* shown as RTP packets.                                            */
-static gboolean dissect_possible_rtpv2_packets_as_rtp = FALSE;
+static bool dissect_possible_rtpv2_packets_as_rtp;
 
 
 /* Reassembly of T.38 PDUs over TPKT over TCP */
-static gboolean t38_tpkt_reassembly = TRUE;
+static bool t38_tpkt_reassembly = true;
 
 /* Preference setting whether TPKT header is used when sending T.38 over TCP.
  * The default setting is Maybe where the dissector will look on the first
@@ -74,7 +74,7 @@ static gboolean t38_tpkt_reassembly = TRUE;
 #define T38_TPKT_NEVER 0   /* Assume that there is never a TPKT header    */
 #define T38_TPKT_ALWAYS 1  /* Assume that there is always a TPKT header   */
 #define T38_TPKT_MAYBE 2   /* Assume TPKT if first octets are 03-00-xx-xx */
-static gint t38_tpkt_usage = T38_TPKT_MAYBE;
+static int t38_tpkt_usage = T38_TPKT_MAYBE;
 
 static const enum_val_t t38_tpkt_options[] = {
   {"never", "Never", T38_TPKT_NEVER},
@@ -93,44 +93,44 @@ static dissector_handle_t rtp_handle;
 static dissector_handle_t t30_hdlc_handle;
 static dissector_handle_t data_handle;
 
-static gint32 Type_of_msg_value;
-static guint32 Data_Field_field_type_value;
-static guint32 Data_value;
-static guint32 T30ind_value;
-static guint32 Data_Field_item_num;
+static int32_t Type_of_msg_value;
+static uint32_t Data_Field_field_type_value;
+static uint32_t Data_value;
+static uint32_t T30ind_value;
+static uint32_t Data_Field_item_num;
 
-static int proto_t38 = -1;
-static int proto_acdr = -1;
+static int proto_t38;
+static int proto_acdr;
 #include "packet-t38-hf.c"
 
 /* T38 setup fields */
-static int hf_t38_setup        = -1;
-static int hf_t38_setup_frame  = -1;
-static int hf_t38_setup_method = -1;
+static int hf_t38_setup;
+static int hf_t38_setup_frame;
+static int hf_t38_setup_method;
 
 /* T38 Data reassemble fields */
-static int hf_t38_fragments = -1;
-static int hf_t38_fragment = -1;
-static int hf_t38_fragment_overlap = -1;
-static int hf_t38_fragment_overlap_conflicts = -1;
-static int hf_t38_fragment_multiple_tails = -1;
-static int hf_t38_fragment_too_long_fragment = -1;
-static int hf_t38_fragment_error = -1;
-static int hf_t38_fragment_count = -1;
-static int hf_t38_reassembled_in = -1;
-static int hf_t38_reassembled_length = -1;
+static int hf_t38_fragments;
+static int hf_t38_fragment;
+static int hf_t38_fragment_overlap;
+static int hf_t38_fragment_overlap_conflicts;
+static int hf_t38_fragment_multiple_tails;
+static int hf_t38_fragment_too_long_fragment;
+static int hf_t38_fragment_error;
+static int hf_t38_fragment_count;
+static int hf_t38_reassembled_in;
+static int hf_t38_reassembled_length;
 
-static gint ett_t38 = -1;
+static int ett_t38;
 #include "packet-t38-ett.c"
-static gint ett_t38_setup = -1;
+static int ett_t38_setup;
 
-static gint ett_data_fragment = -1;
-static gint ett_data_fragments = -1;
+static int ett_data_fragment;
+static int ett_data_fragments;
 
-static expert_field ei_t38_malformed = EI_INIT;
+static expert_field ei_t38_malformed;
 
-static gboolean primary_part = TRUE;
-static guint32 seq_number = 0;
+static bool primary_part = true;
+static uint32_t seq_number;
 
 /* Tables for reassembly of Data fragments. */
 static reassembly_table data_reassembly_table;
@@ -161,14 +161,14 @@ static const fragment_items data_frag_items = {
 typedef struct _fragment_key {
 	address src;
 	address dst;
-	guint32	id;
+	uint32_t	id;
 } fragment_key;
 
-static conversation_t *p_conv= NULL;
-static t38_conv *p_t38_conv = NULL;
-static t38_conv *p_t38_packet_conv = NULL;
-static t38_conv_info *p_t38_conv_info = NULL;
-static t38_conv_info *p_t38_packet_conv_info = NULL;
+static conversation_t *p_conv;
+static t38_conv *p_t38_conv;
+static t38_conv *p_t38_packet_conv;
+static t38_conv_info *p_t38_conv_info;
+static t38_conv_info *p_t38_packet_conv_info;
 
 /* RTP Version is the first 2 bits of the first octet in the UDP payload*/
 #define RTP_VERSION(octet)	((octet) >> 6)
@@ -177,21 +177,21 @@ void proto_reg_handoff_t38(void);
 
 static void show_setup_info(tvbuff_t *tvb, proto_tree *tree, t38_conv *p_t38_conv);
 /* Preferences bool to control whether or not setup info should be shown */
-static gboolean global_t38_show_setup_info = TRUE;
+static bool global_t38_show_setup_info = true;
 
 /* Can tap up to 4 T38 packets within same packet */
 /* We only tap the primary part, not the redundancy */
 #define MAX_T38_MESSAGES_IN_PACKET 4
 static t38_packet_info t38_info_arr[MAX_T38_MESSAGES_IN_PACKET];
 static int t38_info_current=0;
-static t38_packet_info *t38_info=NULL;
+static t38_packet_info *t38_info;
 
 
 /* Set up an T38 conversation */
 void t38_add_address(packet_info *pinfo,
                      address *addr, int port,
                      int other_port,
-                     const gchar *setup_method, guint32 setup_frame_number)
+                     const char *setup_method, uint32_t setup_frame_number)
 {
         address null_addr;
         conversation_t* p_conversation;
@@ -221,7 +221,7 @@ void t38_add_address(packet_info *pinfo,
          */
         if ( !p_conversation || p_conversation->setup_frame != setup_frame_number) {
                 p_conversation = conversation_new( setup_frame_number, addr, &null_addr, CONVERSATION_UDP,
-                                           (guint32)port, (guint32)other_port,
+                                           (uint32_t)port, (uint32_t)other_port,
                                                                    NO_ADDR2 | (!other_port ? NO_PORT2 : 0));
         }
 
@@ -275,13 +275,13 @@ void t38_add_address(packet_info *pinfo,
 
 
 static fragment_head *
-force_reassemble_seq(reassembly_table *table, packet_info *pinfo, guint32 id)
+force_reassemble_seq(reassembly_table *table, packet_info *pinfo, uint32_t id)
 {
 	fragment_head *fd_head;
 	fragment_item *fd_i;
 	fragment_item *last_fd;
-	guint32 dfpos, size, packet_lost, burst_lost, seq_num;
-	guint8 *data;
+	uint32_t dfpos, size, packet_lost, burst_lost, seq_num;
+	uint8_t *data;
 
 	fd_head = fragment_get(table, pinfo, id, NULL);
 
@@ -325,7 +325,7 @@ force_reassemble_seq(reassembly_table *table, packet_info *pinfo, guint32 id)
 	  last_fd=fd_i;
 	}
 
-	data = (guint8 *) g_malloc(size);
+	data = (uint8_t *) g_malloc(size);
 	fd_head->tvb_data = tvb_new_real_data(data, size, size);
         tvb_set_free_cb(fd_head->tvb_data, g_free);
 	fd_head->len = size;		/* record size for caller	*/
@@ -416,7 +416,7 @@ init_t38_info_conv(packet_info *pinfo)
                                    conversation_pt_to_conversation_type(pinfo->ptype),
                                    pinfo->destport, pinfo->srcport, NO_ADDR_B | NO_PORT_B);
 
-	/* create a conv if it doen't exist */
+	/* create a conv if it doesn't exist */
 	if (!p_conv) {
 		p_conv = conversation_new(pinfo->num, &pinfo->net_src, &pinfo->net_dst,
 			      conversation_pt_to_conversation_type(pinfo->ptype), pinfo->srcport, pinfo->destport, NO_ADDR2 | NO_PORT2);
@@ -488,16 +488,16 @@ init_t38_info_conv(packet_info *pinfo)
 static int
 dissect_t38_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
-	guint8 octet1;
+	uint8_t octet1;
 	proto_item *it;
 	proto_tree *tr;
-	guint32 offset=0;
+	uint32_t offset=0;
 
 	/*
 	 * XXX - heuristic to check for misidentified packets.
 	 */
 	if (dissect_possible_rtpv2_packets_as_rtp){
-		octet1 = tvb_get_guint8(tvb, offset);
+		octet1 = tvb_get_uint8(tvb, offset);
 		if (RTP_VERSION(octet1) == 2){
 			return call_dissector(rtp_handle,tvb,pinfo,tree);
 		}
@@ -506,7 +506,7 @@ dissect_t38_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "T.38");
 	col_clear(pinfo->cinfo, COL_INFO);
 
-	primary_part = TRUE;
+	primary_part = true;
 
 	/* This indicate the item number in the primary part of the T38 message, it is used for the reassemble of T30 packets */
 	Data_Field_item_num = 0;
@@ -539,14 +539,14 @@ dissect_t38_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* d
 {
 	proto_item *it;
 	proto_tree *tr;
-	guint32 offset=0;
+	uint32_t offset=0;
         tvbuff_t *next_tvb;
-	guint16 ifp_packet_number=1;
+	uint16_t ifp_packet_number=1;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "T.38");
 	col_clear(pinfo->cinfo, COL_INFO);
 
-	primary_part = TRUE;
+	primary_part = true;
 
 	/* This indicate the item number in the primary part of the T38 message, it is used for the reassemble of T30 packets */
 	Data_Field_item_num = 0;
@@ -588,7 +588,7 @@ dissect_t38_tcp_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* d
 static int
 dissect_t38_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
-	primary_part = TRUE;
+	primary_part = true;
 
 	if(t38_tpkt_usage == T38_TPKT_ALWAYS){
 		dissect_tpkt_encap(tvb,pinfo,tree,t38_tpkt_reassembly,t38_tcp_pdu_handle);
@@ -634,13 +634,13 @@ show_setup_info(tvbuff_t *tvb, proto_tree *tree, t38_conv *p_t38_conversation)
 }
 
 /* This function tries to understand if the payload is sitting on top of AC DR */
-static gboolean
-dissect_t38_acdr_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool
+dissect_t38_acdr_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
-	guint acdr_prot = GPOINTER_TO_UINT(p_get_proto_data(pinfo->pool, pinfo, proto_acdr, 0));
+	unsigned acdr_prot = GPOINTER_TO_UINT(p_get_proto_data(pinfo->pool, pinfo, proto_acdr, 0));
 	if (acdr_prot == ACDR_T38)
-		return dissect_t38_udp(tvb, pinfo, tree, NULL);
-	return FALSE;
+		return dissect_t38_udp(tvb, pinfo, tree, data);
+	return false;
 }
 
 
@@ -694,7 +694,7 @@ proto_register_t38(void)
 			FT_UINT32, BASE_DEC, NULL, 0x00, NULL, HFILL } },
 	};
 
-	static gint *ett[] =
+	static int *ett[] =
 	{
 		&ett_t38,
 #include "packet-t38-ettarr.c"
@@ -747,7 +747,7 @@ proto_register_t38(void)
 	prefs_register_enum_preference(t38_module, "tpkt_usage",
 		"TPKT used over TCP",
 		"Whether T.38 is used with TPKT for TCP",
-		(gint *)&t38_tpkt_usage,t38_tpkt_options,FALSE);
+		(int *)&t38_tpkt_usage,t38_tpkt_options,false);
 
 	prefs_register_bool_preference(t38_module, "show_setup_info",
                 "Show stream setup information",
