@@ -26,9 +26,9 @@ void proto_register_tcg_cp_oids(void);
 void proto_reg_handoff_tcg_cp_oids(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_tcg_cp_oids = -1;
+static int proto_tcg_cp_oids;
 #include "packet-tcg-cp-oids-hf.c"
-static int hf_tcg_cp_oids_UTF8String_PDU = -1;
+static int hf_tcg_cp_oids_UTF8String_PDU;
 
 /* Initialize the subtree pointers */
 #include "packet-tcg-cp-oids-ett.c"
@@ -48,7 +48,7 @@ void proto_register_tcg_cp_oids(void) {
   };
 
   /* List of subtrees */
-  static gint *ett[] = {
+  static int *ett[] = {
 #include "packet-tcg-cp-oids-ettarr.c"
   };
 
@@ -65,8 +65,8 @@ static int
 dissect_tcg_cp_oids_UTF8String_PDU(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_tree *tree _U_, void *data _U_) {
     int offset = 0;
     asn1_ctx_t actx;
-    asn1_ctx_init(&actx, ASN1_ENC_BER, TRUE, pinfo);
-    offset = dissect_ber_restricted_string(FALSE, BER_UNI_TAG_UTF8String, &actx, tree, tvb, offset, hf_tcg_cp_oids_UTF8String_PDU, NULL);
+    asn1_ctx_init(&actx, ASN1_ENC_BER, true, pinfo);
+    offset = dissect_ber_restricted_string(false, BER_UNI_TAG_UTF8String, &actx, tree, tvb, offset, hf_tcg_cp_oids_UTF8String_PDU, NULL);
     return offset;
 }
 
