@@ -16,19 +16,19 @@
 void proto_register_rfc7468(void);
 void proto_reg_handoff_rfc7468(void);
 
-static int proto_rfc7468 = -1;
+static int proto_rfc7468;
 
-static gint ett_rfc7468 = -1;
-static gint ett_rfc7468_preeb = -1;
-static gint ett_rfc7468_data = -1;
-static gint ett_rfc7468_posteb = -1;
+static gint ett_rfc7468;
+static gint ett_rfc7468_preeb;
+static gint ett_rfc7468_data;
+static gint ett_rfc7468_posteb;
 
-static int hf_rfc7468_preeb_label = -1;
-static int hf_rfc7468_ber_data = -1;
-static int hf_rfc7468_posteb_label = -1;
+static int hf_rfc7468_preeb_label;
+static int hf_rfc7468_ber_data;
+static int hf_rfc7468_posteb_label;
 
-static dissector_handle_t rfc7468_handle = NULL;
-static dissector_handle_t ber_handle = NULL;
+static dissector_handle_t rfc7468_handle;
+static dissector_handle_t ber_handle;
 
 static dissector_table_t rfc7468_label_table;
 
@@ -363,7 +363,7 @@ dissect_rfc7468(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data
 //
 #define MAX_EXPLANATORY_TEXT_LINES     20
 
-static gboolean
+static bool
 dissect_rfc7468_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     int offset;
@@ -422,13 +422,13 @@ dissect_rfc7468_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *
      * Did we find a pre-encapsulation boundary?
      */
     if (!found)
-        return FALSE; /* no */
+        return false; /* no */
 
     /*
      * OK, it's an RFC 7468 file.  Dissect it.
      */
     dissect_rfc7468(tvb, pinfo, tree, data);
-    return TRUE;
+    return true;
 }
 
 void
