@@ -81,6 +81,8 @@
  * See Also: http://plan9.bell-labs.com/sys/man/5/INDEX.html
  */
 
+static dissector_handle_t ninep_handle;
+
 enum _9p_msg_t {
 	_9P_TLERROR = 6,
 	_9P_RLERROR,
@@ -312,10 +314,6 @@ enum _9p_qid_t {
 #define _9P_NONUNAME	(guint32)(~0)
 #define _9P_MAXWELEM	16
 
-#ifndef MAXPATHLEN
-#define MAXPATHLEN 1024
-#endif
-
 
 /**
  * @brief Length prefixed string type
@@ -524,6 +522,7 @@ static const value_string linux_errno[] =
 	{38, "Function not implemented"},		/* ENOSYS */
 	{39, "Directory not empty"},			/* ENOTEMPTY */
 	{40, "Too many symbolic links encountered"},	/* ELOOP */
+	{41, "Operation would block"},			/* EWOULDBLOCK */
 	{42, "No message of desired type"},		/* ENOMSG */
 	{43, "Identifier removed"},			/* EIDRM */
 	{44, "Channel number out of range"},		/* ECHRNG */
@@ -956,167 +955,167 @@ void proto_register_9P(void);
 void proto_reg_handoff_9P(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_9P = -1;
-static int hf_9P_msgsz = -1;
-static int hf_9P_msgtype = -1;
-static int hf_9P_tag = -1;
-static int hf_9P_oldtag = -1;
-static int hf_9P_parmsz = -1;
-static int hf_9P_maxsize = -1;
-static int hf_9P_fid = -1;
-static int hf_9P_nqid = -1;
-static int hf_9P_mode = -1;
-static int hf_9P_mode_rwx = -1;
-static int hf_9P_mode_t = -1;
-static int hf_9P_mode_c = -1;
-static int hf_9P_extension = -1;
-static int hf_9P_iounit = -1;
-static int hf_9P_count = -1;
-static int hf_9P_offset = -1;
-static int hf_9P_perm = -1;
-static int hf_9P_qidtype = -1;
-static int hf_9P_qidtype_dir = -1;
-static int hf_9P_qidtype_append = -1;
-static int hf_9P_qidtype_exclusive = -1;
-static int hf_9P_qidtype_mount = -1;
-static int hf_9P_qidtype_auth_file = -1;
-static int hf_9P_qidtype_temp_file = -1;
-static int hf_9P_qidvers = -1;
-static int hf_9P_qidpath = -1;
-static int hf_9P_dm_dir = -1;
-static int hf_9P_dm_append = -1;
-static int hf_9P_dm_exclusive = -1;
-static int hf_9P_dm_mount = -1;
-static int hf_9P_dm_auth_file = -1;
-static int hf_9P_dm_temp_file = -1;
-static int hf_9P_dm_read_owner = -1;
-static int hf_9P_dm_write_owner = -1;
-static int hf_9P_dm_exec_owner = -1;
-static int hf_9P_dm_read_group = -1;
-static int hf_9P_dm_write_group = -1;
-static int hf_9P_dm_exec_group = -1;
-static int hf_9P_dm_read_others = -1;
-static int hf_9P_dm_write_others = -1;
-static int hf_9P_dm_exec_others = -1;
-static int hf_9P_stattype = -1;
-static int hf_9P_statmode = -1;
-static int hf_9P_atime = -1;
-static int hf_9P_mtime = -1;
-static int hf_9P_ctime = -1;
-static int hf_9P_btime = -1;
-static int hf_9P_length = -1;
-static int hf_9P_dev = -1;
-static int hf_9P_wname = -1;
-static int hf_9P_version = -1;
-static int hf_9P_afid = -1;
-static int hf_9P_uname = -1;
-static int hf_9P_aname = -1;
-static int hf_9P_ename = -1;
-static int hf_9P_enum = -1;
-/* static int hf_9P_name = -1; */
-static int hf_9P_filename = -1;
-static int hf_9P_sdlen = -1;
-static int hf_9P_user = -1;
-static int hf_9P_group = -1;
-static int hf_9P_uid = -1;
-static int hf_9P_gid = -1;
-static int hf_9P_muid = -1;
-static int hf_9P_nwalk = -1;
-static int hf_9P_newfid = -1;
-static int hf_9P_dfid = -1;
-static int hf_9P_getattr_flags = -1;
-static int hf_9P_getattr_mode = -1;
-static int hf_9P_getattr_nlink = -1;
-static int hf_9P_getattr_uid = -1;
-static int hf_9P_getattr_gid = -1;
-static int hf_9P_getattr_rdev = -1;
-static int hf_9P_getattr_atime = -1;
-static int hf_9P_getattr_mtime = -1;
-static int hf_9P_getattr_ctime = -1;
-static int hf_9P_getattr_ino = -1;
-static int hf_9P_getattr_size = -1;
-static int hf_9P_getattr_blocks = -1;
-static int hf_9P_getattr_btime = -1;
-static int hf_9P_getattr_gen = -1;
-static int hf_9P_getattr_dataversion = -1;
-static int hf_9P_setattr_flags = -1;
-static int hf_9P_setattr_mode = -1;
-static int hf_9P_setattr_uid = -1;
-static int hf_9P_setattr_gid = -1;
-static int hf_9P_setattr_size = -1;
-static int hf_9P_setattr_atime = -1;
-static int hf_9P_setattr_mtime = -1;
-static int hf_9P_setattr_ctime = -1;
-static int hf_9P_setattr_atime_set = -1;
-static int hf_9P_setattr_mtime_set = -1;
-static int hf_9P_unlinkat_flags = -1;
-static int hf_9P_nlink = -1;
-static int hf_9P_rdev = -1;
-static int hf_9P_size = -1;
-static int hf_9P_blksize = -1;
-static int hf_9P_blocks = -1;
-static int hf_9P_gen = -1;
-static int hf_9P_dataversion = -1;
-static int hf_9P_fstype = -1;
-static int hf_9P_bfree = -1;
-static int hf_9P_bavail = -1;
-static int hf_9P_files = -1;
-static int hf_9P_ffree = -1;
-static int hf_9P_fsid = -1;
-static int hf_9P_namelen = -1;
-static int hf_9P_mknod_major = -1;
-static int hf_9P_mknod_minor = -1;
-static int hf_9P_lflags = -1;
-static int hf_9P_lflags_rdonly = -1;
-static int hf_9P_lflags_wronly = -1;
-static int hf_9P_lflags_rdwr = -1;
-static int hf_9P_lflags_create = -1;
-static int hf_9P_lflags_excl = -1;
-static int hf_9P_lflags_noctty = -1;
-static int hf_9P_lflags_trunc = -1;
-static int hf_9P_lflags_append = -1;
-static int hf_9P_lflags_nonblock = -1;
-static int hf_9P_lflags_dsync = -1;
-static int hf_9P_lflags_fasync = -1;
-static int hf_9P_lflags_direct = -1;
-static int hf_9P_lflags_largefile = -1;
-static int hf_9P_lflags_directory = -1;
-static int hf_9P_lflags_nofollow = -1;
-static int hf_9P_lflags_noatime = -1;
-static int hf_9P_lflags_cloexec = -1;
-static int hf_9P_lflags_sync = -1;
-static int hf_9P_xattr_flag = -1;
-static int hf_9P_lock_type = -1;
-static int hf_9P_lock_flag = -1;
-static int hf_9P_lock_start = -1;
-static int hf_9P_lock_length = -1;
-static int hf_9P_lock_procid = -1;
-static int hf_9P_lock_status = -1;
-static int hf_9P_unknown_message = -1;
+static int proto_9P;
+static int hf_9P_msgsz;
+static int hf_9P_msgtype;
+static int hf_9P_tag;
+static int hf_9P_oldtag;
+static int hf_9P_parmsz;
+static int hf_9P_maxsize;
+static int hf_9P_fid;
+static int hf_9P_nqid;
+static int hf_9P_mode;
+static int hf_9P_mode_rwx;
+static int hf_9P_mode_t;
+static int hf_9P_mode_c;
+static int hf_9P_extension;
+static int hf_9P_iounit;
+static int hf_9P_count;
+static int hf_9P_offset;
+static int hf_9P_perm;
+static int hf_9P_qidtype;
+static int hf_9P_qidtype_dir;
+static int hf_9P_qidtype_append;
+static int hf_9P_qidtype_exclusive;
+static int hf_9P_qidtype_mount;
+static int hf_9P_qidtype_auth_file;
+static int hf_9P_qidtype_temp_file;
+static int hf_9P_qidvers;
+static int hf_9P_qidpath;
+static int hf_9P_dm_dir;
+static int hf_9P_dm_append;
+static int hf_9P_dm_exclusive;
+static int hf_9P_dm_mount;
+static int hf_9P_dm_auth_file;
+static int hf_9P_dm_temp_file;
+static int hf_9P_dm_read_owner;
+static int hf_9P_dm_write_owner;
+static int hf_9P_dm_exec_owner;
+static int hf_9P_dm_read_group;
+static int hf_9P_dm_write_group;
+static int hf_9P_dm_exec_group;
+static int hf_9P_dm_read_others;
+static int hf_9P_dm_write_others;
+static int hf_9P_dm_exec_others;
+static int hf_9P_stattype;
+static int hf_9P_statmode;
+static int hf_9P_atime;
+static int hf_9P_mtime;
+static int hf_9P_ctime;
+static int hf_9P_btime;
+static int hf_9P_length;
+static int hf_9P_dev;
+static int hf_9P_wname;
+static int hf_9P_version;
+static int hf_9P_afid;
+static int hf_9P_uname;
+static int hf_9P_aname;
+static int hf_9P_ename;
+static int hf_9P_enum;
+/* static int hf_9P_name; */
+static int hf_9P_filename;
+static int hf_9P_sdlen;
+static int hf_9P_user;
+static int hf_9P_group;
+static int hf_9P_uid;
+static int hf_9P_gid;
+static int hf_9P_muid;
+static int hf_9P_nwalk;
+static int hf_9P_newfid;
+static int hf_9P_dfid;
+static int hf_9P_getattr_flags;
+static int hf_9P_getattr_mode;
+static int hf_9P_getattr_nlink;
+static int hf_9P_getattr_uid;
+static int hf_9P_getattr_gid;
+static int hf_9P_getattr_rdev;
+static int hf_9P_getattr_atime;
+static int hf_9P_getattr_mtime;
+static int hf_9P_getattr_ctime;
+static int hf_9P_getattr_ino;
+static int hf_9P_getattr_size;
+static int hf_9P_getattr_blocks;
+static int hf_9P_getattr_btime;
+static int hf_9P_getattr_gen;
+static int hf_9P_getattr_dataversion;
+static int hf_9P_setattr_flags;
+static int hf_9P_setattr_mode;
+static int hf_9P_setattr_uid;
+static int hf_9P_setattr_gid;
+static int hf_9P_setattr_size;
+static int hf_9P_setattr_atime;
+static int hf_9P_setattr_mtime;
+static int hf_9P_setattr_ctime;
+static int hf_9P_setattr_atime_set;
+static int hf_9P_setattr_mtime_set;
+static int hf_9P_unlinkat_flags;
+static int hf_9P_nlink;
+static int hf_9P_rdev;
+static int hf_9P_size;
+static int hf_9P_blksize;
+static int hf_9P_blocks;
+static int hf_9P_gen;
+static int hf_9P_dataversion;
+static int hf_9P_fstype;
+static int hf_9P_bfree;
+static int hf_9P_bavail;
+static int hf_9P_files;
+static int hf_9P_ffree;
+static int hf_9P_fsid;
+static int hf_9P_namelen;
+static int hf_9P_mknod_major;
+static int hf_9P_mknod_minor;
+static int hf_9P_lflags;
+static int hf_9P_lflags_rdonly;
+static int hf_9P_lflags_wronly;
+static int hf_9P_lflags_rdwr;
+static int hf_9P_lflags_create;
+static int hf_9P_lflags_excl;
+static int hf_9P_lflags_noctty;
+static int hf_9P_lflags_trunc;
+static int hf_9P_lflags_append;
+static int hf_9P_lflags_nonblock;
+static int hf_9P_lflags_dsync;
+static int hf_9P_lflags_fasync;
+static int hf_9P_lflags_direct;
+static int hf_9P_lflags_largefile;
+static int hf_9P_lflags_directory;
+static int hf_9P_lflags_nofollow;
+static int hf_9P_lflags_noatime;
+static int hf_9P_lflags_cloexec;
+static int hf_9P_lflags_sync;
+static int hf_9P_xattr_flag;
+static int hf_9P_lock_type;
+static int hf_9P_lock_flag;
+static int hf_9P_lock_start;
+static int hf_9P_lock_length;
+static int hf_9P_lock_procid;
+static int hf_9P_lock_status;
+static int hf_9P_unknown_message;
 
 /* subtree pointers */
-static gint ett_9P = -1;
-static gint ett_9P_omode = -1;
-static gint ett_9P_dm = -1;
-static gint ett_9P_wname = -1;
-static gint ett_9P_aname = -1;
-static gint ett_9P_ename = -1;
-static gint ett_9P_uname = -1;
-static gint ett_9P_user = -1;
-static gint ett_9P_group = -1;
-static gint ett_9P_muid = -1;
-static gint ett_9P_filename = -1;
-static gint ett_9P_version = -1;
-static gint ett_9P_qid = -1;
-static gint ett_9P_qidtype = -1;
-static gint ett_9P_getattr_flags = -1;
-static gint ett_9P_setattr_flags = -1;
-static gint ett_9P_lflags = -1;
+static gint ett_9P;
+static gint ett_9P_omode;
+static gint ett_9P_dm;
+static gint ett_9P_wname;
+static gint ett_9P_aname;
+static gint ett_9P_ename;
+static gint ett_9P_uname;
+static gint ett_9P_user;
+static gint ett_9P_group;
+static gint ett_9P_muid;
+static gint ett_9P_filename;
+static gint ett_9P_version;
+static gint ett_9P_qid;
+static gint ett_9P_qidtype;
+static gint ett_9P_getattr_flags;
+static gint ett_9P_setattr_flags;
+static gint ett_9P_lflags;
 
-static expert_field ei_9P_first_250 = EI_INIT;
-static expert_field ei_9P_msgtype = EI_INIT;
+static expert_field ei_9P_first_250;
+static expert_field ei_9P_msgtype;
 
-static wmem_map_t *_9p_hashtable = NULL;
+static wmem_map_t *_9p_hashtable;
 
 static void dissect_9P_dm(tvbuff_t *tvb,  proto_item *tree, int offset, int iscreate);
 static void dissect_9P_qid(tvbuff_t *tvb,  proto_tree *tree, int offset);
@@ -1483,7 +1482,7 @@ static int dissect_9P_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 		if(!pinfo->fd->visited) {
 			_9p_len = tvb_get_letohs(tvb, offset);
 			tvb_s = (char*)tvb_get_string_enc(pinfo->pool, tvb, offset+2, _9p_len, ENC_UTF_8|ENC_NA);
-			conv_set_fid(pinfo, fid, tvb_s, _9p_len+1);
+			conv_set_fid(pinfo, fid, tvb_s, strlen(tvb_s)+1);
 		}
 		offset += _9p_dissect_string(tvb, ninep_tree, offset, hf_9P_aname, ett_9P_aname);
 
@@ -1501,7 +1500,7 @@ static int dissect_9P_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 		fid_path = conv_get_fid(pinfo, fid);
 		proto_item_append_text(ti, " (%s)", fid_path);
 		if (!pinfo->fd->visited) {
-			tmppath = wmem_strbuf_sized_new(pinfo->pool, 0, MAXPATHLEN);
+			tmppath = wmem_strbuf_create(pinfo->pool);
 			wmem_strbuf_append(tmppath, fid_path);
 		}
 		offset += 4;
@@ -1594,7 +1593,7 @@ static int dissect_9P_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 
 		if (!pinfo->fd->visited) {
 			_9p_len = tvb_get_letohs(tvb, offset);
-			tmppath = wmem_strbuf_sized_new(pinfo->pool, 0, MAXPATHLEN);
+			tmppath = wmem_strbuf_create(pinfo->pool);
 			wmem_strbuf_append(tmppath, fid_path);
 			wmem_strbuf_append_c(tmppath, '/');
 			tvb_s = (char*)tvb_get_string_enc(pinfo->pool, tvb, offset+2, _9p_len, ENC_UTF_8|ENC_NA);
@@ -1627,7 +1626,7 @@ static int dissect_9P_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 
 		if (!pinfo->fd->visited) {
 			_9p_len = tvb_get_letohs(tvb, offset);
-			tmppath = wmem_strbuf_sized_new(pinfo->pool, 0, MAXPATHLEN);
+			tmppath = wmem_strbuf_create(pinfo->pool);
 			wmem_strbuf_append(tmppath, fid_path);
 			wmem_strbuf_append_c(tmppath, '/');
 			tvb_s = (char*)tvb_get_string_enc(pinfo->pool, tvb, offset+2, _9p_len, ENC_UTF_8|ENC_NA);
@@ -1972,7 +1971,7 @@ static int dissect_9P_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 
 		if (!pinfo->fd->visited) {
 			_9p_len = tvb_get_letohs(tvb, offset);
-			tmppath = wmem_strbuf_sized_new(pinfo->pool, 0, MAXPATHLEN);
+			tmppath = wmem_strbuf_create(pinfo->pool);
 			wmem_strbuf_append(tmppath, conv_get_fid(pinfo, dfid));
 			wmem_strbuf_append_c(tmppath, '/');
 
@@ -2478,22 +2477,22 @@ void proto_register_9P(void)
 		 {"Temporary file (not backed up)", "9p.dm.temp_file", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x04000000,
 		  NULL, HFILL}},
 		{&hf_9P_dm_read_owner,
-		 {"Read permission for owner", "9p.dm.read_owner", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000400,
+		 {"Read permission for owner", "9p.dm.read_owner", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000100,
 		  NULL, HFILL}},
 		{&hf_9P_dm_write_owner,
-		 {"Write permission for owner", "9p.dm.write_owner", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000200,
+		 {"Write permission for owner", "9p.dm.write_owner", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000080,
 		  NULL, HFILL}},
 		{&hf_9P_dm_exec_owner,
-		 {"Execute permission for owner", "9p.dm.exec_owner", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000100,
+		 {"Execute permission for owner", "9p.dm.exec_owner", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000040,
 		  NULL, HFILL}},
 		{&hf_9P_dm_read_group,
-		 {"Read permission for group", "9p.dm.read_group", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000040,
+		 {"Read permission for group", "9p.dm.read_group", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000020,
 		  NULL, HFILL}},
 		{&hf_9P_dm_write_group,
-		 {"Write permission for group", "9p.dm.write_group", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000020,
+		 {"Write permission for group", "9p.dm.write_group", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000010,
 		  NULL, HFILL}},
 		{&hf_9P_dm_exec_group,
-		 {"Execute permission for group", "9p.dm.exec_group", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000010,
+		 {"Execute permission for group", "9p.dm.exec_group", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000008,
 		  NULL, HFILL}},
 		{&hf_9P_dm_read_others,
 		 {"Read permission for others", "9p.dm.read_others", FT_BOOLEAN, 32, TFS(&tfs_yes_no), 0x00000004,
@@ -2853,14 +2852,12 @@ void proto_register_9P(void)
 	expert_register_field_array(expert_9P, ei, array_length(ei));
 
 	_9p_hashtable = wmem_map_new_autoreset(wmem_epan_scope(), wmem_file_scope(), _9p_hash_hash, _9p_hash_equal);
+
+	ninep_handle = register_dissector("9p", dissect_9P, proto_9P);
 }
 
 void proto_reg_handoff_9P(void)
 {
-	dissector_handle_t ninep_handle;
-
-	ninep_handle = create_dissector_handle(dissect_9P, proto_9P);
-
 	dissector_add_uint_with_preference("tcp.port", NINEPORT, ninep_handle);
 }
 
