@@ -29,7 +29,7 @@
 /*
  */
 static void
-add_value_time_to_tree(guint64 value, int len, proto_tree *tree, tvbuff_t *tvb, int offset, int hf_time_format)
+add_value_time_to_tree(uint64_t value, int len, proto_tree *tree, tvbuff_t *tvb, int offset, int hf_time_format)
 {
     nstime_t dtn_time;
 
@@ -74,51 +74,51 @@ static dissector_handle_t amp_handle;
 void proto_register_amp(void);
 void proto_reg_handoff_amp(void);
 
-static int hf_amp_message_header = -1;
-static int hf_amp_report_bytestring = -1;
-static int hf_amp_report_data = -1;
-static int hf_amp_report_integer8_small = -1;
-static int hf_amp_report_integer = -1;
-static int hf_amp_cbor_header = -1;
-static int hf_amp_primary_timestamp = -1;
-static int hf_amp_agent_name = -1;
-static int hf_amp_text_string = -1;
-static int hf_amp_ari_flags = -1;
-static int hf_ari_value = -1;
-static int hf_ari_struct = -1;
-static int hf_ari_nickname = -1;
-static int hf_ari_parameters = -1;
-static int hf_ari_issuer = -1;
-static int hf_ari_tag = -1;
-static int hf_amp_tnvc_flags = -1;
-static int hf_amp_tnvc_reserved = -1;
-static int hf_amp_tnvc_mixed = -1;
-static int hf_amp_tnvc_typed = -1;
-static int hf_amp_tnvc_name = -1;
-static int hf_amp_tnvc_values = -1;
+static int hf_amp_message_header;
+static int hf_amp_report_bytestring;
+static int hf_amp_report_data;
+static int hf_amp_report_integer8_small;
+static int hf_amp_report_integer;
+static int hf_amp_cbor_header;
+static int hf_amp_primary_timestamp;
+static int hf_amp_agent_name;
+static int hf_amp_text_string;
+static int hf_amp_ari_flags;
+static int hf_ari_value;
+static int hf_ari_struct;
+static int hf_ari_nickname;
+static int hf_ari_parameters;
+static int hf_ari_issuer;
+static int hf_ari_tag;
+static int hf_amp_tnvc_flags;
+static int hf_amp_tnvc_reserved;
+static int hf_amp_tnvc_mixed;
+static int hf_amp_tnvc_typed;
+static int hf_amp_tnvc_name;
+static int hf_amp_tnvc_values;
 
 /* Initialize the protocol and registered fields */
-static int proto_amp = -1;
+static int proto_amp;
 
-static gint ett_amp_message_header = -1;
-static gint ett_amp_proto = -1;
-static gint ett_amp = -1;
-static gint ett_amp_cbor_header = -1;
-static gint ett_amp_message = -1;
-static gint ett_amp_register = -1;
-static gint ett_amp_report_set = -1;
-static gint ett_amp_report = -1;
-static gint ett_amp_tnvc_flags = -1;
-static gint ett_amp_ari_flags = -1;
+static int ett_amp_message_header;
+static int ett_amp_proto;
+static int ett_amp;
+static int ett_amp_cbor_header;
+static int ett_amp_message;
+static int ett_amp_register;
+static int ett_amp_report_set;
+static int ett_amp_report;
+static int ett_amp_tnvc_flags;
+static int ett_amp_ari_flags;
 
-static int hf_amp_reserved = -1;
-static int hf_amp_acl = -1;
-static int hf_amp_nack = -1;
-static int hf_amp_ack = 0;
-static int hf_amp_opcode = -1;
-static int hf_amp_rx_name = -1;
+static int hf_amp_reserved;
+static int hf_amp_acl;
+static int hf_amp_nack;
+static int hf_amp_ack;
+static int hf_amp_opcode;
+static int hf_amp_rx_name;
 
-static expert_field ei_amp_cbor_malformed = EI_INIT;
+static expert_field ei_amp_cbor_malformed;
 
 static const value_string opcode[] = {
     { 0, "Register Agent" },
@@ -127,18 +127,6 @@ static const value_string opcode[] = {
     { 0, NULL }
 };
 
-static const value_string tnvc_yesno[] = {
-    { 0, "no" },
-    { 1, "yes" },
-    { 0, NULL }
-};
-
-static const value_string tnvc_present_notpresent[] = {
-    { 0, "not present" },
-    { 1, "present" },
-    { 0, NULL }
-};
-
 static const value_string amp_ari_struct_type[] = {
     { 0, "Const" },
     { 1, "Control" },
@@ -156,10 +144,6 @@ static const value_string amp_ari_struct_type[] = {
     { 13, "Reserved" },
     { 14, "Reserved" },
     { 15, "Reserved" },
-    { 16, "Reserved" },
-    { 17, "Reserved" },
-    { 18, "Reserved" },
-    { 19, "Reserved" },
     { 0, NULL }
 };
 
@@ -212,9 +196,9 @@ typedef struct {
     int size; // for integers, the value
               // for bytestrings and textstrings, the size of the string
               // for arrays, the number of elements in the array
-    guint64 totalSize; // total size (including size above and any bytestring
+    uint64_t totalSize; // total size (including size above and any bytestring
                        // size).
-    guint64 uint;
+    uint64_t uint;
 } cborObj;
 
 
@@ -231,7 +215,7 @@ static cborObj cbor_info(tvbuff_t *tvb, int offset)
     ret.uint = -1;
     int theSize;
 
-    tmp = tvb_get_guint8(tvb, offset);
+    tmp = tvb_get_uint8(tvb, offset);
 
     offset += 1;
     ret.size += 1;
@@ -245,16 +229,16 @@ static cborObj cbor_info(tvbuff_t *tvb, int offset)
         if ( theSize<24 ) {
             ret.uint = (tmp & 0x1F); // May be actual size or indication of follow-on size
         } else if (theSize==24) { // next byte is uint8_t data
-            ret.uint = tvb_get_guint8(tvb, offset);
+            ret.uint = tvb_get_uint8(tvb, offset);
             ret.size += 1;
         } else if (theSize==25) { // next 2 bytes are uint16_t data
-            ret.uint = tvb_get_guint16(tvb, offset, 0);
+            ret.uint = tvb_get_uint16(tvb, offset, 0);
             ret.size += 2;
         } else if (theSize==26) { // next 4 bytes are uint32_t data
-            ret.uint = tvb_get_guint32(tvb, offset, 0);
+            ret.uint = tvb_get_uint32(tvb, offset, 0);
             ret.size += 4;
         } else if (theSize==27) { // next 8 bytes are uint64_t data
-            ret.uint = tvb_get_guint64(tvb, offset, 0);
+            ret.uint = tvb_get_uint64(tvb, offset, 0);
             ret.size += 8;
         }
         ret.totalSize = ret.size;
@@ -264,16 +248,16 @@ static cborObj cbor_info(tvbuff_t *tvb, int offset)
         if ( theSize<24 ) { // Array size is contained in the identifier byte
             ret.uint = (tmp & 0x1F);
         } else if (theSize==24) { // next byte is uint8_t data (length)
-            ret.uint = tvb_get_guint8(tvb, offset);
+            ret.uint = tvb_get_uint8(tvb, offset);
             ret.size += 1;
         } else if (theSize==25) { // next 2bytes are uint16_t data (length)
-            ret.uint = tvb_get_guint16(tvb, offset, 0);
+            ret.uint = tvb_get_uint16(tvb, offset, 0);
             ret.size += 2;
         } else if (theSize==26) { // next 4bytes are uint32_t data
-            ret.uint = tvb_get_guint32(tvb, offset, 0);
+            ret.uint = tvb_get_uint32(tvb, offset, 0);
             ret.size += 4;
         } else if (theSize==27) { // next byte is uint64_t data
-            ret.uint = tvb_get_guint64(tvb, offset, 0);
+            ret.uint = tvb_get_uint64(tvb, offset, 0);
             ret.size += 8;
         }
         ret.totalSize = ret.size+ret.uint;
@@ -285,19 +269,19 @@ static cborObj cbor_info(tvbuff_t *tvb, int offset)
             ret.uint = (tmp & 0x1F);
         } else if (theSize==24) // next byte is uint8_t data
         {
-            ret.uint = tvb_get_guint8(tvb, offset);
+            ret.uint = tvb_get_uint8(tvb, offset);
             ret.size += 1;
         } else if (theSize==25) // next 2bytes are uint16_t data
         {
-            ret.uint = tvb_get_guint16(tvb, offset, 0);
+            ret.uint = tvb_get_uint16(tvb, offset, 0);
             ret.size += 2;
         } else if (theSize==26) // next 4bytes are uint32_t data
         {
-            ret.uint = tvb_get_guint32(tvb, offset, 0);
+            ret.uint = tvb_get_uint32(tvb, offset, 0);
             ret.size += 4;
         } else if (theSize==27) // next byte is uint64_t data
         {
-            ret.uint = tvb_get_guint64(tvb, offset, 0);
+            ret.uint = tvb_get_uint64(tvb, offset, 0);
             ret.size += 8;
         }
         ret.totalSize = ret.size+ret.uint;
@@ -309,19 +293,19 @@ static cborObj cbor_info(tvbuff_t *tvb, int offset)
             ret.uint = (tmp & 0x1F);
         } else if (theSize==24) // next byte is uint8_t data
         {
-            ret.uint = tvb_get_guint8(tvb, offset);
+            ret.uint = tvb_get_uint8(tvb, offset);
             ret.size += 1;
         } else if (theSize==25) // next 2bytes are uint16_t data
         {
-            ret.uint = tvb_get_guint16(tvb, offset, 0);
+            ret.uint = tvb_get_uint16(tvb, offset, 0);
             ret.size += 2;
         } else if (theSize==26) // next 4bytes are uint32_t data
         {
-            ret.uint = tvb_get_guint32(tvb, offset, 0);
+            ret.uint = tvb_get_uint32(tvb, offset, 0);
             ret.size += 4;
         } else if (theSize==27) // next byte is uint64_t data
         {
-            ret.uint = tvb_get_guint64(tvb, offset, 0);
+            ret.uint = tvb_get_uint64(tvb, offset, 0);
             ret.size += 8;
         }
         // I know how many elements are in the array, but NOT the total
@@ -343,13 +327,13 @@ static cborObj cbor_info(tvbuff_t *tvb, int offset)
         // TODO -- not supported yet.
         break;
     }
-    return(ret);
+    return ret;
 }
 
 void
 dissect_amp_as_subtree(tvbuff_t *tvb,  packet_info *pinfo, proto_tree *tree, int offset)
 {
-    guint64 messages = 0;
+    uint64_t messages = 0;
     unsigned int i=0;
     unsigned int j=0;
     unsigned int k=0;
@@ -402,7 +386,7 @@ dissect_amp_as_subtree(tvbuff_t *tvb,  packet_info *pinfo, proto_tree *tree, int
         // The first byte of this byte string (the AMP message) is going to be the message header
         // This is just a byte, not a CBOR uint8
         int ampHeader;
-        ampHeader = tvb_get_guint8(tvb, offset);
+        ampHeader = tvb_get_uint8(tvb, offset);
         amp_message_tree = proto_tree_add_subtree(amp_tree, tvb, offset, -1,
                                                   ett_amp_message, &amp_message, "AMP Message");
 
@@ -480,8 +464,8 @@ dissect_amp_as_subtree(tvbuff_t *tvb,  packet_info *pinfo, proto_tree *tree, int
                 // Tempate (bytestring); starts with ARI
                 tmpObj3 = cbor_info(tvb, offset);
                 offset += tmpObj3.size;
-                guint8 ariFlags;
-                ariFlags = tvb_get_guint8(tvb, offset);
+                uint8_t ariFlags;
+                ariFlags = tvb_get_uint8(tvb, offset);
 
                 if ( (ariFlags&0x0F)==0x03 ) {
                     // Literal
@@ -551,11 +535,11 @@ dissect_amp_as_subtree(tvbuff_t *tvb,  packet_info *pinfo, proto_tree *tree, int
                     switch ( tmpObj3.type ) {
                     case 0x02: // bytestring
                         // Get the type from the type dictionary
-                        switch ( tvb_get_guint8(tvb, report_types_offset+k) ) {
+                        switch ( tvb_get_uint8(tvb, report_types_offset+k) ) {
                         case 0x12: // string
                             // It's a text string of some size INSIDE a byte string
                             tmpObj4 = cbor_info(tvb, offset+tmpObj3.size);
-                            // printf("tmpObj4.type of (%02x) is (%d)\n", tvb_get_guint8(tvb, offset+tmpObj3.size), tmpObj4.type);
+                            // printf("tmpObj4.type of (%02x) is (%d)\n", tvb_get_uint8(tvb, offset+tmpObj3.size), tmpObj4.type);
                             proto_tree_add_item(amp_report_TNVC_tree, hf_amp_text_string, tvb,
                                         offset+tmpObj3.size+tmpObj4.size,
                                         (int) tmpObj3.uint-tmpObj4.size, 0x00);
@@ -585,7 +569,7 @@ dissect_amp_as_subtree(tvbuff_t *tvb,  packet_info *pinfo, proto_tree *tree, int
                         break;
                     }
                     if ( tmpObj3.totalSize > 0 ) {
-                        DISSECTOR_ASSERT(tmpObj3.totalSize <= G_MAXINT32);
+                        DISSECTOR_ASSERT(tmpObj3.totalSize <= INT32_MAX);
                         offset += (int)tmpObj3.totalSize;
                     } else {
                         break;
@@ -625,7 +609,7 @@ dissect_amp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
   int offset = 0;
   proto_item  *amp_packet;
   proto_item  *amp_tree;
-  gint amp_packet_reported_length;
+  int amp_packet_reported_length;
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, "AMP");
   col_clear(pinfo->cinfo, COL_INFO);
@@ -691,27 +675,27 @@ proto_register_amp(void)
         },
         { &hf_amp_tnvc_mixed,
         { "Mixed", "amp.tnvc.mixed",
-          FT_UINT8, BASE_DEC, VALS(tnvc_yesno), AMP_TNVC_MIXED,
+          FT_BOOLEAN, 8, TFS(&tfs_yes_no), AMP_TNVC_MIXED,
           NULL, HFILL }
         },
         { &hf_amp_tnvc_typed,
         { "TNVC Values are Typed", "amp.tnvc.typed",
-          FT_UINT8, BASE_DEC, VALS(tnvc_yesno), AMP_TNVC_TYPE,
+          FT_BOOLEAN, 8, TFS(&tfs_yes_no), AMP_TNVC_TYPE,
           NULL, HFILL }
         },
         { &hf_amp_tnvc_name,
         { "Name", "amp.tnvc.name",
-          FT_UINT8, BASE_DEC, VALS(tnvc_yesno), AMP_TNVC_NAME,
+          FT_BOOLEAN, 8, TFS(&tfs_yes_no), AMP_TNVC_NAME,
           NULL, HFILL }
         },
         { &hf_amp_tnvc_values,
         { "Values", "amp.tnvc.value",
-          FT_UINT8, BASE_DEC, VALS(tnvc_yesno), AMP_TNVC_VALUE,
+          FT_BOOLEAN, 8, TFS(&tfs_yes_no), AMP_TNVC_VALUE,
           NULL, HFILL }
         },
         { &hf_ari_nickname,
         { "Nickname", "amp.nickname",
-          FT_UINT8, BASE_DEC, VALS(tnvc_present_notpresent), AMP_ARI_NICKNAME,
+          FT_BOOLEAN, 8, TFS(&tfs_present_not_present), AMP_ARI_NICKNAME,
           NULL, HFILL }
         },
         { &hf_amp_ari_flags,
@@ -721,17 +705,17 @@ proto_register_amp(void)
         },
         { &hf_ari_parameters,
         { "Parameters", "amp.parameters",
-          FT_UINT8, BASE_DEC, VALS(tnvc_present_notpresent), AMP_ARI_PARAMETERS,
+          FT_BOOLEAN, 8, TFS(&tfs_present_not_present), AMP_ARI_PARAMETERS,
           NULL, HFILL }
         },
         { &hf_ari_issuer,
         { "Issuer", "amp.issuer",
-          FT_UINT8, BASE_DEC, VALS(tnvc_present_notpresent), AMP_ARI_ISSUER,
+          FT_BOOLEAN, 8, TFS(&tfs_present_not_present), AMP_ARI_ISSUER,
           NULL, HFILL }
         },
         { &hf_ari_tag,
         { "Tag", "amp.tag",
-          FT_UINT8, BASE_DEC, VALS(tnvc_present_notpresent), AMP_ARI_TAG,
+          FT_BOOLEAN, 8, TFS(&tfs_present_not_present), AMP_ARI_TAG,
           NULL, HFILL }
         },
         { &hf_ari_value,
@@ -751,17 +735,17 @@ proto_register_amp(void)
         },
         { &hf_amp_acl,
           { "ACL", "amp.acl",
-          FT_UINT8, BASE_DEC, VALS(tnvc_present_notpresent), AMP_HDR_ACL,
+          FT_BOOLEAN, 8, TFS(&tfs_present_not_present), AMP_HDR_ACL,
           NULL, HFILL }
         },
         { &hf_amp_nack,
           { "NACK", "amp.nack",
-          FT_UINT8, BASE_DEC, VALS(tnvc_present_notpresent), AMP_HDR_NACK,
+          FT_BOOLEAN, 8, TFS(&tfs_present_not_present), AMP_HDR_NACK,
           NULL, HFILL }
         },
         { &hf_amp_ack,
           { "ACK", "amp.ack",
-          FT_UINT8, BASE_DEC, VALS(tnvc_present_notpresent), AMP_HDR_ACK,
+          FT_BOOLEAN, 8, TFS(&tfs_present_not_present), AMP_HDR_ACK,
           NULL, HFILL }
         },
         { &hf_amp_opcode,
@@ -785,7 +769,7 @@ proto_register_amp(void)
     };
 
     /* Setup protocol subtree array */
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_amp,
         &ett_amp_message_header,
         &ett_amp_cbor_header,
