@@ -22,29 +22,29 @@ void proto_reg_handoff_aoe(void);
 static dissector_handle_t aoe_handle;
 
 static int proto_aoe;
-static int hf_aoe_version=-1;
-static int hf_aoe_flags_response=-1;
-static int hf_aoe_flags_error=-1;
-static int hf_aoe_error=-1;
-static int hf_aoe_major=-1;
-static int hf_aoe_minor=-1;
-static int hf_aoe_cmd=-1;
-static int hf_aoe_tag=-1;
-static int hf_aoe_aflags_e=-1;
-static int hf_aoe_aflags_d=-1;
-static int hf_aoe_aflags_a=-1;
-static int hf_aoe_aflags_w=-1;
-static int hf_aoe_err_feature=-1;
-static int hf_aoe_sector_count=-1;
-static int hf_aoe_acmd=-1;
-static int hf_aoe_astatus=-1;
-static int hf_aoe_lba=-1;
-static int hf_aoe_response_in=-1;
-static int hf_aoe_response_to=-1;
-static int hf_aoe_time=-1;
+static int hf_aoe_version;
+static int hf_aoe_flags_response;
+static int hf_aoe_flags_error;
+static int hf_aoe_error;
+static int hf_aoe_major;
+static int hf_aoe_minor;
+static int hf_aoe_cmd;
+static int hf_aoe_tag;
+static int hf_aoe_aflags_e;
+static int hf_aoe_aflags_d;
+static int hf_aoe_aflags_a;
+static int hf_aoe_aflags_w;
+static int hf_aoe_err_feature;
+static int hf_aoe_sector_count;
+static int hf_aoe_acmd;
+static int hf_aoe_astatus;
+static int hf_aoe_lba;
+static int hf_aoe_response_in;
+static int hf_aoe_response_to;
+static int hf_aoe_time;
 
-static gint ett_aoe = -1;
-static gint ett_aoe_flags = -1;
+static int ett_aoe;
+static int ett_aoe_flags;
 
 #define AOE_FLAGS_RESPONSE 0x08
 #define AOE_FLAGS_ERROR    0x04
@@ -112,7 +112,7 @@ static const value_string ata_cmd_vals[] = {
   { 0x90, "Execute device diagnostics" },
   { 0x91, "Initialize device parameters" },
   { 0x92, "Download microcode" },
-  { 0x94, "Standy immediate" },
+  { 0x94, "Standby immediate" },
   { 0x95, "Idle immediate" },
   { 0x96, "Standby" },
   { 0x97, "Idle" },
@@ -131,7 +131,7 @@ static const value_string ata_cmd_vals[] = {
   { 0xcb, "Write dma (no retry)" },
   { 0xde, "Door lock" },
   { 0xdf, "Door unlock" },
-  { 0xe0, "Standy immediate" },
+  { 0xe0, "Standby immediate" },
   { 0xe1, "Idle immediate" },
   { 0xe2, "Standby" },
   { 0xe3, "Idle" },
@@ -153,38 +153,38 @@ static const value_string ata_cmd_vals[] = {
 };
 
 typedef struct ata_info_t {
-  guint32 tag;
+  uint32_t tag;
   void *conversation; /* just used to multiplex different conversations */
-  guint32 request_frame;
-  guint32 response_frame;
+  uint32_t request_frame;
+  uint32_t response_frame;
   nstime_t req_time;
-  guint8 cmd;
+  uint8_t cmd;
 } ata_info_t;
-static wmem_map_t *ata_cmd_unmatched = NULL;
-static wmem_map_t *ata_cmd_matched = NULL;
+static wmem_map_t *ata_cmd_unmatched;
+static wmem_map_t *ata_cmd_matched;
 
-static guint
-ata_cmd_hash_matched(gconstpointer k)
+static unsigned
+ata_cmd_hash_matched(const void *k)
 {
   return GPOINTER_TO_UINT(k);
 }
 
-static gint
-ata_cmd_equal_matched(gconstpointer k1, gconstpointer k2)
+static int
+ata_cmd_equal_matched(const void *k1, const void *k2)
 {
   return k1==k2;
 }
 
-static guint
-ata_cmd_hash_unmatched(gconstpointer k)
+static unsigned
+ata_cmd_hash_unmatched(const void *k)
 {
   const ata_info_t *key = (const ata_info_t *)k;
 
   return key->tag;
 }
 
-static gint
-ata_cmd_equal_unmatched(gconstpointer k1, gconstpointer k2)
+static int
+ata_cmd_equal_unmatched(const void *k1, const void *k2)
 {
   const ata_info_t *key1 = (const ata_info_t *)k1;
   const ata_info_t *key2 = (const ata_info_t *)k2;
@@ -193,11 +193,11 @@ ata_cmd_equal_unmatched(gconstpointer k1, gconstpointer k2)
 }
 
 static void
-dissect_ata_pdu(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gboolean response, guint32 tag)
+dissect_ata_pdu(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, bool response, uint32_t tag)
 {
   proto_item *tmp_item;
-  guint8 aflags;
-  guint64 lba;
+  uint8_t aflags;
+  uint64_t lba;
   ata_info_t *ata_info=NULL;
   conversation_t *conversation;
 
@@ -214,7 +214,7 @@ dissect_ata_pdu(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset,
       ata_info->conversation=conversation;
       ata_info->request_frame=pinfo->num;
       ata_info->response_frame=0;
-      ata_info->cmd=tvb_get_guint8(tvb, offset+3);
+      ata_info->cmd=tvb_get_uint8(tvb, offset+3);
       ata_info->req_time=pinfo->abs_ts;
 
       tmp_ata_info=(ata_info_t *)wmem_map_lookup(ata_cmd_unmatched, ata_info);
@@ -261,7 +261,7 @@ dissect_ata_pdu(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset,
   }
 
   /* aflags */
-  aflags=tvb_get_guint8(tvb, offset);
+  aflags=tvb_get_uint8(tvb, offset);
   proto_tree_add_item(tree, hf_aoe_aflags_e, tvb, offset, 1, ENC_BIG_ENDIAN);
   if(aflags&AOE_AFLAGS_E){
     proto_tree_add_item(tree, hf_aoe_aflags_d, tvb, offset, 1, ENC_BIG_ENDIAN);
@@ -283,7 +283,7 @@ dissect_ata_pdu(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset,
   /* ata command/status */
   if(!response){
     proto_tree_add_item(tree, hf_aoe_acmd, tvb, offset, 1, ENC_BIG_ENDIAN);
-    col_append_fstr(pinfo->cinfo, COL_INFO, " ATA:%s", val_to_str(tvb_get_guint8(tvb, offset), ata_cmd_vals, " Unknown ATA<0x%02x>"));
+    col_append_fstr(pinfo->cinfo, COL_INFO, " ATA:%s", val_to_str(tvb_get_uint8(tvb, offset), ata_cmd_vals, " Unknown ATA<0x%02x>"));
   } else {
     proto_tree_add_item(tree, hf_aoe_astatus, tvb, offset, 1, ENC_BIG_ENDIAN);
     if(ata_info != NULL && ata_info->request_frame){
@@ -306,13 +306,13 @@ dissect_ata_pdu(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset,
 static void
 dissect_aoe_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-  guint8 flags, cmd;
-  guint32 tag;
+  uint8_t flags, cmd;
+  uint32_t tag;
   proto_item *flags_item;
   proto_tree *flags_tree;
 
   /* read and dissect the flags */
-  flags=tvb_get_guint8(tvb, 0)&0x0f;
+  flags=tvb_get_uint8(tvb, 0)&0x0f;
 
   flags_tree=proto_tree_add_subtree(tree, tvb, 0, 1, ett_aoe_flags, &flags_item, "Flags:");
 
@@ -325,7 +325,7 @@ dissect_aoe_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   if(flags&AOE_FLAGS_ERROR){
     proto_item_append_text(flags_item, " Error");
     proto_tree_add_item(tree, hf_aoe_error, tvb, 1, 1, ENC_BIG_ENDIAN);
-    col_append_fstr(pinfo->cinfo, COL_INFO, "Error:%s ", val_to_str(tvb_get_guint8(tvb, 1), error_vals, "Unknown error<%d>"));
+    col_append_fstr(pinfo->cinfo, COL_INFO, "Error:%s ", val_to_str(tvb_get_uint8(tvb, 1), error_vals, "Unknown error<%d>"));
   }
 
   /* major/minor address */
@@ -333,7 +333,7 @@ dissect_aoe_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   proto_tree_add_item(tree, hf_aoe_minor, tvb, 4, 1, ENC_BIG_ENDIAN);
 
   /* command */
-  cmd=tvb_get_guint8(tvb, 5);
+  cmd=tvb_get_uint8(tvb, 5);
   proto_tree_add_item(tree, hf_aoe_cmd, tvb, 5, 1, ENC_BIG_ENDIAN);
   col_append_fstr(pinfo->cinfo, COL_INFO, "%s %s", val_to_str(cmd, cmd_vals, "Unknown command<%d>"), (flags&AOE_FLAGS_RESPONSE)?"Response":"Request");
 
@@ -358,7 +358,7 @@ dissect_aoe(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void* da
 {
   proto_item *item;
   proto_tree *tree;
-  guint8 version;
+  uint8_t version;
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, "AoE");
   col_clear(pinfo->cinfo, COL_INFO);
@@ -366,7 +366,7 @@ dissect_aoe(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void* da
   item = proto_tree_add_item(parent_tree, proto_aoe, tvb, 0, -1, ENC_NA);
   tree = proto_item_add_subtree(item, ett_aoe);
 
-  version=tvb_get_guint8(tvb, 0)>>4;
+  version=tvb_get_uint8(tvb, 0)>>4;
   proto_tree_add_uint(tree, hf_aoe_version, tvb, 0, 1, version);
   switch(version){
   case 1:
@@ -434,7 +434,7 @@ proto_register_aoe(void)
       { "Time from request", "aoe.time", FT_RELATIVE_TIME, BASE_NONE, NULL, 0, "Time between Request and Reply for ATA calls", HFILL }},
   };
 
-  static gint *ett[] = {
+  static int *ett[] = {
     &ett_aoe,
     &ett_aoe_flags,
   };
