@@ -37,21 +37,23 @@
 void proto_register_aruba_iap(void);
 void proto_reg_handoff_aruba_iap(void);
 
-static int proto_aruba_iap = -1;
-static gint ett_aruba_iap  = -1;
+static dissector_handle_t iap_handle;
 
-static int hf_iap_magic = -1;
-static int hf_iap_version = -1;
-static int hf_iap_type = -1;
-static int hf_iap_length = -1;
-static int hf_iap_id = -1;
-static int hf_iap_status = -1;
-static int hf_iap_uptime = -1;
-static int hf_iap_vc_ip = -1;
-static int hf_iap_pvid = -1;
-static int hf_iap_model = -1;
-static int hf_iap_unknown_uint = -1;
-static int hf_iap_unknown_bytes = -1;
+static int proto_aruba_iap;
+static int ett_aruba_iap;
+
+static int hf_iap_magic;
+static int hf_iap_version;
+static int hf_iap_type;
+static int hf_iap_length;
+static int hf_iap_id;
+static int hf_iap_status;
+static int hf_iap_uptime;
+static int hf_iap_vc_ip;
+static int hf_iap_pvid;
+static int hf_iap_model;
+static int hf_iap_unknown_uint;
+static int hf_iap_unknown_bytes;
 
 static const value_string iap_model[] = {
     { 0x0a, "Orion (IAP-104, IAP-105, IAP-175, RAP-3WN and RAP-3WNP)" },
@@ -67,6 +69,7 @@ static const value_string iap_model[] = {
     { 0x37, "Draco (IAP-344/345)" },
     { 0x39, "Scorpio (IAP-514 and IAP-515)" },
     { 0x40, "Gemini (IAP-500 Series)" },
+    { 0x47, "Norma (IAP-635)" },
     { 0, NULL }
 };
 
@@ -75,8 +78,8 @@ dissect_aruba_iap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* dat
 {
     proto_tree *ti;
     proto_tree *aruba_iap_tree;
-    guint16 magic;
-    guint8 type;
+    uint16_t magic;
+    uint8_t type;
     int offset = 0;
 
     magic = tvb_get_ntohs(tvb, offset);
@@ -100,7 +103,7 @@ dissect_aruba_iap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* dat
     col_add_fstr(pinfo->cinfo, COL_INFO, "Aruba Instant AP");
 
     proto_tree_add_item(aruba_iap_tree, hf_iap_type, tvb, offset, 1, ENC_BIG_ENDIAN);
-    type = tvb_get_guint8(tvb, offset);
+    type = tvb_get_uint8(tvb, offset);
     offset += 1;
 
     proto_tree_add_item(aruba_iap_tree, hf_iap_length, tvb, offset, 1, ENC_BIG_ENDIAN);
@@ -118,7 +121,7 @@ dissect_aruba_iap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* dat
         offset += 4;
 
         proto_tree_add_item(aruba_iap_tree, hf_iap_vc_ip, tvb, offset, 4, ENC_BIG_ENDIAN);
-        col_append_fstr(pinfo->cinfo, COL_INFO, " VC IP: %s", tvb_ip_to_str(tvb, offset));
+        col_append_fstr(pinfo->cinfo, COL_INFO, " VC IP: %s", tvb_ip_to_str(pinfo->pool, tvb, offset));
         offset += 4;
 
         proto_tree_add_item(aruba_iap_tree, hf_iap_model, tvb, offset, 1, ENC_BIG_ENDIAN);
@@ -194,7 +197,7 @@ proto_register_aruba_iap(void)
 
     };
 
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_aruba_iap,
     };
 
@@ -202,15 +205,14 @@ proto_register_aruba_iap(void)
                     "aruba_iap", "aruba_iap");
     proto_register_field_array(proto_aruba_iap, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+
+    iap_handle = register_dissector("aruba_iap", dissect_aruba_iap, proto_aruba_iap);
 }
 
 
 void
 proto_reg_handoff_aruba_iap(void)
 {
-    dissector_handle_t iap_handle;
-
-    iap_handle = create_dissector_handle(dissect_aruba_iap, proto_aruba_iap);
     dissector_add_uint("ethertype", ETHERTYPE_IAP, iap_handle);
 }
 
