@@ -7,6 +7,8 @@
  *   5883: Bidirectional Forwarding Detection (BFD) for Multihop Paths
  *   5884: Bidirectional Forwarding Detection (BFD) for MPLS Label Switched Paths (LSPs)
  *   5885: Bidirectional Forwarding Detection (BFD) for the Pseudowire Virtual Circuit Connectivity Verification (VCCV)
+ *   7130: Bidirectional Forwarding Detection (BFD) on Link Aggregation Group (LAG) Interfaces
+ *   7881: Seamless Bidirectional Forwarding Detection (S-BFD) for IPv4, IPv6, and MPLS
  * (and https://tools.ietf.org/html/draft-ietf-bfd-base-01 for version 0)
  *
  * Copyright 2003, Hannes Gredler <hannes@juniper.net>
@@ -37,8 +39,13 @@
 void proto_register_bfd(void);
 void proto_reg_handoff_bfd(void);
 
+static dissector_handle_t bfd_control_handle;
+static dissector_handle_t bfd_echo_handle;
+
 /* 3784: BFD control, 3785: BFD echo, 4784: BFD multi hop control */
-#define UDP_PORT_RANGE_BFD_CTRL  "3784,4784"
+/* 6784: BFD on LAG, 7784: seamless BFD */
+/* https://www.iana.org/assignments/service-names-port-numbers/service-names-port-numbers.xhtml?search=bfd */
+#define UDP_PORT_RANGE_BFD_CTRL  "3784,4784,6784,7784"
 #define UDP_PORT_BFD_ECHO  3785
 
 /* As per RFC 6428 : https://tools.ietf.org/html/rfc6428
@@ -111,61 +118,61 @@ static const value_string bfd_control_auth_type_values[] = {
 #define SHA1_AUTH_LEN 28
 #define SHA1_CHECKSUM_LEN 20
 
-static gint proto_bfd = -1;
-static gint proto_bfd_echo = -1;
+static int proto_bfd;
+static int proto_bfd_echo;
 
-static gint hf_bfd_version = -1;
-static gint hf_bfd_diag = -1;
-static gint hf_bfd_sta = -1;
-static gint hf_bfd_flags = -1;
-static gint hf_bfd_flags_h = -1;
-static gint hf_bfd_flags_p = -1;
-static gint hf_bfd_flags_f = -1;
-static gint hf_bfd_flags_c = -1;
-static gint hf_bfd_flags_a = -1;
-static gint hf_bfd_flags_d = -1;
-static gint hf_bfd_flags_m = -1;
-static gint hf_bfd_flags_d_v0 = -1;
-static gint hf_bfd_flags_p_v0 = -1;
-static gint hf_bfd_flags_f_v0 = -1;
-static gint hf_bfd_detect_time_multiplier = -1;
-static gint hf_bfd_message_length = -1;
-static gint hf_bfd_my_discriminator = -1;
-static gint hf_bfd_your_discriminator = -1;
-static gint hf_bfd_desired_min_tx_interval = -1;
-static gint hf_bfd_required_min_rx_interval = -1;
-static gint hf_bfd_required_min_echo_interval = -1;
-static gint hf_bfd_checksum = -1;
+static int hf_bfd_version;
+static int hf_bfd_diag;
+static int hf_bfd_sta;
+static int hf_bfd_flags;
+static int hf_bfd_flags_h;
+static int hf_bfd_flags_p;
+static int hf_bfd_flags_f;
+static int hf_bfd_flags_c;
+static int hf_bfd_flags_a;
+static int hf_bfd_flags_d;
+static int hf_bfd_flags_m;
+static int hf_bfd_flags_d_v0;
+static int hf_bfd_flags_p_v0;
+static int hf_bfd_flags_f_v0;
+static int hf_bfd_detect_time_multiplier;
+static int hf_bfd_message_length;
+static int hf_bfd_my_discriminator;
+static int hf_bfd_your_discriminator;
+static int hf_bfd_desired_min_tx_interval;
+static int hf_bfd_required_min_rx_interval;
+static int hf_bfd_required_min_echo_interval;
+static int hf_bfd_checksum;
 
-static gint hf_bfd_auth_type = -1;
-static gint hf_bfd_auth_len = -1;
-static gint hf_bfd_auth_key = -1;
-static gint hf_bfd_auth_password = -1;
-static gint hf_bfd_auth_seq_num = -1;
+static int hf_bfd_auth_type;
+static int hf_bfd_auth_len;
+static int hf_bfd_auth_key;
+static int hf_bfd_auth_password;
+static int hf_bfd_auth_seq_num;
 
-static gint hf_bfd_echo = -1;
+static int hf_bfd_echo;
 
-static gint ett_bfd = -1;
-static gint ett_bfd_flags = -1;
-static gint ett_bfd_auth = -1;
+static int ett_bfd;
+static int ett_bfd_flags;
+static int ett_bfd_auth;
 
-static gint ett_bfd_echo = -1;
+static int ett_bfd_echo;
 
-static expert_field ei_bfd_auth_len_invalid = EI_INIT;
-static expert_field ei_bfd_auth_no_data = EI_INIT;
+static expert_field ei_bfd_auth_len_invalid;
+static expert_field ei_bfd_auth_no_data;
 
-static gint hf_mep_type = -1;
-static gint hf_mep_len = -1;
-static gint hf_mep_global_id = -1;
-static gint hf_mep_node_id = -1;
-/* static gint hf_mep_interface_no = -1; */
-static gint hf_mep_tunnel_no = -1;
-static gint hf_mep_lsp_no = -1;
-static gint hf_mep_ac_id = -1;
-static gint hf_mep_agi_type = -1;
-static gint hf_mep_agi_len = -1;
-static gint hf_mep_agi_val = -1;
-static gint hf_section_interface_no = -1;
+static int hf_mep_type;
+static int hf_mep_len;
+static int hf_mep_global_id;
+static int hf_mep_node_id;
+/* static int hf_mep_interface_no; */
+static int hf_mep_tunnel_no;
+static int hf_mep_lsp_no;
+static int hf_mep_ac_id;
+static int hf_mep_agi_type;
+static int hf_mep_agi_len;
+static int hf_mep_agi_val;
+static int hf_section_interface_no;
 /*
  * Control packet version 0, draft-katz-ward-bfd-01.txt
  *
@@ -261,10 +268,10 @@ static gint hf_section_interface_no = -1;
 /* Given the type of authentication being used, return the required length of
  * the authentication header
  */
-static guint8
-get_bfd_required_auth_len(guint8 auth_type)
+static uint8_t
+get_bfd_required_auth_len(uint8_t auth_type)
 {
-    guint8 auth_len = 0;
+    uint8_t auth_len = 0;
 
     switch (auth_type) {
         case BFD_AUTH_MD5:
@@ -284,10 +291,10 @@ get_bfd_required_auth_len(guint8 auth_type)
 /* Given the type of authentication being used, return the length of
  * checksum field
  */
-static guint8
-get_bfd_checksum_len(guint8 auth_type)
+static uint8_t
+get_bfd_checksum_len(uint8_t auth_type)
 {
-    guint8 checksum_len = 0;
+    uint8_t checksum_len = 0;
     switch (auth_type) {
         case BFD_AUTH_MD5:
         case BFD_AUTH_MET_MD5:
@@ -307,14 +314,14 @@ static void
 dissect_bfd_authentication(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     int           offset    = 24;
-    guint8        auth_type;
-    guint8        auth_len;
+    uint8_t       auth_type;
+    uint8_t       auth_len;
     proto_item   *auth_item = NULL;
     proto_tree   *auth_tree = NULL;
-    const guint8 *password;
+    const uint8_t *password;
 
-    auth_type = tvb_get_guint8(tvb, offset);
-    auth_len  = tvb_get_guint8(tvb, offset + 1);
+    auth_type = tvb_get_uint8(tvb, offset);
+    auth_len  = tvb_get_uint8(tvb, offset + 1);
 
     if (tree) {
         auth_tree = proto_tree_add_subtree_format(tree, tvb, offset, auth_len,
@@ -333,7 +340,7 @@ dissect_bfd_authentication(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     switch (auth_type) {
         case BFD_AUTH_SIMPLE:
             proto_tree_add_item_ret_string(auth_tree, hf_bfd_auth_password, tvb, offset+3,
-                                    auth_len-3, ENC_ASCII|ENC_NA, wmem_packet_scope(), &password);
+                                    auth_len-3, ENC_ASCII|ENC_NA, pinfo->pool, &password);
             proto_item_append_text(auth_item, ": %s", password);
             break;
         case BFD_AUTH_MD5:
@@ -363,7 +370,7 @@ static int
 dissect_bfd_echo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
     proto_tree *bfd_tree = NULL;
-    guint bfd_length = tvb_reported_length_remaining(tvb, 0);
+    unsigned bfd_length = tvb_reported_length_remaining(tvb, 0);
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "BFD Echo");
     /* XXX Add direction */
@@ -386,27 +393,27 @@ dissect_bfd_echo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
 static int
 dissect_bfd_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
-    guint flags;
-    guint bfd_version;
-    guint bfd_diag;
-    guint bfd_sta        = 0;
-    guint bfd_flags;
-    guint bfd_flags_a    = 0;
-    guint bfd_detect_time_multiplier;
-    guint bfd_length;
-    guint bfd_my_discriminator;
-    guint bfd_your_discriminator;
-    guint bfd_desired_min_tx_interval;
-    guint bfd_required_min_rx_interval;
-    guint bfd_required_min_echo_interval;
+    unsigned flags;
+    unsigned bfd_version;
+    unsigned bfd_diag;
+    unsigned bfd_sta        = 0;
+    unsigned bfd_flags;
+    unsigned bfd_flags_a    = 0;
+    unsigned bfd_detect_time_multiplier;
+    unsigned bfd_length;
+    unsigned bfd_my_discriminator;
+    unsigned bfd_your_discriminator;
+    unsigned bfd_desired_min_tx_interval;
+    unsigned bfd_required_min_rx_interval;
+    unsigned bfd_required_min_echo_interval;
     proto_tree *bfd_tree = NULL;
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "BFD Control");
     col_clear(pinfo->cinfo, COL_INFO);
 
-    bfd_version = (tvb_get_guint8(tvb, 0) & 0xe0) >> 5;
-    bfd_diag    = (tvb_get_guint8(tvb, 0) & 0x1f);
-    flags       = tvb_get_guint8(tvb, 1);
+    bfd_version = (tvb_get_uint8(tvb, 0) & 0xe0) >> 5;
+    bfd_diag    = (tvb_get_uint8(tvb, 0) & 0x1f);
+    flags       = tvb_get_uint8(tvb, 1);
     switch (bfd_version) {
         case 0:
             bfd_flags      = flags;
@@ -419,8 +426,8 @@ dissect_bfd_control(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* d
             break;
     }
 
-    bfd_detect_time_multiplier     = tvb_get_guint8(tvb, 2);
-    bfd_length                     = tvb_get_guint8(tvb, 3);
+    bfd_detect_time_multiplier     = tvb_get_uint8(tvb, 2);
+    bfd_length                     = tvb_get_uint8(tvb, 3);
     bfd_my_discriminator           = tvb_get_ntohl(tvb, 4);
     bfd_your_discriminator         = tvb_get_ntohl(tvb, 8);
     bfd_desired_min_tx_interval    = tvb_get_ntohl(tvb, 12);
@@ -552,10 +559,10 @@ dissect_bfd_mep (tvbuff_t *tvb, proto_tree *tree, const int hfindex)
 {
     proto_item *ti;
     proto_tree *bfd_tree;
-    gint        offset = 0;
-    gint        mep_type;
-    gint        mep_len;
-    gint        mep_agi_len;
+    int         offset = 0;
+    int         mep_type;
+    int         mep_len;
+    int         mep_agi_len;
 
     if (!tree)
         return;
@@ -570,7 +577,7 @@ dissect_bfd_mep (tvbuff_t *tvb, proto_tree *tree, const int hfindex)
        under a particular protocol-tree. */
     if (!hfindex)
       {
-        offset   = tvb_get_guint8(tvb, 3);
+        offset   = tvb_get_uint8(tvb, 3);
         mep_type = tvb_get_ntohs (tvb, offset);
         mep_len  = tvb_get_ntohs (tvb, (offset + 2));
         ti       = proto_tree_add_protocol_format (tree, proto_bfd, tvb, offset, (mep_len + 4),
@@ -621,7 +628,7 @@ dissect_bfd_mep (tvbuff_t *tvb, proto_tree *tree, const int hfindex)
 
         case TLV_TYPE_MPLSTP_PW_MEP:
 
-            mep_agi_len   = tvb_get_guint8 (tvb, (offset + 17));
+            mep_agi_len   = tvb_get_uint8 (tvb, (offset + 17));
             bfd_tree = proto_item_add_subtree (ti, ett_bfd);
             proto_tree_add_uint (bfd_tree, hf_mep_type, tvb, offset,
                                  2, (mep_type));
@@ -638,7 +645,7 @@ dissect_bfd_mep (tvbuff_t *tvb, proto_tree *tree, const int hfindex)
             proto_tree_add_uint (bfd_tree, hf_mep_agi_len, tvb, (offset + 17),
                                  1, mep_agi_len);
             proto_tree_add_item (bfd_tree, hf_mep_agi_val, tvb, (offset + 18),
-                                 mep_agi_len, ENC_ASCII|ENC_NA);
+                                 mep_agi_len, ENC_ASCII);
 
             break;
 
@@ -865,7 +872,7 @@ proto_register_bfd(void)
     };
 
     /* Setup protocol subtree array */
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_bfd,
         &ett_bfd_flags,
         &ett_bfd_auth,
@@ -893,17 +900,15 @@ proto_register_bfd(void)
     proto_register_subtree_array(ett, array_length(ett));
     expert_bfd = expert_register_protocol(proto_bfd);
     expert_register_field_array(expert_bfd, ei, array_length(ei));
+
+    /* Register dissectors */
+    bfd_control_handle = register_dissector("bfd", dissect_bfd_control, proto_bfd);
+    bfd_echo_handle = register_dissector("bfd_echo", dissect_bfd_echo, proto_bfd_echo);
 }
 
 void
 proto_reg_handoff_bfd(void)
 {
-    dissector_handle_t bfd_control_handle;
-    dissector_handle_t bfd_echo_handle;
-
-    bfd_control_handle = create_dissector_handle(dissect_bfd_control, proto_bfd);
-    bfd_echo_handle = create_dissector_handle(dissect_bfd_echo, proto_bfd_echo);
-
     dissector_add_uint_range_with_preference("udp.port", UDP_PORT_RANGE_BFD_CTRL, bfd_control_handle);
     dissector_add_uint("udp.port", UDP_PORT_BFD_ECHO, bfd_echo_handle);
 
