@@ -16,6 +16,7 @@
 #include <epan/conversation.h>
 #include <epan/exceptions.h>
 #include <epan/show_exception.h>
+#include <epan/expert.h>
 #include <epan/prefs.h>
 #include <epan/proto_data.h>
 #include <epan/reassemble.h>
@@ -49,6 +50,7 @@ enum {
   EXT_NO_EXTENSION    = 0,
   EXT_SELECTIVE_ACKS  = 1,
   EXT_EXTENSION_BITS  = 2,
+  EXT_CLOSE_REASON    = 3,
   EXT_NUM_EXT
 };
 
@@ -56,10 +58,66 @@ static const value_string bt_utp_extension_type_vals[] = {
   { EXT_NO_EXTENSION,   "No Extension" },
   { EXT_SELECTIVE_ACKS, "Selective ACKs" },
   { EXT_EXTENSION_BITS, "Extension bits" },
+  { EXT_CLOSE_REASON,   "Close reason" },
   { 0, NULL }
 };
 
-static int proto_bt_utp = -1;
+/* https://github.com/arvidn/libtorrent/blob/master/include/libtorrent/close_reason.hpp */
+static const value_string bt_utp_close_reason_vals[] = {
+  {  0, "None" },
+  {  1, "Duplicate peer ID" },
+  {  2, "Torrent removed" },
+  {  3, "Memory allocation failed" },
+  {  4, "Port blocked" },
+  {  5, "Address blocked" },
+  {  6, "Upload to upload" },
+  {  7, "Not interested upload only" },
+  {  8, "Timeout" },
+  {  9, "Timeout: interest" },
+  { 10, "Timeout: activity" },
+  { 11, "Timeout: handshake" },
+  { 12, "Timeout: request" },
+  { 13, "Protocol blocked" },
+  { 14, "Peer churn" },
+  { 15, "Too many connections" },
+  { 16, "Too many files" },
+  /* Reasons caused by the peer sending unexpected data are 256 and up */
+  {256, "Encryption error" },
+  {257, "Invalid info hash" },
+  {258, "Self connection" },
+  {259, "Invalid metadata" },
+  {260, "Metadata too big" },
+  {261, "Message too big" },
+  {262, "Invalid message id" },
+  {263, "Invalid message" },
+  {264, "Invalid piece message" },
+  {265, "Invalid have message" },
+  {266, "Invalid bitfield message" },
+  {267, "Invalid choke message" },
+  {268, "Invalid unchoke message" },
+  {269, "Invalid interested message" },
+  {270, "Invalid not interested message" },
+  {271, "Invalid request message" },
+  {272, "Invalid reject message" },
+  {273, "Invalid allow fast message" },
+  {274, "Invalid extended message" },
+  {275, "Invalid cancel message" },
+  {276, "Invalid DHT port message" },
+  {277, "Invalid suggest message" },
+  {278, "Invalid have all message" },
+  {279, "Invalid don't have message" },
+  {280, "Invalid PEX message" },
+  {281, "Invalid metadata request message" },
+  {282, "Invalid metadata message" },
+  {283, "Invalid metadata offset" },
+  {284, "Request when choked" },
+  {285, "Corrupt pieces" },
+  {286, "PEX message too big" },
+  {287, "PEX too frequent" },
+  {  0, NULL }
+};
+
+static int proto_bt_utp;
 
 /* ---  "Original" uTP Header ("version 0" ?) --------------
 
@@ -134,68 +192,71 @@ Fields Types
 static dissector_handle_t bt_utp_handle;
 static dissector_handle_t bittorrent_handle;
 
-static int hf_bt_utp_ver = -1;
-static int hf_bt_utp_type = -1;
-static int hf_bt_utp_flags = -1;
-static int hf_bt_utp_extension = -1;
-static int hf_bt_utp_next_extension_type = -1;
-static int hf_bt_utp_extension_len = -1;
-static int hf_bt_utp_extension_bitmask = -1;
-static int hf_bt_utp_extension_unknown = -1;
-static int hf_bt_utp_connection_id_v0 = -1;
-static int hf_bt_utp_connection_id_v1 = -1;
-static int hf_bt_utp_stream = -1;
-static int hf_bt_utp_timestamp_sec = -1;
-static int hf_bt_utp_timestamp_us = -1;
-static int hf_bt_utp_timestamp_diff_us = -1;
-static int hf_bt_utp_wnd_size_v0 = -1;
-static int hf_bt_utp_wnd_size_v1 = -1;
-static int hf_bt_utp_seq_nr = -1;
-static int hf_bt_utp_ack_nr = -1;
-static int hf_bt_utp_len = -1;
-static int hf_bt_utp_data = -1;
-static int hf_bt_utp_pdu_size = -1;
-static int hf_bt_utp_continuation_to = -1;
+static int hf_bt_utp_ver;
+static int hf_bt_utp_type;
+static int hf_bt_utp_flags;
+static int hf_bt_utp_extension;
+static int hf_bt_utp_next_extension_type;
+static int hf_bt_utp_extension_len;
+static int hf_bt_utp_extension_bitmask;
+static int hf_bt_utp_extension_close_reason;
+static int hf_bt_utp_extension_unknown;
+static int hf_bt_utp_connection_id_v0;
+static int hf_bt_utp_connection_id_v1;
+static int hf_bt_utp_stream;
+static int hf_bt_utp_timestamp_sec;
+static int hf_bt_utp_timestamp_us;
+static int hf_bt_utp_timestamp_diff_us;
+static int hf_bt_utp_wnd_size_v0;
+static int hf_bt_utp_wnd_size_v1;
+static int hf_bt_utp_seq_nr;
+static int hf_bt_utp_ack_nr;
+static int hf_bt_utp_len;
+static int hf_bt_utp_data;
+static int hf_bt_utp_pdu_size;
+static int hf_bt_utp_continuation_to;
 
-static gint ett_bt_utp = -1;
-static gint ett_bt_utp_extension = -1;
+static expert_field ei_extension_len_invalid;
 
-static gboolean enable_version0 = FALSE;
-static guint max_window_size = V1_MAX_WINDOW_SIZE;
-/* XXX: Desegementation and OOO-reassembly are not supported yet */
-static gboolean utp_desegment = FALSE;
-/*static gboolean utp_reassemble_out_of_order = FALSE;*/
-static gboolean utp_analyze_seq = TRUE;
+static int ett_bt_utp;
+static int ett_bt_utp_extension;
 
-static guint32 bt_utp_stream_count = 0;
+static bool enable_version0;
+static unsigned max_window_size = V1_MAX_WINDOW_SIZE;
+/* XXX: Desegmentation and OOO-reassembly are not supported yet */
+static bool utp_desegment;
+/*static bool utp_reassemble_out_of_order = false;*/
+static bool utp_analyze_seq = true;
+
+static uint32_t bt_utp_stream_count;
 
 typedef struct _utp_multisegment_pdu {
 
-  guint16 first_seq;
-  guint16 last_seq;
-  guint first_seq_start_offset;
-  guint last_seq_end_offset;
-  /*gint length;
-  guint32 reassembly_id;*/
-  guint32 first_frame;
+  uint16_t first_seq;
+  uint16_t last_seq;
+  unsigned first_seq_start_offset;
+  unsigned last_seq_end_offset;
+  /*int length;
+  uint32_t reassembly_id;*/
+  uint32_t first_frame;
 
 } utp_multisegment_pdu;
 
 typedef struct _utp_flow_t {
 #if 0
   /* XXX: Some other things to add in later. */
-  gboolean base_seq_set;
-  guint16 base_seq;
-  guint32 fin;
-  guint32 window;
-  guint32 maxnextseq;
+  bool base_seq_set;
+  uint16_t base_seq;
+  uint32_t fin;
+  uint32_t window;
+  uint32_t maxnextseq;
 #endif
 
   wmem_tree_t *multisegment_pdus;
 } utp_flow_t;
 
 typedef struct {
-  guint32 stream;
+  uint32_t stream;
 
   utp_flow_t flow[2];
   utp_flow_t *fwd;
@@ -204,20 +265,20 @@ typedef struct {
   /* XXX: Some other things to add in later. */
   nstime_t ts_first;
   nstime_t ts_prev;
-  guint8 conversation_completeness;
+  uint8_t conversation_completeness;
 #endif
 } utp_stream_info_t;
 
 /* Per-packet header information. */
 typedef struct {
-  guint8  type;
-  gboolean v0;
-  guint32 connection; /* The prelease "V0" version is 32 bit */
-  guint32 stream;
-  guint16 seq;
-  guint16 ack;
-  guint32 seglen; /* reported length remaining */
-  gboolean have_seglen;
+  uint8_t type;
+  bool v0;
+  uint32_t connection; /* The prelease "V0" version is 32 bit */
+  uint32_t stream;
+  uint16_t seq;
+  uint16_t ack;
+  uint32_t seglen; /* reported length remaining */
+  bool have_seglen;
 
   proto_tree *tree; /* For the bittorrent subdissector to access */
 } utp_info_t;
@@ -227,7 +288,7 @@ get_utp_stream_info(packet_info *pinfo, utp_info_t *utp_info)
 {
   conversation_t* conv;
   utp_stream_info_t *stream_info;
-  guint32 id_up, id_down;
+  uint32_t id_up, id_down;
   int direction;
 
   /* Handle connection ID wrapping correctly. (Mainline libutp source
@@ -238,15 +299,15 @@ get_utp_stream_info(packet_info *pinfo, utp_info_t *utp_info)
     id_up = utp_info->connection+1;
     id_down = utp_info->connection-1;
   } else {
-    id_up = (guint16)(utp_info->connection+1);
-    id_down = (guint16)(utp_info->connection-1);
+    id_up = (uint16_t)(utp_info->connection+1);
+    id_down = (uint16_t)(utp_info->connection-1);
   }
 
   if (utp_info->type == ST_SYN) {
     /* SYN packets are special, they have the connection ID for the other
      * side, and allow us to know both.
      */
-    conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_BT_UTP,
+    conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, CONVERSATION_BT_UTP,
  id_up, utp_info->connection, 0);
     if (!conv) {
       /* XXX: A SYN for between the same pair of hosts with a duplicate
@@ -257,7 +318,7 @@ get_utp_stream_info(packet_info *pinfo, utp_info_t *utp_info)
        * number matches. (The latter still doesn't help if the client also
        * doesn't start with random sequence numbers.)
        */
-      conv = conversation_new(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_BT_UTP, id_up, utp_info->connection, 0);
+      conv = conversation_new(pinfo->num, &pinfo->src, &pinfo->dst, CONVERSATION_BT_UTP, id_up, utp_info->connection, 0);
     }
   } else {
     /* For non-SYN packets, we know our connection ID, but we don't know if
@@ -267,21 +328,21 @@ get_utp_stream_info(packet_info *pinfo, utp_info_t *utp_info)
      * we have a wildcarded conversation around (if we've seen previous
      * non-SYN packets from our current direction but none in the other.)
      */
-    conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_BT_UTP, utp_info->connection, 0, NO_PORT_B);
+    conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, CONVERSATION_BT_UTP, utp_info->connection, 0, NO_PORT_B);
     if (!conv) {
       /* Do we have a complete conversation originated by our src, or
        * possibly a wildcarded conversation originated in this direction
        * (but we saw a non-SYN for the non-initiating side first)? */
-      conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_BT_UTP, utp_info->connection, id_up, 0);
+      conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, CONVERSATION_BT_UTP, utp_info->connection, id_up, 0);
       if (!conv) {
         /* As above, but dst initiated? */
-        conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_BT_UTP, utp_info->connection, id_down, 0);
+        conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, CONVERSATION_BT_UTP, utp_info->connection, id_down, 0);
         if (!conv) {
           /* Didn't find it, so create a new wildcarded conversation. When we
            * get a packet for the other direction, find_conversation() above
            * will set port2 with the other connection ID.
            */
-          conv = conversation_new(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_BT_UTP, utp_info->connection, 0, NO_PORT2);
+          conv = conversation_new(pinfo->num, &pinfo->src, &pinfo->dst, CONVERSATION_BT_UTP, utp_info->connection, 0, NO_PORT2);
         }
       }
     }
@@ -331,7 +392,7 @@ scan_for_next_pdu(tvbuff_t *tvb, proto_tree *utp_tree, packet_info *pinfo, wmem_
 {
   utp_multisegment_pdu *msp;
   utp_info_t *p_utp_info;
-  guint16 seq, prev_seq;
+  uint16_t seq, prev_seq;
 
   p_utp_info = (utp_info_t *)p_get_proto_data(pinfo->pool, pinfo, proto_bt_utp, pinfo->curr_layer_num);
 
@@ -388,7 +449,7 @@ scan_for_next_pdu(tvbuff_t *tvb, proto_tree *utp_tree, packet_info *pinfo, wmem_
 }
 
 static utp_multisegment_pdu *
-pdu_store_sequencenumber_of_next_pdu(packet_info *pinfo, guint16 seq, int offset, guint32 bytes_until_next_pdu, wmem_tree_t *multisegment_pdus)
+pdu_store_sequencenumber_of_next_pdu(packet_info *pinfo, uint16_t seq, int offset, uint32_t bytes_until_next_pdu, wmem_tree_t *multisegment_pdus)
 {
   utp_multisegment_pdu *msp;
 
@@ -406,7 +467,7 @@ pdu_store_sequencenumber_of_next_pdu(packet_info *pinfo, guint16 seq, int offset
 #if 0
 static void
 desegment_utp(tvbuff_t *tvb, packet_info *pinfo, int offset,
-              guint32 seq, guint32 nxtseq,
+              uint32_t seq, uint32_t nxtseq,
               proto_tree *tree, proto_tree *utp_tree,
               utp_stream_info_t *stream_info)
 {
@@ -416,19 +477,19 @@ desegment_utp(tvbuff_t *tvb, packet_info *pinfo, int offset,
 
 void
 utp_dissect_pdus(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
-                 gboolean proto_desegment, guint fixed_len,
-                 guint (*get_pdu_len)(packet_info *, tvbuff_t *, int, void*),
+                 bool proto_desegment, unsigned fixed_len,
+                 unsigned (*get_pdu_len)(packet_info *, tvbuff_t *, int, void*),
                  dissector_t dissect_pdu, void* dissector_data)
 {
   volatile int offset = 0;
   int offset_before;
-  guint captured_length_remaining;
-  volatile guint plen;
-  guint length;
+  unsigned captured_length_remaining;
+  volatile unsigned plen;
+  unsigned length;
   tvbuff_t *next_tvb;
   proto_item *item=NULL;
   const char *saved_proto;
-  guint8 curr_layer_num;
+  uint8_t curr_layer_num;
   wmem_list_frame_t *frame;
 
   while (tvb_reported_length_remaining(tvb, offset) > 0) {
@@ -476,7 +537,11 @@ utp_dissect_pdus(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
        * Support protocols which have a variable length which cannot
        * always be determined within the given fixed_len.
        */
-      DISSECTOR_ASSERT(proto_desegment && pinfo->can_desegment);
+      /*
+       * If another segment was requested but we can't do reassembly,
+       * abort and warn about the unreassembled packet.
+       */
+      THROW_ON(!(proto_desegment && pinfo->can_desegment), FragmentBoundsError);
       pinfo->desegment_offset = offset;
       pinfo->desegment_len = DESEGMENT_ONE_MORE_SEGMENT;
       return;
@@ -506,7 +571,7 @@ utp_dissect_pdus(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
      * somewhere in the middle of a segment.
      */
     if(!pinfo->fd->visited && utp_analyze_seq) {
-      guint remaining_bytes;
+      unsigned remaining_bytes;
       remaining_bytes = tvb_reported_length_remaining(tvb, offset);
       if(plen>remaining_bytes) {
         pinfo->want_pdu_tracking=2;
@@ -535,7 +600,7 @@ utp_dissect_pdus(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
     curr_layer_num = pinfo->curr_layer_num-1;
     frame = wmem_list_frame_prev(wmem_list_tail(pinfo->layers));
-    while (frame && (proto_bt_utp != (gint) GPOINTER_TO_UINT(wmem_list_frame_data(frame)))) {
+    while (frame && (proto_bt_utp != (int) GPOINTER_TO_UINT(wmem_list_frame_data(frame)))) {
       frame = wmem_list_frame_prev(frame);
       curr_layer_num--;
     }
@@ -612,13 +677,13 @@ utp_dissect_pdus(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   }
 }
 
-static gint
+static int
 get_utp_version(tvbuff_t *tvb) {
-  guint8  v0_flags;
-  guint8  v1_ver_type, ext, ext_len;
-  guint32 window;
-  guint   len, offset = 0;
-  gint    ver = -1;
+  uint8_t v0_flags;
+  uint8_t v1_ver_type, ext, ext_len;
+  uint32_t window;
+  unsigned   len, offset = 0;
+  int     ver = -1;
 
   /* Simple heuristics inspired by code from utp.cpp */
 
@@ -629,11 +694,11 @@ get_utp_version(tvbuff_t *tvb) {
     return -1;
   }
 
-  v1_ver_type = tvb_get_guint8(tvb, 0);
-  ext = tvb_get_guint8(tvb, 1);
+  v1_ver_type = tvb_get_uint8(tvb, 0);
+  ext = tvb_get_uint8(tvb, 1);
   if (((v1_ver_type & 0x0f) == 1) && ((v1_ver_type>>4) < ST_NUM_STATES) &&
       (ext < EXT_NUM_EXT)) {
-    window = tvb_get_guint32(tvb, 12, ENC_BIG_ENDIAN);
+    window = tvb_get_uint32(tvb, 12, ENC_BIG_ENDIAN);
     if (window > max_window_size) {
       return -1;
     }
@@ -644,8 +709,8 @@ get_utp_version(tvbuff_t *tvb) {
     if (len < V0_FIXED_HDR_SIZE) {
       return -1;
     }
-    v0_flags = tvb_get_guint8(tvb, 18);
-    ext = tvb_get_guint8(tvb, 17);
+    v0_flags = tvb_get_uint8(tvb, 18);
+    ext = tvb_get_uint8(tvb, 17);
     if ((v0_flags < ST_NUM_STATES) && (ext < EXT_NUM_EXT)) {
       ver = 0;
       offset = V0_FIXED_HDR_SIZE;
@@ -669,8 +734,8 @@ get_utp_version(tvbuff_t *tvb) {
     if (len < offset + 2) {
       return -1;
     }
-    ext = tvb_get_guint8(tvb, offset);
-    ext_len = tvb_get_guint8(tvb, offset+1);
+    ext = tvb_get_uint8(tvb, offset);
+    ext_len = tvb_get_uint8(tvb, offset+1);
     if (ext >= EXT_NUM_EXT || ext_len < 4) {
       return -1;
     }
@@ -680,17 +745,17 @@ get_utp_version(tvbuff_t *tvb) {
 }
 
 static int
-dissect_utp_header_v0(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, guint8 *extension_type)
+dissect_utp_header_v0(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, uint8_t *extension_type)
 {
   /* "Original" (V0) */
   utp_info_t        *p_utp_info = NULL;
   utp_stream_info_t *stream_info = NULL;
 
   proto_item     *ti;
-  guint32 type, connection, win, seq, ack;
+  uint32_t type, connection, win, seq, ack;
 
   p_utp_info = wmem_new(pinfo->pool, utp_info_t);
-  p_utp_info->v0 = TRUE;
+  p_utp_info->v0 = true;
   p_add_proto_data(pinfo->pool, pinfo, proto_bt_utp, pinfo->curr_layer_num, p_utp_info);
 
   proto_tree_add_item_ret_uint(tree, hf_bt_utp_connection_id_v0, tvb, offset, 4, ENC_BIG_ENDIAN, &connection);
@@ -704,7 +769,7 @@ dissect_utp_header_v0(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
   proto_tree_add_item_ret_uint(tree, hf_bt_utp_wnd_size_v0, tvb, offset, 1, ENC_BIG_ENDIAN, &win);
   offset += 1;
   proto_tree_add_item(tree, hf_bt_utp_next_extension_type, tvb, offset, 1, ENC_BIG_ENDIAN);
-  *extension_type = tvb_get_guint8(tvb, offset);
+  *extension_type = tvb_get_uint8(tvb, offset);
   offset += 1;
   proto_tree_add_item_ret_uint(tree, hf_bt_utp_flags, tvb, offset, 1, ENC_BIG_ENDIAN, &type);
   offset += 1;
@@ -737,7 +802,7 @@ dissect_utp_header_v0(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
 }
 
 static int
-dissect_utp_header_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, guint8 *extension_type)
+dissect_utp_header_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, uint8_t *extension_type)
 {
   /* V1 */
   utp_info_t        *p_utp_info = NULL;
@@ -745,17 +810,17 @@ dissect_utp_header_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
 
   proto_item     *ti;
 
-  guint32 type, connection, win, seq, ack;
+  uint32_t type, connection, win, seq, ack;
 
   p_utp_info = wmem_new(pinfo->pool, utp_info_t);
-  p_utp_info->v0 = FALSE;
+  p_utp_info->v0 = false;
   p_add_proto_data(pinfo->pool, pinfo, proto_bt_utp, pinfo->curr_layer_num, p_utp_info);
 
   proto_tree_add_item(tree, hf_bt_utp_ver, tvb, offset, 1, ENC_BIG_ENDIAN);
   proto_tree_add_item_ret_uint(tree, hf_bt_utp_type, tvb, offset, 1, ENC_BIG_ENDIAN, &type);
   offset += 1;
   proto_tree_add_item(tree, hf_bt_utp_next_extension_type, tvb, offset, 1, ENC_BIG_ENDIAN);
-  *extension_type = tvb_get_guint8(tvb, offset);
+  *extension_type = tvb_get_uint8(tvb, offset);
   offset += 1;
   proto_tree_add_item_ret_uint(tree, hf_bt_utp_connection_id_v1, tvb, offset, 2, ENC_BIG_ENDIAN, &connection);
   offset += 2;
@@ -793,85 +858,64 @@ dissect_utp_header_v1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
 }
 
 static int
-dissect_utp_extension(tvbuff_t *tvb, packet_info _U_*pinfo, proto_tree *tree, int offset, guint8 *extension_type)
+dissect_utp_extension(tvbuff_t *tvb, packet_info _U_*pinfo, proto_tree *tree, int offset, uint8_t *extension_type)
 {
   proto_item *ti;
   proto_tree *ext_tree;
-  guint8 extension_length;
+  uint32_t next_extension, extension_length;
   /* display the extension tree */
 
   while(*extension_type != EXT_NO_EXTENSION && offset < (int)tvb_reported_length(tvb))
   {
+    ti = proto_tree_add_none_format(tree, hf_bt_utp_extension, tvb, offset, -1, "Extension: %s", val_to_str_const(*extension_type, bt_utp_extension_type_vals, "Unknown"));
+    ext_tree = proto_item_add_subtree(ti, ett_bt_utp_extension);
+
+    proto_tree_add_item_ret_uint(ext_tree, hf_bt_utp_next_extension_type, tvb, offset, 1, ENC_BIG_ENDIAN, &next_extension);
+    offset += 1;
+
+    proto_tree_add_item_ret_uint(ext_tree, hf_bt_utp_extension_len, tvb, offset, 1, ENC_BIG_ENDIAN, &extension_length);
+    proto_item_append_text(ti, ", Len=%d", extension_length);
+    offset += 1;
+
     switch(*extension_type){
       case EXT_SELECTIVE_ACKS: /* 1 */
       {
-        ti = proto_tree_add_item(tree, hf_bt_utp_extension, tvb, offset, -1, ENC_NA);
-        ext_tree = proto_item_add_subtree(ti, ett_bt_utp_extension);
-
-        proto_tree_add_item(ext_tree, hf_bt_utp_next_extension_type, tvb, offset, 1, ENC_BIG_ENDIAN);
-        *extension_type = tvb_get_guint8(tvb, offset);
-        offset += 1;
-
-        proto_tree_add_item(ext_tree, hf_bt_utp_extension_len, tvb, offset, 1, ENC_BIG_ENDIAN);
-        extension_length = tvb_get_guint8(tvb, offset);
-        proto_item_append_text(ti, " Selective ACKs, Len=%d", extension_length);
-        offset += 1;
-
         proto_tree_add_item(ext_tree, hf_bt_utp_extension_bitmask, tvb, offset, extension_length, ENC_NA);
-        offset += extension_length;
-        proto_item_set_len(ti, 1 + 1 + extension_length);
         break;
       }
       case EXT_EXTENSION_BITS: /* 2 */
       {
-        ti = proto_tree_add_item(tree, hf_bt_utp_extension, tvb, offset, -1, ENC_NA);
-        ext_tree = proto_item_add_subtree(ti, ett_bt_utp_extension);
-
-        proto_tree_add_item(ext_tree, hf_bt_utp_next_extension_type, tvb, offset, 1, ENC_BIG_ENDIAN);
-        *extension_type = tvb_get_guint8(tvb, offset);
-        offset += 1;
-
-        proto_tree_add_item(ext_tree, hf_bt_utp_extension_len, tvb, offset, 1, ENC_BIG_ENDIAN);
-        extension_length = tvb_get_guint8(tvb, offset);
-        proto_item_append_text(ti, " Extension Bits, Len=%d", extension_length);
-        offset += 1;
-
         proto_tree_add_item(ext_tree, hf_bt_utp_extension_bitmask, tvb, offset, extension_length, ENC_NA);
-        offset += extension_length;
-        proto_item_set_len(ti, 1 + 1 + extension_length);
+        break;
+      }
+      case EXT_CLOSE_REASON: /* 3 */
+      {
+        if (extension_length != 4) {
+          expert_add_info(pinfo, ti, &ei_extension_len_invalid);
+        }
+        proto_tree_add_item(ext_tree, hf_bt_utp_extension_close_reason, tvb, offset, 4, ENC_NA);
         break;
       }
       default:
-        ti = proto_tree_add_item(tree, hf_bt_utp_extension, tvb, offset, -1, ENC_NA);
-        ext_tree = proto_item_add_subtree(ti, ett_bt_utp_extension);
-
-        proto_tree_add_item(ext_tree, hf_bt_utp_next_extension_type, tvb, offset, 1, ENC_BIG_ENDIAN);
-        *extension_type = tvb_get_guint8(tvb, offset);
-        offset += 1;
-
-        proto_tree_add_item(ext_tree, hf_bt_utp_extension_len, tvb, offset, 1, ENC_BIG_ENDIAN);
-        extension_length = tvb_get_guint8(tvb, offset);
-        proto_item_append_text(ti, " Unknown, Len=%d", extension_length);
-        offset += 1;
-
         proto_tree_add_item(ext_tree, hf_bt_utp_extension_unknown, tvb, offset, extension_length, ENC_NA);
-        offset += extension_length;
-        proto_item_set_len(ti, 1 + 1 + extension_length);
       break;
     }
+    offset += extension_length;
+    proto_item_set_len(ti, 1 + 1 + extension_length);
+    *extension_type = next_extension;
   }
 
   return offset;
 }
 
-static gboolean
+static bool
 decode_utp(tvbuff_t *tvb, int offset, packet_info *pinfo,
     proto_tree *tree)
 {
   proto_tree *parent_tree;
   tvbuff_t *next_tvb;
   int save_desegment_offset;
-  guint32 save_desegment_len;
+  uint32_t save_desegment_len;
 
   /* XXX: Check for retransmission? */
 
@@ -885,7 +929,7 @@ decode_utp(tvbuff_t *tvb, int offset, packet_info *pinfo,
   parent_tree = proto_tree_get_parent_tree(tree);
   if (call_dissector_with_data(bittorrent_handle, next_tvb, pinfo, parent_tree, NULL)) {
     pinfo->want_pdu_tracking -= !!(pinfo->want_pdu_tracking);
-    return TRUE;
+    return true;
   }
 
   DISSECTOR_ASSERT(save_desegment_offset == pinfo->desegment_offset &&
@@ -894,12 +938,12 @@ decode_utp(tvbuff_t *tvb, int offset, packet_info *pinfo,
   call_data_dissector(tvb, pinfo, parent_tree);
   pinfo->want_pdu_tracking -= !!(pinfo->want_pdu_tracking);
 
-  return FALSE;
+  return false;
 }
 
 static void
 process_utp_payload(tvbuff_t *tvb, packet_info *pinfo,
-    proto_tree *tree, guint16 seq, gboolean is_utp_segment,
+    proto_tree *tree, uint16_t seq, bool is_utp_segment,
     utp_stream_info_t *stream_info)
 {
   volatile int offset = 0;
@@ -957,14 +1001,14 @@ process_utp_payload(tvbuff_t *tvb, packet_info *pinfo,
   ENDTRY;
 }
 
-static guint
+static unsigned
 dissect_utp_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
   proto_item *ti;
 
   utp_info_t *p_utp_info;
-  guint len_tvb;
-  gboolean save_fragmented;
+  unsigned len_tvb;
+  bool save_fragmented;
 
   p_utp_info = (utp_info_t *)p_get_proto_data(pinfo->pool, pinfo, proto_bt_utp, pinfo->curr_layer_num);
 
@@ -986,7 +1030,7 @@ dissect_utp_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   pinfo->can_desegment = 0;
   if (!pinfo->fragmented && !pinfo->flags.in_error_pkt) {
     p_utp_info->seglen = len_tvb;
-    p_utp_info->have_seglen = TRUE;
+    p_utp_info->have_seglen = true;
 
     ti = proto_tree_add_uint(tree, hf_bt_utp_len, tvb, 0, 0, len_tvb);
     proto_item_set_generated(ti);
@@ -997,18 +1041,18 @@ dissect_utp_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       pinfo->can_desegment = 2;
     }
   } else {
-    p_utp_info->have_seglen = FALSE;
+    p_utp_info->have_seglen = false;
   }
 
   if(tvb_captured_length(tvb)) {
     proto_tree_add_item(tree, hf_bt_utp_data, tvb, 0, len_tvb, ENC_NA);
     if (pinfo->can_desegment) {
       /* XXX: desegment_utp() is not implemented, but we can't get
-       * into this code path yet because utp_desegment is FALSE. */
+       * into this code path yet because utp_desegment is false. */
     } else {
       save_fragmented = pinfo->fragmented;
-      pinfo->fragmented = TRUE;
-      process_utp_payload(tvb, pinfo, tree, p_utp_info->seq, TRUE, stream_info);
+      pinfo->fragmented = true;
+      process_utp_payload(tvb, pinfo, tree, p_utp_info->seq, true, stream_info);
       pinfo->fragmented = save_fragmented;
     }
   }
@@ -1019,7 +1063,7 @@ dissect_utp_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 static int
 dissect_bt_utp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
-  gint version;
+  int version;
   version = get_utp_version(tvb);
 
   /* try dissecting */
@@ -1027,8 +1071,8 @@ dissect_bt_utp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _
   {
     proto_tree *sub_tree = NULL;
     proto_item *ti;
-    gint offset = 0;
-    guint8 extension_type;
+    int offset = 0;
+    uint8_t extension_type;
 
     /* set the protocol column */
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "BT-uTP");
@@ -1056,10 +1100,10 @@ dissect_bt_utp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _
   return 0;
 }
 
-static gboolean
-dissect_bt_utp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool
+dissect_bt_utp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
-  gint version;
+  int version;
   version = get_utp_version(tvb);
 
   if (version >= 0)
@@ -1070,10 +1114,10 @@ dissect_bt_utp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *d
     conversation_set_dissector_from_frame_number(conversation, pinfo->num, bt_utp_handle);
 
     dissect_bt_utp(tvb, pinfo, tree, data);
-    return TRUE;
+    return true;
   }
 
-  return FALSE;
+  return false;
 }
 
 static void
@@ -1121,6 +1165,11 @@ proto_register_bt_utp(void)
       FT_BYTES, BASE_NONE, NULL, 0x0,
       NULL, HFILL }
     },
+    { &hf_bt_utp_extension_close_reason,
+      { "Close Reason", "bt-utp.extension_close_reason",
+      FT_UINT32, BASE_DEC, VALS(bt_utp_close_reason_vals), 0x0,
+      NULL, HFILL }
+    },
     { &hf_bt_utp_extension_unknown,
       { "Extension Unknown", "bt-utp.extension_unknown",
       FT_BYTES, BASE_NONE, NULL, 0x0,
@@ -1198,10 +1247,18 @@ proto_register_bt_utp(void)
     },
   };
 
+  static ei_register_info ei[] = {
+    { &ei_extension_len_invalid,
+      { "bt-utp.extension_len.invalid", PI_PROTOCOL, PI_WARN,
+        "The extension is an unexpected length", EXPFILL }
+    },
+  };
+
   /* Setup protocol subtree array */
-  static gint *ett[] = { &ett_bt_utp, &ett_bt_utp_extension };
+  static int *ett[] = { &ett_bt_utp, &ett_bt_utp_extension };
 
   module_t *bt_utp_module;
+  expert_module_t *expert_bt_utp;
 
   /* Register protocol */
   proto_bt_utp = proto_register_protocol ("uTorrent Transport Protocol", "BT-uTP", "bt-utp");
@@ -1235,7 +1292,12 @@ proto_register_bt_utp(void)
   proto_register_field_array(proto_bt_utp, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
+  expert_bt_utp = expert_register_protocol(proto_bt_utp);
+  expert_register_field_array(expert_bt_utp, ei, array_length(ei));
+
   register_init_routine(utp_init);
+
+  bt_utp_handle = register_dissector("bt-utp", dissect_bt_utp, proto_bt_utp);
 }
 
 void
@@ -1248,7 +1310,6 @@ proto_reg_handoff_bt_utp(void)
    */
   heur_dissector_add("udp", dissect_bt_utp_heur, "BitTorrent UTP over UDP", "bt_utp_udp", proto_bt_utp, HEURISTIC_DISABLE);
 
-  bt_utp_handle = create_dissector_handle(dissect_bt_utp, proto_bt_utp);
   dissector_add_for_decode_as_with_preference("udp.port", bt_utp_handle);
 
   bittorrent_handle = find_dissector_add_dependency("bittorrent.utp", proto_bt_utp);
