@@ -23,24 +23,26 @@
 void proto_register_calcappprotocol(void);
 void proto_reg_handoff_calcappprotocol(void);
 
+static dissector_handle_t calcappprotocol_handle;
+
 #define CALCAPPPROTOCOL_PAYLOAD_PROTOCOL_ID_LEGACY 0x29097603
 
 
 /* Initialize the protocol and registered fields */
-static int proto_calcappprotocol = -1;
+static int proto_calcappprotocol;
 static int tap_calcappprotocol   = -1;
-static int hf_message_type       = -1;
-static int hf_message_flags      = -1;
-static int hf_message_length     = -1;
-static int hf_message_jobid      = -1;
-static int hf_message_jobsize    = -1;
-static int hf_message_completed  = -1;
+static int hf_message_type;
+static int hf_message_flags;
+static int hf_message_length;
+static int hf_message_jobid;
+static int hf_message_jobsize;
+static int hf_message_completed;
 
-static guint64 calcappprotocol_total_msgs     = 0;
-static guint64 calcappprotocol_total_bytes    = 0;
+static uint64_t calcappprotocol_total_msgs;
+static uint64_t calcappprotocol_total_bytes;
 
 /* Initialize the subtree pointers */
-static gint ett_calcappprotocol = -1;
+static int ett_calcappprotocol;
 
 /* Dissectors for messages. This is specific to CalcAppProtocol */
 #define MESSAGE_TYPE_LENGTH      1
@@ -80,8 +82,8 @@ static const value_string message_type_values[] = {
 
 
 typedef struct _tap_calcappprotocol_rec_t {
-  guint8      type;
-  guint16     size;
+  uint8_t     type;
+  uint16_t    size;
   const char* type_string;
 } tap_calcappprotocol_rec_t;
 
@@ -90,7 +92,7 @@ static void
 dissect_calcappprotocol_message(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *calcappprotocol_tree)
 {
   tap_calcappprotocol_rec_t* tap_rec = wmem_new0(pinfo->pool, tap_calcappprotocol_rec_t);
-  tap_rec->type        = tvb_get_guint8(message_tvb, MESSAGE_TYPE_OFFSET);
+  tap_rec->type        = tvb_get_uint8(message_tvb, MESSAGE_TYPE_OFFSET);
   tap_rec->size        = tvb_get_ntohs(message_tvb,  MESSAGE_LENGTH_OFFSET);
   tap_rec->type_string = val_to_str_const(tap_rec->type, message_type_values, "Unknown CalcAppProtocol message type");
   tap_queue_packet(tap_calcappprotocol, pinfo, tap_rec);
@@ -125,7 +127,7 @@ dissect_calcappprotocol(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *t
   };
   /* dissect the message */
   dissect_calcappprotocol_message(message_tvb, pinfo, calcappprotocol_tree);
-  return(TRUE);
+  return true;
 }
 
 
@@ -160,10 +162,10 @@ static stat_tap_table_item calcappprotocol_stat_fields[] = {
 static void calcappprotocol_stat_init(stat_tap_table_ui* new_stat)
 {
   const char *table_name = "CalcAppProtocol Statistics";
-  int num_fields = sizeof(calcappprotocol_stat_fields)/sizeof(stat_tap_table_item);
+  int num_fields = array_length(calcappprotocol_stat_fields);
   stat_tap_table *table;
   int i = 0;
-  stat_tap_table_item_type items[sizeof(calcappprotocol_stat_fields)/sizeof(stat_tap_table_item)];
+  stat_tap_table_item_type items[array_length(calcappprotocol_stat_fields)];
 
   table = stat_tap_find_table(new_stat, table_name);
   if (table) {
@@ -205,15 +207,15 @@ static void calcappprotocol_stat_init(stat_tap_table_ui* new_stat)
 }
 
 static tap_packet_status
-calcappprotocol_stat_packet(void* tapdata, packet_info* pinfo _U_, epan_dissect_t* edt _U_, const void* data)
+calcappprotocol_stat_packet(void* tapdata, packet_info* pinfo _U_, epan_dissect_t* edt _U_, const void* data, tap_flags_t flags _U_)
 {
   stat_data_t*                     stat_data = (stat_data_t*)tapdata;
   const tap_calcappprotocol_rec_t* tap_rec   = (const tap_calcappprotocol_rec_t*)data;
   stat_tap_table*                  table;
   stat_tap_table_item_type*        msg_data;
-  gint                             idx;
-  guint64                          messages;
-  guint64                          bytes;
+  int                              idx;
+  uint64_t                         messages;
+  uint64_t                         bytes;
   int                              i         = 0;
   double                           firstSeen = -1.0;
   double                           lastSeen  = -1.0;
@@ -241,9 +243,9 @@ calcappprotocol_stat_packet(void* tapdata, packet_info* pinfo _U_, epan_dissect_
   /* Update messages and bytes share */
   while (message_type_values[i].strptr) {
     msg_data = stat_tap_get_field_data(table, i, MESSAGES_COLUMN);
-    const guint m = msg_data->value.uint_value;
+    const unsigned m = msg_data->value.uint_value;
     msg_data = stat_tap_get_field_data(table, i, BYTES_COLUMN);
-    const guint b = msg_data->value.uint_value;
+    const unsigned b = msg_data->value.uint_value;
 
     msg_data = stat_tap_get_field_data(table, i, MESSAGES_SHARE_COLUMN);
     msg_data->type = TABLE_ITEM_FLOAT;
@@ -301,7 +303,7 @@ calcappprotocol_stat_packet(void* tapdata, packet_info* pinfo _U_, epan_dissect_
 static void
 calcappprotocol_stat_reset(stat_tap_table* table)
 {
-  guint element;
+  unsigned element;
   stat_tap_table_item_type* item_data;
 
   for (element = 0; element < table->num_elements; element++) {
@@ -369,12 +371,12 @@ proto_register_calcappprotocol(void)
   };
 
   /* Setup protocol subtree array */
-  static gint *ett[] = {
+  static int *ett[] = {
     &ett_calcappprotocol
   };
 
   static tap_param calcappprotocol_stat_params[] = {
-    { PARAM_FILTER, "filter", "Filter", NULL, TRUE }
+    { PARAM_FILTER, "filter", "Filter", NULL, true }
   };
 
   static stat_tap_table_ui calcappprotocol_stat_table = {
@@ -387,8 +389,8 @@ proto_register_calcappprotocol(void)
     calcappprotocol_stat_reset,
     NULL,
     NULL,
-    sizeof(calcappprotocol_stat_fields)/sizeof(stat_tap_table_item), calcappprotocol_stat_fields,
-    sizeof(calcappprotocol_stat_params)/sizeof(tap_param), calcappprotocol_stat_params,
+    array_length(calcappprotocol_stat_fields), calcappprotocol_stat_fields,
+    array_length(calcappprotocol_stat_params), calcappprotocol_stat_params,
     NULL,
     0
   };
@@ -402,14 +404,13 @@ proto_register_calcappprotocol(void)
   tap_calcappprotocol = register_tap("calcappprotocol");
 
   register_stat_tap_table_ui(&calcappprotocol_stat_table);
+
+  calcappprotocol_handle = register_dissector("calcappprotocol", dissect_calcappprotocol, proto_calcappprotocol);
 }
 
 void
 proto_reg_handoff_calcappprotocol(void)
 {
-  dissector_handle_t calcappprotocol_handle;
-
-  calcappprotocol_handle = create_dissector_handle(dissect_calcappprotocol, proto_calcappprotocol);
   dissector_add_uint("sctp.ppi", CALCAPPPROTOCOL_PAYLOAD_PROTOCOL_ID_LEGACY, calcappprotocol_handle);
   dissector_add_uint("sctp.ppi", CALCAPP_PAYLOAD_PROTOCOL_ID, calcappprotocol_handle);
 }
