@@ -19,12 +19,12 @@ void proto_reg_handoff_daytime(void);
 
 static dissector_handle_t daytime_handle;
 
-static int proto_daytime = -1;
+static int proto_daytime;
 
-static int hf_daytime_string = -1;
-static int hf_response_request = -1;
+static int hf_daytime_string;
+static int hf_response_request;
 
-static gint ett_daytime = -1;
+static int ett_daytime;
 
 /* This dissector works for TCP and UDP daytime packets */
 #define DAYTIME_PORT 13
@@ -64,12 +64,12 @@ proto_register_daytime(void)
     },
     { &hf_response_request,
       { "Type", "daytime.response_request",
-        FT_BOOLEAN, 8, TFS(&tfs_response_request), 0x0,
+        FT_BOOLEAN, BASE_NONE, TFS(&tfs_response_request), 0x0,
         NULL, HFILL }
     },
   };
 
-  static gint *ett[] = {
+  static int *ett[] = {
     &ett_daytime,
   };
 
