@@ -19,46 +19,46 @@
 void proto_register_epm (void);
 void proto_reg_handoff_epm (void);
 
-static int proto_epm3 = -1;
-static int proto_epm4 = -1;
+static int proto_epm3;
+static int proto_epm4;
 
-static int hf_epm_opnum = -1;
-static int hf_epm_inquiry_type = -1;
-static int hf_epm_object = -1;
-static int hf_epm_if_id = -1;
-static int hf_epm_ver_maj = -1;
-static int hf_epm_ver_min = -1;
-static int hf_epm_ver_opt = -1;
-static int hf_epm_hnd = -1;
-static int hf_epm_max_ents = -1;
-static int hf_epm_num_ents = -1;
-static int hf_epm_uuid = -1;
-static int hf_epm_uuid_version = -1;
-static int hf_epm_tower_length = -1;
-/* static int hf_epm_tower_data = -1; */
-static int hf_epm_max_towers = -1;
-static int hf_epm_num_towers = -1;
-static int hf_epm_rc = -1;
-static int hf_epm_replace = -1;
-static int hf_epm_tower_num_floors = -1;
-static int hf_epm_tower_rhs_len = -1;
-static int hf_epm_tower_lhs_len = -1;
-static int hf_epm_tower_proto_id = -1;
-static int hf_epm_annotation = -1;
-static int hf_epm_ann_offset = -1;
-static int hf_epm_ann_len = -1;
-static int hf_epm_proto_named_pipes = -1;
-static int hf_epm_proto_netbios_name = -1;
-static int hf_epm_proto_ip = -1;
-static int hf_epm_proto_udp_port = -1;
-static int hf_epm_proto_tcp_port = -1;
-static int hf_epm_proto_http_port = -1;
+static int hf_epm_opnum;
+static int hf_epm_inquiry_type;
+static int hf_epm_object;
+static int hf_epm_if_id;
+static int hf_epm_ver_maj;
+static int hf_epm_ver_min;
+static int hf_epm_ver_opt;
+static int hf_epm_hnd;
+static int hf_epm_max_ents;
+static int hf_epm_num_ents;
+static int hf_epm_uuid;
+static int hf_epm_uuid_version;
+static int hf_epm_tower_length;
+/* static int hf_epm_tower_data; */
+static int hf_epm_max_towers;
+static int hf_epm_num_towers;
+static int hf_epm_rc;
+static int hf_epm_replace;
+static int hf_epm_tower_num_floors;
+static int hf_epm_tower_rhs_len;
+static int hf_epm_tower_lhs_len;
+static int hf_epm_tower_proto_id;
+static int hf_epm_annotation;
+static int hf_epm_ann_offset;
+static int hf_epm_ann_len;
+static int hf_epm_proto_named_pipes;
+static int hf_epm_proto_netbios_name;
+static int hf_epm_proto_ip;
+static int hf_epm_proto_udp_port;
+static int hf_epm_proto_tcp_port;
+static int hf_epm_proto_http_port;
 
-static gint ett_epm = -1;
-static gint ett_epm_tower_floor = -1;
-static gint ett_epm_entry = -1;
+static gint ett_epm;
+static gint ett_epm_tower_floor;
+static gint ett_epm_entry;
 
-static expert_field ei_epm_proto_undecoded = EI_INIT;
+static expert_field ei_epm_proto_undecoded;
 
 
 /* the UUID is identical for interface versions 3 and 4 */
@@ -334,7 +334,7 @@ epm_dissect_tower_data (tvbuff_t *tvb, int offset,
         case PROTO_ID_UUID:
             dcerpc_tvb_get_uuid (tvb, offset+1, &u8little_endian, &uuid);
 
-            uuid_name = guids_get_uuid_name(&uuid);
+            uuid_name = guids_get_uuid_name(&uuid, pinfo->pool);
 
             if(uuid_name != NULL) {
                 proto_tree_add_guid_format (tr, hf_epm_uuid, tvb, offset+1, 16, (e_guid_t *) &uuid,
@@ -399,7 +399,7 @@ epm_dissect_tower_data (tvbuff_t *tvb, int offset,
 
         case PROTO_ID_IP: /* this one is always big endian */
             proto_tree_add_item(tr, hf_epm_proto_ip, tvb, offset, 4, ENC_BIG_ENDIAN);
-            proto_item_append_text(tr, "IP:%s", tvb_ip_to_str(tvb, offset));
+            proto_item_append_text(tr, "IP:%s", tvb_ip_to_str(pinfo->pool, tvb, offset));
             break;
 
         case PROTO_ID_RPC_CO:
@@ -447,7 +447,7 @@ epm_dissect_tower_data (tvbuff_t *tvb, int offset,
 static void
 epm_fmt_uuid_version( gchar *result, guint32 revision )
 {
-   g_snprintf( result, ITEM_LABEL_LENGTH, "%d.%02d", (guint8)(( revision & 0xFF00 ) >> 8), (guint8)(revision & 0xFF) );
+   snprintf( result, ITEM_LABEL_LENGTH, "%d.%02d", (guint8)(( revision & 0xFF00 ) >> 8), (guint8)(revision & 0xFF) );
 }
 
 /* typedef struct {
@@ -651,7 +651,7 @@ epm_dissect_ept_lookup_handle_free_resp (tvbuff_t *tvb, int offset,
 }
 
 
-static dcerpc_sub_dissector epm_dissectors[] = {
+static const dcerpc_sub_dissector epm_dissectors[] = {
     { 0, "Insert",
         epm_dissect_ept_insert_rqst,
         epm_dissect_ept_insert_resp },
