@@ -59,12 +59,9 @@
 #define NETLOGON_NETRGETFORESTTRUSTINFORMATION		0x2c
 #define NETLOGON_NETRLOGONSAMLOGONWITHFLAGS		0x2d
 #define NETLOGON_NETRSERVERGETTRUSTINFO			0x2e
-
-/* Secure channel types */
-
-#define SEC_CHAN_WKSTA   2
-#define SEC_CHAN_DOMAIN  4
-#define SEC_CHAN_BDC     6
+#define NETLOGON_DSRUPDATEREADONLYSERVERDNSRECORDS	0x30
+#define NETLOGON_NETRCHAINSETCLIENTATTRIBUTES		0x36 /* This is documented as 49 (0x31) but it's 54) */
+#define NETLOGON_NETRSERVERAUTHENTICATEKERBEROS		0x3B
 
 
 /* needed to decrypt PAC_LOGON_INFO in kerberos */
