@@ -23,22 +23,23 @@
 #include "packet-windows-common.h"
 
 
-int hf_nt_cs_len = -1;
+int hf_nt_cs_len;
 int hf_nt_error;
-int hf_nt_cs_size = -1;
-static int hf_lsa_String_name_len = -1;
-static int hf_lsa_String_name_size = -1;
-static int hf_nt_data_blob_len = -1;
-static int hf_nt_data_blob_data = -1;
-static int hf_nt_midl_blob_len = -1;
-static int hf_nt_midl_fill_bytes = -1;
-static int hf_nt_midl_version = -1;
-static int hf_nt_midl_hdr_len = -1;
+int hf_nt_cs_size;
+static int hf_lsa_String_name_len;
+static int hf_lsa_String_name_size;
+static int hf_nt_data_blob_len;
+static int hf_nt_data_blob_data;
+static int hf_nt_midl_blob_len;
+static int hf_nt_midl_fill_bytes;
+static int hf_nt_midl_version;
+static int hf_nt_midl_hdr_len;
 
-static gint ett_nt_MIDL_BLOB = -1;
-static gint ett_lsa_String = -1;
-static gint ett_nt_data_blob = -1;
-static expert_field ei_dcerpc_nt_badsid = EI_INIT;
+static gint ett_nt_MIDL_BLOB;
+static gint ett_lsa_String;
+static gint ett_nt_data_blob;
+static gint ett_nt_counted_string;
+static expert_field ei_dcerpc_nt_badsid;
 
 
 
@@ -161,8 +162,6 @@ dissect_ndr_counted_string_cb(tvbuff_t *tvb, int offset,
 	return offset;
 }
 
-static gint ett_nt_counted_string = -1;
-
 static int
 dissect_ndr_counted_string_helper(tvbuff_t *tvb, int offset,
 				  packet_info *pinfo, proto_tree *tree,
@@ -215,7 +214,7 @@ dissect_ndr_counted_string_ptr(tvbuff_t *tvb, int offset,
 
 /* Dissect a counted byte_array as a callback to dissect_ndr_pointer_cb() */
 
-static gint ett_nt_counted_byte_array = -1;
+static gint ett_nt_counted_byte_array;
 
 /* Dissect a counted byte array in-line. */
 
@@ -285,7 +284,7 @@ static void cb_byte_array_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 	if ((end_offset - start_offset) <= 12)
 		return;
 
-	s = tvb_bytes_to_str(wmem_packet_scope(), tvb, start_offset + 12, (end_offset - start_offset - 12) );
+	s = tvb_bytes_to_str(pinfo->pool, tvb, start_offset + 12, (end_offset - start_offset - 12) );
 
 	/* Append string to COL_INFO */
 
@@ -322,7 +321,7 @@ dissect_ndr_counted_byte_array(tvbuff_t *tvb, int offset,
 }
 
 /* Dissect a counted ascii string in-line. */
-static gint ett_nt_counted_ascii_string = -1;
+static gint ett_nt_counted_ascii_string;
 
 int
 dissect_ndr_counted_ascii_string_cb(tvbuff_t *tvb, int offset,
@@ -380,7 +379,7 @@ dissect_ndr_counted_ascii_string(tvbuff_t *tvb, int offset,
 		tvb, offset, pinfo, tree, di, drep, hf_index, cb_str_postprocess, GINT_TO_POINTER(2 + levels));
 }
 
-static int hf_nt_guid = -1;
+static int hf_nt_guid;
 
 int
 dissect_nt_GUID(tvbuff_t *tvb, int offset,
@@ -511,7 +510,7 @@ typedef struct {
 	pol_value *list;		 /* List of policy handle entries */
 } pol_hash_value;
 
-static wmem_map_t *pol_hash = NULL;
+static wmem_map_t *pol_hash;
 
 /* Hash function */
 
@@ -605,10 +604,10 @@ static void add_pol_handle(e_ctx_hnd *policy_hnd, guint32 frame,
 		 * and put the hash value in the policy handle hash
 		 * table.
 		 */
-		value = (pol_hash_value *)wmem_alloc(wmem_file_scope(), sizeof(pol_hash_value));
+		value = wmem_new(wmem_file_scope(), pol_hash_value);
 		value->list = pol;
 		pol->next = NULL;
-		key = (pol_hash_key *)wmem_alloc(wmem_file_scope(), sizeof(pol_hash_key));
+		key = wmem_new(wmem_file_scope(), pol_hash_key);
 		memcpy(&key->policy_hnd, policy_hnd, sizeof(key->policy_hnd));
 		wmem_map_insert(pol_hash, key, value);
 	} else {
@@ -705,7 +704,7 @@ void dcerpc_smb_store_pol_pkts(e_ctx_hnd *policy_hnd, packet_info *pinfo,
 
 	/* Create a new value */
 
-	pol = (pol_value *)wmem_alloc(wmem_file_scope(), sizeof(pol_value));
+	pol = wmem_new(wmem_file_scope(), pol_value);
 
 	pol->open_frame = is_open ? pinfo->num : 0;
 	pol->close_frame = is_close ? pinfo->num : 0;
@@ -775,7 +774,7 @@ void dcerpc_store_polhnd_name(e_ctx_hnd *policy_hnd, packet_info *pinfo,
 		if (pol->name && name) {
 #ifdef DEBUG_HASH_COLL
 			if (strcmp(pol->name, name) != 0)
-				g_warning("dcerpc_smb: pol_hash name collision %s/%s\n", value->name, name);
+				ws_warning("dcerpc_smb: pol_hash name collision %s/%s\n", value->name, name);
 #endif
 			/* pol->name is wmem_file_scope() allocated, don't free it now */
 		}
@@ -787,7 +786,7 @@ void dcerpc_store_polhnd_name(e_ctx_hnd *policy_hnd, packet_info *pinfo,
 
 	/* Create a new value */
 
-	pol = (pol_value *)wmem_alloc(wmem_file_scope(), sizeof(pol_value));
+	pol = wmem_new(wmem_file_scope(), pol_value);
 
 	pol->open_frame = 0;
 	pol->close_frame = 0;
@@ -896,12 +895,34 @@ dissect_doserror(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 	return offset;
 }
 
+/* Dissect a HRESULT status code */
+
+int
+dissect_hresult(tvbuff_t *tvb, gint offset, packet_info *pinfo,
+	       proto_tree *tree, dcerpc_info *di, guint8 *drep,
+	       int hfindex, guint32 *pdata)
+{
+	guint32 status;
+
+	offset = dissect_ndr_uint32(tvb, offset, pinfo, tree, di, drep,
+				    hfindex, &status);
+
+	if (status != 0)
+		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s",
+				val_to_str_ext(status, &HRES_errors_ext,
+					   "Unknown error 0x%08x"));
+	if (pdata)
+		*pdata = status;
+
+	return offset;
+}
+
 /* Dissect a NT policy handle */
 
-static int hf_nt_policy_open_frame = -1;
-static int hf_nt_policy_close_frame = -1;
+static int hf_nt_policy_open_frame;
+static int hf_nt_policy_close_frame;
 
-static gint ett_nt_policy_hnd = -1;
+static gint ett_nt_policy_hnd;
 
 /* this function is used to dissect a "handle".
  * it will keep track of which frame a handle is opened from and in which
@@ -1066,7 +1087,7 @@ PIDL_dissect_policy_hnd(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 		if(!pol_name){
 			pol_name="<...>";
 		}
-		pol_string=wmem_strdup_printf(wmem_packet_scope(), "%s(%s)", di->dcerpc_procedure_name, pol_name);
+		pol_string=wmem_strdup_printf(pinfo->pool, "%s(%s)", di->dcerpc_procedure_name, pol_name);
 		dcerpc_store_polhnd_name(&policy_hnd, pinfo, pol_string);
 		dcerpc_store_polhnd_type(&policy_hnd, pinfo, param&PIDL_POLHND_TYPE_MASK);
 	}
@@ -1170,39 +1191,13 @@ dissect_ndr_uint16s(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 				      tree, drep, hfindex, length);
 }
 
-/*
- * Helper routines for dissecting NDR strings
- */
-void cb_wstr_postprocess(packet_info *pinfo, proto_tree *tree _U_,
-			proto_item *item, dcerpc_info *di, tvbuff_t *tvb,
-			int start_offset, int end_offset,
-			void *callback_args)
+static void cb_str_postprocess_options(packet_info *pinfo,
+				       proto_item *item,
+				       dcerpc_info *di,
+				       gint options,
+				       const char *s)
 {
-	gint options = GPOINTER_TO_INT(callback_args);
 	gint levels = CB_STR_ITEM_LEVELS(options);
-	char *s;
-
-	/* Align start_offset on 4-byte boundary. */
-
-	if (start_offset % 4)
-		start_offset += 4 - (start_offset % 4);
-
-	/* Get string value */
-
-	if ((end_offset - start_offset) <= 12)
-		return;		/* XXX: Use unistr2 dissector instead? */
-
-	/*
-	 * XXX - need to handle non-printable characters here.
-	 *
-	 * XXX - this is typically called after the string has already
-	 * been fetched and processed by some other routine; is there
-	 * some way we can get that string, rather than duplicating the
-	 * efforts of that routine?
-	 */
-	s = tvb_get_string_enc(wmem_packet_scope(),
-		tvb, start_offset + 12, end_offset - start_offset - 12,
-		ENC_UTF_16|ENC_LITTLE_ENDIAN);
 
 	/* Append string to COL_INFO */
 
@@ -1234,13 +1229,48 @@ void cb_wstr_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 	}
 }
 
+/*
+ * Helper routines for dissecting NDR strings
+ */
+void cb_wstr_postprocess(packet_info *pinfo, proto_tree *tree _U_,
+			proto_item *item, dcerpc_info *di, tvbuff_t *tvb,
+			int start_offset, int end_offset,
+			void *callback_args)
+{
+	gint options = GPOINTER_TO_INT(callback_args);
+	char *s;
+
+	/* Align start_offset on 4-byte boundary. */
+
+	if (start_offset % 4)
+		start_offset += 4 - (start_offset % 4);
+
+	/* Get string value */
+
+	if ((end_offset - start_offset) <= 12)
+		return;		/* XXX: Use unistr2 dissector instead? */
+
+	/*
+	 * XXX - need to handle non-printable characters here.
+	 *
+	 * XXX - this is typically called after the string has already
+	 * been fetched and processed by some other routine; is there
+	 * some way we can get that string, rather than duplicating the
+	 * efforts of that routine?
+	 */
+	s = tvb_get_string_enc(pinfo->pool,
+		tvb, start_offset + 12, end_offset - start_offset - 12,
+		ENC_UTF_16|ENC_LITTLE_ENDIAN);
+
+	cb_str_postprocess_options(pinfo, item, di, options, s);
+}
+
 void cb_str_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 			proto_item *item, dcerpc_info *di, tvbuff_t *tvb,
 			int start_offset, int end_offset,
 			void *callback_args)
 {
 	gint options = GPOINTER_TO_INT(callback_args);
-	gint levels = CB_STR_ITEM_LEVELS(options);
 	guint8 *s;
 
 	/* Align start_offset on 4-byte boundary. */
@@ -1261,40 +1291,10 @@ void cb_str_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 	 * some way we can get that string, rather than duplicating the
 	 * efforts of that routine?
 	 */
-	s = tvb_get_string_enc(wmem_packet_scope(),
+	s = tvb_get_string_enc(pinfo->pool,
 		tvb, start_offset + 12, (end_offset - start_offset - 12), ENC_ASCII);
 
-	/* Append string to COL_INFO */
-
-	if (options & CB_STR_COL_INFO) {
-		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s", s);
-	}
-
-	/* Append string to upper-level proto_items */
-
-	if (levels > 0 && item && s && s[0]) {
-		proto_item_append_text(item, ": %s", s);
-		item = GET_ITEM_PARENT(item);
-		levels--;
-		if (levels > 0) {
-			proto_item_append_text(item, ": %s", s);
-			item = GET_ITEM_PARENT(item);
-			levels--;
-			while (levels > 0) {
-				proto_item_append_text(item, " %s", s);
-				item = GET_ITEM_PARENT(item);
-				levels--;
-			}
-		}
-	}
-
-	/* Save string to dcv->private_data */
-
-	if (options & CB_STR_SAVE) {
-		dcerpc_call_value *dcv = (dcerpc_call_value *)di->call_data;
-
-		dcv->private_data = wmem_strdup(wmem_file_scope(), s);
-	}
+	cb_str_postprocess_options(pinfo, item, di, options, s);
 }
 
 /* Dissect a pointer to a NDR string and append the string value to the
@@ -1313,13 +1313,13 @@ int dissect_ndr_str_pointer_item(tvbuff_t *tvb, gint offset,
 
 /* SID dissection routines */
 
-static int hf_nt_count = -1;
-static int hf_nt_domain_sid = -1;
+static int hf_nt_count;
+static int hf_nt_domain_sid;
 
 /* That's a SID that is always 28 bytes long */
 int
 dissect_ndr_nt_SID28(tvbuff_t *tvb, int offset, packet_info *pinfo,
-			proto_tree *tree, dcerpc_info *di, guint8 *drep _U_)
+			proto_tree *tree, dcerpc_info *di, guint8 *drep _U_, int hf_index)
 {
 	proto_item *item;
 	dcerpc_call_value *dcv = (dcerpc_call_value *)di->call_data;
@@ -1327,8 +1327,8 @@ dissect_ndr_nt_SID28(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	const char *name;
 	int newoffset;
 
-	if(di->hf_index!=-1){
-		name=proto_registrar_get_name(di->hf_index);
+	if(hf_index > 0){
+		name=proto_registrar_get_name(hf_index);
 	} else {
 		name="Domain";
 	}
@@ -1378,7 +1378,7 @@ dissect_ndr_nt_SID(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	char *sid_str=NULL;
 	const char *name;
 
-	if(di->hf_index!=-1){
+	if(di->hf_index > 0){
 		name=proto_registrar_get_name(di->hf_index);
 	} else {
 		name="Domain";
@@ -1418,10 +1418,13 @@ dissect_ndr_nt_SID(tvbuff_t *tvb, int offset, packet_info *pinfo,
 */
 /* Note this is in fact for dissecting the dom_sid2*/
 int
-dissect_ndr_nt_SID_with_options(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree, dcerpc_info *di, guint8 *drep, guint32 options)
+dissect_ndr_nt_SID_with_options(tvbuff_t *tvb, int offset, packet_info *pinfo,
+	proto_tree *tree, dcerpc_info *di, guint8 *drep, guint32 options, int hf_index)
 {
 	dcerpc_call_value *dcv = (dcerpc_call_value *)di->call_data;
 	gint levels = CB_STR_ITEM_LEVELS(options);
+
+	di->hf_index = hf_index;
 	offset=dissect_ndr_nt_SID(tvb, offset, pinfo, tree, di, drep);
 
 	if(dcv && dcv->private_data){
@@ -1466,33 +1469,47 @@ static int
 dissect_ndr_nt_SID_hf_through_ptr(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		   proto_tree *tree, dcerpc_info *di, guint8 *drep)
 {
-	offset = dissect_ndr_nt_SID(tvb, offset, pinfo, tree, di, drep);
+	offset = dissect_ndr_nt_SID_with_options(tvb, offset, pinfo, tree,
+						 di, drep,
+						 CB_STR_ITEM_LEVELS(2),
+						 di->hf_index);
 
 	return offset;
 }
 
-static gint ett_nt_sid_pointer = -1;
+static gint ett_nt_sid_pointer;
 
 int
-dissect_ndr_nt_PSID(tvbuff_t *tvb, int offset,
-		    packet_info *pinfo, proto_tree *parent_tree,
-		    dcerpc_info *di, guint8 *drep)
+dissect_ndr_nt_PSID_cb(tvbuff_t *tvb, int offset,
+		       packet_info *pinfo, proto_tree *parent_tree,
+		       dcerpc_info *di, guint8 *drep,
+		       dcerpc_callback_fnct_t *callback, void *callback_args)
 {
 	proto_item *item;
 	proto_tree *tree;
 	int old_offset=offset;
 
 	tree = proto_tree_add_subtree(parent_tree, tvb, offset, -1,
-			ett_nt_sid_pointer, &item, "SID pointer:");
+			ett_nt_sid_pointer, &item, "SID pointer");
 
-	offset = dissect_ndr_pointer(tvb, offset, pinfo, tree, di, drep,
+	offset = dissect_ndr_pointer_cb(tvb, offset, pinfo, tree, di, drep,
 			dissect_ndr_nt_SID_hf_through_ptr, NDR_POINTER_UNIQUE,
-			"SID pointer", hf_nt_domain_sid);
+			"SID pointer", hf_nt_domain_sid,
+			callback, callback_args);
 
 	proto_item_set_len(item, offset-old_offset);
 	return offset;
 }
 
+int
+dissect_ndr_nt_PSID(tvbuff_t *tvb, int offset,
+		    packet_info *pinfo, proto_tree *parent_tree,
+		    dcerpc_info *di, guint8 *drep)
+{
+	return dissect_ndr_nt_PSID_cb(tvb, offset, pinfo, parent_tree,
+				      di, drep, NULL, NULL);
+}
+
 static const true_false_string tfs_nt_acb_disabled = {
 	"Account is DISABLED",
 	"Account is NOT disabled"
@@ -1538,27 +1555,27 @@ static const true_false_string tfs_nt_acb_autolock = {
 	"This account has NOT been auto locked"
 };
 
-static gint ett_nt_acct_ctrl = -1;
+static gint ett_nt_acct_ctrl;
 
-static int hf_nt_acct_ctrl = -1;
-static int hf_nt_acb_disabled = -1;
-static int hf_nt_acb_homedirreq = -1;
-static int hf_nt_acb_pwnotreq = -1;
-static int hf_nt_acb_tempdup = -1;
-static int hf_nt_acb_normal = -1;
-static int hf_nt_acb_mns = -1;
-static int hf_nt_acb_domtrust = -1;
-static int hf_nt_acb_wstrust = -1;
-static int hf_nt_acb_svrtrust = -1;
-static int hf_nt_acb_pwnoexp = -1;
-static int hf_nt_acb_autolock = -1;
+static int hf_nt_acct_ctrl;
+static int hf_nt_acb_disabled;
+static int hf_nt_acb_homedirreq;
+static int hf_nt_acb_pwnotreq;
+static int hf_nt_acb_tempdup;
+static int hf_nt_acb_normal;
+static int hf_nt_acb_mns;
+static int hf_nt_acb_domtrust;
+static int hf_nt_acb_wstrust;
+static int hf_nt_acb_svrtrust;
+static int hf_nt_acb_pwnoexp;
+static int hf_nt_acb_autolock;
 
 int
 dissect_ndr_nt_acct_ctrl(tvbuff_t *tvb, int offset, packet_info *pinfo,
 			proto_tree *parent_tree, dcerpc_info *di, guint8 *drep)
 {
 	guint32 mask;
-	static const int * flags[] = {
+	static int * const flags[] = {
 		&hf_nt_acb_autolock,
 		&hf_nt_acb_pwnoexp,
 		&hf_nt_acb_svrtrust,
@@ -1581,7 +1598,7 @@ dissect_ndr_nt_acct_ctrl(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	return offset;
 }
 
-static int hf_logonhours_unknown_char = -1;
+static int hf_logonhours_unknown_char;
 
 static int
 dissect_LOGON_HOURS_entry(tvbuff_t *tvb, int offset,
@@ -1593,7 +1610,7 @@ dissect_LOGON_HOURS_entry(tvbuff_t *tvb, int offset,
 	return offset;
 }
 
-static gint ett_nt_logon_hours_hours = -1;
+static gint ett_nt_logon_hours_hours;
 
 static int
 dissect_LOGON_HOURS_hours(tvbuff_t *tvb, int offset,
@@ -1614,8 +1631,8 @@ dissect_LOGON_HOURS_hours(tvbuff_t *tvb, int offset,
 	return offset;
 }
 
-static gint ett_nt_logon_hours = -1;
-static int hf_logonhours_divisions = -1;
+static gint ett_nt_logon_hours;
+static int hf_logonhours_divisions;
 
 int
 dissect_ndr_nt_LOGON_HOURS(tvbuff_t *tvb, int offset,
@@ -1626,7 +1643,7 @@ dissect_ndr_nt_LOGON_HOURS(tvbuff_t *tvb, int offset,
 	proto_tree *tree;
 	int old_offset=offset;
 
-	ALIGN_TO_4_BYTES;  /* strcture starts with short, but is aligned for longs */
+	ALIGN_TO_4_BYTES;  /* structure starts with short, but is aligned for longs */
 
 	tree = proto_tree_add_subtree(parent_tree, tvb, offset, -1,
 			ett_nt_logon_hours, &item, "LOGON_HOURS:");
@@ -1664,7 +1681,7 @@ dissect_ndr_nt_PSID_ARRAY_sids (tvbuff_t *tvb, int offset,
 	return offset;
 }
 
-static gint ett_nt_sid_array = -1;
+static gint ett_nt_sid_array;
 
 int
 dissect_ndr_nt_PSID_ARRAY(tvbuff_t *tvb, int offset,
@@ -1696,8 +1713,64 @@ dissect_ndr_nt_PSID_ARRAY(tvbuff_t *tvb, int offset,
 	return offset;
 }
 
-static gint ett_nt_sid_and_attributes = -1;
-static int hf_nt_attrib = -1;
+static gint ett_nt_sid_and_attributes;
+static gint ett_nt_se_group_attrs;
+static int hf_nt_se_group_attrs;
+static int hf_nt_se_group_attrs_mandatory;
+static int hf_nt_se_group_attrs_enabled_by_default;
+static int hf_nt_se_group_attrs_enabled;
+static int hf_nt_se_group_attrs_owner;
+static int hf_nt_se_group_attrs_resource_group;
+
+static const true_false_string group_attrs_mandatory = {
+    "The MANDATORY bit is SET",
+    "The mandatory bit is NOT set",
+};
+static const true_false_string group_attrs_enabled_by_default = {
+    "The ENABLED_BY_DEFAULT bit is SET",
+    "The enabled_by_default bit is NOT set",
+};
+static const true_false_string group_attrs_enabled = {
+    "The ENABLED bit is SET",
+    "The enabled bit is NOT set",
+};
+static const true_false_string group_attrs_owner = {
+    "The OWNER bit is SET",
+    "The owner bit is NOT set",
+};
+static const true_false_string group_attrs_resource_group = {
+    "The RESOURCE GROUP bit is SET",
+    "The resource group bit is NOT set",
+};
+
+int
+dissect_ndr_nt_SE_GROUP_ATTRIBUTES(tvbuff_t *tvb, int offset,
+			packet_info *pinfo, proto_tree *parent_tree,
+			dcerpc_info *di, guint8 *drep)
+{
+    guint32 mask;
+    static int * const attr[] = {
+        &hf_nt_se_group_attrs_mandatory,
+        &hf_nt_se_group_attrs_enabled_by_default,
+        &hf_nt_se_group_attrs_enabled,
+        &hf_nt_se_group_attrs_owner,
+        &hf_nt_se_group_attrs_resource_group,
+        NULL
+    };
+
+    if(di->conformant_run){
+        /*just a run to handle conformant arrays, nothing to dissect */
+        return offset;
+    }
+
+    offset=dissect_ndr_uint32(tvb, offset, pinfo, NULL, di, drep,
+                              -1, &mask);
+
+    proto_tree_add_bitmask_value_with_flags(parent_tree, tvb, offset-4,
+					    hf_nt_se_group_attrs, ett_nt_se_group_attrs,
+					    attr, mask, BMT_NO_APPEND);
+    return offset;
+}
 
 int
 dissect_ndr_nt_SID_AND_ATTRIBUTES(tvbuff_t *tvb, int offset,
@@ -1712,13 +1785,12 @@ dissect_ndr_nt_SID_AND_ATTRIBUTES(tvbuff_t *tvb, int offset,
 
 	offset = dissect_ndr_nt_PSID(tvb, offset, pinfo, tree, di, drep);
 
-	offset = dissect_ndr_uint32 (tvb, offset, pinfo, tree, di, drep,
-				     hf_nt_attrib, NULL);
+	offset = dissect_ndr_nt_SE_GROUP_ATTRIBUTES(tvb, offset, pinfo, tree, di, drep);
 
 	return offset;
 }
 
-static gint ett_nt_sid_and_attributes_array = -1;
+static gint ett_nt_sid_and_attributes_array;
 
 int
 dissect_ndr_nt_SID_AND_ATTRIBUTES_ARRAY(tvbuff_t *tvb, int offset,
@@ -1828,57 +1900,57 @@ void dcerpc_smb_init(int proto_dcerpc)
 
 		{ &hf_nt_acb_disabled,
 		  { "Account disabled", "dcerpc.nt.acb.disabled", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_disabled), 0x0001,
+		    TFS(&tfs_nt_acb_disabled), 0x00000001,
 		    "If this account is enabled or disabled", HFILL }},
 
 		{ &hf_nt_acb_homedirreq,
 		  { "Home dir required", "dcerpc.nt.acb.homedirreq", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_homedirreq), 0x0002,
+		    TFS(&tfs_nt_acb_homedirreq), 0x00000002,
 		    "Is homedirs required for this account?", HFILL }},
 
 		{ &hf_nt_acb_pwnotreq,
 		  { "Password required", "dcerpc.nt.acb.pwnotreq", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_pwnotreq), 0x0004,
+		    TFS(&tfs_nt_acb_pwnotreq), 0x00000004,
 		    "If a password is required for this account?", HFILL }},
 
 		{ &hf_nt_acb_tempdup,
 		  { "Temporary duplicate account", "dcerpc.nt.acb.tempdup", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_tempdup), 0x0008,
+		    TFS(&tfs_nt_acb_tempdup), 0x00000008,
 		    "If this is a temporary duplicate account", HFILL }},
 
 		{ &hf_nt_acb_normal,
 		  { "Normal user account", "dcerpc.nt.acb.normal", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_normal), 0x0010,
+		    TFS(&tfs_nt_acb_normal), 0x00000010,
 		    "If this is a normal user account", HFILL }},
 
 		{ &hf_nt_acb_mns,
 		  { "MNS logon user account", "dcerpc.nt.acb.mns", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_mns), 0x0020,
+		    TFS(&tfs_nt_acb_mns), 0x00000020,
 		    NULL, HFILL }},
 
 		{ &hf_nt_acb_domtrust,
 		  { "Interdomain trust account", "dcerpc.nt.acb.domtrust", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_domtrust), 0x0040,
+		    TFS(&tfs_nt_acb_domtrust), 0x00000040,
 		    NULL, HFILL }},
 
 		{ &hf_nt_acb_wstrust,
 		  { "Workstation trust account", "dcerpc.nt.acb.wstrust", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_wstrust), 0x0080,
+		    TFS(&tfs_nt_acb_wstrust), 0x00000080,
 		    NULL, HFILL }},
 
 		{ &hf_nt_acb_svrtrust,
 		  { "Server trust account", "dcerpc.nt.acb.svrtrust", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_svrtrust), 0x0100,
+		    TFS(&tfs_nt_acb_svrtrust), 0x00000100,
 		    NULL, HFILL }},
 
 		{ &hf_nt_acb_pwnoexp,
 		  { "Password expires", "dcerpc.nt.acb.pwnoexp", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_pwnoexp), 0x0200,
+		    TFS(&tfs_nt_acb_pwnoexp), 0x00000200,
 		    "If this account expires or not", HFILL }},
 
 		{ &hf_nt_acb_autolock,
 		  { "Account is autolocked", "dcerpc.nt.acb.autolock", FT_BOOLEAN, 32,
-		    TFS(&tfs_nt_acb_autolock), 0x0400,
+		    TFS(&tfs_nt_acb_autolock), 0x00000400,
 		    "If this account has been autolocked", HFILL }},
 
 		{ &hf_nt_error,
@@ -1912,10 +1984,6 @@ void dcerpc_smb_init(int proto_dcerpc)
 
 		/* Misc */
 
-		{ &hf_nt_attrib,
-		  { "Attributes", "dcerpc.nt.attr",
-		    FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL }},
-
 		{ &hf_lsa_String_name_len,
 		  { "Name Len", "dcerpc.lsa_String.name_len",
 		    FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL }},
@@ -1948,6 +2016,35 @@ void dcerpc_smb_init(int proto_dcerpc)
 		  "HDR Length", "nt.midl.hdr_len", FT_UINT16, BASE_DEC,
 		  NULL, 0, "Length of header", HFILL }},
 
+		{ &hf_nt_se_group_attrs,
+		  { "Group Attributes", "dcerpc.nt.groups.attrs",
+		    FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL }},
+
+		{ &hf_nt_se_group_attrs_mandatory,
+		   { "Mandatory", "dcerpc.nt.groups.attrs.mandatory",
+		     FT_BOOLEAN, 32, TFS(&group_attrs_mandatory), 0x00000001,
+		     "The group attributes MANDATORY flag", HFILL }},
+
+		{ &hf_nt_se_group_attrs_enabled_by_default, {
+		  "Enabled By Default", "dcerpc.nt.groups.attrs.enabled_by_default",
+		  FT_BOOLEAN, 32, TFS(&group_attrs_enabled_by_default), 0x00000002,
+		  "The group attributes ENABLED_BY_DEFAULT flag", HFILL }},
+
+		{ &hf_nt_se_group_attrs_enabled, {
+		  "Enabled", "dcerpc.nt.groups.attrs.enabled",
+		  FT_BOOLEAN, 32, TFS(&group_attrs_enabled), 0x00000004,
+		  "The group attributes ENABLED flag", HFILL }},
+
+		{ &hf_nt_se_group_attrs_owner, {
+		  "Owner", "dcerpc.nt.groups.attrs.owner",
+		  FT_BOOLEAN, 32, TFS(&group_attrs_owner), 0x00000008,
+		  "The group attributes OWNER flag", HFILL }},
+
+		{ &hf_nt_se_group_attrs_resource_group, {
+		  "Resource Group", "dcerpc.nt.groups.attrs.resource_group",
+		  FT_BOOLEAN, 32, TFS(&group_attrs_resource_group), 0x20000000,
+		  "The group attributes RESOURCE GROUP flag", HFILL }},
+
 	};
 
 	static gint *ett[] = {
@@ -1962,6 +2059,7 @@ void dcerpc_smb_init(int proto_dcerpc)
 		&ett_nt_sid_array,
 		&ett_nt_sid_and_attributes_array,
 		&ett_nt_sid_and_attributes,
+		&ett_nt_se_group_attrs,
 		&ett_nt_counted_ascii_string,
 		&ett_lsa_String,
 		&ett_nt_MIDL_BLOB,
@@ -1983,7 +2081,7 @@ void dcerpc_smb_init(int proto_dcerpc)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
