@@ -7,20 +7,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
- * USA.51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -31,76 +18,78 @@
 void proto_register_dpnet(void);
 void proto_reg_handoff_dpnet(void);
 
+static dissector_handle_t dpnet_handle;
+
 #define DPNET_PORT 6073
 
-static int proto_dpnet = -1;
+static int proto_dpnet;
 
-static int hf_dpnet_lead = -1;
-static int hf_dpnet_command = -1;
-static int hf_dpnet_payload = -1;
-static int hf_dpnet_type = -1;
-static int hf_dpnet_application = -1;
-static int hf_dpnet_data = -1;
-static int hf_dpnet_reply_offset = -1;
-static int hf_dpnet_response_size = -1;
+static int hf_dpnet_lead;
+static int hf_dpnet_command;
+static int hf_dpnet_payload;
+static int hf_dpnet_type;
+static int hf_dpnet_application;
+static int hf_dpnet_data;
+static int hf_dpnet_reply_offset;
+static int hf_dpnet_response_size;
 
-static int hf_dpnet_desc_size = -1;
-static int hf_dpnet_desc_flags = -1;
-static int hf_dpnet_max_players = -1;
-static int hf_dpnet_current_players = -1;
-static int hf_dpnet_session_offset = -1;
-static int hf_dpnet_session_size = -1;
-static int hf_dpnet_session_name = -1;
-static int hf_dpnet_password_offset = -1;
-static int hf_dpnet_password_size = -1;
-static int hf_dpnet_reserved_offset = -1;
-static int hf_dpnet_reserved_size = -1;
-static int hf_dpnet_application_offset = -1;
-static int hf_dpnet_application_size = -1;
-static int hf_dpnet_application_data = -1;
-static int hf_dpnet_instance = -1;
-static int hf_dpnet_data_cframe_control = -1;
-static int hf_dpnet_data_cframe_msgid = -1;
-static int hf_dpnet_data_cframe_rspid = -1;
-static int hf_dpnet_data_cframe_protocol = -1;
-static int hf_dpnet_data_cframe_session = -1;
-static int hf_dpnet_data_cframe_timestamp = -1;
-static int hf_dpnet_data_cframe_padding = -1;
-static int hf_dpnet_data_cframe_flags = -1;
-static int hf_dpnet_data_cframe_retry = -1;
-static int hf_dpnet_data_cframe_nseq = -1;
-static int hf_dpnet_data_cframe_nrcv = -1;
-static int hf_dpnet_data_cframe_sack_mask1 = -1;
-static int hf_dpnet_data_cframe_sack_mask2 = -1;
-static int hf_dpnet_data_cframe_send_mask1 = -1;
-static int hf_dpnet_data_cframe_send_mask2 = -1;
-static int hf_dpnet_data_cframe_signature = -1;
-static int hf_dpnet_data_cframe_send_secret = -1;
-static int hf_dpnet_data_cframe_recv_secret = -1;
-static int hf_dpnet_data_cframe_signing_opts = -1;
-static int hf_dpnet_data_cframe_echo_time = -1;
-static int hf_dpnet_data_seq        = -1;
-static int hf_dpnet_data_nseq       = -1;
-static int hf_dpnet_data_command = -1;
-static int hf_dpnet_command_data     = -1;
-static int hf_dpnet_command_reliable = -1;
-static int hf_dpnet_command_seq      = -1;
-static int hf_dpnet_command_poll     = -1;
-static int hf_dpnet_command_new_msg  = -1;
-static int hf_dpnet_command_end_msg  = -1;
-static int hf_dpnet_command_user1    = -1;
-static int hf_dpnet_command_user2    = -1;
-static int hf_dpnet_desc_client_server = -1;
-static int hf_dpnet_desc_migrate_host  = -1;
-static int hf_dpnet_desc_nodpnsvr      = -1;
-static int hf_dpnet_desc_req_password  = -1;
-static int hf_dpnet_desc_no_enums      = -1;
-static int hf_dpnet_desc_fast_signed   = -1;
-static int hf_dpnet_desc_full_signed   = -1;
+static int hf_dpnet_desc_size;
+static int hf_dpnet_desc_flags;
+static int hf_dpnet_max_players;
+static int hf_dpnet_current_players;
+static int hf_dpnet_session_offset;
+static int hf_dpnet_session_size;
+static int hf_dpnet_session_name;
+static int hf_dpnet_password_offset;
+static int hf_dpnet_password_size;
+static int hf_dpnet_reserved_offset;
+static int hf_dpnet_reserved_size;
+static int hf_dpnet_application_offset;
+static int hf_dpnet_application_size;
+static int hf_dpnet_application_data;
+static int hf_dpnet_instance;
+static int hf_dpnet_data_cframe_control;
+static int hf_dpnet_data_cframe_msgid;
+static int hf_dpnet_data_cframe_rspid;
+static int hf_dpnet_data_cframe_protocol;
+static int hf_dpnet_data_cframe_session;
+static int hf_dpnet_data_cframe_timestamp;
+static int hf_dpnet_data_cframe_padding;
+static int hf_dpnet_data_cframe_flags;
+static int hf_dpnet_data_cframe_retry;
+static int hf_dpnet_data_cframe_nseq;
+static int hf_dpnet_data_cframe_nrcv;
+static int hf_dpnet_data_cframe_sack_mask1;
+static int hf_dpnet_data_cframe_sack_mask2;
+static int hf_dpnet_data_cframe_send_mask1;
+static int hf_dpnet_data_cframe_send_mask2;
+static int hf_dpnet_data_cframe_signature;
+static int hf_dpnet_data_cframe_send_secret;
+static int hf_dpnet_data_cframe_recv_secret;
+static int hf_dpnet_data_cframe_signing_opts;
+static int hf_dpnet_data_cframe_echo_time;
+static int hf_dpnet_data_seq;
+static int hf_dpnet_data_nseq;
+static int hf_dpnet_data_command;
+static int hf_dpnet_command_data;
+static int hf_dpnet_command_reliable;
+static int hf_dpnet_command_seq;
+static int hf_dpnet_command_poll;
+static int hf_dpnet_command_new_msg;
+static int hf_dpnet_command_end_msg;
+static int hf_dpnet_command_user1;
+static int hf_dpnet_command_user2;
+static int hf_dpnet_desc_client_server;
+static int hf_dpnet_desc_migrate_host;
+static int hf_dpnet_desc_nodpnsvr;
+static int hf_dpnet_desc_req_password;
+static int hf_dpnet_desc_no_enums;
+static int hf_dpnet_desc_fast_signed;
+static int hf_dpnet_desc_full_signed;
 
-static gint ett_dpnet = -1;
-static gint ett_dpnet_command_flags = -1;
-static gint ett_dpnet_desc_flags = -1;
+static int ett_dpnet;
+static int ett_dpnet_command_flags;
+static int ett_dpnet_desc_flags;
 
 #define DPNET_QUERY_GUID     0x01
 
@@ -143,13 +132,13 @@ static gint ett_dpnet_desc_flags = -1;
 #define PACKET_SIGNING_FAST                  0x01
 #define PACKET_SIGNING_FULL                  0x02
 
-#define SESSION_CLIENT_SERVER                0x00000001
-#define SESSION_MIGRATE_HOST                 0x00000004
-#define SESSION_NODPNSVR                     0x00000040
-#define SESSION_REQUIREPASSWORD              0x00000080
-#define SESSION_NOENUMS                      0x00000100
-#define SESSION_FAST_SIGNED                  0x00000200
-#define SESSION_FULL_SIGNED                  0x00000400
+#define SESSION_CLIENT_SERVER                0x0001
+#define SESSION_MIGRATE_HOST                 0x0004
+#define SESSION_NODPNSVR                     0x0040
+#define SESSION_REQUIREPASSWORD              0x0080
+#define SESSION_NOENUMS                      0x0100
+#define SESSION_FAST_SIGNED                  0x0200
+#define SESSION_FULL_SIGNED                  0x0400
 
 static const value_string packetenumttypes[] = {
     { 1, "Application GUID" },
@@ -234,7 +223,7 @@ static const true_false_string tfs_flags_full = {
 };
 
 
-static const int * desc_flags[] = {
+static int * const desc_flags[] = {
     &hf_dpnet_desc_client_server,
     &hf_dpnet_desc_migrate_host,
     &hf_dpnet_desc_nodpnsvr,
@@ -245,7 +234,7 @@ static const int * desc_flags[] = {
     NULL
 };
 
-static const int * command_flags[] = {
+static int * const command_flags[] = {
     &hf_dpnet_command_data,
     &hf_dpnet_command_reliable,
     &hf_dpnet_command_seq,
@@ -259,12 +248,12 @@ static const int * command_flags[] = {
 
 static void process_dpnet_query(proto_tree *dpnet_tree, tvbuff_t *tvb, packet_info *pinfo)
 {
-    gint offset = 0, data_tvb_len;
-    guint8  has_guid;
-    guint8  is_query;
+    int offset = 0, data_tvb_len;
+    uint8_t has_guid;
+    uint8_t is_query;
 
     proto_tree_add_item(dpnet_tree, hf_dpnet_lead, tvb, 0, 1, ENC_BIG_ENDIAN); offset += 1;
-    is_query = tvb_get_guint8(tvb, offset);
+    is_query = tvb_get_uint8(tvb, offset);
     proto_tree_add_item(dpnet_tree, hf_dpnet_command, tvb, offset, 1, ENC_BIG_ENDIAN); offset += 1;
     proto_tree_add_item(dpnet_tree, hf_dpnet_payload, tvb, offset, 2, ENC_LITTLE_ENDIAN); offset += 2;
 
@@ -272,7 +261,7 @@ static void process_dpnet_query(proto_tree *dpnet_tree, tvbuff_t *tvb, packet_in
     {
         col_set_str(pinfo->cinfo, COL_INFO, "DPNET Enum Query");
 
-        has_guid = tvb_get_guint8(tvb, offset);
+        has_guid = tvb_get_uint8(tvb, offset);
         proto_tree_add_item(dpnet_tree, hf_dpnet_type, tvb, offset, 1, ENC_BIG_ENDIAN); offset += 1;
 
         if (has_guid & DPNET_QUERY_GUID) {
@@ -287,8 +276,8 @@ static void process_dpnet_query(proto_tree *dpnet_tree, tvbuff_t *tvb, packet_in
     }
     else if(is_query == DPNET_ENUM_RESPONSE)
     {
-        guint32 session_offset, session_size;
-        guint32 application_offset, application_size;
+        uint32_t session_offset, session_size;
+        uint32_t application_offset, application_size;
 
         col_set_str(pinfo->cinfo, COL_INFO, "DPNET Enum Response");
 
@@ -327,7 +316,7 @@ static void process_dpnet_query(proto_tree *dpnet_tree, tvbuff_t *tvb, packet_in
 static void
 dpnet_process_data_frame(proto_tree *dpnet_tree, tvbuff_t *tvb, packet_info *pinfo)
 {
-    gint offset = 0;
+    int offset = 0;
 
     col_set_str(pinfo->cinfo, COL_INFO, "DPNET DFrame");
 
@@ -339,18 +328,18 @@ dpnet_process_data_frame(proto_tree *dpnet_tree, tvbuff_t *tvb, packet_info *pin
 static void
 dpnet_process_control_frame(proto_tree *dpnet_tree, tvbuff_t *tvb, packet_info *pinfo)
 {
-    gint offset = 0;
-    gint command;
-    const gchar *command_str;
-    gint flag;
-    guint32 data_tvb_len;
+    int offset = 0;
+    int command;
+    const char *command_str;
+    int flag;
+    uint32_t data_tvb_len;
 
     col_set_str(pinfo->cinfo, COL_INFO, "DPNET CFrame");
 
     proto_tree_add_bitmask(dpnet_tree, tvb, offset, hf_dpnet_data_command, ett_dpnet_command_flags, command_flags, ENC_BIG_ENDIAN);
     offset += 1;
 
-    command = tvb_get_guint8(tvb, offset);
+    command = tvb_get_uint8(tvb, offset);
     command_str = val_to_str_const(command, msg_cframe_control, "Unknown Control (obsolete or malformed?)");
     col_append_fstr(pinfo->cinfo, COL_INFO, " - %s", command_str);
 
@@ -409,7 +398,7 @@ dpnet_process_control_frame(proto_tree *dpnet_tree, tvbuff_t *tvb, packet_info *
                 proto_tree_add_item(dpnet_tree, hf_dpnet_data_cframe_signature, tvb, offset, 8, ENC_NA);
             break;
         case FRAME_EXOPCODE_SACK:
-            flag = tvb_get_guint8(tvb, offset);
+            flag = tvb_get_uint8(tvb, offset);
             proto_tree_add_item(dpnet_tree, hf_dpnet_data_cframe_flags, tvb, offset, 1, ENC_LITTLE_ENDIAN);
             offset += 1;
             proto_tree_add_item(dpnet_tree, hf_dpnet_data_cframe_retry, tvb, offset, 1, ENC_LITTLE_ENDIAN);
@@ -451,7 +440,7 @@ dpnet_process_control_frame(proto_tree *dpnet_tree, tvbuff_t *tvb, packet_info *
 static int
 dissect_dpnet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
-    guint8  lead;
+    uint8_t lead;
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "DPNET");
     /* Clear out stuff in the info column */
@@ -460,7 +449,7 @@ dissect_dpnet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U
     proto_item *ti = proto_tree_add_item(tree, proto_dpnet, tvb, 0, -1, ENC_NA);
     proto_tree *dpnet_tree = proto_item_add_subtree(ti, ett_dpnet);
 
-    lead = tvb_get_guint8(tvb, 0);
+    lead = tvb_get_uint8(tvb, 0);
     if(lead == 0)
     {
         process_dpnet_query(dpnet_tree, tvb, pinfo);
@@ -518,19 +507,19 @@ proto_register_dpnet(void)
         },
         { &hf_dpnet_reply_offset,
             { "Reply Offset", "dpnet.reply_offset",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_response_size,
             { "Response Size", "dpnet.response_size",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_desc_size,
             { "Description Size", "dpnet.desc_size",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
@@ -542,67 +531,67 @@ proto_register_dpnet(void)
         },
         { &hf_dpnet_max_players,
             { "Max Players", "dpnet.max_players",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_current_players,
             { "Current Players", "dpnet.current_players",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_session_offset,
             { "Session Offset", "dpnet.session_offset",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_session_size,
             { "Session Size", "dpnet.session_size",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_session_name,
             { "Session name", "dpnet.session_name",
-            FT_STRING, STR_UNICODE,
+            FT_STRING, BASE_NONE,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_password_offset,
             { "Password Offset", "dpnet.password_offset",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_password_size,
             { "Password Size", "dpnet.password_size",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_reserved_offset,
             { "Reserved Offset", "dpnet.reserved_offset",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_reserved_size,
             { "Reserved Size", "dpnet.reserved_size",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_application_offset,
             { "Application Offset", "dpnet.application_offset",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
         { &hf_dpnet_application_size,
             { "Application Size", "dpnet.application_size",
-            FT_UINT16, BASE_DEC,
+            FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
         },
@@ -655,7 +644,7 @@ proto_register_dpnet(void)
             NULL, HFILL }
         },
         { &hf_dpnet_data_cframe_timestamp,
-            { "Timestmap", "dpnet.cframe.timestamp",
+            { "Timestamp", "dpnet.cframe.timestamp",
             FT_UINT32, BASE_DEC,
             NULL, 0,
             NULL, HFILL }
@@ -849,7 +838,7 @@ proto_register_dpnet(void)
     };
 
     /* Setup protocol subtree array */
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_dpnet,
         &ett_dpnet_command_flags,
         &ett_dpnet_desc_flags
@@ -860,14 +849,13 @@ proto_register_dpnet(void)
 
     proto_register_field_array(proto_dpnet, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+
+    dpnet_handle = register_dissector("dpnet", dissect_dpnet, proto_dpnet);
 }
 
 void
 proto_reg_handoff_dpnet(void)
 {
-    static dissector_handle_t dpnet_handle;
-
-    dpnet_handle = create_dissector_handle(dissect_dpnet, proto_dpnet);
     dissector_add_uint("udp.port", DPNET_PORT, dpnet_handle);
 }
 
