@@ -20,28 +20,28 @@ void proto_reg_handoff_dvb_eit(void);
 
 static dissector_handle_t dvb_eit_handle;
 
-static int proto_dvb_eit = -1;
-static int hf_dvb_eit_service_id = -1;
-static int hf_dvb_eit_reserved = -1;
-static int hf_dvb_eit_version_number = -1;
-static int hf_dvb_eit_current_next_indicator = -1;
-static int hf_dvb_eit_section_number = -1;
-static int hf_dvb_eit_last_section_number = -1;
+static int proto_dvb_eit;
+static int hf_dvb_eit_service_id;
+static int hf_dvb_eit_reserved;
+static int hf_dvb_eit_version_number;
+static int hf_dvb_eit_current_next_indicator;
+static int hf_dvb_eit_section_number;
+static int hf_dvb_eit_last_section_number;
 
-static int hf_dvb_eit_transport_stream_id = -1;
-static int hf_dvb_eit_original_network_id = -1;
-static int hf_dvb_eit_segment_last_section_number = -1;
-static int hf_dvb_eit_last_table_id = -1;
+static int hf_dvb_eit_transport_stream_id;
+static int hf_dvb_eit_original_network_id;
+static int hf_dvb_eit_segment_last_section_number;
+static int hf_dvb_eit_last_table_id;
 
-static int hf_dvb_eit_event_id = -1;
-static int hf_dvb_eit_start_time = -1;
-static int hf_dvb_eit_duration = -1;
-static int hf_dvb_eit_running_status = -1;
-static int hf_dvb_eit_free_ca_mode = -1;
-static int hf_dvb_eit_descriptors_loop_length = -1;
+static int hf_dvb_eit_event_id;
+static int hf_dvb_eit_start_time;
+static int hf_dvb_eit_duration;
+static int hf_dvb_eit_running_status;
+static int hf_dvb_eit_free_ca_mode;
+static int hf_dvb_eit_descriptors_loop_length;
 
-static gint ett_dvb_eit = -1;
-static gint ett_dvb_eit_event = -1;
+static int ett_dvb_eit;
+static int ett_dvb_eit_event;
 
 
 #define DVB_EIT_RESERVED_MASK                     0xC0
@@ -74,9 +74,9 @@ static int
 dissect_dvb_eit(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
 
-    guint       offset = 0, length = 0;
-    guint       descriptor_len;
-    guint16     evt_id;
+    unsigned    offset = 0, length = 0;
+    unsigned    descriptor_len;
+    uint16_t    evt_id;
 
     proto_item *ti;
     proto_tree *dvb_eit_tree;
@@ -134,7 +134,7 @@ dissect_dvb_eit(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
         proto_tree_add_item(dvb_eit_event_tree, hf_dvb_eit_event_id, tvb, offset, 2, ENC_BIG_ENDIAN);
         offset += 2;
 
-        if (tvb_memeql(tvb, offset, (const guint8*)"\xFF\xFF\xFF\xFF\xFF", 5)) {
+        if (tvb_memeql(tvb, offset, (const uint8_t*)"\xFF\xFF\xFF\xFF\xFF", 5)) {
             if (packet_mpeg_sect_mjd_to_utc_time(tvb, offset, &start_time) < 0) {
                 proto_tree_add_time_format(dvb_eit_event_tree, hf_dvb_eit_start_time, tvb, offset, 5,
                                     &start_time, "Unparseable time");
@@ -151,9 +151,9 @@ dissect_dvb_eit(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
 
         duration_item = proto_tree_add_item(dvb_eit_event_tree, hf_dvb_eit_duration, tvb, offset, 3, ENC_BIG_ENDIAN);
         proto_item_append_text(duration_item, " (%02u:%02u:%02u)",
-            MPEG_SECT_BCD44_TO_DEC(tvb_get_guint8(tvb, offset)),
-            MPEG_SECT_BCD44_TO_DEC(tvb_get_guint8(tvb, offset + 1)),
-            MPEG_SECT_BCD44_TO_DEC(tvb_get_guint8(tvb, offset + 2)));
+            MPEG_SECT_BCD44_TO_DEC(tvb_get_uint8(tvb, offset)),
+            MPEG_SECT_BCD44_TO_DEC(tvb_get_uint8(tvb, offset + 1)),
+            MPEG_SECT_BCD44_TO_DEC(tvb_get_uint8(tvb, offset + 2)));
         offset += 3;
 
         proto_tree_add_item(dvb_eit_event_tree, hf_dvb_eit_running_status,          tvb, offset, 2, ENC_BIG_ENDIAN);
@@ -258,7 +258,7 @@ proto_register_dvb_eit(void)
         } }
     };
 
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_dvb_eit,
         &ett_dvb_eit_event
     };
