@@ -7,19 +7,7 @@
  * By Gerald Combs <gerald@wireshark.com>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -30,174 +18,174 @@ void proto_register_ehs(void);
 void proto_reg_handoff_ehs(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_ehs = -1;
+static int proto_ehs;
 
-static int hf_ehs_ph_version = -1;
-static int hf_ehs_ph_project = -1;
-static int hf_ehs_ph_support_mode = -1;
-static int hf_ehs_ph_data_mode = -1;
-static int hf_ehs_ph_mission = -1;
-static int hf_ehs_ph_protocol = -1;
+static int hf_ehs_ph_version;
+static int hf_ehs_ph_project;
+static int hf_ehs_ph_support_mode;
+static int hf_ehs_ph_data_mode;
+static int hf_ehs_ph_mission;
+static int hf_ehs_ph_protocol;
 
-static int hf_ehs_ph_year = -1;            /* numeric year as years since 1900 */
-static int hf_ehs_ph_jday = -1;            /* julian day of year */
-static int hf_ehs_ph_hour = -1;
-static int hf_ehs_ph_minute = -1;
-static int hf_ehs_ph_second = -1;
-static int hf_ehs_ph_tenths = -1;
+static int hf_ehs_ph_year;            /* numeric year as years since 1900 */
+static int hf_ehs_ph_jday;            /* julian day of year */
+static int hf_ehs_ph_hour;
+static int hf_ehs_ph_minute;
+static int hf_ehs_ph_second;
+static int hf_ehs_ph_tenths;
 
-static int hf_ehs_ph_new_data_flag = -1;   /* indicates the time has changed */
-/* static int hf_ehs_ph_pad1 = -1; */
-static int hf_ehs_ph_hold_flag = -1;       /* indicates a hold condition */
-static int hf_ehs_ph_sign_flag = -1;       /* indicates pre-mission, i.e. countdown, time */
+static int hf_ehs_ph_new_data_flag;   /* indicates the time has changed */
+/* static int hf_ehs_ph_pad1; */
+static int hf_ehs_ph_hold_flag;       /* indicates a hold condition */
+static int hf_ehs_ph_sign_flag;       /* indicates pre-mission, i.e. countdown, time */
 
-/* static int hf_ehs_ph_pad2 = -1; */
-/* static int hf_ehs_ph_pad3 = -1; */
-/* static int hf_ehs_ph_pad4 = -1; */
+/* static int hf_ehs_ph_pad2; */
+/* static int hf_ehs_ph_pad3; */
+/* static int hf_ehs_ph_pad4; */
 
-static int hf_ehs_ph_hosc_packet_size = -1;
+static int hf_ehs_ph_hosc_packet_size;
 
 /* generic ehs secondary header values */
-static int hf_ehs_sh_version = -1;
-static int hf_ehs_sh_data_status_bit_5 = -1;
-static int hf_ehs_sh_data_status_bit_4 = -1;
-static int hf_ehs_sh_data_status_bit_3 = -1;
-static int hf_ehs_sh_data_status_bit_2 = -1;
-static int hf_ehs_sh_data_status_bit_1 = -1;
-static int hf_ehs_sh_data_status_bit_0 = -1;
+static int hf_ehs_sh_version;
+static int hf_ehs_sh_data_status_bit_5;
+static int hf_ehs_sh_data_status_bit_4;
+static int hf_ehs_sh_data_status_bit_3;
+static int hf_ehs_sh_data_status_bit_2;
+static int hf_ehs_sh_data_status_bit_1;
+static int hf_ehs_sh_data_status_bit_0;
 
 /* other common remappings of the data status bits specific to certain secondary ehs header values */
-static int hf_ehs_sh_parent_stream_error = -1;      /* data status bit 3 */
-static int hf_ehs_sh_vcdu_sequence_error = -1;      /* data status bit 2 */
-static int hf_ehs_sh_packet_sequence_error = -1;    /* data status bit 1 */
+static int hf_ehs_sh_parent_stream_error;      /* data status bit 3 */
+static int hf_ehs_sh_vcdu_sequence_error;      /* data status bit 2 */
+static int hf_ehs_sh_packet_sequence_error;    /* data status bit 1 */
 
 /* common ehs secondary header values */
-static int hf_ehs_sh_vcdu_sequence_number = -1;
-static int hf_ehs_sh_data_stream_id = -1;
-/* static int hf_ehs_sh_pdss_reserved_1 = -1; */
-/* static int hf_ehs_sh_pdss_reserved_2 = -1; */
-/* static int hf_ehs_sh_pdss_reserved_3 = -1; */
-static int hf_ehs_sh_gse_pkt_id = -1;
-static int hf_ehs_sh_payload_vs_core_id = -1;
-static int hf_ehs_sh_apid = -1;
-static int hf_ehs_sh_virtual_channel = -1;
-static int hf_ehs_sh_pdss_reserved_sync = -1;
+static int hf_ehs_sh_vcdu_sequence_number;
+static int hf_ehs_sh_data_stream_id;
+/* static int hf_ehs_sh_pdss_reserved_1; */
+/* static int hf_ehs_sh_pdss_reserved_2; */
+/* static int hf_ehs_sh_pdss_reserved_3; */
+static int hf_ehs_sh_gse_pkt_id;
+static int hf_ehs_sh_payload_vs_core_id;
+static int hf_ehs_sh_apid;
+static int hf_ehs_sh_virtual_channel;
+static int hf_ehs_sh_pdss_reserved_sync;
 
 /* tdm ehs secondary header values */
-static int hf_ehs_sh_tdm_secondary_header_length = -1;
+static int hf_ehs_sh_tdm_secondary_header_length;
 
-static int hf_ehs_sh_tdm_extra_data_packet = -1;
-static int hf_ehs_sh_tdm_backup_stream_id_number = -1;
-static int hf_ehs_sh_tdm_end_of_data_flag = -1;
-static int hf_ehs_sh_tdm_parent_frame_error = -1;
-static int hf_ehs_sh_tdm_checksum_error = -1;
-static int hf_ehs_sh_tdm_fixed_value_error = -1;
+static int hf_ehs_sh_tdm_extra_data_packet;
+static int hf_ehs_sh_tdm_backup_stream_id_number;
+static int hf_ehs_sh_tdm_end_of_data_flag;
+static int hf_ehs_sh_tdm_parent_frame_error;
+static int hf_ehs_sh_tdm_checksum_error;
+static int hf_ehs_sh_tdm_fixed_value_error;
 
-static int hf_ehs_sh_tdm_minor_frame_counter_error = -1;
-static int hf_ehs_sh_tdm_format_id_error = -1;
-static int hf_ehs_sh_tdm_bit_slip_error = -1;
-static int hf_ehs_sh_tdm_sync_error = -1;
-static int hf_ehs_sh_tdm_aoslos_flag = -1;
-static int hf_ehs_sh_tdm_override_errors_flag = -1;
-static int hf_ehs_sh_tdm_data_status = -1;
+static int hf_ehs_sh_tdm_minor_frame_counter_error;
+static int hf_ehs_sh_tdm_format_id_error;
+static int hf_ehs_sh_tdm_bit_slip_error;
+static int hf_ehs_sh_tdm_sync_error;
+static int hf_ehs_sh_tdm_aoslos_flag;
+static int hf_ehs_sh_tdm_override_errors_flag;
+static int hf_ehs_sh_tdm_data_status;
 
-static int hf_ehs_sh_tdm_idq = -1;
-static int hf_ehs_sh_tdm_cdq = -1;
-static int hf_ehs_sh_tdm_adq = -1;
-static int hf_ehs_sh_tdm_data_dq = -1;
-/* static int hf_ehs_sh_tdm_unused = -1; */
-static int hf_ehs_sh_tdm_format_id = -1;
+static int hf_ehs_sh_tdm_idq;
+static int hf_ehs_sh_tdm_cdq;
+static int hf_ehs_sh_tdm_adq;
+static int hf_ehs_sh_tdm_data_dq;
+/* static int hf_ehs_sh_tdm_unused; */
+static int hf_ehs_sh_tdm_format_id;
 
-static int hf_ehs_sh_tdm_major_frame_packet_index = -1;
-static int hf_ehs_sh_tdm_numpkts_per_major_frame = -1;
-static int hf_ehs_sh_tdm_num_minor_frames_per_packet = -1;
+static int hf_ehs_sh_tdm_major_frame_packet_index;
+static int hf_ehs_sh_tdm_numpkts_per_major_frame;
+static int hf_ehs_sh_tdm_num_minor_frames_per_packet;
 
-static int hf_ehs_sh_tdm_cntmet_present = -1;
-static int hf_ehs_sh_tdm_obt_present = -1;
-static int hf_ehs_sh_tdm_major_frame_status_present = -1;
-/* static int hf_ehs_sh_tdm_reserved = -1; */
+static int hf_ehs_sh_tdm_cntmet_present;
+static int hf_ehs_sh_tdm_obt_present;
+static int hf_ehs_sh_tdm_major_frame_status_present;
+/* static int hf_ehs_sh_tdm_reserved; */
 
-static int hf_ehs_sh_tdm_cnt_year = -1;            /* numeric year as years since 1900 */
-static int hf_ehs_sh_tdm_cnt_jday = -1;            /* julian day of year */
-static int hf_ehs_sh_tdm_cnt_hour = -1;
-static int hf_ehs_sh_tdm_cnt_minute = -1;
-static int hf_ehs_sh_tdm_cnt_second = -1;
-static int hf_ehs_sh_tdm_cnt_tenths = -1;
+static int hf_ehs_sh_tdm_cnt_year;            /* numeric year as years since 1900 */
+static int hf_ehs_sh_tdm_cnt_jday;            /* julian day of year */
+static int hf_ehs_sh_tdm_cnt_hour;
+static int hf_ehs_sh_tdm_cnt_minute;
+static int hf_ehs_sh_tdm_cnt_second;
+static int hf_ehs_sh_tdm_cnt_tenths;
 
-static int hf_ehs_sh_tdm_obt_year = -1;            /* numeric year as years since 1900 */
-static int hf_ehs_sh_tdm_obt_jday = -1;            /* julian day of year */
-static int hf_ehs_sh_tdm_obt_hour = -1;
-static int hf_ehs_sh_tdm_obt_minute = -1;
-static int hf_ehs_sh_tdm_obt_second = -1;
-static int hf_ehs_sh_tdm_obt_tenths = -1;
+static int hf_ehs_sh_tdm_obt_year;            /* numeric year as years since 1900 */
+static int hf_ehs_sh_tdm_obt_jday;            /* julian day of year */
+static int hf_ehs_sh_tdm_obt_hour;
+static int hf_ehs_sh_tdm_obt_minute;
+static int hf_ehs_sh_tdm_obt_second;
+static int hf_ehs_sh_tdm_obt_tenths;
 
-static int hf_ehs_sh_tdm_obt_delta_time_flag = -1;
-static int hf_ehs_sh_tdm_obt_computed_flag = -1;
-static int hf_ehs_sh_tdm_obt_not_retrieved_flag = -1;
-/* static int hf_ehs_sh_tdm_obt_reserved = -1; */
-static int hf_ehs_sh_tdm_obt_source_apid = -1;
+static int hf_ehs_sh_tdm_obt_delta_time_flag;
+static int hf_ehs_sh_tdm_obt_computed_flag;
+static int hf_ehs_sh_tdm_obt_not_retrieved_flag;
+/* static int hf_ehs_sh_tdm_obt_reserved; */
+static int hf_ehs_sh_tdm_obt_source_apid;
 
-static int hf_ehs_sh_tdm_num_major_frame_status_words = -1;
+static int hf_ehs_sh_tdm_num_major_frame_status_words;
 
-/* static int hf_ehs_sh_tdm_mjfs_reserved = -1; */
-static int hf_ehs_sh_tdm_mjfs_parent_frame_error = -1;
-static int hf_ehs_sh_tdm_mjfs_checksum_error = -1;
-static int hf_ehs_sh_tdm_mjfs_fixed_value_error = -1;
+/* static int hf_ehs_sh_tdm_mjfs_reserved; */
+static int hf_ehs_sh_tdm_mjfs_parent_frame_error;
+static int hf_ehs_sh_tdm_mjfs_checksum_error;
+static int hf_ehs_sh_tdm_mjfs_fixed_value_error;
 
-static int hf_ehs_sh_tdm_mnfs_parent_frame_error = -1;
-static int hf_ehs_sh_tdm_mnfs_data_not_available = -1;
-static int hf_ehs_sh_tdm_mnfs_checksum_error = -1;
-static int hf_ehs_sh_tdm_mnfs_fixed_value_error = -1;
-static int hf_ehs_sh_tdm_mnfs_counter_error = -1;
-static int hf_ehs_sh_tdm_mnfs_format_id_error = -1;
-static int hf_ehs_sh_tdm_mnfs_bit_slip_error = -1;
-static int hf_ehs_sh_tdm_mnfs_sync_error = -1;
+static int hf_ehs_sh_tdm_mnfs_parent_frame_error;
+static int hf_ehs_sh_tdm_mnfs_data_not_available;
+static int hf_ehs_sh_tdm_mnfs_checksum_error;
+static int hf_ehs_sh_tdm_mnfs_fixed_value_error;
+static int hf_ehs_sh_tdm_mnfs_counter_error;
+static int hf_ehs_sh_tdm_mnfs_format_id_error;
+static int hf_ehs_sh_tdm_mnfs_bit_slip_error;
+static int hf_ehs_sh_tdm_mnfs_sync_error;
 
 /* pseudo ehs secondary header values */
-/* static int hf_ehs_sh_pseudo_unused = -1; */
-static int hf_ehs_sh_pseudo_workstation_id = -1;
-static int hf_ehs_sh_pseudo_user_id = -1;
-static int hf_ehs_sh_pseudo_comp_id = -1;
+/* static int hf_ehs_sh_pseudo_unused; */
+static int hf_ehs_sh_pseudo_workstation_id;
+static int hf_ehs_sh_pseudo_user_id;
+static int hf_ehs_sh_pseudo_comp_id;
 
 /* data zone values for well known protocol AOS/LOS */
-static int hf_ehs_dz_aoslos_indicator = -1;
+static int hf_ehs_dz_aoslos_indicator;
 
 /* data zone values for well known protocol UDSM */
-static int hf_ehs_dz_udsm_ccsds_vs_bpdu = -1;
-/* static int hf_ehs_dz_udsm_unused1 = -1; */
+static int hf_ehs_dz_udsm_ccsds_vs_bpdu;
+/* static int hf_ehs_dz_udsm_unused1; */
 
-/* static int hf_ehs_dz_udsm_unused2 = -1; */
+/* static int hf_ehs_dz_udsm_unused2; */
 
-/* static int hf_ehs_dz_udsm_unused3 = -1; */
-static int hf_ehs_dz_udsm_gse_pkt_id = -1;
-static int hf_ehs_dz_udsm_payload_vs_core = -1;
-static int hf_ehs_dz_udsm_apid = -1;
+/* static int hf_ehs_dz_udsm_unused3; */
+static int hf_ehs_dz_udsm_gse_pkt_id;
+static int hf_ehs_dz_udsm_payload_vs_core;
+static int hf_ehs_dz_udsm_apid;
 
-static int hf_ehs_dz_udsm_start_time_year = -1;
-static int hf_ehs_dz_udsm_start_time_jday = -1;
-static int hf_ehs_dz_udsm_start_time_hour = -1;
-static int hf_ehs_dz_udsm_start_time_minute = -1;
-static int hf_ehs_dz_udsm_start_time_second = -1;
+static int hf_ehs_dz_udsm_start_time_year;
+static int hf_ehs_dz_udsm_start_time_jday;
+static int hf_ehs_dz_udsm_start_time_hour;
+static int hf_ehs_dz_udsm_start_time_minute;
+static int hf_ehs_dz_udsm_start_time_second;
 
-static int hf_ehs_dz_udsm_stop_time_year = -1;
-static int hf_ehs_dz_udsm_stop_time_jday = -1;
-static int hf_ehs_dz_udsm_stop_time_hour = -1;
-static int hf_ehs_dz_udsm_stop_time_minute = -1;
-static int hf_ehs_dz_udsm_stop_time_second = -1;
+static int hf_ehs_dz_udsm_stop_time_year;
+static int hf_ehs_dz_udsm_stop_time_jday;
+static int hf_ehs_dz_udsm_stop_time_hour;
+static int hf_ehs_dz_udsm_stop_time_minute;
+static int hf_ehs_dz_udsm_stop_time_second;
 
-/* static int hf_ehs_dz_udsm_unused4 = -1; */
+/* static int hf_ehs_dz_udsm_unused4; */
 
-static int hf_ehs_dz_udsm_num_pkts_xmtd = -1;
+static int hf_ehs_dz_udsm_num_pkts_xmtd;
 
-static int hf_ehs_dz_udsm_num_vcdu_seqerrs = -1;
+static int hf_ehs_dz_udsm_num_vcdu_seqerrs;
 
-static int hf_ehs_dz_udsm_num_pkt_seqerrs = -1;
+static int hf_ehs_dz_udsm_num_pkt_seqerrs;
 
-static int hf_ehs_dz_udsm_num_pktlen_errors = -1;
+static int hf_ehs_dz_udsm_num_pktlen_errors;
 
-static int hf_ehs_dz_udsm_event = -1;
+static int hf_ehs_dz_udsm_event;
 
-static int hf_ehs_dz_udsm_num_pkts_xmtd_rollover = -1;
+static int hf_ehs_dz_udsm_num_pkts_xmtd_rollover;
 
 
 static dissector_handle_t ehs_handle;
@@ -206,17 +194,17 @@ static dissector_handle_t ehs_handle;
 static dissector_handle_t ccsds_handle;
 
 /* Initialize the subtree pointers */
-static gint ett_ehs = -1;
-static gint ett_ehs_primary_header = -1;
-static gint ett_ehs_secondary_header = -1;
-static gint ett_ehs_data_zone = -1;
-static gint ett_ehs_cnt_time = -1;
-static gint ett_ehs_obt_time = -1;
-static gint ett_ehs_udsm_start_time = -1;
-static gint ett_ehs_udsm_stop_time = -1;
-static gint ett_ehs_ground_receipt_time = -1;
-static gint ett_ehs_major_frame = -1;
-static gint ett_ehs_minor_frame = -1;
+static int ett_ehs;
+static int ett_ehs_primary_header;
+static int ett_ehs_secondary_header;
+static int ett_ehs_data_zone;
+static int ett_ehs_cnt_time;
+static int ett_ehs_obt_time;
+static int ett_ehs_udsm_start_time;
+static int ett_ehs_udsm_stop_time;
+static int ett_ehs_ground_receipt_time;
+static int ett_ehs_major_frame;
+static int ett_ehs_minor_frame;
 
 /* EHS protocol types */
 typedef enum EHS_Protocol_Type
@@ -646,13 +634,13 @@ tdm_secondary_header_dissector ( proto_tree* ehs_secondary_header_tree, tvbuff_t
   proto_tree_add_item ( ehs_secondary_header_tree, hf_ehs_sh_tdm_numpkts_per_major_frame, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
-  num_minor_frames = 1 + tvb_get_guint8 ( tvb, *offset );
+  num_minor_frames = 1 + tvb_get_uint8 ( tvb, *offset );
   proto_tree_add_item ( ehs_secondary_header_tree, hf_ehs_sh_tdm_num_minor_frames_per_packet, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
-  cntmet_present = tvb_get_guint8 ( tvb, *offset ) & 0x80;
-  obt_present = tvb_get_guint8 ( tvb, *offset ) & 0x40;
-  mjfs_present = tvb_get_guint8 ( tvb, *offset ) & 0x20;
+  cntmet_present = tvb_get_uint8 ( tvb, *offset ) & 0x80;
+  obt_present = tvb_get_uint8 ( tvb, *offset ) & 0x40;
+  mjfs_present = tvb_get_uint8 ( tvb, *offset ) & 0x20;
   proto_tree_add_item ( ehs_secondary_header_tree, hf_ehs_sh_tdm_cntmet_present, tvb, *offset, 1, ENC_BIG_ENDIAN );
   proto_tree_add_item ( ehs_secondary_header_tree, hf_ehs_sh_tdm_obt_present, tvb, *offset, 1, ENC_BIG_ENDIAN );
   proto_tree_add_item ( ehs_secondary_header_tree, hf_ehs_sh_tdm_major_frame_status_present, tvb, *offset, 1, ENC_BIG_ENDIAN );
@@ -663,7 +651,7 @@ tdm_secondary_header_dissector ( proto_tree* ehs_secondary_header_tree, tvbuff_t
   {
     time_tree = proto_tree_add_subtree(ehs_secondary_header_tree, tvb, *offset, 7, ett_ehs_cnt_time, &time_item, "CNT/MET Time: ");
 
-    year = tvb_get_guint8 ( tvb, *offset );
+    year = tvb_get_uint8 ( tvb, *offset );
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_cnt_year, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
@@ -671,19 +659,19 @@ tdm_secondary_header_dissector ( proto_tree* ehs_secondary_header_tree, tvbuff_t
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_cnt_jday, tvb, *offset, 2, ENC_BIG_ENDIAN );
     *offset += 2;
 
-    hour = tvb_get_guint8 ( tvb, *offset );
+    hour = tvb_get_uint8 ( tvb, *offset );
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_cnt_hour, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
-    minute = tvb_get_guint8 ( tvb, *offset );
+    minute = tvb_get_uint8 ( tvb, *offset );
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_cnt_minute, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
-    second = tvb_get_guint8 ( tvb, *offset );
+    second = tvb_get_uint8 ( tvb, *offset );
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_cnt_second, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
-    tenths = tvb_get_guint8 ( tvb, *offset ) >> 4;
+    tenths = tvb_get_uint8 ( tvb, *offset ) >> 4;
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_cnt_tenths, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
@@ -696,7 +684,7 @@ tdm_secondary_header_dissector ( proto_tree* ehs_secondary_header_tree, tvbuff_t
   {
     time_tree = proto_tree_add_subtree(ehs_secondary_header_tree, tvb, *offset, 7, ett_ehs_obt_time, &time_item, "OBT Time: ");
 
-    year = tvb_get_guint8 ( tvb, *offset );
+    year = tvb_get_uint8 ( tvb, *offset );
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_obt_year, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
@@ -704,19 +692,19 @@ tdm_secondary_header_dissector ( proto_tree* ehs_secondary_header_tree, tvbuff_t
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_obt_jday, tvb, *offset, 2, ENC_BIG_ENDIAN );
     *offset += 2;
 
-    hour = tvb_get_guint8 ( tvb, *offset );
+    hour = tvb_get_uint8 ( tvb, *offset );
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_obt_hour, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
-    minute = tvb_get_guint8 ( tvb, *offset );
+    minute = tvb_get_uint8 ( tvb, *offset );
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_obt_minute, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
-    second = tvb_get_guint8 ( tvb, *offset );
+    second = tvb_get_uint8 ( tvb, *offset );
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_obt_second, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
-    tenths = tvb_get_guint8 ( tvb, *offset ) >> 4;
+    tenths = tvb_get_uint8 ( tvb, *offset ) >> 4;
     proto_tree_add_item ( time_tree, hf_ehs_sh_tdm_obt_tenths, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
@@ -732,14 +720,14 @@ tdm_secondary_header_dissector ( proto_tree* ehs_secondary_header_tree, tvbuff_t
 
   if ( mjfs_present )
   {
-    num_major_frames = 1 + tvb_get_guint8 ( tvb, *offset );
+    num_major_frames = 1 + tvb_get_uint8 ( tvb, *offset );
     proto_tree_add_item ( ehs_secondary_header_tree, hf_ehs_sh_tdm_num_major_frame_status_words, tvb, *offset, 1, ENC_BIG_ENDIAN );
     ++(*offset);
 
     for ( j=0; j < num_major_frames; ++j )
     {
       proto_tree* major_tree;
-      const int * major_fields[] = {
+      static int * const major_fields[] = {
         /* &hf_ehs_sh_tdm_mjfs_reserved, */
         &hf_ehs_sh_tdm_mjfs_parent_frame_error,
         &hf_ehs_sh_tdm_mjfs_checksum_error,
@@ -756,7 +744,7 @@ tdm_secondary_header_dissector ( proto_tree* ehs_secondary_header_tree, tvbuff_t
   for ( j=0; j < num_minor_frames; ++j )
   {
     proto_tree* minor_tree;
-    const int * minor_fields[] = {
+    static int * const minor_fields[] = {
         &hf_ehs_sh_tdm_mnfs_parent_frame_error,
         &hf_ehs_sh_tdm_mnfs_data_not_available,
         &hf_ehs_sh_tdm_mnfs_checksum_error,
@@ -937,7 +925,7 @@ udsm_data_zone_dissector ( proto_tree* ehs_tree, tvbuff_t* tvb, int* offset, pac
   *offset += 2;
 
   time_tree = proto_tree_add_subtree(ehs_data_zone_tree, tvb, *offset, 7, ett_ehs_udsm_start_time, &time_item, "UDSM Start Time: ");
-  year = tvb_get_guint8 ( tvb, *offset );
+  year = tvb_get_uint8 ( tvb, *offset );
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_start_time_year, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
@@ -945,15 +933,15 @@ udsm_data_zone_dissector ( proto_tree* ehs_tree, tvbuff_t* tvb, int* offset, pac
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_start_time_jday, tvb, *offset, 2, ENC_BIG_ENDIAN );
   *offset += 2;
 
-  hour = tvb_get_guint8 ( tvb, *offset );
+  hour = tvb_get_uint8 ( tvb, *offset );
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_start_time_hour, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
-  minute = tvb_get_guint8 ( tvb, *offset );
+  minute = tvb_get_uint8 ( tvb, *offset );
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_start_time_minute, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
-  second = tvb_get_guint8 ( tvb, *offset );
+  second = tvb_get_uint8 ( tvb, *offset );
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_start_time_second, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
@@ -961,7 +949,7 @@ udsm_data_zone_dissector ( proto_tree* ehs_tree, tvbuff_t* tvb, int* offset, pac
   proto_item_append_text( time_item, "%04d/%03d:%02d:%02d:%02d = UDSM Start Time", year + 1900, jday, hour, minute, second );
 
   time_tree = proto_tree_add_subtree(ehs_data_zone_tree, tvb, *offset, 7, ett_ehs_udsm_stop_time, &time_item, "UDSM Stop Time: ");
-  year = tvb_get_guint8 ( tvb, *offset );
+  year = tvb_get_uint8 ( tvb, *offset );
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_stop_time_year, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
@@ -969,15 +957,15 @@ udsm_data_zone_dissector ( proto_tree* ehs_tree, tvbuff_t* tvb, int* offset, pac
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_stop_time_jday, tvb, *offset, 2, ENC_BIG_ENDIAN );
   *offset += 2;
 
-  hour = tvb_get_guint8 ( tvb, *offset );
+  hour = tvb_get_uint8 ( tvb, *offset );
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_stop_time_hour, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
-  minute = tvb_get_guint8 ( tvb, *offset );
+  minute = tvb_get_uint8 ( tvb, *offset );
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_stop_time_minute, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
-  second = tvb_get_guint8 ( tvb, *offset );
+  second = tvb_get_uint8 ( tvb, *offset );
   proto_tree_add_item ( time_tree, hf_ehs_dz_udsm_stop_time_second, tvb, *offset, 1, ENC_BIG_ENDIAN );
   ++(*offset);
 
@@ -1074,7 +1062,7 @@ static int
 dissect_ehs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
   int         offset = 0;
-  guint16     first_word;
+  uint16_t    first_word;
 
   tvbuff_t   *new_tvb;
 
@@ -1111,12 +1099,12 @@ dissect_ehs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
   ++offset;
 
   /* save protocol for use later on */
-  protocol = tvb_get_guint8 ( tvb, offset );
+  protocol = tvb_get_uint8 ( tvb, offset );
   proto_tree_add_item ( ehs_primary_header_tree, hf_ehs_ph_protocol, tvb, offset, 1, ENC_BIG_ENDIAN );
   ++offset;
 
   time_tree = proto_tree_add_subtree(ehs_primary_header_tree, tvb, offset, 7, ett_ehs_ground_receipt_time, &time_item, "EHS Ground Receipt Time: ");
-  year = tvb_get_guint8 ( tvb, offset );
+  year = tvb_get_uint8 ( tvb, offset );
   proto_tree_add_item ( time_tree, hf_ehs_ph_year, tvb, offset, 1, ENC_BIG_ENDIAN );
   ++offset;
 
@@ -1124,19 +1112,19 @@ dissect_ehs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
   proto_tree_add_item ( time_tree, hf_ehs_ph_jday, tvb, offset, 2, ENC_BIG_ENDIAN );
   offset += 2;
 
-  hour = tvb_get_guint8 ( tvb, offset );
+  hour = tvb_get_uint8 ( tvb, offset );
   proto_tree_add_item ( time_tree, hf_ehs_ph_hour, tvb, offset, 1, ENC_BIG_ENDIAN );
   ++offset;
 
-  minute = tvb_get_guint8 ( tvb, offset );
+  minute = tvb_get_uint8 ( tvb, offset );
   proto_tree_add_item ( time_tree, hf_ehs_ph_minute, tvb, offset, 1, ENC_BIG_ENDIAN );
   ++offset;
 
-  second = tvb_get_guint8 ( tvb, offset );
+  second = tvb_get_uint8 ( tvb, offset );
   proto_tree_add_item ( time_tree, hf_ehs_ph_second, tvb, offset, 1, ENC_BIG_ENDIAN );
   ++offset;
 
-  tenths = tvb_get_guint8 ( tvb, offset ) >> 4;
+  tenths = tvb_get_uint8 ( tvb, offset ) >> 4;
   proto_tree_add_item ( time_tree, hf_ehs_ph_tenths, tvb, offset, 1, ENC_BIG_ENDIAN );
 
   /* format a more readable ground receipt time string */
@@ -1234,43 +1222,43 @@ proto_register_ehs(void)
 
       { &hf_ehs_ph_mission,
         { "Mission", "ehs.mission",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_ph_protocol,
         { "Protocol", "ehs.protocol",
-          FT_UINT8, BASE_DEC, VALS(ehs_primary_header_protocol), 0xff,
+          FT_UINT8, BASE_DEC, VALS(ehs_primary_header_protocol), 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_ph_year,
         { "Years since 1900", "ehs.year",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_ph_jday,
         { "Julian Day of Year", "ehs.jday",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_ph_hour,
         { "Hour", "ehs.hour",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_ph_minute,
         { "Minute", "ehs.minute",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_ph_second,
         { "Second", "ehs.second",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
@@ -1324,7 +1312,7 @@ proto_register_ehs(void)
 
       { &hf_ehs_ph_hosc_packet_size,
         { "HOSC Packet Size", "ehs.hosc_packet_size",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
@@ -1388,7 +1376,7 @@ proto_register_ehs(void)
       /* common ehs secondary header values */
       { &hf_ehs_sh_vcdu_sequence_number,
         { "VCDU Sequence Number", "ehs2.vcdu_seqno",
-          FT_UINT24, BASE_DEC, NULL, 0xffffff,
+          FT_UINT24, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
@@ -1434,13 +1422,13 @@ proto_register_ehs(void)
 
       { &hf_ehs_sh_virtual_channel,
         { "Virtual Channel", "ehs2.vcid",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_sh_pdss_reserved_sync,
         { "Pdss Reserved Sync", "ehs2.sync",
-          FT_UINT16, BASE_HEX, NULL, 0xffff,
+          FT_UINT16, BASE_HEX, NULL, 0x0,
           NULL, HFILL }
       },
 
@@ -1448,7 +1436,7 @@ proto_register_ehs(void)
       /* tdm ehs secondary header values */
       { &hf_ehs_sh_tdm_secondary_header_length,
         { "Secondary Header Length", "ehs2.tdm_secondary_header_length",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
@@ -1521,57 +1509,57 @@ proto_register_ehs(void)
 
       { &hf_ehs_sh_tdm_idq,
         { "IDQ", "ehs2.tdm_idq",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_sh_tdm_cdq,
         { "CDQ", "ehs2.tdm_cdq",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_sh_tdm_adq,
         { "ADQ", "ehs2.tdm_adq",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_sh_tdm_data_dq,
         { "Data DQ", "ehs2.tdm_data_dq",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
 #if 0
       { &hf_ehs_sh_tdm_unused,
         { "Unused", "ehs2.tdm_unused",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 #endif
 
       { &hf_ehs_sh_tdm_format_id,
         { "Format ID", "ehs2.tdm_format_id",
-          FT_UINT16, BASE_HEX, NULL, 0xffff,
+          FT_UINT16, BASE_HEX, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_sh_tdm_major_frame_packet_index,
         { "Major Frame Packet Index", "ehs2.tdm_major_frame_packet_index",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_sh_tdm_numpkts_per_major_frame,
         { "Num Packets per Major Frame", "ehs2.tdm_numpkts_per_major_frame",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_sh_tdm_num_minor_frames_per_packet,
         { "Num Minor Frames per Packet", "ehs2.tdm_num_minor_frame_per_packet",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
@@ -1600,27 +1588,27 @@ proto_register_ehs(void)
 
       { &hf_ehs_sh_tdm_cnt_year,
         { "CNT Years since 1900", "ehs2.tdm_cnt_year",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_cnt_jday,
         { "CNT Julian Day of Year", "ehs2.tdm_cnt_jday",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_cnt_hour,
         { "CNT Hour", "ehs2.tdm_cnt_hour",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_cnt_minute,
         { "CNT Minute", "ehs2.tdm_cnt_minute",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_cnt_second,
         { "CNT Second", "ehs2.tdm_cnt_second",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_cnt_tenths,
@@ -1631,27 +1619,27 @@ proto_register_ehs(void)
 
       { &hf_ehs_sh_tdm_obt_year,
         { "OBT Years since 1900", "ehs2.tdm_cnt_year",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_obt_jday,
         { "OBT Julian Day of Year", "ehs2.tdm_cnt_jday",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_obt_hour,
         { "OBT Hour", "ehs2.tdm_cnt_hour",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_obt_minute,
         { "OBT Minute", "ehs2.tdm_cnt_minute",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_obt_second,
         { "OBT Second", "ehs2.tdm_cnt_second",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_tdm_obt_tenths,
@@ -1690,7 +1678,7 @@ proto_register_ehs(void)
 
       { &hf_ehs_sh_tdm_num_major_frame_status_words,
         { "Number of Major Frame Status Words", "ehs2.tdm_num_major_frame_status_words",
-          FT_UINT8, BASE_DEC, NULL, 0x0ff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
@@ -1769,17 +1757,17 @@ proto_register_ehs(void)
 #endif
       { &hf_ehs_sh_pseudo_workstation_id,
         { "Workstation ID", "ehs2.pseudo_workstation_id",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_pseudo_user_id,
         { "User ID", "ehs2.pseudo_user_id",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_sh_pseudo_comp_id,
         { "Comp ID", "ehs2.pseudo_comp_id",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
@@ -1835,53 +1823,53 @@ proto_register_ehs(void)
 
       { &hf_ehs_dz_udsm_start_time_year,
         { "Start Time Years since 1900", "ehs.dz.udsm_start_time_year",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_dz_udsm_start_time_jday,
         { "Start Time Julian Day", "ehs.dz.udsm_start_time_jday",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_dz_udsm_start_time_hour,
         { "Start Time Hour", "ehs.dz.udsm_start_time_hour",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_dz_udsm_start_time_minute,
         { "Start Time Minute", "ehs.dz.udsm_start_time_minute",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_dz_udsm_start_time_second,
         { "Start Time Second", "ehs.dz.udsm_start_time_second",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_dz_udsm_stop_time_year,
         { "Stop Time Years since 1900", "ehs.dz.udsm_stop_time_year",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_dz_udsm_stop_time_jday,
         { "Stop Time Julian Day", "ehs.dz.udsm_stop_time_jday",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_dz_udsm_stop_time_hour,
         { "Stop Time Hour", "ehs.dz.udsm_stop_time_hour",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_dz_udsm_stop_time_minute,
         { "Stop Time Minute", "ehs.dz.udsm_stop_time_minute",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
       { &hf_ehs_dz_udsm_stop_time_second,
         { "Stop Time Second", "ehs.dz.udsm_stop_time_second",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
@@ -1895,44 +1883,44 @@ proto_register_ehs(void)
 
       { &hf_ehs_dz_udsm_num_pkts_xmtd,
         { "Num Pkts Transmitted", "ehs.dz.udsm_num_pkts_xmtd",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_dz_udsm_num_vcdu_seqerrs,
         { "Num VCDU Sequence Errors", "ehs.dz.udsm_num_vcdu_seqerrs",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_dz_udsm_num_pkt_seqerrs,
         { "Num Packet Sequence Errors", "ehs.dz.udsm_num_pkt_seqerrs",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_dz_udsm_num_pktlen_errors,
         { "Num Pkt Length Errors", "ehs.dz.udsm_num_pktlen_errors",
-          FT_UINT16, BASE_DEC, NULL, 0xffff,
+          FT_UINT16, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_dz_udsm_event,
         { "UDSM Event Code", "ehs.dz.udsm_event",
-          FT_UINT8, BASE_DEC, VALS(ehs_data_zone_udsm_event), 0xff,
+          FT_UINT8, BASE_DEC, VALS(ehs_data_zone_udsm_event), 0x0,
           NULL, HFILL }
       },
 
       { &hf_ehs_dz_udsm_num_pkts_xmtd_rollover,
         { "Num Pkts Transmitted Rollover Counter", "ehs.dz.udsm_num_pkts_xmtd_rollover",
-          FT_UINT8, BASE_DEC, NULL, 0xff,
+          FT_UINT8, BASE_DEC, NULL, 0x0,
           NULL, HFILL }
       },
 
     };
 
   /* Setup protocol subtree array */
-  static gint *ett[] = {
+  static int *ett[] = {
     &ett_ehs,
     &ett_ehs_primary_header,
     &ett_ehs_secondary_header,
@@ -1965,7 +1953,7 @@ proto_reg_handoff_ehs(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local Variables:
  * c-basic-offset: 2
