@@ -21,58 +21,58 @@
 #include <epan/etypes.h>
 
 
-static int proto_elmi = -1;
+static int proto_elmi;
 
 void proto_register_elmi(void);
 void proto_reg_handoff_elmi(void);
 
 static dissector_handle_t elmi_handle;
 
-static gint ett_elmi = -1;
-static gint ett_elmi_info_elem = -1;
-static gint ett_elmi_sub_info_elem = -1;
+static int ett_elmi;
+static int ett_elmi_info_elem;
+static int ett_elmi_sub_info_elem;
 
-static int hf_elmi_ver = -1;
-static int hf_elmi_msg_type = -1;
-static int hf_elmi_info_elem = -1;
-static int hf_elmi_info_elem_len = -1;
-static int hf_elmi_report_type = -1;
-static int hf_elmi_snd_seq_num = -1;
-static int hf_elmi_rcv_seq_num = -1;
-static int hf_elmi_dat_inst = -1;
-static int hf_elmi_reserved = -1;
-static int hf_elmi_uni_status = -1;
-static int hf_elmi_evc_refid = -1;
-static int hf_elmi_evc_status = -1;
-static int hf_last_ie = -1;
-static int hf_map_seq = -1;
-static int hf_priority = -1;
-static int hf_default_evc = -1;
-static int hf_elmi_sub_info_elem = -1;
-static int hf_elmi_sub_info_elem_len = -1;
-static int hf_elmi_uni_id = -1;
-static int hf_elmi_evc_type = -1;
-static int hf_elmi_evc_id = -1;
-static int hf_elmi_ce_vlan_id = -1;
-static int hf_elmi_sub_info_color_mode_flag = -1;
-static int hf_elmi_sub_info_coupling_flag = -1;
-static int hf_elmi_sub_info_per_cos_bit = -1;
-static int hf_elmi_sub_cir_magnitude = -1;
-static int hf_elmi_sub_cir_multiplier = -1;
-static int hf_elmi_sub_cbs_magnitude = -1;
-static int hf_elmi_sub_cbs_multiplier = -1;
-static int hf_elmi_sub_eir_magnitude = -1;
-static int hf_elmi_sub_eir_multiplier = -1;
-static int hf_elmi_sub_ebs_magnitude = -1;
-static int hf_elmi_sub_ebs_multiplier = -1;
-static int hf_elmi_sub_user_prio_0 = -1;
-static int hf_elmi_sub_user_prio_1 = -1;
-static int hf_elmi_sub_user_prio_2 = -1;
-static int hf_elmi_sub_user_prio_3 = -1;
-static int hf_elmi_sub_user_prio_4 = -1;
-static int hf_elmi_sub_user_prio_5 = -1;
-static int hf_elmi_sub_user_prio_6 = -1;
-static int hf_elmi_sub_user_prio_7 = -1;
+static int hf_elmi_ver;
+static int hf_elmi_msg_type;
+static int hf_elmi_info_elem;
+static int hf_elmi_info_elem_len;
+static int hf_elmi_report_type;
+static int hf_elmi_snd_seq_num;
+static int hf_elmi_rcv_seq_num;
+static int hf_elmi_dat_inst;
+static int hf_elmi_reserved;
+static int hf_elmi_uni_status;
+static int hf_elmi_evc_refid;
+static int hf_elmi_evc_status;
+static int hf_last_ie;
+static int hf_map_seq;
+static int hf_priority;
+static int hf_default_evc;
+static int hf_elmi_sub_info_elem;
+static int hf_elmi_sub_info_elem_len;
+static int hf_elmi_uni_id;
+static int hf_elmi_evc_type;
+static int hf_elmi_evc_id;
+static int hf_elmi_ce_vlan_id;
+static int hf_elmi_sub_info_color_mode_flag;
+static int hf_elmi_sub_info_coupling_flag;
+static int hf_elmi_sub_info_per_cos_bit;
+static int hf_elmi_sub_cir_magnitude;
+static int hf_elmi_sub_cir_multiplier;
+static int hf_elmi_sub_cbs_magnitude;
+static int hf_elmi_sub_cbs_multiplier;
+static int hf_elmi_sub_eir_magnitude;
+static int hf_elmi_sub_eir_multiplier;
+static int hf_elmi_sub_ebs_magnitude;
+static int hf_elmi_sub_ebs_multiplier;
+static int hf_elmi_sub_user_prio_0;
+static int hf_elmi_sub_user_prio_1;
+static int hf_elmi_sub_user_prio_2;
+static int hf_elmi_sub_user_prio_3;
+static int hf_elmi_sub_user_prio_4;
+static int hf_elmi_sub_user_prio_5;
+static int hf_elmi_sub_user_prio_6;
+static int hf_elmi_sub_user_prio_7;
 
 static const value_string elmi_msg_type[] = {
     { 0x75, "Status enquiry" },
@@ -143,19 +143,19 @@ static const value_string elmi_evc_type[] = {
     { 0, NULL }
 };
 
-static gint
+static int
 dissect_elmi_sub_info_elem(
-        tvbuff_t *tvb, gint offset, proto_tree *tree)
+        tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-    gint        offset_start;
-    guint8      sub_tag, len;
+    int         offset_start;
+    uint8_t     sub_tag, len;
     proto_item *tree_pi;
     proto_tree *sub_info_elem_tree = tree;
 
     offset_start = offset;
 
-    sub_tag = tvb_get_guint8(tvb, offset);
-    len = tvb_get_guint8(tvb, offset + 1);
+    sub_tag = tvb_get_uint8(tvb, offset);
+    len = tvb_get_uint8(tvb, offset + 1);
 
     sub_info_elem_tree = proto_tree_add_subtree_format(
             tree, tvb, offset, len + 2, ett_elmi_sub_info_elem, &tree_pi,
@@ -233,18 +233,18 @@ dissect_elmi_sub_info_elem(
 
 }
 
-static gint
+static int
 dissect_elmi_info_elem(
-        tvbuff_t *tvb, gint offset, packet_info *pinfo _U_, proto_tree *tree)
+        tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree *tree)
 {
-    gint        offset_start;
-    guint8      tag, len, ret;
+    int         offset_start;
+    uint8_t     tag, len, ret;
     proto_item *tree_pi;
     proto_tree *info_elem_tree;
 
     offset_start = offset;
 
-    tag = tvb_get_guint8(tvb, offset);
+    tag = tvb_get_uint8(tvb, offset);
     if (tag==0)
         return -1;
 
@@ -256,7 +256,7 @@ dissect_elmi_info_elem(
             tvb, offset, 1, ENC_BIG_ENDIAN);
     offset++;
 
-    len = tvb_get_guint8(tvb, offset);
+    len = tvb_get_uint8(tvb, offset);
     proto_tree_add_item(info_elem_tree, hf_elmi_info_elem_len,
             tvb, offset, 1, ENC_BIG_ENDIAN);
     offset++;
@@ -338,9 +338,9 @@ dissect_elmi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
 {
     proto_item *pi;
     proto_tree *elmi_tree;
-    gint        offset=0;
-    guint8      msg_type;
-    gint        ret;
+    int         offset=0;
+    uint8_t     msg_type;
+    int         ret;
 
     col_clear(pinfo->cinfo, COL_INFO);
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "E-LMI");
@@ -353,7 +353,7 @@ dissect_elmi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     proto_tree_add_item(elmi_tree, hf_elmi_ver, tvb, offset, 1, ENC_BIG_ENDIAN);
     offset++;
 
-    msg_type = tvb_get_guint8(tvb, offset);
+    msg_type = tvb_get_uint8(tvb, offset);
     proto_tree_add_item(elmi_tree, hf_elmi_msg_type,
             tvb, offset, 1, ENC_BIG_ENDIAN);
     col_append_str(pinfo->cinfo, COL_INFO,
@@ -502,15 +502,14 @@ proto_register_elmi(void)
                 TFS(&tfs_applicable_not_applicable), 0x80, NULL, HFILL } },
     };
 
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_elmi,
         &ett_elmi_info_elem,
         &ett_elmi_sub_info_elem
     };
 
 
-    proto_elmi = proto_register_protocol(
-            "Ethernet Local Management Interface", "E-LMI", "elmi");
+    proto_elmi = proto_register_protocol("Ethernet Local Management Interface", "E-LMI", "elmi");
 
     proto_register_field_array(proto_elmi, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
