@@ -10,9 +10,17 @@
  */
 
 /*
-Zero Protocol coming from Facebook and used the same framing like QUIC (tag-map value) but based on TCP
-It was reverse engineered based off of QUIC dissector functionality
-*/
+ * Zero Protocol coming from Facebook and used the same framing like QUIC
+ * (tag-map value) but based on TCP
+ *
+ * See
+ *
+ *    https://engineering.fb.com/networking-traffic/building-zero-protocol-for-fast-secure-mobile-connections/
+ *
+ * for some (not much!) information on it.
+ *
+ * It was reverse engineered based off of QUIC dissector functionality
+ */
 #include "config.h"
 
 #include <epan/packet.h>
@@ -23,50 +31,49 @@ It was reverse engineered based off of QUIC dissector functionality
 void proto_register_fb_zero(void);
 void proto_reg_handoff_fb_zero(void);
 
-static int proto_fb_zero = -1;
+static int proto_fb_zero;
 
 static dissector_handle_t fb_zero_handle;
 
-static int hf_fb_zero_puflags = -1;
-static int hf_fb_zero_puflags_vrsn = -1;
-static int hf_fb_zero_puflags_unknown = -1;
-static int hf_fb_zero_version = -1;
-static int hf_fb_zero_length = -1;
-static int hf_fb_zero_tag = -1;
-static int hf_fb_zero_tags = -1;
-static int hf_fb_zero_tag_number = -1;
-static int hf_fb_zero_tag_value = -1;
-static int hf_fb_zero_tag_type = -1;
-static int hf_fb_zero_tag_offset_end = -1;
-static int hf_fb_zero_tag_length = -1;
-static int hf_fb_zero_tag_sni = -1;
-static int hf_fb_zero_tag_vers = -1;
-static int hf_fb_zero_tag_sno = -1;
-static int hf_fb_zero_tag_aead = -1;
-static int hf_fb_zero_tag_scid = -1;
-static int hf_fb_zero_tag_time = -1;
-static int hf_fb_zero_tag_alpn = -1;
-static int hf_fb_zero_tag_pubs = -1;
-static int hf_fb_zero_tag_kexs = -1;
-static int hf_fb_zero_tag_nonc = -1;
+static int hf_fb_zero_puflags;
+static int hf_fb_zero_puflags_vrsn;
+static int hf_fb_zero_puflags_unknown;
+static int hf_fb_zero_version;
+static int hf_fb_zero_length;
+static int hf_fb_zero_tag;
+static int hf_fb_zero_tags;
+static int hf_fb_zero_tag_number;
+static int hf_fb_zero_tag_value;
+static int hf_fb_zero_tag_type;
+static int hf_fb_zero_tag_offset_end;
+static int hf_fb_zero_tag_length;
+static int hf_fb_zero_tag_sni;
+static int hf_fb_zero_tag_vers;
+static int hf_fb_zero_tag_sno;
+static int hf_fb_zero_tag_aead;
+static int hf_fb_zero_tag_scid;
+static int hf_fb_zero_tag_time;
+static int hf_fb_zero_tag_alpn;
+static int hf_fb_zero_tag_pubs;
+static int hf_fb_zero_tag_kexs;
+static int hf_fb_zero_tag_nonc;
 
-static int hf_fb_zero_tag_unknown = -1;
+static int hf_fb_zero_tag_unknown;
 
-static int hf_fb_zero_padding = -1;
-static int hf_fb_zero_payload = -1;
-static int hf_fb_zero_unknown = -1;
+static int hf_fb_zero_padding;
+static int hf_fb_zero_payload;
+static int hf_fb_zero_unknown;
 
-static gint ett_fb_zero = -1;
-static gint ett_fb_zero_puflags = -1;
-static gint ett_fb_zero_prflags = -1;
-static gint ett_fb_zero_ft = -1;
-static gint ett_fb_zero_ftflags = -1;
-static gint ett_fb_zero_tag_value = -1;
+static int ett_fb_zero;
+static int ett_fb_zero_puflags;
+static int ett_fb_zero_prflags;
+static int ett_fb_zero_ft;
+static int ett_fb_zero_ftflags;
+static int ett_fb_zero_tag_value;
 
-static expert_field ei_fb_zero_tag_undecoded = EI_INIT;
-static expert_field ei_fb_zero_tag_length = EI_INIT;
-static expert_field ei_fb_zero_tag_unknown = EI_INIT;
-static expert_field ei_fb_zero_length_invalid = EI_INIT;
+static expert_field ei_fb_zero_tag_undecoded;
+static expert_field ei_fb_zero_tag_offset_end_invalid;
+static expert_field ei_fb_zero_length_invalid;
 
 #define FBZERO_MIN_LENGTH 3
 
@@ -138,7 +145,7 @@ static const value_string tag_vals[] = {
 static const value_string tag_aead_vals[] = {
     { AEAD_AESG, "AES-GCM with a 12-byte tag and IV" },
     { AEAD_S20P, "Salsa20 with Poly1305" },
-    { AEAD_CC12, "Salsa20 with Poly1305" },
+    { AEAD_CC12, "ChaCha20 with Poly1305" },
     { 0, NULL }
 };
 
@@ -156,127 +163,213 @@ static const value_string tag_kexs_vals[] = {
 };
 
 
-static guint32
-dissect_fb_zero_tag(tvbuff_t *tvb, packet_info *pinfo, proto_tree *fb_zero_tree, guint offset, guint32 tag_number){
-    guint32 tag_offset_start = offset + tag_number*4*2;
-    guint32 tag_offset = 0, total_tag_len = 0;
-    gint32 tag_len;
+static uint32_t
+dissect_fb_zero_tag(tvbuff_t *tvb, packet_info *pinfo, proto_tree *fb_zero_tree, unsigned offset, uint32_t tag_number){
+    uint32_t tag_offset_start = offset + tag_number*4*2;
+    uint32_t tag_offset = 0, total_tag_len = 0;
+    int32_t tag_len = 0;
+    bool tag_offset_valid = true;
 
     while(tag_number){
-        proto_tree *tag_tree, *ti_len, *ti_tag, *ti_type;
-        guint32 offset_end, tag;
-        const guint8* tag_str;
+        proto_tree *tag_tree;
+        proto_item *ti_tag, *ti_type, *ti_offset_len, *ti_len;
+        uint32_t offset_end, tag;
+        const uint8_t* tag_str;
 
-        ti_tag = proto_tree_add_item(fb_zero_tree, hf_fb_zero_tags, tvb, offset, 8, ENC_NA);
+        /*
+         * This item covers the tag type and end offset; the tag values
+         * are in a separate region following all the type/end offset
+         * pairs.
+         */
+        ti_tag = proto_tree_add_item(fb_zero_tree, hf_fb_zero_tags, tvb, offset, 4*2, ENC_NA);
         tag_tree = proto_item_add_subtree(ti_tag, ett_fb_zero_tag_value);
-        ti_type = proto_tree_add_item_ret_string(tag_tree, hf_fb_zero_tag_type, tvb, offset, 4, ENC_ASCII|ENC_NA, wmem_packet_scope(), &tag_str);
+        ti_type = proto_tree_add_item_ret_string(tag_tree, hf_fb_zero_tag_type, tvb, offset, 4, ENC_ASCII|ENC_NA, pinfo->pool, &tag_str);
         tag = tvb_get_ntohl(tvb, offset);
-        proto_item_append_text(ti_type, " (%s)", val_to_str(tag, tag_vals, "Unknown"));
-        proto_item_append_text(ti_tag, ": %s (%s)", tag_str, val_to_str(tag, tag_vals, "Unknown"));
+        proto_item_append_text(ti_type, " (%s)", val_to_str_const(tag, tag_vals, "Unknown"));
+        proto_item_append_text(ti_tag, ": %s (%s)", tag_str, val_to_str_const(tag, tag_vals, "Unknown"));
         offset += 4;
 
-        proto_tree_add_item(tag_tree, hf_fb_zero_tag_offset_end, tvb, offset, 4, ENC_LITTLE_ENDIAN);
-        offset_end = tvb_get_letohl(tvb, offset);
-
-        tag_len = offset_end - tag_offset;
-        total_tag_len += tag_len;
-        ti_len = proto_tree_add_uint(tag_tree, hf_fb_zero_tag_length, tvb, offset, 4, tag_len);
-        proto_item_append_text(ti_tag, " (l=%u)", tag_len);
-        proto_item_set_generated(ti_len);
-        offset += 4;
-
-        /* Fix issue with CRT.. (Fragmentation ?) */
-        if( tag_len > tvb_reported_length_remaining(tvb, tag_offset_start + tag_offset)){
-            tag_len = tvb_reported_length_remaining(tvb, tag_offset_start + tag_offset);
-            offset_end = tag_offset + tag_len;
-            expert_add_info(pinfo, ti_len, &ei_fb_zero_tag_length);
+        ti_offset_len = proto_tree_add_item_ret_uint(tag_tree, hf_fb_zero_tag_offset_end, tvb, offset, 4, ENC_LITTLE_ENDIAN, &offset_end);
+        if(offset_end < tag_offset){
+            expert_add_info_format(pinfo, ti_offset_len, &ei_fb_zero_tag_offset_end_invalid,
+                                   "Invalid tag end offset %u < %u",
+                                   offset_end, tag_offset);
+            /*
+             * We can continue to show the tag type, end offset, and length,
+             * but we can no longer show the values, or subsequent length
+             * values, as the end offset in the tag value region is bogus.
+             */
+            tag_offset_valid = false;
+        } else {
+            tag_len = offset_end - tag_offset;
+            if(!tvb_bytes_exist(tvb, tag_offset_start + tag_offset, tag_len)){
+                expert_add_info_format(pinfo, ti_offset_len, &ei_fb_zero_tag_offset_end_invalid,
+                                       "Invalid tag end offset %u past end of packet",
+                                       offset_end);
+                /*
+                 * We can continue to show the tag type, end offset,
+                 * and length, but we can no longer show the values,
+                 * as the end offset in the tag value region is bogus.
+                 *
+                 * We don't just throw an exception here, because we
+                 * want to show all the tag type and end offset values.
+                 */
+                tag_offset_valid = false;
+            }
+            total_tag_len += tag_len;
+            ti_len = proto_tree_add_uint(tag_tree, hf_fb_zero_tag_length, tvb, offset, 4, tag_len);
+            proto_item_append_text(ti_tag, " (l=%u)", tag_len);
+            proto_item_set_generated(ti_len);
         }
+        offset += 4;
 
-        proto_tree_add_item(tag_tree, hf_fb_zero_tag_value, tvb, tag_offset_start + tag_offset, tag_len, ENC_NA);
+        if(tag_offset_valid){
+            proto_tree_add_item(tag_tree, hf_fb_zero_tag_value, tvb, tag_offset_start + tag_offset, tag_len, ENC_NA);
+        }
 
         switch(tag){
             case TAG_SNI:
-                proto_tree_add_item_ret_string(tag_tree, hf_fb_zero_tag_sni, tvb, tag_offset_start + tag_offset, tag_len, ENC_ASCII|ENC_NA, wmem_packet_scope(), &tag_str);
-                proto_item_append_text(ti_tag, ": %s", tag_str);
-                tag_offset += tag_len;
-            break;
+                if(tag_offset_valid){
+                    proto_tree_add_item_ret_string(tag_tree, hf_fb_zero_tag_sni, tvb, tag_offset_start + tag_offset, tag_len, ENC_ASCII|ENC_NA, pinfo->pool, &tag_str);
+                    proto_item_append_text(ti_tag, ": %s", tag_str);
+                    tag_offset += tag_len;
+                }
+                break;
             case TAG_VERS:
-                proto_tree_add_item_ret_string(tag_tree, hf_fb_zero_tag_vers, tvb, tag_offset_start + tag_offset, 4, ENC_ASCII|ENC_NA, wmem_packet_scope(), &tag_str);
-                proto_item_append_text(ti_tag, ": %s", tag_str);
-                tag_offset += 4;
+                if(tag_offset_valid){
+                    if(tag_len != 4){
+                        expert_add_info_format(pinfo, fb_zero_tree, &ei_fb_zero_length_invalid,
+                                               "Invalid tag length: %u, should be 4", tag_len);
+                        tag_offset += tag_len;
+                        break;
+                    }
+                    proto_tree_add_item_ret_string(tag_tree, hf_fb_zero_tag_vers, tvb, tag_offset_start + tag_offset, 4, ENC_ASCII|ENC_NA, pinfo->pool, &tag_str);
+                    proto_item_append_text(ti_tag, ": %s", tag_str);
+                    tag_offset += 4;
+                }
             break;
             case TAG_SNO:
-                proto_tree_add_item(tag_tree, hf_fb_zero_tag_sno, tvb, tag_offset_start + tag_offset, tag_len, ENC_NA);
-                tag_offset += tag_len;
+                if(tag_offset_valid){
+                    proto_tree_add_item(tag_tree, hf_fb_zero_tag_sno, tvb, tag_offset_start + tag_offset, tag_len, ENC_NA);
+                    tag_offset += tag_len;
+                }
             break;
             case TAG_AEAD:
-                while(offset_end - tag_offset >= 4){
-                    proto_tree *ti_aead;
-                    ti_aead = proto_tree_add_item(tag_tree, hf_fb_zero_tag_aead, tvb, tag_offset_start + tag_offset, 4, ENC_ASCII|ENC_NA);
-                    proto_item_append_text(ti_aead, " (%s)", val_to_str(tvb_get_ntohl(tvb, tag_offset_start + tag_offset), tag_aead_vals, "Unknown"));
-                    proto_item_append_text(ti_tag, ", %s", val_to_str(tvb_get_ntohl(tvb, tag_offset_start + tag_offset), tag_aead_vals, "Unknown"));
-                    tag_offset += 4;
+                if(tag_offset_valid){
+                    while(offset_end - tag_offset >= 4){
+                        proto_tree *ti_aead;
+                        ti_aead = proto_tree_add_item(tag_tree, hf_fb_zero_tag_aead, tvb, tag_offset_start + tag_offset, 4, ENC_ASCII);
+                        proto_item_append_text(ti_aead, " (%s)", val_to_str_const(tvb_get_ntohl(tvb, tag_offset_start + tag_offset), tag_aead_vals, "Unknown"));
+                        proto_item_append_text(ti_tag, ", %s", val_to_str_const(tvb_get_ntohl(tvb, tag_offset_start + tag_offset), tag_aead_vals, "Unknown"));
+                        tag_offset += 4;
+                    }
+                    if(offset_end - tag_offset > 0){
+                        expert_add_info_format(pinfo, fb_zero_tree, &ei_fb_zero_length_invalid,
+                                               "Invalid tag length: %u, should be a multiple of 4", tag_len);
+                        tag_offset = offset_end;
+                    }
                 }
             break;
             case TAG_SCID:
-                proto_tree_add_item(tag_tree, hf_fb_zero_tag_scid, tvb, tag_offset_start + tag_offset, tag_len, ENC_NA);
-                tag_offset += tag_len;
-            break;
-            case TAG_TIME:
-                proto_tree_add_item(tag_tree, hf_fb_zero_tag_time, tvb, tag_offset_start + tag_offset, 4, ENC_LITTLE_ENDIAN);
-                proto_item_append_text(ti_tag, ": %u", tvb_get_letohl(tvb, tag_offset_start + tag_offset));
-                tag_offset += 4;
-            break;
-            case TAG_ALPN:
-                proto_tree_add_item_ret_string(tag_tree, hf_fb_zero_tag_alpn, tvb, tag_offset_start + tag_offset, 4, ENC_ASCII|ENC_NA, wmem_packet_scope(), &tag_str);
-                proto_item_append_text(ti_tag, ": %s", tag_str);
-                tag_offset += 4;
-            break;
-            case TAG_PUBS:
-                /*TODO FIX: 24 Length + Pubs key?.. ! */
-                proto_tree_add_item(tag_tree, hf_fb_zero_tag_pubs, tvb, tag_offset_start + tag_offset, 2, ENC_LITTLE_ENDIAN);
-                tag_offset += 2;
-                while(offset_end - tag_offset >= 3){
-                    proto_tree_add_item(tag_tree, hf_fb_zero_tag_pubs, tvb, tag_offset_start + tag_offset, 3, ENC_LITTLE_ENDIAN);
-                    tag_offset += 3;
+                if(tag_offset_valid){
+                    proto_tree_add_item(tag_tree, hf_fb_zero_tag_scid, tvb, tag_offset_start + tag_offset, tag_len, ENC_NA);
+                    tag_offset += tag_len;
                 }
             break;
-            case TAG_KEXS:
-                while(offset_end - tag_offset >= 4){
-                    proto_tree *ti_kexs;
-                    ti_kexs = proto_tree_add_item(tag_tree, hf_fb_zero_tag_kexs, tvb, tag_offset_start + tag_offset, 4, ENC_ASCII|ENC_NA);
-                    proto_item_append_text(ti_kexs, " (%s)", val_to_str(tvb_get_ntohl(tvb, tag_offset_start + tag_offset), tag_kexs_vals, "Unknown"));
-                    proto_item_append_text(ti_tag, ", %s", val_to_str(tvb_get_ntohl(tvb, tag_offset_start + tag_offset), tag_kexs_vals, "Unknown"));
+            case TAG_TIME:
+                if(tag_offset_valid){
+                    if(tag_len != 4){
+                        expert_add_info_format(pinfo, fb_zero_tree, &ei_fb_zero_length_invalid,
+                                               "Invalid tag length: %u, should be 4", tag_len);
+                        tag_offset += tag_len;
+                        break;
+                    }
+                    proto_tree_add_item(tag_tree, hf_fb_zero_tag_time, tvb, tag_offset_start + tag_offset, 4, ENC_LITTLE_ENDIAN);
+                    proto_item_append_text(ti_tag, ": %u", tvb_get_letohl(tvb, tag_offset_start + tag_offset));
                     tag_offset += 4;
                 }
             break;
+            case TAG_ALPN:
+                if(tag_offset_valid){
+                    if(tag_len != 4){
+                        expert_add_info_format(pinfo, fb_zero_tree, &ei_fb_zero_length_invalid,
+                                               "Invalid tag length: %u, should be 4", tag_len);
+                        tag_offset += tag_len;
+                        break;
+                    }
+                    proto_tree_add_item_ret_string(tag_tree, hf_fb_zero_tag_alpn, tvb, tag_offset_start + tag_offset, 4, ENC_ASCII|ENC_NA, pinfo->pool, &tag_str);
+                    proto_item_append_text(ti_tag, ": %s", tag_str);
+                    tag_offset += 4;
+                }
+            break;
+            case TAG_PUBS:
+                if(tag_offset_valid){
+                    /*TODO FIX: 24 Length + Pubs key?.. ! */
+                    if(tag_len < 2){
+                        expert_add_info_format(pinfo, fb_zero_tree, &ei_fb_zero_length_invalid,
+                                               "Invalid tag length: %u, should be >= 2", tag_len);
+                        tag_offset += tag_len;
+                        break;
+                    }
+                    proto_tree_add_item(tag_tree, hf_fb_zero_tag_pubs, tvb, tag_offset_start + tag_offset, 2, ENC_LITTLE_ENDIAN);
+                    tag_offset += 2;
+                    while(offset_end - tag_offset >= 3){
+                        proto_tree_add_item(tag_tree, hf_fb_zero_tag_pubs, tvb, tag_offset_start + tag_offset, 3, ENC_LITTLE_ENDIAN);
+                        tag_offset += 3;
+                    }
+                    if(offset_end - tag_offset > 0){
+                        expert_add_info_format(pinfo, fb_zero_tree, &ei_fb_zero_length_invalid,
+                                               "Invalid tag length: %u, should be a multiple of 3", tag_len);
+                        tag_offset = offset_end;
+                    }
+                }
+            break;
+            case TAG_KEXS:
+                if(tag_offset_valid){
+                    while(offset_end - tag_offset >= 4){
+                        proto_tree *ti_kexs;
+                        ti_kexs = proto_tree_add_item(tag_tree, hf_fb_zero_tag_kexs, tvb, tag_offset_start + tag_offset, 4, ENC_ASCII);
+                        proto_item_append_text(ti_kexs, " (%s)", val_to_str_const(tvb_get_ntohl(tvb, tag_offset_start + tag_offset), tag_kexs_vals, "Unknown"));
+                        proto_item_append_text(ti_tag, ", %s", val_to_str_const(tvb_get_ntohl(tvb, tag_offset_start + tag_offset), tag_kexs_vals, "Unknown"));
+                        tag_offset += 4;
+                    }
+                    if(offset_end - tag_offset > 0){
+                        expert_add_info_format(pinfo, fb_zero_tree, &ei_fb_zero_length_invalid,
+                                               "Invalid tag length: %u, should be a multiple of 4", tag_len);
+                        tag_offset = offset_end;
+                    }
+                }
+            break;
             case TAG_NONC:
-                /*TODO: Enhance display: 32 bytes consisting of 4 bytes of timestamp (big-endian, UNIX epoch seconds), 8 bytes of server orbit and 20 bytes of random data. */
-                proto_tree_add_item(tag_tree, hf_fb_zero_tag_nonc, tvb, tag_offset_start + tag_offset, 32, ENC_NA);
-                tag_offset += 32;
+                if(tag_offset_valid){
+                    /*TODO: Enhance display: 32 bytes consisting of 4 bytes of timestamp (big-endian, UNIX epoch seconds), 8 bytes of server orbit and 20 bytes of random data. */
+                    if(tag_len != 32){
+                        expert_add_info_format(pinfo, fb_zero_tree, &ei_fb_zero_length_invalid,
+                                               "Invalid tag length: %u, should be 32", tag_len);
+                        tag_offset += tag_len;
+                        break;
+                    }
+                    proto_tree_add_item(tag_tree, hf_fb_zero_tag_nonc, tvb, tag_offset_start + tag_offset, 32, ENC_NA);
+                    tag_offset += 32;
+                }
             break;
-
             default:
-                proto_tree_add_item(tag_tree, hf_fb_zero_tag_unknown, tvb, tag_offset_start + tag_offset, tag_len, ENC_NA);
                 expert_add_info_format(pinfo, ti_tag, &ei_fb_zero_tag_undecoded,
                                  "Dissector for FB Zero Tag"
                                  " %s (%s) code not implemented, Contact"
-                                 " Wireshark developers if you want this supported", tvb_get_string_enc(wmem_packet_scope(), tvb, offset-8, 4, ENC_ASCII|ENC_NA), val_to_str(tag, tag_vals, "Unknown"));
-                goto end;
-            break;
-        }
-
-        if(tag_offset != offset_end){
-            /* Wrong Tag len... */
-            proto_tree_add_expert(tag_tree, pinfo, &ei_fb_zero_tag_unknown, tvb, tag_offset_start + tag_offset, offset_end - tag_offset);
-            // XXX Return instead?
-            goto end;
+                                 " Wireshark developers if you want this supported",
+                                 tvb_get_string_enc(pinfo->pool, tvb, offset-8, 4, ENC_ASCII|ENC_NA), val_to_str_const(tag, tag_vals, "Unknown"));
+                if(tag_offset_valid){
+                    proto_tree_add_item(tag_tree, hf_fb_zero_tag_unknown, tvb, tag_offset_start + tag_offset, tag_len, ENC_NA);
+                    tag_offset += tag_len;
+                }
+                break;
         }
 
         tag_number--;
     }
 
-    end:
+    /* XXX - can this still occur? */
     if (offset + total_tag_len <= offset) {
         expert_add_info_format(pinfo, fb_zero_tree, &ei_fb_zero_length_invalid,
                          "Invalid total tag length: %u", total_tag_len);
@@ -288,25 +381,32 @@ dissect_fb_zero_tag(tvbuff_t *tvb, packet_info *pinfo, proto_tree *fb_zero_tree,
 
 
 static int
-dissect_fb_zero_unencrypt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *fb_zero_tree, guint offset, guint8 len_pkn _U_){
+dissect_fb_zero_unencrypt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *fb_zero_tree, unsigned offset, uint8_t len_pkn _U_){
 
     while(tvb_reported_length_remaining(tvb, offset) > 0){
         proto_item *ti;
-        guint32 message_tag, tag_number, length;
-        const guint8* message_tag_str;
+        uint32_t message_tag, tag_number, length;
+        const uint8_t* message_tag_str;
         proto_tree_add_item(fb_zero_tree, hf_fb_zero_unknown, tvb, offset, 1, ENC_NA);
         offset += 1;
 
+        /*
+         * XXX: in theory, a tagged message could be split between
+         * TCP segments - even the *header containing the length*
+         * could be split - but, from the sequence described in the
+         * Facebook blog post, that's probably unlikely in practice.
+         */
         proto_tree_add_item_ret_uint(fb_zero_tree, hf_fb_zero_length, tvb, offset, 4, ENC_LITTLE_ENDIAN, &length);
         offset += 4;
 
         message_tag = tvb_get_ntohl(tvb, offset);
         /* check if it is a known message_tag (CHLO, SNOM...) */
         if(try_val_to_str(message_tag, message_tag_vals)){
-            ti = proto_tree_add_item_ret_string(fb_zero_tree, hf_fb_zero_tag, tvb, offset, 4, ENC_ASCII|ENC_NA, wmem_packet_scope(), &message_tag_str);
+            ti = proto_tree_add_item_ret_string(fb_zero_tree, hf_fb_zero_tag, tvb, offset, 4, ENC_ASCII|ENC_NA, pinfo->pool, &message_tag_str);
 
-            proto_item_append_text(ti, ", Type: %s (%s)", message_tag_str, val_to_str(message_tag, message_tag_vals, "Unknown Tag"));
-            col_add_fstr(pinfo->cinfo, COL_INFO, "%s", val_to_str(message_tag, message_tag_vals, "Unknown"));
+            proto_item_append_text(ti, ", Type: %s (%s)", message_tag_str,
+                                   val_to_str_const(message_tag, message_tag_vals, "Unknown Tag"));
+            col_add_str(pinfo->cinfo, COL_INFO, val_to_str_const(message_tag, message_tag_vals, "Unknown"));
             offset += 4;
 
             proto_tree_add_item(fb_zero_tree, hf_fb_zero_tag_number, tvb, offset, 2, ENC_LITTLE_ENDIAN);
@@ -333,9 +433,9 @@ dissect_fb_zero_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 {
     proto_item *ti, *ti_puflags;
     proto_tree *fb_zero_tree, *puflags_tree;
-    guint offset = 0;
-    guint8 puflags;
-    guint32 message_tag, version;
+    unsigned offset = 0;
+    uint8_t puflags;
+    uint32_t message_tag, version;
 
     if (tvb_captured_length(tvb) < FBZERO_MIN_LENGTH)
         return 0;
@@ -351,13 +451,13 @@ dissect_fb_zero_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     puflags_tree = proto_item_add_subtree(ti_puflags, ett_fb_zero_puflags);
     proto_tree_add_item(puflags_tree, hf_fb_zero_puflags_vrsn, tvb, offset, 1, ENC_NA);
     proto_tree_add_item(puflags_tree, hf_fb_zero_puflags_unknown, tvb, offset, 1, ENC_LITTLE_ENDIAN);
-    puflags = tvb_get_guint8(tvb, offset);
+    puflags = tvb_get_uint8(tvb, offset);
     offset += 1;
 
     if(puflags & PUFLAGS_VRSN){
         version = tvb_get_ntoh24(tvb, offset);
         if(version == VERSION_QTV){
-            proto_tree_add_item(fb_zero_tree, hf_fb_zero_version, tvb, offset, 3, ENC_ASCII|ENC_NA);
+            proto_tree_add_item(fb_zero_tree, hf_fb_zero_version, tvb, offset, 3, ENC_ASCII);
             offset += 3;
         }
     }
@@ -382,15 +482,15 @@ dissect_fb_zero(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     return dissect_fb_zero_common(tvb, pinfo, tree, NULL);
 }
 
-static gboolean dissect_fb_zero_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+static bool dissect_fb_zero_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     conversation_t *conversation = NULL;
     int offset = 0;
-    guint32 version, length, message_tag;
+    uint32_t version, length, message_tag;
     /* Verify packet size (Flag (1 byte) + Version (3bytes) + Flag (1 byte) + length (4 bytes) + Tag (4 bytes)) */
     if (tvb_captured_length(tvb) < 13)
     {
-        return FALSE;
+        return false;
     }
 
     /* Flag */
@@ -414,10 +514,10 @@ static gboolean dissect_fb_zero_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tr
         conversation = find_or_create_conversation(pinfo);
         conversation_set_dissector(conversation, fb_zero_handle);
         dissect_fb_zero(tvb, pinfo, tree, data);
-        return TRUE;
+        return true;
     }
 
-    return FALSE;
+    return false;
 }
 
 void
@@ -558,7 +658,7 @@ proto_register_fb_zero(void)
     };
 
 
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_fb_zero,
         &ett_fb_zero_puflags,
         &ett_fb_zero_prflags,
@@ -569,8 +669,7 @@ proto_register_fb_zero(void)
 
     static ei_register_info ei[] = {
         { &ei_fb_zero_tag_undecoded, { "fb_zero.tag.undecoded", PI_UNDECODED, PI_NOTE, "Dissector for FB Zero Tag code not implemented, Contact Wireshark developers if you want this supported", EXPFILL }},
-        { &ei_fb_zero_tag_length, { "fb_zero.tag.length.truncated", PI_MALFORMED, PI_NOTE, "Truncated Tag Length...", EXPFILL }},
-        { &ei_fb_zero_tag_unknown, { "fb_zero.tag.unknown.data", PI_UNDECODED, PI_NOTE, "Unknown Data", EXPFILL }},
+        { &ei_fb_zero_tag_offset_end_invalid, { "fb_zero.offset_end.invalid", PI_PROTOCOL, PI_ERROR, "Invalid tag end offset", EXPFILL }},
         { &ei_fb_zero_length_invalid, { "fb_zero.length.invalid", PI_PROTOCOL, PI_WARN, "Invalid length", EXPFILL }},
     };
 
