@@ -47,20 +47,20 @@ void proto_reg_handoff_flip(void);
 
 static dissector_handle_t flip_handle;
 
-static int proto_flip = -1;
+static int proto_flip;
 
 /* BASIC */
-static int hf_flip_basic_e         = -1;
-static int hf_flip_basic_reserved  = -1;
-static int hf_flip_basic_flowid    = -1;
-static int hf_flip_basic_seqnum    = -1;
-static int hf_flip_basic_len       = -1;
+static int hf_flip_basic_e;
+static int hf_flip_basic_reserved;
+static int hf_flip_basic_flowid;
+static int hf_flip_basic_seqnum;
+static int hf_flip_basic_len;
 
 /* CHECKSUM */
-static int hf_flip_chksum_etype  = -1;
-static int hf_flip_chksum_spare  = -1;
-static int hf_flip_chksum_e      = -1;
-static int hf_flip_chksum_chksum = -1;
+static int hf_flip_chksum_etype;
+static int hf_flip_chksum_spare;
+static int hf_flip_chksum_e;
+static int hf_flip_chksum_chksum;
 
 #define FLIP_BASIC            (0)
 #define FLIP_CHKSUM           (1)
@@ -76,12 +76,12 @@ static const value_string flip_etype[] = {
 
 static dissector_table_t subdissector_table;
 
-static gint ett_flip         = -1;
-static gint ett_flip_basic   = -1;
-static gint ett_flip_chksum  = -1;
-static gint ett_flip_payload = -1;
+static int ett_flip;
+static int ett_flip_basic;
+static int ett_flip_chksum;
+static int ett_flip_payload;
 
-static void flip_prompt(packet_info *pinfo _U_, gchar* result)
+static void flip_prompt(packet_info *pinfo _U_, char* result)
 {
     snprintf(result, MAX_DECODE_AS_PROMPT_LEN, "Decode FLIP payload protocol as");
 }
@@ -91,17 +91,17 @@ static int
 dissect_flip_chksum_hdr(tvbuff_t    *tvb,
                         packet_info *pinfo,
                         proto_tree  *tree,
-                        guint16     computed_chksum,
-                        gboolean    *ext_hdr_follows_ptr)
+                        uint16_t    computed_chksum,
+                        bool        *ext_hdr_follows_ptr)
 {
     proto_tree *chksum_hdr_tree;
-    guint32  dw;
-    guint8   chksum_hdr_etype;
-    guint8   chksum_hdr_ext;
-    guint16  chksum_hdr_chksum;
+    uint32_t dw;
+    uint8_t  chksum_hdr_etype;
+    uint8_t  chksum_hdr_ext;
+    uint16_t chksum_hdr_chksum;
 
-    gint bytes_dissected;
-    gint offset;
+    int bytes_dissected;
+    int offset;
 
     chksum_hdr_tree = NULL;
 
@@ -109,16 +109,16 @@ dissect_flip_chksum_hdr(tvbuff_t    *tvb,
     offset          = 0;
 
     dw = tvb_get_ntohl(tvb, offset);
-    chksum_hdr_etype  = (guint8) ((dw & 0xFF000000) >> 24);
-    chksum_hdr_ext    = (guint8) ((dw & 0x00010000) >> 16);
-    chksum_hdr_chksum = (guint16) (dw & 0x0000FFFF);
+    chksum_hdr_etype  = (uint8_t) ((dw & 0xFF000000) >> 24);
+    chksum_hdr_ext    = (uint8_t) ((dw & 0x00010000) >> 16);
+    chksum_hdr_chksum = (uint16_t) (dw & 0x0000FFFF);
 
     /* The actually shouldn't be any headers after checksum. */
     if (chksum_hdr_ext == 1) {
-        *ext_hdr_follows_ptr = TRUE;
+        *ext_hdr_follows_ptr = true;
     }
     else {
-        *ext_hdr_follows_ptr = FALSE;
+        *ext_hdr_follows_ptr = false;
     }
 
     if (tree) {
@@ -173,23 +173,23 @@ dissect_flip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     proto_tree *basic_hdr_tree = NULL;
     tvbuff_t   *flip_tvb;
 
-    guint32 dw1;
+    uint32_t dw1;
 
     /* Basic header fields. */
-    guint8   basic_hdr_ext;
-    guint32  basic_hdr_flow_id;
-    guint16  basic_hdr_len;
+    uint8_t  basic_hdr_ext;
+    uint32_t basic_hdr_flow_id;
+    uint16_t basic_hdr_len;
 
-    gboolean ext_hdr = FALSE;
+    bool ext_hdr = false;
 
-    gint bytes_dissected = 0;
-    gint payload_len;
-    gint frame_len;
-    gint flip_len;
-    gint offset = 0;
+    int bytes_dissected = 0;
+    int payload_len;
+    int frame_len;
+    int flip_len;
+    int offset = 0;
 
     /* Error handling for basic header. */
-    gboolean is_faulty_frame = FALSE;
+    bool is_faulty_frame = false;
 
     /* Show this protocol as FLIP. */
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "FLIP");
@@ -217,12 +217,12 @@ dissect_flip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     basic_hdr_flow_id  = (dw1 & 0x0FFFFFFF);
 
     /* Process the second 32 bits of the basic header. */
-    basic_hdr_len    = (guint16) (tvb_get_ntohl(tvb, offset + 4) & 0x0000FFFF);
+    basic_hdr_len    = (uint16_t) (tvb_get_ntohl(tvb, offset + 4) & 0x0000FFFF);
 
 
     /* Does the basic header indicate that an extension is next? */
     if (basic_hdr_ext == 1) {
-        ext_hdr = TRUE;
+        ext_hdr = true;
     }
 
     flip_len = basic_hdr_len;
@@ -232,7 +232,7 @@ dissect_flip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
      */
     if ((flip_len < FLIP_BASIC_HDR_LEN) || (flip_len > frame_len)) {
         /* Faulty frame. Show the basic header anyway for debugging. */
-        is_faulty_frame = TRUE;
+        is_faulty_frame = true;
     }
 
     /* Fill in the info column. */
@@ -273,7 +273,7 @@ dissect_flip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     /*
      * Process faults found when parsing the basic header.
      */
-    if (is_faulty_frame == TRUE) {
+    if (is_faulty_frame == true) {
         if (flip_len > frame_len) {
             col_add_fstr(pinfo->cinfo, COL_INFO,
                          "Length mismatch: frame %d bytes, hdr %d bytes",
@@ -295,21 +295,21 @@ dissect_flip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     /*
      * Dissect extension headers (if any).
      */
-    if ((ext_hdr == TRUE) && (payload_len < FLIP_EXTENSION_HDR_MIN_LEN)) {
+    if ((ext_hdr == true) && (payload_len < FLIP_EXTENSION_HDR_MIN_LEN)) {
         col_add_fstr(pinfo->cinfo, COL_INFO,
                      "Extension header indicated, but not enough data");
         goto DISSECT_FLIP_EXIT;
     }
 
-    while ((ext_hdr == TRUE) && (payload_len >= FLIP_EXTENSION_HDR_MIN_LEN)) {
+    while ((ext_hdr == true) && (payload_len >= FLIP_EXTENSION_HDR_MIN_LEN)) {
         /* Detect the next header type. */
-        guint8  ext_hdr_type;
-        gint    bytes_handled;
-        guint16 computed_chksum;
+        uint8_t ext_hdr_type;
+        int     bytes_handled;
+        uint16_t computed_chksum;
 
         tvbuff_t *chksum_tvb;
 
-        ext_hdr_type = tvb_get_guint8(flip_tvb, offset);
+        ext_hdr_type = tvb_get_uint8(flip_tvb, offset);
 
         switch (ext_hdr_type) {
         case FLIP_CHKSUM:
@@ -355,7 +355,7 @@ dissect_flip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     if (payload_len > 0) {
 
         tvbuff_t           *payload_tvb;
-        gint               data_len;
+        int                data_len;
 
         payload_tvb = tvb_new_subset_length(flip_tvb, offset, payload_len);
 
@@ -424,7 +424,7 @@ proto_register_flip(void)
         }
     };
 
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_flip,
         &ett_flip_basic,
         &ett_flip_chksum,
