@@ -19,87 +19,87 @@
 #include "packet-usb.h"
 #include "packet-ftdi-ft.h"
 
-static int proto_ftdi_ft = -1;
+static int proto_ftdi_ft;
 
-static gint hf_setup_brequest = -1;
-static gint hf_setup_lvalue = -1;
-static gint hf_setup_lvalue_purge = -1;
-static gint hf_setup_lvalue_dtr = -1;
-static gint hf_setup_lvalue_rts = -1;
-static gint hf_setup_lvalue_xon_char = -1;
-static gint hf_setup_lvalue_baud_low = -1;
-static gint hf_setup_lvalue_data_size = -1;
-static gint hf_setup_lvalue_event_char = -1;
-static gint hf_setup_lvalue_error_char = -1;
-static gint hf_setup_lvalue_latency_time = -1;
-static gint hf_setup_lvalue_bitmask = -1;
-static gint hf_setup_hvalue = -1;
-static gint hf_setup_hvalue_dtr = -1;
-static gint hf_setup_hvalue_rts = -1;
-static gint hf_setup_hvalue_xoff_char = -1;
-static gint hf_setup_hvalue_baud_mid = -1;
-static gint hf_setup_hvalue_parity = -1;
-static gint hf_setup_hvalue_stop_bits = -1;
-static gint hf_setup_hvalue_break_bit = -1;
-static gint hf_setup_hvalue_trigger = -1;
-static gint hf_setup_hvalue_error_replacement = -1;
-static gint hf_setup_hvalue_bitmode = -1;
-static gint hf_setup_lindex = -1;
-static gint hf_setup_lindex_port_ab = -1;
-static gint hf_setup_lindex_port_abcd = -1;
-static gint hf_setup_lindex_baud_high = -1;
-static gint hf_setup_hindex = -1;
-static gint hf_setup_hindex_rts_cts = -1;
-static gint hf_setup_hindex_dtr_dsr = -1;
-static gint hf_setup_hindex_xon_xoff = -1;
-static gint hf_setup_hindex_baud_high = -1;
-static gint hf_setup_hindex_baud_clock_divide = -1;
-static gint hf_setup_wlength = -1;
-static gint hf_response_lat_timer = -1;
-static gint hf_modem_status = -1;
-static gint hf_modem_status_fs_max_packet = -1;
-static gint hf_modem_status_hs_max_packet = -1;
-static gint hf_modem_status_cts = -1;
-static gint hf_modem_status_dsr = -1;
-static gint hf_modem_status_ri = -1;
-static gint hf_modem_status_dcd = -1;
-static gint hf_line_status = -1;
-static gint hf_line_status_receive_overflow = -1;
-static gint hf_line_status_parity_error = -1;
-static gint hf_line_status_framing_error = -1;
-static gint hf_line_status_break_received = -1;
-static gint hf_line_status_tx_holding_reg_empty = -1;
-static gint hf_line_status_tx_empty = -1;
-static gint hf_if_a_rx_payload = -1;
-static gint hf_if_a_tx_payload = -1;
-static gint hf_if_b_rx_payload = -1;
-static gint hf_if_b_tx_payload = -1;
-static gint hf_if_c_rx_payload = -1;
-static gint hf_if_c_tx_payload = -1;
-static gint hf_if_d_rx_payload = -1;
-static gint hf_if_d_tx_payload = -1;
-static gint hf_ftdi_fragments = -1;
-static gint hf_ftdi_fragment = -1;
-static gint hf_ftdi_fragment_overlap = -1;
-static gint hf_ftdi_fragment_overlap_conflicts = -1;
-static gint hf_ftdi_fragment_multiple_tails = -1;
-static gint hf_ftdi_fragment_too_long_fragment = -1;
-static gint hf_ftdi_fragment_error = -1;
-static gint hf_ftdi_fragment_count = -1;
-static gint hf_ftdi_reassembled_in = -1;
-static gint hf_ftdi_reassembled_length = -1;
+static int hf_setup_brequest;
+static int hf_setup_lvalue;
+static int hf_setup_lvalue_purge;
+static int hf_setup_lvalue_dtr;
+static int hf_setup_lvalue_rts;
+static int hf_setup_lvalue_xon_char;
+static int hf_setup_lvalue_baud_low;
+static int hf_setup_lvalue_data_size;
+static int hf_setup_lvalue_event_char;
+static int hf_setup_lvalue_error_char;
+static int hf_setup_lvalue_latency_time;
+static int hf_setup_lvalue_bitmask;
+static int hf_setup_hvalue;
+static int hf_setup_hvalue_dtr;
+static int hf_setup_hvalue_rts;
+static int hf_setup_hvalue_xoff_char;
+static int hf_setup_hvalue_baud_mid;
+static int hf_setup_hvalue_parity;
+static int hf_setup_hvalue_stop_bits;
+static int hf_setup_hvalue_break_bit;
+static int hf_setup_hvalue_trigger;
+static int hf_setup_hvalue_error_replacement;
+static int hf_setup_hvalue_bitmode;
+static int hf_setup_lindex;
+static int hf_setup_lindex_port_ab;
+static int hf_setup_lindex_port_abcd;
+static int hf_setup_lindex_baud_high;
+static int hf_setup_hindex;
+static int hf_setup_hindex_rts_cts;
+static int hf_setup_hindex_dtr_dsr;
+static int hf_setup_hindex_xon_xoff;
+static int hf_setup_hindex_baud_high;
+static int hf_setup_hindex_baud_clock_divide;
+static int hf_setup_wlength;
+static int hf_response_lat_timer;
+static int hf_modem_status;
+static int hf_modem_status_fs_max_packet;
+static int hf_modem_status_hs_max_packet;
+static int hf_modem_status_cts;
+static int hf_modem_status_dsr;
+static int hf_modem_status_ri;
+static int hf_modem_status_dcd;
+static int hf_line_status;
+static int hf_line_status_receive_overflow;
+static int hf_line_status_parity_error;
+static int hf_line_status_framing_error;
+static int hf_line_status_break_received;
+static int hf_line_status_tx_holding_reg_empty;
+static int hf_line_status_tx_empty;
+static int hf_if_a_rx_payload;
+static int hf_if_a_tx_payload;
+static int hf_if_b_rx_payload;
+static int hf_if_b_tx_payload;
+static int hf_if_c_rx_payload;
+static int hf_if_c_tx_payload;
+static int hf_if_d_rx_payload;
+static int hf_if_d_tx_payload;
+static int hf_ftdi_fragments;
+static int hf_ftdi_fragment;
+static int hf_ftdi_fragment_overlap;
+static int hf_ftdi_fragment_overlap_conflicts;
+static int hf_ftdi_fragment_multiple_tails;
+static int hf_ftdi_fragment_too_long_fragment;
+static int hf_ftdi_fragment_error;
+static int hf_ftdi_fragment_count;
+static int hf_ftdi_reassembled_in;
+static int hf_ftdi_reassembled_length;
 
-static gint ett_ftdi_ft = -1;
-static gint ett_modem_ctrl_lvalue = -1;
-static gint ett_modem_ctrl_hvalue = -1;
-static gint ett_flow_ctrl_hindex = -1;
-static gint ett_baudrate_lindex = -1;
-static gint ett_baudrate_hindex = -1;
-static gint ett_setdata_hvalue = -1;
-static gint ett_modem_status = -1;
-static gint ett_line_status = -1;
-static gint ett_ftdi_fragment = -1;
-static gint ett_ftdi_fragments = -1;
+static int ett_ftdi_ft;
+static int ett_modem_ctrl_lvalue;
+static int ett_modem_ctrl_hvalue;
+static int ett_flow_ctrl_hindex;
+static int ett_baudrate_lindex;
+static int ett_baudrate_hindex;
+static int ett_setdata_hvalue;
+static int ett_modem_status;
+static int ett_line_status;
+static int ett_ftdi_fragment;
+static int ett_ftdi_fragments;
 
 static const fragment_items ftdi_frag_items = {
     /* Fragment subtrees */
@@ -126,42 +126,42 @@ static const fragment_items ftdi_frag_items = {
 
 static dissector_handle_t ftdi_mpsse_handle;
 
-static expert_field ei_undecoded = EI_INIT;
+static expert_field ei_undecoded;
 
 static dissector_handle_t ftdi_ft_handle;
 
 static reassembly_table ftdi_reassembly_table;
 
-static wmem_tree_t *request_info = NULL;
-static wmem_tree_t *bitmode_info = NULL;
-static wmem_tree_t *desegment_info = NULL;
+static wmem_tree_t *request_info;
+static wmem_tree_t *bitmode_info;
+static wmem_tree_t *desegment_info;
 
 typedef struct _request_data {
-    guint32  bus_id;
-    guint32  device_address;
-    guint8   request;
-    guint8   hvalue;
-    guint8   lindex;
+    uint32_t bus_id;
+    uint32_t device_address;
+    uint8_t  request;
+    uint8_t  hvalue;
+    uint8_t  lindex;
 } request_data_t;
 
 typedef struct _bitmode_data {
-    guint32        bus_id;
-    guint32        device_address;
+    uint32_t       bus_id;
+    uint32_t       device_address;
     FTDI_INTERFACE interface;
-    guint8         bitmode;
+    uint8_t        bitmode;
 } bitmode_data_t;
 
 typedef struct _desegment_data desegment_data_t;
 struct _desegment_data {
-    guint32           bus_id;
-    guint32           device_address;
+    uint32_t          bus_id;
+    uint32_t          device_address;
     FTDI_INTERFACE    interface;
-    guint8            bitmode;
-    gint              p2p_dir;
+    uint8_t           bitmode;
+    int               p2p_dir;
     /* First frame where the segmented data starts (reassembly key) */
-    guint32           first_frame;
-    guint32           last_frame;
-    gint              first_frame_offset;
+    uint32_t          first_frame;
+    uint32_t          last_frame;
+    int               first_frame_offset;
     /* Points to desegment data if the previous desegment data ends
      * in last_frame that is equal to this desegment data first_frame.
      */
@@ -169,12 +169,12 @@ struct _desegment_data {
 };
 
 typedef struct _ftdi_fragment_key {
-    guint32           bus_id;
-    guint32           device_address;
+    uint32_t          bus_id;
+    uint32_t          device_address;
     FTDI_INTERFACE    interface;
-    guint8            bitmode;
-    gint              p2p_dir;
-    guint32           id;
+    uint8_t           bitmode;
+    int               p2p_dir;
+    uint32_t          id;
 } ftdi_fragment_key_t;
 
 #define REQUEST_RESET           0x00
@@ -357,7 +357,7 @@ endpoint_to_interface(usb_conv_info_t *usb_conv_info)
 }
 
 static FTDI_INTERFACE
-lindex_to_interface(guint8 lindex)
+lindex_to_interface(uint8_t lindex)
 {
     switch (lindex)
     {
@@ -375,10 +375,10 @@ lindex_to_interface(guint8 lindex)
     }
 }
 
-static gint
-dissect_request_reset(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_reset(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue_purge, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -395,8 +395,8 @@ dissect_request_reset(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_
     return offset - offset_start;
 }
 
-static gint
-dissect_request_modem_ctrl(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_modem_ctrl(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
     static int * const lvalue_bits[] = {
         &hf_setup_lvalue_dtr,
@@ -408,7 +408,7 @@ dissect_request_modem_ctrl(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, p
         &hf_setup_hvalue_rts,
         NULL
     };
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_bitmask(tree, tvb, offset, hf_setup_lvalue,
         ett_modem_ctrl_lvalue, lvalue_bits, ENC_LITTLE_ENDIAN);
@@ -427,8 +427,8 @@ dissect_request_modem_ctrl(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, p
     return offset - offset_start;
 }
 
-static gint
-dissect_request_set_flow_ctrl(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_set_flow_ctrl(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
     static int * const hindex_bits[] = {
         &hf_setup_hindex_rts_cts,
@@ -436,7 +436,7 @@ dissect_request_set_flow_ctrl(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset
         &hf_setup_hindex_xon_xoff,
         NULL
     };
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue_xon_char, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -454,8 +454,8 @@ dissect_request_set_flow_ctrl(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset
     return offset - offset_start;
 }
 
-static gint
-dissect_request_set_baud_rate(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *tree, FTDI_CHIP chip)
+static int
+dissect_request_set_baud_rate(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *tree, FTDI_CHIP chip)
 {
     static int * const lindex_bits[] = {
         &hf_setup_lindex_baud_high,
@@ -471,7 +471,7 @@ dissect_request_set_baud_rate(tvbuff_t *tvb, packet_info *pinfo, gint offset, pr
         NULL
     };
 
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue_baud_low, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -525,8 +525,8 @@ dissect_request_set_baud_rate(tvbuff_t *tvb, packet_info *pinfo, gint offset, pr
     return offset - offset_start;
 }
 
-static gint
-dissect_request_set_data(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_set_data(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
     static int * const hvalue_bits[] = {
         &hf_setup_hvalue_parity,
@@ -534,7 +534,7 @@ dissect_request_set_data(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, pro
         &hf_setup_hvalue_break_bit,
         NULL
     };
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue_data_size, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -552,10 +552,10 @@ dissect_request_set_data(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, pro
     return offset - offset_start;
 }
 
-static gint
-dissect_request_get_modem_stat(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_get_modem_stat(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -572,10 +572,10 @@ dissect_request_get_modem_stat(tvbuff_t *tvb, packet_info *pinfo _U_, gint offse
     return offset - offset_start;
 }
 
-static gint
-dissect_request_set_event_char(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_set_event_char(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue_event_char, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -592,10 +592,10 @@ dissect_request_set_event_char(tvbuff_t *tvb, packet_info *pinfo _U_, gint offse
     return offset - offset_start;
 }
 
-static gint
-dissect_request_set_error_char(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_set_error_char(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue_error_char, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -613,10 +613,10 @@ dissect_request_set_error_char(tvbuff_t *tvb, packet_info *pinfo _U_, gint offse
     return offset - offset_start;
 }
 
-static gint
-dissect_request_set_lat_timer(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_set_lat_timer(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue_latency_time, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -633,10 +633,10 @@ dissect_request_set_lat_timer(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset
     return offset - offset_start;
 }
 
-static gint
-dissect_request_get_lat_timer(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_get_lat_timer(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -653,10 +653,10 @@ dissect_request_get_lat_timer(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset
     return offset - offset_start;
 }
 
-static gint
-dissect_response_get_lat_timer(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_response_get_lat_timer(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_response_lat_timer, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -664,10 +664,10 @@ dissect_response_get_lat_timer(tvbuff_t *tvb, packet_info *pinfo _U_, gint offse
     return offset - offset_start;
 }
 
-static gint
-dissect_request_set_bitmode(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree)
+static int
+dissect_request_set_bitmode(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree)
 {
-    gint offset_start = offset;
+    int offset_start = offset;
 
     proto_tree_add_item(tree, hf_setup_lvalue_bitmask, tvb, offset, 1, ENC_LITTLE_ENDIAN);
     offset++;
@@ -684,8 +684,8 @@ dissect_request_set_bitmode(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset,
     return offset - offset_start;
 }
 
-static gint
-dissect_modem_status_bytes(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, proto_tree *tree, gint *out_rx_len)
+static int
+dissect_modem_status_bytes(tvbuff_t *tvb, packet_info *pinfo _U_, int offset, proto_tree *tree, int *out_rx_len)
 {
     static int * const modem_status_bits[] = {
         &hf_modem_status_fs_max_packet,
@@ -705,7 +705,7 @@ dissect_modem_status_bytes(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, p
         &hf_line_status_tx_empty,
         NULL
     };
-    guint64 modem_status;
+    uint64_t modem_status;
 
     proto_tree_add_bitmask_ret_uint64(tree, tvb, offset, hf_modem_status,
         ett_modem_status, modem_status_bits, ENC_LITTLE_ENDIAN, &modem_status);
@@ -734,11 +734,11 @@ dissect_modem_status_bytes(tvbuff_t *tvb, packet_info *pinfo _U_, gint offset, p
 }
 
 static void
-record_interface_mode(packet_info *pinfo, usb_conv_info_t *usb_conv_info, FTDI_INTERFACE interface, guint8 bitmode)
+record_interface_mode(packet_info *pinfo, usb_conv_info_t *usb_conv_info, FTDI_INTERFACE interface, uint8_t bitmode)
 {
-    guint32         k_bus_id = usb_conv_info->bus_id;
-    guint32         k_device_address = usb_conv_info->device_address;
-    guint32         k_interface = (guint32)interface;
+    uint32_t        k_bus_id = usb_conv_info->bus_id;
+    uint32_t        k_device_address = usb_conv_info->device_address;
+    uint32_t        k_interface = (uint32_t)interface;
     wmem_tree_key_t key[] = {
         {1, &k_bus_id},
         {1, &k_device_address},
@@ -756,12 +756,12 @@ record_interface_mode(packet_info *pinfo, usb_conv_info_t *usb_conv_info, FTDI_I
     wmem_tree_insert32_array(bitmode_info, key, bitmode_data);
 }
 
-static guint8
+static uint8_t
 get_recorded_interface_mode(packet_info *pinfo, usb_conv_info_t *usb_conv_info, FTDI_INTERFACE interface)
 {
-    guint32         k_bus_id = usb_conv_info->bus_id;
-    guint32         k_device_address = usb_conv_info->device_address;
-    guint32         k_interface = (guint32)interface;
+    uint32_t        k_bus_id = usb_conv_info->bus_id;
+    uint32_t        k_device_address = usb_conv_info->device_address;
+    uint32_t        k_interface = (uint32_t)interface;
     wmem_tree_key_t key[] = {
         {1, &k_bus_id},
         {1, &k_device_address},
@@ -783,12 +783,12 @@ get_recorded_interface_mode(packet_info *pinfo, usb_conv_info_t *usb_conv_info,
 
 static desegment_data_t *
 record_desegment_data(packet_info *pinfo, usb_conv_info_t *usb_conv_info,
-                      FTDI_INTERFACE interface, guint8 bitmode)
+                      FTDI_INTERFACE interface, uint8_t bitmode)
 {
-    guint32         k_bus_id = usb_conv_info->bus_id;
-    guint32         k_device_address = usb_conv_info->device_address;
-    guint32         k_interface = (guint32)interface;
-    guint32         k_p2p_dir = (guint32)pinfo->p2p_dir;
+    uint32_t        k_bus_id = usb_conv_info->bus_id;
+    uint32_t        k_device_address = usb_conv_info->device_address;
+    uint32_t        k_interface = (uint32_t)interface;
+    uint32_t        k_p2p_dir = (uint32_t)pinfo->p2p_dir;
     wmem_tree_key_t key[] = {
         {1, &k_bus_id},
         {1, &k_device_address},
@@ -817,12 +817,12 @@ record_desegment_data(packet_info *pinfo, usb_conv_info_t *usb_conv_info,
 
 static desegment_data_t *
 get_recorded_desegment_data(packet_info *pinfo, usb_conv_info_t *usb_conv_info,
-                            FTDI_INTERFACE interface, guint8 bitmode)
+                            FTDI_INTERFACE interface, uint8_t bitmode)
 {
-    guint32         k_bus_id = usb_conv_info->bus_id;
-    guint32         k_device_address = usb_conv_info->device_address;
-    guint32         k_interface = (guint32)interface;
-    guint32         k_p2p_dir = (guint32)pinfo->p2p_dir;
+    uint32_t        k_bus_id = usb_conv_info->bus_id;
+    uint32_t        k_device_address = usb_conv_info->device_address;
+    uint32_t        k_interface = (uint32_t)interface;
+    uint32_t        k_p2p_dir = (uint32_t)pinfo->p2p_dir;
     wmem_tree_key_t key[] = {
         {1, &k_bus_id},
         {1, &k_device_address},
@@ -848,13 +848,13 @@ get_recorded_desegment_data(packet_info *pinfo, usb_conv_info_t *usb_conv_info,
     return NULL;
 }
 
-static guint ftdi_fragment_key_hash(gconstpointer k)
+static unsigned ftdi_fragment_key_hash(const void *k)
 {
     const ftdi_fragment_key_t *key = (const ftdi_fragment_key_t *)k;
     return key->id;
 }
 
-static gint ftdi_fragment_key_equal(gconstpointer k1, gconstpointer k2)
+static int ftdi_fragment_key_equal(const void *k1, const void *k2)
 {
     const ftdi_fragment_key_t *key1 = (const ftdi_fragment_key_t *)k1;
     const ftdi_fragment_key_t *key2 = (const ftdi_fragment_key_t *)k2;
@@ -868,7 +868,7 @@ static gint ftdi_fragment_key_equal(gconstpointer k1, gconstpointer k2)
            (key1->p2p_dir == key2->p2p_dir);
 }
 
-static gpointer ftdi_fragment_key(const packet_info *pinfo _U_, const guint32 id, const void *data)
+static void *ftdi_fragment_key(const packet_info *pinfo _U_, const uint32_t id, const void *data)
 {
     desegment_data_t *desegment_data = (desegment_data_t *)data;
     ftdi_fragment_key_t *key = g_slice_new(ftdi_fragment_key_t);
@@ -880,10 +880,10 @@ static gpointer ftdi_fragment_key(const packet_info *pinfo _U_, const guint32 id
     key->p2p_dir = desegment_data->p2p_dir;
     key->id = id;
 
-    return (gpointer)key;
+    return (void *)key;
 }
 
-static void ftdi_fragment_free_key(gpointer ptr)
+static void ftdi_fragment_free_key(void *ptr)
 {
     ftdi_fragment_key_t *key = (ftdi_fragment_key_t *)ptr;
     g_slice_free(ftdi_fragment_key_t, key);
@@ -900,10 +900,10 @@ static const reassembly_table_functions ftdi_reassembly_table_functions = {
 
 static void
 dissect_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, usb_conv_info_t *usb_conv_info,
-                FTDI_INTERFACE interface, guint8 bitmode)
+                FTDI_INTERFACE interface, uint8_t bitmode)
 {
-    guint32           k_bus_id;
-    guint32           k_device_address;
+    uint32_t          k_bus_id;
+    uint32_t          k_device_address;
 
     k_bus_id = usb_conv_info->bus_id;
     k_device_address = usb_conv_info->device_address;
@@ -921,15 +921,15 @@ dissect_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, usb_conv_in
     }
 }
 
-static gint
+static int
 dissect_serial_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_tree *ftdi_tree,
                        usb_conv_info_t *usb_conv_info, FTDI_INTERFACE interface)
 {
-    guint16           save_can_desegment;
+    uint16_t          save_can_desegment;
     int               save_desegment_offset;
-    guint32           save_desegment_len;
+    uint32_t          save_desegment_len;
     desegment_data_t *desegment_data;
-    guint32           bytes;
+    uint32_t          bytes;
 
     save_can_desegment = pinfo->can_desegment;
     save_desegment_offset = pinfo->desegment_offset;
@@ -939,9 +939,9 @@ dissect_serial_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, prot
     if (bytes > 0)
     {
         tvbuff_t *payload_tvb = NULL;
-        guint32   reassembled_bytes = 0;
-        guint8    bitmode;
-        guint8    curr_layer_num = pinfo->curr_layer_num;
+        uint32_t  reassembled_bytes = 0;
+        uint8_t   bitmode;
+        uint8_t   curr_layer_num = pinfo->curr_layer_num;
 
         bitmode = get_recorded_interface_mode(pinfo, usb_conv_info, interface);
 
@@ -1025,7 +1025,7 @@ dissect_serial_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, prot
              * or any way to "shorten" the last added fragment. The most problematic case is when current
              * packet is both last packet for previous reassembly and a first packet for next reassembly.
              */
-            guint8 save_curr_layer_num = pinfo->curr_layer_num;
+            uint8_t save_curr_layer_num = pinfo->curr_layer_num;
             pinfo->curr_layer_num = curr_layer_num;
 
             if (!pinfo->desegment_len)
@@ -1034,7 +1034,7 @@ dissect_serial_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, prot
                 {
                     /* Current tvb is really the last fragment */
                     fragment_add_check(&ftdi_reassembly_table, tvb, 0, pinfo, desegment_data->first_frame,
-                                       desegment_data, reassembled_bytes, bytes, FALSE);
+                                       desegment_data, reassembled_bytes, bytes, false);
                     desegment_data->last_frame = pinfo->num;
                 }
             }
@@ -1045,29 +1045,29 @@ dissect_serial_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, prot
                 if (!desegment_data)
                 {
                     /* Start desegmenting */
-                    gint fragment_length = tvb_reported_length_remaining(tvb, pinfo->desegment_offset);
+                    int fragment_length = tvb_reported_length_remaining(tvb, pinfo->desegment_offset);
                     desegment_data = record_desegment_data(pinfo, usb_conv_info, interface, bitmode);
                     desegment_data->first_frame_offset = pinfo->desegment_offset;
                     fragment_add_check(&ftdi_reassembly_table, tvb, pinfo->desegment_offset, pinfo,
-                                       desegment_data->first_frame, desegment_data, 0, fragment_length, TRUE);
+                                       desegment_data->first_frame, desegment_data, 0, fragment_length, true);
                 }
                 else if (pinfo->desegment_offset == 0)
                 {
                     /* Continue reassembling */
                     fragment_add_check(&ftdi_reassembly_table, tvb, 0, pinfo, desegment_data->first_frame,
-                                       desegment_data, reassembled_bytes, bytes, TRUE);
+                                       desegment_data, reassembled_bytes, bytes, true);
                 }
                 else
                 {
-                    gint fragment_length;
-                    gint previous_bytes;
+                    int fragment_length;
+                    int previous_bytes;
                     desegment_data_t *previous_desegment_data;
 
                     /* This packet contains both an end from a previous reassembly and start of a new one */
-                    DISSECTOR_ASSERT((guint32)pinfo->desegment_offset > reassembled_bytes);
+                    DISSECTOR_ASSERT((uint32_t)pinfo->desegment_offset > reassembled_bytes);
                     previous_bytes = pinfo->desegment_offset - reassembled_bytes;
                     fragment_add_check(&ftdi_reassembly_table, tvb, 0, pinfo, desegment_data->first_frame,
-                                       desegment_data, reassembled_bytes, previous_bytes, FALSE);
+                                       desegment_data, reassembled_bytes, previous_bytes, false);
                     desegment_data->last_frame = pinfo->num;
 
                     previous_desegment_data = desegment_data;
@@ -1076,7 +1076,7 @@ dissect_serial_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, prot
                     desegment_data->first_frame_offset = previous_bytes;
                     desegment_data->previous = previous_desegment_data;
                     fragment_add_check(&ftdi_reassembly_table, tvb, previous_bytes, pinfo, desegment_data->first_frame,
-                                       desegment_data, 0, fragment_length, TRUE);
+                                       desegment_data, 0, fragment_length, true);
                 }
             }
 
@@ -1091,17 +1091,17 @@ dissect_serial_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, prot
     return bytes;
 }
 
-static gint
+static int
 dissect_ftdi_ft(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     proto_item       *main_item;
     proto_tree       *main_tree;
-    gint              offset = 0;
+    int               offset = 0;
     usb_conv_info_t  *usb_conv_info = (usb_conv_info_t *)data;
     request_data_t   *request_data = NULL;
     wmem_tree_key_t   key[4];
-    guint32           k_bus_id;
-    guint32           k_device_address;
+    uint32_t          k_bus_id;
+    uint32_t          k_device_address;
 
     if (!usb_conv_info)
     {
@@ -1141,19 +1141,19 @@ dissect_ftdi_ft(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 
         if (usb_conv_info->is_setup)
         {
-            gint         bytes_dissected;
-            guint8       brequest;
-            guint8       hvalue;
-            guint8       lindex;
+            int          bytes_dissected;
+            uint8_t      brequest;
+            uint8_t      hvalue;
+            uint8_t      lindex;
 
-            brequest = tvb_get_guint8(tvb, offset);
+            brequest = tvb_get_uint8(tvb, offset);
             col_append_fstr(pinfo->cinfo, COL_INFO, ": %s",
                 val_to_str_ext_const(brequest, &request_vals_ext, "Unknown"));
             proto_tree_add_item(main_tree, hf_setup_brequest, tvb, offset, 1, ENC_LITTLE_ENDIAN);
             offset++;
 
-            hvalue = tvb_get_guint8(tvb, offset + 1);
-            lindex = tvb_get_guint8(tvb, offset + 2);
+            hvalue = tvb_get_uint8(tvb, offset + 1);
+            lindex = tvb_get_uint8(tvb, offset + 2);
 
             switch (brequest)
             {
@@ -1258,7 +1258,7 @@ dissect_ftdi_ft(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
     {
         const char *interface_str;
         FTDI_INTERFACE interface;
-        gint rx_hf, tx_hf;
+        int rx_hf, tx_hf;
 
         interface = endpoint_to_interface(usb_conv_info);
         switch (interface)
@@ -1290,8 +1290,8 @@ dissect_ftdi_ft(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
         col_set_str(pinfo->cinfo, COL_PROTOCOL, "FTDI FT");
         if (pinfo->p2p_dir == P2P_DIR_RECV)
         {
-            gint total_rx_len = 0;
-            gint rx_len;
+            int total_rx_len = 0;
+            int rx_len;
             tvbuff_t *rx_tvb = tvb_new_composite();
 
             col_add_fstr(pinfo->cinfo, COL_INFO, "INTERFACE %s RX", interface_str);
@@ -1326,7 +1326,7 @@ dissect_ftdi_ft(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
         }
         else
         {
-            gint bytes;
+            int bytes;
 
             col_add_fstr(pinfo->cinfo, COL_INFO, "INTERFACE %s TX", interface_str);
             bytes = tvb_reported_length_remaining(tvb, offset);
@@ -1696,7 +1696,7 @@ proto_register_ftdi_ft(void)
         { &ei_undecoded, { "ftdi-ft.undecoded", PI_UNDECODED, PI_WARN, "Not dissected yet (report to wireshark.org)", EXPFILL }},
     };
 
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_ftdi_ft,
         &ett_modem_ctrl_lvalue,
         &ett_modem_ctrl_hvalue,
