@@ -22,12 +22,12 @@ void proto_register_g723(void);
 static dissector_handle_t g723_handle;
 
 /* Initialize the protocol and registered fields */
-static int proto_g723					= -1;
-static int hf_g723_frame_size_and_codec	= -1;
-static int hf_g723_lpc_B5_B0			= -1;
+static int proto_g723;
+static int hf_g723_frame_size_and_codec;
+static int hf_g723_lpc_B5_B0;
 
 /* Initialize the subtree pointers */
-static int ett_g723 = -1;
+static int ett_g723;
 
 
 /*		 RFC 3551
@@ -54,7 +54,7 @@ static int
 dissect_g723(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
 	int offset = 0;
-	guint octet;
+	unsigned octet;
 
 	proto_item *ti;
 	proto_tree *g723_tree;
@@ -102,7 +102,7 @@ proto_register_g723(void)
 
 	};
 
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_g723,
 	};
 
