@@ -12,7 +12,7 @@
  */
 
 /*
- * RFC 1436: http://tools.ietf.org/html/rfc1436
+ * RFC 1436: https://tools.ietf.org/html/rfc1436
  * http://en.wikipedia.org/wiki/Gopher_%28protocol%29
  */
 
@@ -25,19 +25,19 @@ void proto_register_gopher(void);
 void proto_reg_handoff_gopher(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_gopher = -1;
-static int hf_gopher_request = -1;
-static int hf_gopher_dir_item = -1;
-static int hf_gopher_di_type = -1;
-static int hf_gopher_di_name = -1;
-static int hf_gopher_di_selector = -1;
-static int hf_gopher_di_host = -1;
-static int hf_gopher_di_port = -1;
-static int hf_gopher_unknown = -1;
+static int proto_gopher;
+static int hf_gopher_request;
+static int hf_gopher_dir_item;
+static int hf_gopher_di_type;
+static int hf_gopher_di_name;
+static int hf_gopher_di_selector;
+static int hf_gopher_di_host;
+static int hf_gopher_di_port;
+static int hf_gopher_unknown;
 
 /* Initialize the subtree pointers */
-static gint ett_gopher = -1;
-static gint ett_dir_item = -1;
+static int ett_gopher;
+static int ett_dir_item;
 
 static dissector_handle_t gopher_handle;
 
@@ -65,50 +65,47 @@ static const value_string item_types[] = {
 
 #define TCP_DEFAULT_RANGE "70"
 
-static range_t *gopher_tcp_range = NULL;
+static range_t *gopher_tcp_range;
 
-/* Returns TRUE if the packet is from a client */
-static gboolean
+/* Returns true if the packet is from a client */
+static bool
 is_client(packet_info *pinfo) {
-    if (value_is_in_range(gopher_tcp_range, pinfo->destport)) {
-        return TRUE;
-    }
-    return FALSE;
+    return value_is_in_range(gopher_tcp_range, pinfo->destport);
 }
 
 /* Name + Tab + Selector + Tab + Host + Tab + Port */
 #define MAX_DIR_LINE_LEN (70 + 1 + 255 + 1 + 255 + 1 + 5)
 #define MIN_DIR_LINE_LEN (0 + 1 + 0 + 1 + 1 + 1 + 1)
-static gboolean
-find_dir_tokens(tvbuff_t *tvb, gint name_start, gint *sel_start, gint *host_start, gint *port_start, gint *line_len, gint *next_offset) {
-    gint remain;
+static bool
+find_dir_tokens(tvbuff_t *tvb, int name_start, int *sel_start, int *host_start, int *port_start, int *line_len, int *next_offset) {
+    int remain;
 
     if (tvb_captured_length_remaining(tvb, name_start) < MIN_DIR_LINE_LEN)
-        return FALSE;
+        return false;
 
     if (! (sel_start && host_start && port_start && line_len && next_offset) )
-        return FALSE;
+        return false;
 
-    *line_len = tvb_find_line_end(tvb, name_start, MAX_DIR_LINE_LEN, next_offset, FALSE);
+    *line_len = tvb_find_line_end(tvb, name_start, MAX_DIR_LINE_LEN, next_offset, false);
     if (*line_len < MIN_DIR_LINE_LEN)
-        return FALSE;
+        return false;
 
     remain = *line_len;
     *sel_start = tvb_find_guint8(tvb, name_start, remain, '\t') + 1;
     if (*sel_start < name_start + 1)
-        return FALSE;
+        return false;
 
     remain -= *sel_start - name_start;
     *host_start = tvb_find_guint8(tvb, *sel_start, remain, '\t') + 1;
     if (*host_start < *sel_start + 1)
-        return FALSE;
+        return false;
 
     remain -= *host_start - *sel_start;
     *port_start = tvb_find_guint8(tvb, *host_start, remain, '\t') + 1;
     if (*port_start < *host_start + 1)
-        return FALSE;
+        return false;
 
-    return TRUE;
+    return true;
 }
 
 /* Dissect the packets */
@@ -117,23 +114,23 @@ static int
 dissect_gopher(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_) {
     proto_item *ti;
     proto_tree *gopher_tree, *dir_tree = NULL;
-    gboolean client = is_client(pinfo);
-    gint line_len;
-    const gchar *request = "[Invalid request]";
-    gboolean is_dir = FALSE;
-    gint offset = 0, next_offset;
-    gint sel_start, host_start, port_start;
-    gchar *name;
+    bool client = is_client(pinfo);
+    int line_len;
+    const char *request = "[Invalid request]";
+    bool is_dir = false;
+    int offset = 0, next_offset;
+    int sel_start, host_start, port_start;
+    char *name;
 
     /* Fill in our protocol and info columns */
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "Gopher");
 
     if (client) {
-        line_len = tvb_find_line_end(tvb, 0, -1, NULL, FALSE);
+        line_len = tvb_find_line_end(tvb, 0, -1, NULL, false);
         if (line_len == 0) {
             request = "[Directory list]";
         } else if (line_len > 0) {
-            request = tvb_get_string_enc(wmem_packet_scope(), tvb, 0, line_len, ENC_ASCII);
+            request = tvb_get_string_enc(pinfo->pool, tvb, 0, line_len, ENC_ASCII);
         }
         col_add_fstr(pinfo->cinfo, COL_INFO, "Request: %s", request);
     } else {
@@ -158,26 +155,26 @@ dissect_gopher(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _
                     col_append_str(pinfo->cinfo, COL_INFO, ": [Directory list]");
                 }
 
-                name = tvb_get_string_enc(wmem_packet_scope(), tvb, offset + 1, sel_start - offset - 2, ENC_ASCII);
+                name = tvb_get_string_enc(pinfo->pool, tvb, offset + 1, sel_start - offset - 2, ENC_ASCII);
                 ti = proto_tree_add_string(gopher_tree, hf_gopher_dir_item, tvb,
                                 offset, line_len + 1, name);
                 dir_tree = proto_item_add_subtree(ti, ett_dir_item);
                 proto_tree_add_item(dir_tree, hf_gopher_di_type, tvb, offset, 1, ENC_ASCII|ENC_NA);
                 proto_tree_add_item(dir_tree, hf_gopher_di_name, tvb, offset + 1,
-                                    sel_start - offset - 2, ENC_ASCII|ENC_NA);
+                                    sel_start - offset - 2, ENC_ASCII);
                 proto_tree_add_item(dir_tree, hf_gopher_di_selector, tvb, sel_start,
-                                    host_start - sel_start - 1, ENC_ASCII|ENC_NA);
+                                    host_start - sel_start - 1, ENC_ASCII);
                 proto_tree_add_item(dir_tree, hf_gopher_di_host, tvb, host_start,
-                                    port_start - host_start - 1, ENC_ASCII|ENC_NA);
+                                    port_start - host_start - 1, ENC_ASCII);
                 proto_tree_add_item(dir_tree, hf_gopher_di_port, tvb, port_start,
-                                    line_len - (port_start - offset - 1), ENC_ASCII|ENC_NA);
-                is_dir = TRUE;
+                                    line_len - (port_start - offset - 1), ENC_ASCII);
+                is_dir = true;
                 offset = next_offset;
             }
 
             if (!is_dir) {
                 proto_item_append_text(ti, "[Unknown]");
-                proto_tree_add_item(gopher_tree, hf_gopher_unknown, tvb, 0, -1, ENC_ASCII|ENC_NA);
+                proto_tree_add_item(gopher_tree, hf_gopher_unknown, tvb, 0, -1, ENC_ASCII);
             }
         }
 
@@ -245,7 +242,7 @@ proto_register_gopher(void)
     };
 
     /* Setup protocol subtree array */
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_gopher,
         &ett_dir_item
     };
@@ -253,6 +250,9 @@ proto_register_gopher(void)
     /* Register the protocol name and description */
     proto_gopher = proto_register_protocol("Gopher", "Gopher", "gopher");
 
+    /* Register the dissector handle */
+    gopher_handle = register_dissector("gopher", dissect_gopher, proto_gopher);
+
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_gopher, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
@@ -267,12 +267,12 @@ proto_register_gopher(void)
 void
 proto_reg_handoff_gopher(void)
 {
-    gopher_handle = create_dissector_handle(dissect_gopher, proto_gopher);
     dissector_add_uint_range_with_preference("tcp.port", TCP_DEFAULT_RANGE, gopher_handle);
+    gopher_prefs_apply();
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
