@@ -20,12 +20,17 @@
 #include <epan/llcsaps.h>
 #include "packet-gre.h"
 #include "packet-wccp.h"
+#include <epan/decode_as.h>
 
 #define GRE_IN_UDP_PORT 4754
 
 void proto_register_gre(void);
 void proto_reg_handoff_gre(void);
 
+static dissector_handle_t gre_handle;
+static capture_dissector_handle_t gre_cap_handle;
+
+
 /*
  * See RFC 1701 "Generic Routing Encapsulation (GRE)", RFC 1702
  * "Generic Routing Encapsulation over IPv4 networks", RFC 2637
@@ -36,62 +41,64 @@ void proto_reg_handoff_gre(void);
  * "Encapsulating MPLS in IP or Generic Routing Encapsulation (GRE)".
  */
 
-static int proto_gre = -1;
-static int hf_gre_proto = -1;
-static int hf_gre_flags_and_version = -1;
-static int hf_gre_flags_checksum = -1;
-static int hf_gre_flags_routing = -1;
-static int hf_gre_flags_key = -1;
-static int hf_gre_flags_sequence_number = -1;
-static int hf_gre_flags_strict_source_route = -1;
-static int hf_gre_flags_recursion_control = -1;
-static int hf_gre_flags_ack = -1;
-static int hf_gre_flags_reserved_ppp = -1;
-static int hf_gre_flags_reserved = -1;
-static int hf_gre_flags_version = -1;
-static int hf_gre_checksum = -1;
-static int hf_gre_checksum_status = -1;
-static int hf_gre_offset = -1;
-static int hf_gre_key = -1;
-static int hf_gre_key_payload_length = -1;
-static int hf_gre_key_call_id = -1;
-static int hf_gre_sequence_number = -1;
-static int hf_gre_ack_number = -1;
-static int hf_gre_routing = -1;
-static int hf_gre_routing_address_family = -1;
-static int hf_gre_routing_sre_length = -1;
-static int hf_gre_routing_sre_offset = -1;
-static int hf_gre_routing_information = -1;
+static int proto_gre;
+static int hf_gre_proto;
+static int hf_gre_flags_and_version;
+static int hf_gre_flags_checksum;
+static int hf_gre_flags_routing;
+static int hf_gre_flags_key;
+static int hf_gre_flags_sequence_number;
+static int hf_gre_flags_strict_source_route;
+static int hf_gre_flags_recursion_control;
+static int hf_gre_flags_ack;
+static int hf_gre_flags_reserved_ppp;
+static int hf_gre_flags_reserved;
+static int hf_gre_flags_version;
+static int hf_gre_checksum;
+static int hf_gre_checksum_status;
+static int hf_gre_offset;
+static int hf_gre_key;
+static int hf_gre_key_payload_length;
+static int hf_gre_key_call_id;
+static int hf_gre_sequence_number;
+static int hf_gre_ack_number;
+static int hf_gre_routing;
+static int hf_gre_routing_address_family;
+static int hf_gre_routing_sre_length;
+static int hf_gre_routing_sre_offset;
+static int hf_gre_routing_information;
 
 /* Ref 3GPP2 A.S0012-C v2.0 and A.S0008-A v1.0 */
-static int hf_gre_3gpp2_attrib = -1;
-static int hf_gre_3gpp2_attrib_id = -1;
-static int hf_gre_3gpp2_attrib_length = -1;
-static int hf_gre_3gpp2_sdi = -1;
-static int hf_gre_3gpp2_fci = -1;
-static int hf_gre_3gpp2_di = -1;
-static int hf_gre_3gpp2_flow_disc = -1;
-static int hf_gre_3gpp2_seg = -1;
+static int hf_gre_3gpp2_attrib;
+static int hf_gre_3gpp2_attrib_id;
+static int hf_gre_3gpp2_attrib_length;
+static int hf_gre_3gpp2_sdi;
+static int hf_gre_3gpp2_fci;
+static int hf_gre_3gpp2_di;
+static int hf_gre_3gpp2_flow_disc;
+static int hf_gre_3gpp2_seg;
 
-static int hf_gre_wccp_redirect_header = -1;
-static int hf_gre_wccp_dynamic_service = -1;
-static int hf_gre_wccp_alternative_bucket_used = -1;
-static int hf_gre_wccp_redirect_header_valid = -1;
-static int hf_gre_wccp_service_id = -1;
-static int hf_gre_wccp_alternative_bucket = -1;
-static int hf_gre_wccp_primary_bucket = -1;
+static int hf_gre_wccp_redirect_header;
+static int hf_gre_wccp_dynamic_service;
+static int hf_gre_wccp_alternative_bucket_used;
+static int hf_gre_wccp_redirect_header_valid;
+static int hf_gre_wccp_service_id;
+static int hf_gre_wccp_alternative_bucket;
+static int hf_gre_wccp_primary_bucket;
 
-static gint ett_gre = -1;
-static gint ett_gre_flags = -1;
-static gint ett_gre_routing = -1;
-static gint ett_gre_wccp2_redirect_header = -1;
-static gint ett_3gpp2_attribs = -1;
-static gint ett_3gpp2_attr = -1;
+static int ett_gre;
+static int ett_gre_flags;
+static int ett_gre_routing;
+static int ett_gre_wccp2_redirect_header;
+static int ett_3gpp2_attribs;
+static int ett_3gpp2_attr;
 
-static expert_field ei_gre_checksum_incorrect = EI_INIT;
+static expert_field ei_gre_checksum_incorrect;
 
 static dissector_table_t gre_dissector_table;
 
+static dissector_table_t gre_subdissector_table;
+
 static const value_string gre_version[] = {
     { 0, "GRE" },                /* [RFC2784] */
     { 1, "Enhanced GRE" },       /* [RFC2637] */
@@ -205,19 +212,19 @@ static const true_false_string gre_wccp_redirect_header_valid_val = {
 static int
 dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-    gboolean    last_attrib  = FALSE;
+    bool        last_attrib  = false;
     proto_item *attr_item;
     proto_tree *attr_tree;
-    guint8      value;
+    uint8_t     value;
     int         start_offset = offset;
 
     proto_item *ti = proto_tree_add_item(tree, hf_gre_3gpp2_attrib, tvb, offset, 0, ENC_NA);
     proto_tree *atree = proto_item_add_subtree(ti, ett_3gpp2_attribs);
 
-    while(last_attrib != TRUE)
+    while(last_attrib != true)
     {
-        guint8 attrib_id = tvb_get_guint8(tvb, offset);
-        guint8 attrib_length = tvb_get_guint8(tvb, offset + 1);
+        uint8_t attrib_id = tvb_get_guint8(tvb, offset);
+        uint8_t attrib_length = tvb_get_guint8(tvb, offset + 1);
 
         attr_tree = proto_tree_add_subtree(atree, tvb, offset, attrib_length + 1 + 1, ett_3gpp2_attr, &attr_item,
                                         val_to_str((attrib_id&0x7f), gre_3gpp2_attrib_id_vals, "%u (Unknown)"));
@@ -226,7 +233,7 @@ dissect_gre_3gpp2_attribs(tvbuff_t *tvb, int offset, proto_tree *tree)
         proto_tree_add_item(attr_tree, hf_gre_3gpp2_attrib_length, tvb, offset+1, 1, ENC_BIG_ENDIAN);
 
         offset += 2;
-        last_attrib = (attrib_id & 0x80)?TRUE:FALSE;
+        last_attrib = (attrib_id & 0x80)?true:false;
         attrib_id &= 0x7F;
 
         switch(attrib_id)
@@ -296,29 +303,29 @@ dissect_gre_wccp2_redirect_header(tvbuff_t *tvb, int offset, proto_tree *tree)
     proto_tree_add_item(rh_tree, hf_gre_wccp_primary_bucket, tvb, offset +3, 1, ENC_BIG_ENDIAN);
 }
 
-static gboolean
-capture_gre(const guchar *pd _U_, int offset _U_, int len _U_, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header _U_)
+static bool
+capture_gre(const unsigned char *pd _U_, int offset _U_, int len _U_, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header _U_)
 {
     capture_dissector_increment_count(cpinfo, proto_gre);
-    return TRUE;
+    return true;
 }
 
 static int
 dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
 
-    int         offset             = 0;
-    guint16     flags_and_ver;
-    guint16     type;
-    gboolean    is_ppp             = FALSE;
-    gboolean    is_wccp2           = FALSE;
-    proto_item *ti, *it_flags;
-    proto_tree *gre_tree, *fv_tree = NULL;
-    guint16     sre_af;
-    guint8      sre_length;
-    tvbuff_t   *next_tvb;
+    int             offset             = 0;
+    gre_hdr_info_t  gre_hdr_info;
+    uint16_t        type;
+    bool            is_ppp             = false;
+    bool            is_wccp2           = false;
+    proto_item     *ti, *it_flags;
+    proto_tree     *gre_tree, *fv_tree = NULL;
+    uint16_t        sre_af;
+    uint8_t         sre_length;
+    tvbuff_t       *next_tvb;
 
-    flags_and_ver = tvb_get_ntohs(tvb, offset);
+    gre_hdr_info.flags_and_ver = tvb_get_ntohs(tvb, offset);
     type = tvb_get_ntohs(tvb, offset + 2);
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "GRE");
@@ -328,12 +335,12 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     switch (type) {
 
     case ETHERTYPE_PPP:
-        if (flags_and_ver & GRE_VERSION)
-            is_ppp = TRUE;
+        if (gre_hdr_info.flags_and_ver & GRE_VERSION)
+            is_ppp = true;
         break;
     case ETHERTYPE_3GPP2:
     case ETHERTYPE_CDMA2000_A10_UBS:
-        is_ppp = TRUE;
+        is_ppp = true;
         break;
 
     case GRE_WCCP:
@@ -341,7 +348,7 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
            encapsulation type; if it looks as if the first octet of the packet
            isn't the beginning of an IPv4 header, assume it's WCCP2. */
         if ((tvb_get_guint8(tvb, offset + 2 + 2) & 0xF0) != 0x40) {
-            is_wccp2 = TRUE;
+            is_wccp2 = true;
         }
         break;
     }
@@ -390,8 +397,8 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
         proto_tree_add_item(gre_tree, hf_gre_proto, tvb, offset, 2, ENC_BIG_ENDIAN);
         offset += 2;
 
-        if (flags_and_ver & GRE_CHECKSUM || flags_and_ver & GRE_ROUTING) {
-            guint length, reported_length;
+        if (gre_hdr_info.flags_and_ver & GRE_CHECKSUM || gre_hdr_info.flags_and_ver & GRE_ROUTING) {
+            unsigned length, reported_length;
             vec_t cksum_vec[1];
 
             /* Checksum check !... */
@@ -399,7 +406,7 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
             reported_length = tvb_reported_length(tvb);
             /* The Checksum Present bit is set, and the packet isn't part of a
                fragmented datagram and isn't truncated, so we can checksum it. */
-            if ((flags_and_ver & GRE_CHECKSUM) && !pinfo->fragmented && length >= reported_length) {
+            if ((gre_hdr_info.flags_and_ver & GRE_CHECKSUM) && !pinfo->fragmented && length >= reported_length) {
                 SET_CKSUM_VEC_TVB(cksum_vec[0], tvb, 0, reported_length);
                 proto_tree_add_checksum(gre_tree, tvb, offset, hf_gre_checksum, hf_gre_checksum_status, &ei_gre_checksum_incorrect, pinfo, in_cksum(cksum_vec, 1),
                                 ENC_BIG_ENDIAN, PROTO_CHECKSUM_VERIFY|PROTO_CHECKSUM_IN_CKSUM);
@@ -413,7 +420,7 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
             offset += 2;
         }
 
-        if (flags_and_ver & GRE_KEY) {
+        if (gre_hdr_info.flags_and_ver & GRE_KEY) {
             /* RFC2637 Section 4.1 : Enhanced GRE Header */
             if (is_ppp && type!=ETHERTYPE_CDMA2000_A10_UBS) {
 
@@ -424,21 +431,21 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                 offset += 2;
             }
             else {
-                proto_tree_add_item(gre_tree, hf_gre_key, tvb, offset, 4, ENC_BIG_ENDIAN);
+                proto_tree_add_item_ret_uint(gre_tree, hf_gre_key, tvb, offset, 4, ENC_BIG_ENDIAN, &gre_hdr_info.key);
                 offset += 4;
             }
         }
-        if (flags_and_ver & GRE_SEQUENCE) {
+        if (gre_hdr_info.flags_and_ver & GRE_SEQUENCE) {
 
             proto_tree_add_item(gre_tree, hf_gre_sequence_number , tvb, offset, 4, ENC_BIG_ENDIAN);
             offset += 4;
         }
-        if (is_ppp && (flags_and_ver & GRE_ACK)) {
+        if (is_ppp && (gre_hdr_info.flags_and_ver & GRE_ACK)) {
 
             proto_tree_add_item(gre_tree, hf_gre_ack_number , tvb, offset, 4, ENC_BIG_ENDIAN);
             offset += 4;
         }
-        if (flags_and_ver & GRE_ROUTING) {
+        if (gre_hdr_info.flags_and_ver & GRE_ROUTING) {
             proto_item *it_routing;
             proto_tree *r_tree;
             for (;;) {
@@ -483,18 +490,25 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
            and some other bits in RFC 1701 and says that they should be
            zero for RFC 2784-compliant GRE; as such, the absence of the
            S bit doesn't necessarily mean there's no payload.  */
-        if (!(flags_and_ver & GRE_SEQUENCE)) {
+        if (!(gre_hdr_info.flags_and_ver & GRE_SEQUENCE)) {
             if (tvb_reported_length_remaining(tvb, offset) <= 0)
                 return offset; /* no payload */
         }
         next_tvb = tvb_new_subset_remaining(tvb, offset);
-        pinfo->flags.in_gre_pkt = TRUE;
-        if (!dissector_try_uint_new(gre_dissector_table, type, next_tvb, pinfo, tree, TRUE, &flags_and_ver))
-            call_data_dissector(next_tvb, pinfo, gre_tree);
+        pinfo->flags.in_gre_pkt = true;
+        if (!dissector_try_uint_new(gre_dissector_table, type, next_tvb, pinfo, tree, true, &gre_hdr_info))
+            if (!dissector_try_payload_new(gre_subdissector_table, next_tvb, pinfo, tree, true, &gre_hdr_info)) {
+              call_data_dissector(next_tvb, pinfo, gre_tree);
+            }
     }
     return tvb_captured_length(tvb);
 }
 
+static void
+gre_prompt(packet_info *pinfo _U_, char* result)
+{
+  snprintf(result, MAX_DECODE_AS_PROMPT_LEN, "GRE proto as");
+}
 
 void
 proto_register_gre(void)
@@ -702,7 +716,7 @@ proto_register_gre(void)
             "Primary bucket index used to redirect the packet.", HFILL  }
         },
     };
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_gre,
         &ett_gre_flags,
         &ett_gre_routing,
@@ -720,6 +734,8 @@ proto_register_gre(void)
 
     proto_gre = proto_register_protocol("Generic Routing Encapsulation",
                                         "GRE", "gre");
+    gre_handle = register_dissector("gre", dissect_gre, proto_gre);
+    gre_cap_handle = register_capture_dissector("gre", capture_gre, proto_gre);
     proto_register_field_array(proto_gre, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
     expert_gre = expert_register_protocol(proto_gre);
@@ -746,18 +762,16 @@ proto_register_gre(void)
      */
     gre_dissector_table = register_dissector_table("gre.proto",
                                                    "GRE protocol type", proto_gre, FT_UINT16, BASE_HEX);
+
+    gre_subdissector_table = register_decode_as_next_proto(proto_gre, "gre.subproto",
+                                                                "GRE protocol type", gre_prompt);
 }
 
 void
 proto_reg_handoff_gre(void)
 {
-    dissector_handle_t gre_handle;
-    capture_dissector_handle_t gre_cap_handle;
-
-    gre_handle = create_dissector_handle(dissect_gre, proto_gre);
     dissector_add_uint("ip.proto", IP_PROTO_GRE, gre_handle);
     dissector_add_uint("udp.port", GRE_IN_UDP_PORT, gre_handle);
-    gre_cap_handle = create_capture_dissector_handle(capture_gre, proto_gre);
     capture_dissector_add_uint("ip.proto", IP_PROTO_GRE, gre_cap_handle);
 }
 
