@@ -22,109 +22,109 @@
 void proto_register_abis_om2000(void);
 
 /* initialize the protocol and registered fields */
-static int proto_abis_om2000 = -1;
+static int proto_abis_om2000;
 
-static int hf_om2k_msg_code = -1;
-static int hf_om2k_mo_if = -1;
-static int hf_om2k_mo_class = -1;
-static int hf_om2k_mo_sub1 = -1;
-static int hf_om2k_mo_sub2 = -1;
-static int hf_om2k_mo_instance = -1;
+static int hf_om2k_msg_code;
+static int hf_om2k_mo_if;
+static int hf_om2k_mo_class;
+static int hf_om2k_mo_sub1;
+static int hf_om2k_mo_sub2;
+static int hf_om2k_mo_instance;
 
-static int hf_om2k_aip = -1;
-static int hf_om2k_oip = -1;
-static int hf_om2k_comb = -1;
-static int hf_om2k_ts = -1;
-static int hf_om2k_hsn = -1;
-static int hf_om2k_maio = -1;
-static int hf_om2k_bsic = -1;
-static int hf_om2k_diversity = -1;
-static int hf_om2k_fn_offs = -1;
-static int hf_om2k_ext_range = -1;
-static int hf_om2k_irc = -1;
-static int hf_om2k_bs_pa_mfrms = -1;
-static int hf_om2k_bs_ag_blks_res= -1;
-static int hf_om2k_drx_dev_max = -1;
-static int hf_om2k_cr = -1;
-static int hf_om2k_ipt3 = -1;
-static int hf_om2k_aop = -1;
-static int hf_om2k_t3105 = -1;
-static int hf_om2k_ny1 = -1;
-static int hf_om2k_cbi = -1;
-static int hf_om2k_tsc = -1;
-static int hf_om2k_icm = -1;
-static int hf_om2k_tta = -1;
-static int hf_om2k_icm_cr = -1;
-static int hf_om2k_lsc_fm = -1;
-static int hf_om2k_lsc_lsi = -1;
-static int hf_om2k_lsc_lsa = -1;
-static int hf_om2k_ls_ft = -1;
-static int hf_om2k_cst = -1;
-static int hf_om2k_ea = -1;
-static int hf_om2k_unknown_tag = -1;
-static int hf_om2k_unknown_val = -1;
-static int hf_om2k_nom_pwr = -1;
-static int hf_om2k_fill_mark = -1;
-static int hf_om2k_bcc = -1;
-static int hf_om2k_mo_state = -1;
-static int hf_om2k_la_state = -1;
-static int hf_om2k_tsn_state = -1;
-static int hf_om2k_bts_manuf = -1;
-static int hf_om2k_bts_gen = -1;
-static int hf_om2k_bts_rev = -1;
-static int hf_om2k_bts_var = -1;
-static int hf_om2k_brr = -1;
-static int hf_om2k_bfr = -1;
-static int hf_om2k_hwinfo_sig = -1;
-static int hf_om2k_capa_sig = -1;
-static int hf_om2k_file_rev = -1;
-static int hf_om2k_filerel_ilr = -1;
-static int hf_om2k_filerel_cur = -1;
-static int hf_om2k_filerel_other = -1;
-static int hf_om2k_cal_time = -1;
-static int hf_om2k_list_nr = -1;
-static int hf_om2k_list_nr_end = -1;
-static int hf_om2k_isl = -1;
-static int hf_om2k_isl_icp1 = -1;
-static int hf_om2k_isl_icp2 = -1;
-static int hf_om2k_isl_ci = -1;
-static int hf_om2k_conl = -1;
-static int hf_om2k_conl_nr_cgs = -1;
-static int hf_om2k_conl_nr_cps_cg = -1;
-static int hf_om2k_conl_ccp = -1;
-static int hf_om2k_conl_ci = -1;
-static int hf_om2k_conl_tag = -1;
-static int hf_om2k_conl_tei = -1;
-static int hf_om2k_tf_mode = -1;
-static int hf_om2k_tf_fs_offset = -1;
-static int hf_om2k_attr_id = -1;
-static int hf_om2k_attr_index = -1;
-static int hf_om2k_result_code = -1;
-static int hf_om2k_reason_code = -1;
-static int hf_om2k_iwd_type = -1;
-static int hf_om2k_iwd_gen_rev = -1;
-static int hf_om2k_trxc_list = -1;
-static int hf_om2k_max_allowed_power = -1;
-static int hf_om2k_max_allowed_num_trxcs = -1;
-static int hf_om2k_mctr_feat_sts_bitmap = -1;
-static int hf_om2k_config_type = -1;
-static int hf_om2k_jitter_size = -1;
-static int hf_om2k_packing_algo = -1;
-static int hf_om2k_power_bo_ctype_map = -1;
-static int hf_om2k_power_bo_priority = -1;
-static int hf_om2k_power_bo_value = -1;
+static int hf_om2k_aip;
+static int hf_om2k_oip;
+static int hf_om2k_comb;
+static int hf_om2k_ts;
+static int hf_om2k_hsn;
+static int hf_om2k_maio;
+static int hf_om2k_bsic;
+static int hf_om2k_diversity;
+static int hf_om2k_fn_offs;
+static int hf_om2k_ext_range;
+static int hf_om2k_irc;
+static int hf_om2k_bs_pa_mfrms;
+static int hf_om2k_bs_ag_blks_res;
+static int hf_om2k_drx_dev_max;
+static int hf_om2k_cr;
+static int hf_om2k_ipt3;
+static int hf_om2k_aop;
+static int hf_om2k_t3105;
+static int hf_om2k_ny1;
+static int hf_om2k_cbi;
+static int hf_om2k_tsc;
+static int hf_om2k_icm;
+static int hf_om2k_tta;
+static int hf_om2k_icm_cr;
+static int hf_om2k_lsc_fm;
+static int hf_om2k_lsc_lsi;
+static int hf_om2k_lsc_lsa;
+static int hf_om2k_ls_ft;
+static int hf_om2k_cst;
+static int hf_om2k_ea;
+static int hf_om2k_unknown_tag;
+static int hf_om2k_unknown_val;
+static int hf_om2k_nom_pwr;
+static int hf_om2k_fill_mark;
+static int hf_om2k_bcc;
+static int hf_om2k_mo_state;
+static int hf_om2k_la_state;
+static int hf_om2k_tsn_state;
+static int hf_om2k_bts_manuf;
+static int hf_om2k_bts_gen;
+static int hf_om2k_bts_rev;
+static int hf_om2k_bts_var;
+static int hf_om2k_brr;
+static int hf_om2k_bfr;
+static int hf_om2k_hwinfo_sig;
+static int hf_om2k_capa_sig;
+static int hf_om2k_file_rev;
+static int hf_om2k_filerel_ilr;
+static int hf_om2k_filerel_cur;
+static int hf_om2k_filerel_other;
+static int hf_om2k_cal_time;
+static int hf_om2k_list_nr;
+static int hf_om2k_list_nr_end;
+static int hf_om2k_isl;
+static int hf_om2k_isl_icp1;
+static int hf_om2k_isl_icp2;
+static int hf_om2k_isl_ci;
+static int hf_om2k_conl;
+static int hf_om2k_conl_nr_cgs;
+static int hf_om2k_conl_nr_cps_cg;
+static int hf_om2k_conl_ccp;
+static int hf_om2k_conl_ci;
+static int hf_om2k_conl_tag;
+static int hf_om2k_conl_tei;
+static int hf_om2k_tf_mode;
+static int hf_om2k_tf_fs_offset;
+static int hf_om2k_attr_id;
+static int hf_om2k_attr_index;
+static int hf_om2k_result_code;
+static int hf_om2k_reason_code;
+static int hf_om2k_iwd_type;
+static int hf_om2k_iwd_gen_rev;
+static int hf_om2k_trxc_list;
+static int hf_om2k_max_allowed_power;
+static int hf_om2k_max_allowed_num_trxcs;
+static int hf_om2k_mctr_feat_sts_bitmap;
+static int hf_om2k_config_type;
+static int hf_om2k_jitter_size;
+static int hf_om2k_packing_algo;
+static int hf_om2k_power_bo_ctype_map;
+static int hf_om2k_power_bo_priority;
+static int hf_om2k_power_bo_value;
 
 /* initialize the subtree pointers */
-static int ett_om2000 = -1;
-static int ett_om2k_mo = -1;
-static int ett_om2k_isl = -1;
-static int ett_om2k_conl = -1;
-static int ett_om2k_iwd = -1;
+static int ett_om2000;
+static int ett_om2k_mo;
+static int ett_om2k_isl;
+static int ett_om2k_conl;
+static int ett_om2k_iwd;
 
-static expert_field ei_om2k_not_performed = EI_INIT;
-static expert_field ei_om2k_reject = EI_INIT;
-static expert_field ei_om2k_nack = EI_INIT;
-static expert_field ei_om2k_ena_res_disabled = EI_INIT;
+static expert_field ei_om2k_not_performed;
+static expert_field ei_om2k_reject;
+static expert_field ei_om2k_nack;
+static expert_field ei_om2k_ena_res_disabled;
 
 static const value_string om2k_msgcode_vals[] = {
 	{ 0x0000, "Abort SP Command" },
@@ -632,11 +632,11 @@ static const value_string om2k_iwd_type_vals[] = {
 	{ 0, NULL }
 };
 
-static gint
-dissect_tss_mo_state(tvbuff_t *tvb, gint offset, proto_tree *tree)
+static int
+dissect_tss_mo_state(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
-	guint8 tmp;
-	guint  i = 0;
+	uint8_t tmp;
+	unsigned  i = 0;
 
 	for (i = 0; i < 8; i+= 2) {
 		tmp = tvb_get_guint8(tvb, offset);
@@ -653,8 +653,8 @@ dissect_tss_mo_state(tvbuff_t *tvb, gint offset, proto_tree *tree)
 }
 
 
-static gint
-dissect_om2k_time(tvbuff_t *tvb, gint offset, proto_tree *tree)
+static int
+dissect_om2k_time(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	nstime_t  tmptime;
 	time_t    tval;
@@ -677,24 +677,24 @@ dissect_om2k_time(tvbuff_t *tvb, gint offset, proto_tree *tree)
 	return 6;
 }
 
-static gint
-dissect_om2k_attr_unkn(tvbuff_t *tvb, gint offset, gint len, gint iei, proto_tree *tree)
+static int
+dissect_om2k_attr_unkn(tvbuff_t *tvb, packet_info *pinfo, int offset, int len, int iei, proto_tree *tree)
 {
 	proto_tree_add_bytes_format(tree, hf_om2k_unknown_val, tvb,
 				    offset, len, NULL,
 				    "%s: %s",
 				    val_to_str_ext(iei, &om2k_attr_vals_ext, "0x%02x"),
-				    tvb_bytes_to_str(wmem_packet_scope(), tvb, offset, len));
+				    tvb_bytes_to_str(pinfo->pool, tvb, offset, len));
 	return len;
 }
 
-static gint
-dissect_om2k_is_list(tvbuff_t *tvb, gint base_offset, proto_tree *tree)
+static int
+dissect_om2k_is_list(tvbuff_t *tvb, int base_offset, proto_tree *tree)
 {
-	gint        offset = base_offset;
+	int         offset = base_offset;
 	proto_item *ti;
 	proto_tree *isl_tree;
-	guint8      len    = tvb_get_guint8(tvb, offset++);
+	uint8_t     len    = tvb_get_guint8(tvb, offset++);
 
 	ti       = proto_tree_add_item(tree, hf_om2k_isl, tvb, offset, len, ENC_NA);
 	isl_tree = proto_item_add_subtree(ti, ett_om2k_isl);
@@ -712,13 +712,13 @@ dissect_om2k_is_list(tvbuff_t *tvb, gint base_offset, proto_tree *tree)
 	return offset - base_offset;
 }
 
-static gint
-dissect_om2k_con_list(tvbuff_t *tvb, gint base_offset, proto_tree *tree)
+static int
+dissect_om2k_con_list(tvbuff_t *tvb, int base_offset, proto_tree *tree)
 {
-	gint        offset = base_offset;
+	int         offset = base_offset;
 	proto_item *ti;
 	proto_tree *conl_tree;
-	guint8      len    = tvb_get_guint8(tvb, offset++);
+	uint8_t     len    = tvb_get_guint8(tvb, offset++);
 
 	ti = proto_tree_add_item(tree, hf_om2k_conl, tvb, offset, len, ENC_NA);
 	conl_tree = proto_item_add_subtree(ti, ett_om2k_conl);
@@ -727,7 +727,7 @@ dissect_om2k_con_list(tvbuff_t *tvb, gint base_offset, proto_tree *tree)
 			    offset++, 1, ENC_BIG_ENDIAN);
 
 	while (offset < base_offset + len) {
-		guint8 nr_cps_cg = tvb_get_guint8(tvb, offset);
+		uint8_t nr_cps_cg = tvb_get_guint8(tvb, offset);
 		proto_tree_add_item(conl_tree, hf_om2k_conl_nr_cps_cg, tvb,
 				    offset++, 1, ENC_BIG_ENDIAN);
 		while (nr_cps_cg--) {
@@ -745,57 +745,57 @@ dissect_om2k_con_list(tvbuff_t *tvb, gint base_offset, proto_tree *tree)
 	return offset - base_offset;
 }
 
-static gint
-dissect_om2k_negotiation_record1(tvbuff_t *tvb, gint base_offset, proto_tree *tree)
+static int
+dissect_om2k_negotiation_record1(tvbuff_t *tvb, int base_offset, proto_tree *tree)
 {
-	gint offset = base_offset;
-	guint8 i;
-	guint8 num_iwd = tvb_get_guint8(tvb, offset++);
+	int offset = base_offset;
+	uint8_t i;
+	uint8_t num_iwd = tvb_get_guint8(tvb, offset++);
 
 	for (i = 0; i < num_iwd; i++) {
-		guint8 j;
+		uint8_t j;
 		proto_item *ti;
 		proto_tree *iwd_tree;
-		guint8 num_vers = tvb_get_guint8(tvb, offset++);
+		uint8_t num_vers = tvb_get_guint8(tvb, offset++);
 
 		ti = proto_tree_add_item(tree, hf_om2k_iwd_type, tvb, offset++, 1, ENC_NA);
 		iwd_tree = proto_item_add_subtree(ti, ett_om2k_iwd);
 
 		for (j = 0; j < num_vers; j++) {
 			proto_tree_add_item(iwd_tree, hf_om2k_iwd_gen_rev, tvb,
-					    offset, 6, ENC_ASCII|ENC_NA);
+					    offset, 6, ENC_ASCII);
 			offset += 6;
 		}
 	}
 	return offset - base_offset;
 }
 
-static gint
-dissect_om2k_mo_record(tvbuff_t *tvb, gint base_offset, gint len, proto_tree *tree)
+static int
+dissect_om2k_mo_record(tvbuff_t *tvb, packet_info *pinfo, int base_offset, int len, proto_tree *tree)
 {
-	gint offset = base_offset;
+	int offset = base_offset;
 	proto_tree_add_item(tree, hf_om2k_mo_class, tvb, offset++, 1, ENC_NA);
 	proto_tree_add_item(tree, hf_om2k_mo_instance, tvb, offset++, 1, ENC_NA);
 
 	while (offset < len) {
-		guint16 attr_id;
-		guint8 attr_len;
+		uint16_t attr_id;
+		uint8_t attr_len;
 
 		attr_id = tvb_get_guint16(tvb, offset, ENC_BIG_ENDIAN);
 		offset += 2;
 		attr_len = tvb_get_guint8(tvb, offset++);
-		offset += dissect_om2k_attr_unkn(tvb, offset, attr_len, attr_id, tree);
+		offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, attr_len, attr_id, tree);
 	}
 
 	return offset - base_offset;
 }
 
-static gint
-dissect_om2k_negotiation_record2(tvbuff_t *tvb, gint base_offset, proto_tree *tree)
+static int
+dissect_om2k_negotiation_record2(tvbuff_t *tvb, int base_offset, proto_tree *tree)
 {
-	gint offset = base_offset;
-	guint8 i;
-	guint8 num_iwd = tvb_get_guint8(tvb, offset++);
+	int offset = base_offset;
+	uint8_t i;
+	uint8_t num_iwd = tvb_get_guint8(tvb, offset++);
 
 	for (i = 0; i < num_iwd; i++) {
 		proto_item *ti;
@@ -805,7 +805,7 @@ dissect_om2k_negotiation_record2(tvbuff_t *tvb, gint base_offset, proto_tree *tr
 		iwd_tree = proto_item_add_subtree(ti, ett_om2k_iwd);
 
 		proto_tree_add_item(iwd_tree, hf_om2k_iwd_gen_rev, tvb,
-				    offset, 6, ENC_ASCII|ENC_NA);
+				    offset, 6, ENC_ASCII);
 		offset += 6;
 	}
 	return offset - base_offset;
@@ -813,12 +813,12 @@ dissect_om2k_negotiation_record2(tvbuff_t *tvb, gint base_offset, proto_tree *tr
 
 
 
-static gint
-dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *tree, guint16 msg_code)
+static int
+dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, int offset, proto_tree *tree, uint16_t msg_code)
 {
 	while (tvb_reported_length_remaining(tvb, offset) > 0) {
-		guint8 iei = tvb_get_guint8(tvb, offset++);
-		guint8 len, tmp;
+		uint8_t iei = tvb_get_guint8(tvb, offset++);
+		uint8_t len, tmp;
 		proto_item *ti;
 
 		switch (iei) {
@@ -880,7 +880,7 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			/* FIXME */
 		case 0x15: /* External Condition Map Class 2 */
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 2, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 2, iei, tree);
 			break;
 		case 0x16: /* File Relation Indication */
 			proto_tree_add_item(tree, hf_om2k_filerel_ilr, tvb,
@@ -894,7 +894,7 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			break;
 		case 0x17: /* File Revision */
 			proto_tree_add_item(tree, hf_om2k_file_rev, tvb,
-					    offset, 8, ENC_ASCII|ENC_NA);
+					    offset, 8, ENC_ASCII);
 			offset += 8;
 			break;
 		case 0x1c: /* Filling Marker */
@@ -909,13 +909,13 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 		case 0x1e: /* Frequency List */
 			len = tvb_get_guint8(tvb, offset++);
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, len, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, len, iei, tree);
 			break;
 		case 0x1f: /* Frequency Specifier Rx */
 			/* FIXME */
 		case 0x20: /* Frequency Specifier Rx */
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 2, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 2, iei, tree);
 			break;
 		case 0x21: /* HSN */
 			proto_tree_add_item(tree, hf_om2k_hsn, tvb,
@@ -933,7 +933,7 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			/* FIXME */
 		case 0x26: /* Internal Fault Map Class 2A Ext */
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 6, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 6, iei, tree);
 			break;
 		case 0x27: /* IS Connection List */
 			offset += dissect_om2k_is_list(tvb, offset, tree);
@@ -979,7 +979,7 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			break;
 		case 0x34: /* Replacement Unit Map */
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 6, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 6, iei, tree);
 			break;
 		case 0x35: /* Result Code */
 			proto_tree_add_item(tree, hf_om2k_result_code, tvb,
@@ -1003,16 +1003,16 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			break;
 		case 0x40: /* BTS Version */
 			proto_tree_add_item(tree, hf_om2k_bts_manuf, tvb,
-					    offset, 3, ENC_ASCII|ENC_NA);
+					    offset, 3, ENC_ASCII);
 			offset += 3;
 			proto_tree_add_item(tree, hf_om2k_bts_gen, tvb,
-					    offset, 3, ENC_ASCII|ENC_NA);
+					    offset, 3, ENC_ASCII);
 			offset += 3;
 			proto_tree_add_item(tree, hf_om2k_bts_rev, tvb,
-					    offset, 3, ENC_ASCII|ENC_NA);
+					    offset, 3, ENC_ASCII);
 			offset += 3;
 			proto_tree_add_item(tree, hf_om2k_bts_var, tvb,
-					    offset, 3, ENC_ASCII|ENC_NA);
+					    offset, 3, ENC_ASCII);
 			offset += 3;
 			break;
 		case 0x43: /* OML Function Map 1 */
@@ -1021,7 +1021,7 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 		case 0x46: /* RSL Function Map 2 */
 			len = tvb_get_guint8(tvb, offset++);
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, len, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, len, iei, tree);
 			break;
 		case 0x47: /* Ext Range */
 			proto_tree_add_item(tree, hf_om2k_ext_range, tvb,
@@ -1036,11 +1036,11 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			break;
 		case 0x50: /* Replacement Unit Map Extension */
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 6, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 6, iei, tree);
 			break;
 		case 0x74: /* ICM Boundary */
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 5, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 5, iei, tree);
 			break;
 		case 0x79: /* Link Supervision Control */
 			proto_tree_add_item(tree, hf_om2k_lsc_fm, tvb,
@@ -1076,7 +1076,7 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			offset += 2;
 			break;
 		case 0x85: /* MO Record */
-			offset += dissect_om2k_mo_record(tvb, offset, tvb_reported_length_remaining(tvb, offset), tree);
+			offset += dissect_om2k_mo_record(tvb, pinfo, offset, tvb_reported_length_remaining(tvb, offset), tree);
 			break;
 		case 0x87: /* TTA */
 			proto_tree_add_item(tree, hf_om2k_tta, tvb,
@@ -1105,7 +1105,7 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			break;
 		case 0x95: /* Dedication information */
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 3, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 3, iei, tree);
 			break;
 		case 0x98: /* FS Offset */
 			proto_tree_add_item(tree, hf_om2k_tf_fs_offset, tvb,
@@ -1114,7 +1114,7 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			break;
 		case 0x9c: /* External Condition Class 2 Extension */
 			/* FIXME */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 4, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 4, iei, tree);
 			break;
 		case 0x9d: /* TSs MO State */
 			offset += dissect_tss_mo_state(tvb, offset, tree);
@@ -1167,16 +1167,16 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 			 * TLV structure is quite clear in the protocol
 			 * traces */
 			tmp = tvb_get_guint8(tvb, offset++);
-			offset += dissect_om2k_attr_unkn(tvb, offset, tmp, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, tmp, iei, tree);
 			break;
 		case 0xb5: /* unknown 2-bytes fixed length attribute of TX Config */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 2, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 2, iei, tree);
 			break;
 		case 0xd2: /* unknown 6-bytes fixed length attribute of TRXC Fault Rep */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 6, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 6, iei, tree);
 			break;
 		case 0xac: /* unknown 58-bytes fixed length attribute of message type 0x0136 */
-			offset += dissect_om2k_attr_unkn(tvb, offset, 58, iei, tree);
+			offset += dissect_om2k_attr_unkn(tvb, pinfo, offset, 58, iei, tree);
 			break;
 		default:
 			tmp = tvb_get_guint8(tvb, offset);
@@ -1191,11 +1191,11 @@ dissect_om2k_attrs(tvbuff_t *tvb, packet_info *pinfo, gint offset, proto_tree *t
 	return offset;
 }
 
-static guint
-dissect_om2k_mo(tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *tree)
+static unsigned
+dissect_om2k_mo(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	guint8      mo_class = tvb_get_guint8(tvb, offset);
-	guint8      inst  = tvb_get_guint8(tvb, offset+3);
+	uint8_t     mo_class = tvb_get_guint8(tvb, offset);
+	uint8_t     inst  = tvb_get_guint8(tvb, offset+3);
 
 	col_append_fstr(pinfo->cinfo, COL_INFO, ", (%-4s %u)",
 				val_to_str(mo_class, om2k_mo_class_short_vals,
@@ -1203,8 +1203,8 @@ dissect_om2k_mo(tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *tree
 	if (tree) {
 		proto_item *ti;
 		proto_tree *mo_tree;
-		guint8      sub1  = tvb_get_guint8(tvb, offset+1);
-		guint8      sub2  = tvb_get_guint8(tvb, offset+2);
+		uint8_t     sub1  = tvb_get_guint8(tvb, offset+1);
+		uint8_t     sub2  = tvb_get_guint8(tvb, offset+2);
 
 		ti      = proto_tree_add_item(tree, hf_om2k_mo_if, tvb, offset,
 					      4, ENC_NA);
@@ -1229,9 +1229,9 @@ dissect_abis_om2000(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* d
 {
 	proto_item *ti;
 	proto_tree *om2k_tree;
-	guint16     msg_code;
-	guint8      tmp;
-	const gchar *msgt_str;
+	uint16_t    msg_code;
+	uint8_t     tmp;
+	const char *msgt_str;
 
 	int offset;
 
@@ -1375,12 +1375,12 @@ proto_register_abis_om2000(void)
 		},
 		{ &hf_om2k_ext_range,
 		  { "Extended Range", "gsm_abis_om2000.ext_range",
-		    FT_BOOLEAN, 1, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01' ? */
+		    FT_BOOLEAN, BASE_NONE, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01' ? */
 		    NULL, HFILL }
 		},
 		{ &hf_om2k_irc,
 		  { "Interference Rejection Combining", "gsm_abis_om2000.irc",
-		    FT_BOOLEAN, 1, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01,' ? */
+		    FT_BOOLEAN, BASE_NONE, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01,' ? */
 		    NULL, HFILL }
 		},
 		{ &hf_om2k_bs_pa_mfrms,
@@ -1400,12 +1400,12 @@ proto_register_abis_om2000(void)
 		},
 		{ &hf_om2k_cr,
 		  { "CCCH Repeat", "gsm_abis_om2000.ccch_repeat",
-		    FT_BOOLEAN, 1, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01,' ? */
+		    FT_BOOLEAN, BASE_NONE, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01,' ? */
 		    NULL, HFILL }
 		},
 		{ &hf_om2k_ipt3,
 		  { "Inhibit Paging Request Type 3", "gsm_abis_om2000.ipt3",
-		    FT_BOOLEAN, 2, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x02,' ? */
+		    FT_BOOLEAN, BASE_NONE, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x02,' ? */
 		    NULL, HFILL }
 		},
 		{ &hf_om2k_aop,
@@ -1425,7 +1425,7 @@ proto_register_abis_om2000(void)
 		},
 		{ &hf_om2k_cbi,
 		  { "CBCH Indicator", "gsm_abis_om2000.cbi",
-		    FT_BOOLEAN, 1, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01,' ? */
+		    FT_BOOLEAN, BASE_NONE, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01,' ? */
 		    NULL, HFILL }
 		},
 		{ &hf_om2k_tsc,
@@ -1435,7 +1435,7 @@ proto_register_abis_om2000(void)
 		},
 		{ &hf_om2k_icm,
 		  { "Idle Channel Measurement", "gsm_abis_om2000.icm",
-		    FT_BOOLEAN, 1, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01,' ? */
+		    FT_BOOLEAN, BASE_NONE, NULL, 0,          /* XXX: bitmask needed? 'FT_BOOLEAN, 8, NULL, 0x01,' ? */
 		    NULL, HFILL }
 		},
 		{ &hf_om2k_tta,
@@ -1602,12 +1602,12 @@ proto_register_abis_om2000(void)
 		},
 		{ &hf_om2k_isl_icp1,
 		  { "ICP1", "gsm_abis_om2000.is_list.icp1",
-		    FT_UINT16, BASE_DEC, NULL, 0x7ff,
+		    FT_UINT16, BASE_DEC, NULL, 0x07ff,
 		    NULL, HFILL }
 		},
 		{ &hf_om2k_isl_icp2,
 		  { "ICP2", "gsm_abis_om2000.is_list.icp2",
-		    FT_UINT16, BASE_DEC, NULL, 0x7ff,
+		    FT_UINT16, BASE_DEC, NULL, 0x07ff,
 		    NULL, HFILL }
 		},
 		{ &hf_om2k_isl_ci,
@@ -1632,7 +1632,7 @@ proto_register_abis_om2000(void)
 		},
 		{ &hf_om2k_conl_ccp,
 		  { "CON Connection Point", "gsm_abis_om2000.con_list.cpp",
-		    FT_UINT16, BASE_DEC, NULL, 0x7ff,
+            FT_UINT16, BASE_DEC, NULL, 0x07ff,
 		    NULL, HFILL }
 		},
 		{ &hf_om2k_conl_ci,
@@ -1741,7 +1741,7 @@ proto_register_abis_om2000(void)
 		    NULL, HFILL }
 		},
 	};
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_om2000,
 		&ett_om2k_mo,
 		&ett_om2k_isl,
