@@ -63,27 +63,27 @@ void proto_reg_handoff_gsm_ipa(void);
 
 static dissector_handle_t ipa_tcp_handle;
 static dissector_handle_t ipa_udp_handle;
-static gboolean global_ipa_in_root = FALSE;
-static gboolean global_ipa_in_info = FALSE;
+static bool global_ipa_in_root;
+static bool global_ipa_in_info;
 
 /* Initialize the protocol and registered fields */
-static int proto_ipa = -1;
-static int proto_ipaccess = -1;
+static int proto_ipa;
+static int proto_ipaccess;
 
-static int hf_ipa_data_len = -1;
-static int hf_ipa_protocol = -1;
-static int hf_ipa_hsl_debug = -1;
-static int hf_ipa_osmo_proto = -1;
-static int hf_ipa_osmo_ctrl_data = -1;
+static int hf_ipa_data_len;
+static int hf_ipa_protocol;
+static int hf_ipa_hsl_debug;
+static int hf_ipa_osmo_proto;
+static int hf_ipa_osmo_ctrl_data;
 
-static int hf_ipaccess_msgtype = -1;
-static int hf_ipaccess_attr_tag = -1;
-static int hf_ipaccess_attr_string = -1;
-static int hf_ipaccess_attribute_unk = -1;
+static int hf_ipaccess_msgtype;
+static int hf_ipaccess_attr_tag;
+static int hf_ipaccess_attr_string;
+static int hf_ipaccess_attribute_unk;
 
 /* Initialize the subtree pointers */
-static gint ett_ipa = -1;
-static gint ett_ipaccess = -1;
+static int ett_ipa;
+static int ett_ipaccess;
 
 enum {
 	SUB_OML,
@@ -169,10 +169,10 @@ static const value_string ipa_osmo_proto_vals[] = {
 };
 
 
-static gint
+static int
 dissect_ipa_attr(tvbuff_t *tvb, int base_offs, proto_tree *tree)
 {
-	guint8 len, attr_type;
+	uint8_t len, attr_type;
 
 	int offset = base_offs;
 
@@ -185,7 +185,7 @@ dissect_ipa_attr(tvbuff_t *tvb, int base_offs, proto_tree *tree)
 			proto_tree_add_item(tree, hf_ipaccess_attr_tag,
 					    tvb, offset+2, 1, ENC_BIG_ENDIAN);
 			proto_tree_add_item(tree, hf_ipaccess_attr_string,
-					    tvb, offset+3, len-1, ENC_ASCII|ENC_NA);
+					    tvb, offset+3, len-1, ENC_ASCII);
 			break;
 		case 0x01:	/* a single-byte request for a certain attr */
 			len = 0;
@@ -204,12 +204,12 @@ dissect_ipa_attr(tvbuff_t *tvb, int base_offs, proto_tree *tree)
 }
 
 /* Dissect an ip.access specific message */
-static gint
+static int
 dissect_ipaccess(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	proto_item *ti;
 	proto_tree *ipaccess_tree;
-	guint8 msg_type;
+	uint8_t msg_type;
 
 	msg_type = tvb_get_guint8(tvb, 0);
 
@@ -231,12 +231,12 @@ dissect_ipaccess(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 }
 
 /* Dissect the osmocom extension header */
-static gint
+static int
 dissect_osmo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ipatree, proto_tree *tree, proto_item *ipa_ti)
 {
 	tvbuff_t *next_tvb;
-	guint8 osmo_proto;
-	const gchar *name;
+	uint8_t osmo_proto;
+	const char *name;
 
 	osmo_proto = tvb_get_guint8(tvb, 0);
 	name = val_to_str(osmo_proto, ipa_osmo_proto_vals, "unknown 0x%02x");
@@ -259,7 +259,7 @@ dissect_osmo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ipatree, proto_tree
 		return 1;
 	/* Simply display the CTRL data as text */
 	} else if (osmo_proto == IPAC_PROTO_EXT_CTRL) {
-		proto_tree_add_item(tree, hf_ipa_osmo_ctrl_data, next_tvb, 0, -1, ENC_ASCII|ENC_NA);
+		proto_tree_add_item(tree, hf_ipa_osmo_ctrl_data, next_tvb, 0, -1, ENC_ASCII);
 		return 1;
 	}
 
@@ -271,22 +271,22 @@ dissect_osmo(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ipatree, proto_tree
 
 
 /* Code to actually dissect the packets */
-static gboolean
-dissect_ipa(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean is_udp)
+static bool
+dissect_ipa(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, bool is_udp)
 {
-	gint remaining;
-	gint header_length = 3;
+	int remaining;
+	int header_length = 3;
 	int offset = 0;
-	guint16 len, msg_type;
+	uint16_t len, msg_type;
 
 	if (tvb_reported_length(tvb) < 4)
-		return FALSE;
+		return false;
 
 	//sanity check the message type
 	msg_type = tvb_get_guint8(tvb, 2);
 	if ((try_val_to_str(msg_type, ipa_protocol_vals) == NULL) &&
 		(msg_type >= ABISIP_RSL_MAX))
-		return FALSE;
+		return false;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPA");
 	col_clear(pinfo->cinfo, COL_INFO);
@@ -349,11 +349,11 @@ dissect_ipa(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean is_udp
 			break;
 		case HSL_DEBUG:
 			proto_tree_add_item(ipa_tree, hf_ipa_hsl_debug,
-					next_tvb, 0, len, ENC_ASCII|ENC_NA);
-			if (global_ipa_in_root == TRUE)
+					next_tvb, 0, len, ENC_ASCII);
+			if (global_ipa_in_root == true)
 				proto_tree_add_item(tree, hf_ipa_hsl_debug,
-						next_tvb, 0, len, ENC_ASCII|ENC_NA);
-			if (global_ipa_in_info == TRUE)
+						next_tvb, 0, len, ENC_ASCII);
+			if (global_ipa_in_info == true)
 				col_append_fstr(pinfo->cinfo, COL_INFO, "%s ",
 						tvb_get_stringz_enc(pinfo->pool, next_tvb, 0, NULL, ENC_ASCII));
 			break;
@@ -367,13 +367,13 @@ dissect_ipa(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gboolean is_udp
 		offset += len + header_length;
 	}
 
-	return TRUE;
+	return true;
 }
 
 static int
 dissect_ipa_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
-	if (!dissect_ipa(tvb, pinfo, tree, FALSE))
+	if (!dissect_ipa(tvb, pinfo, tree, false))
 		return 0;
 	return tvb_captured_length(tvb);
 }
@@ -381,7 +381,7 @@ dissect_ipa_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
 static int
 dissect_ipa_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
-	if (!dissect_ipa(tvb, pinfo, tree, TRUE))
+	if (!dissect_ipa(tvb, pinfo, tree, true))
 		return 0;
 
 	return tvb_captured_length(tvb);
@@ -443,7 +443,7 @@ void proto_register_ipa(void)
 		 },
 	};
 
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_ipa,
 		&ett_ipaccess,
 	};
@@ -468,6 +468,9 @@ void proto_register_ipa(void)
 	prefs_register_bool_preference(ipa_module, "hsl_debug_in_info",
 					"HSL Debug messages in INFO column",
 					NULL, &global_ipa_in_info);
+
+	ipa_tcp_handle = register_dissector("gsm_ipa.tcp", dissect_ipa_tcp, proto_ipa);
+	ipa_udp_handle = register_dissector("gsm_ipa.udp", dissect_ipa_udp, proto_ipa);
 }
 
 void proto_reg_handoff_gsm_ipa(void)
@@ -478,8 +481,6 @@ void proto_reg_handoff_gsm_ipa(void)
 	sub_handles[SUB_MGCP] = find_dissector_add_dependency("mgcp", proto_ipa);
 	sub_handles[SUB_DATA] = find_dissector("data");
 
-	ipa_tcp_handle = create_dissector_handle(dissect_ipa_tcp, proto_ipa);
-	ipa_udp_handle = create_dissector_handle(dissect_ipa_udp, proto_ipa);
 	dissector_add_uint_range_with_preference("tcp.port", IPA_TCP_PORTS, ipa_tcp_handle);
 	dissector_add_uint_range_with_preference("udp.port", "", ipa_udp_handle);
 }
