@@ -6,19 +6,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 
@@ -31,30 +19,32 @@
 void proto_register_gsm_um(void);
 void proto_reg_handoff_gsm_um(void);
 
-static int proto_gsm_um = -1;
-static int hf_gsm_um_direction = -1;
-static int hf_gsm_um_channel = -1;
-static int hf_gsm_um_bsic = -1;
-static int hf_gsm_um_arfcn = -1;
-static int hf_gsm_um_band = -1;
-static int hf_gsm_um_frequency = -1;
-static int hf_gsm_um_frame = -1;
-static int hf_gsm_um_error = -1;
-static int hf_gsm_um_timeshift = -1;
-static int hf_gsm_um_l2_pseudo_len = -1;
+static int proto_gsm_um;
+static int hf_gsm_um_direction;
+static int hf_gsm_um_channel;
+static int hf_gsm_um_bsic;
+static int hf_gsm_um_arfcn;
+static int hf_gsm_um_band;
+static int hf_gsm_um_frequency;
+static int hf_gsm_um_frame;
+static int hf_gsm_um_error;
+static int hf_gsm_um_timeshift;
+static int hf_gsm_um_l2_pseudo_len;
 
-static gint ett_gsm_um = -1;
+static int ett_gsm_um;
+
+static dissector_handle_t gsm_um_handle;
 
 static dissector_handle_t lapdm_handle;
 static dissector_handle_t dtap_handle;
 
-static gboolean dcs1800_gsm = TRUE;
+static bool dcs1800_gsm = true;
 
 #define	GSM_UM_L2_PSEUDO_LEN		0xfc
 
 
 static void
-decode_arfcn(guint16 arfcn, const char **band, guint *uplink, guint *downlink)
+decode_arfcn(uint16_t arfcn, const char **band, unsigned *uplink, unsigned *downlink)
 {
 	/* Decode ARFCN to frequency using GSM 05.05 */
 	if( arfcn >= 1 && arfcn <= 124 ) {
@@ -165,7 +155,7 @@ dissect_gsm_um(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 		/* Show the other fields, if we have them (ie. downlink, BTS->MS) */
 		if( !pinfo->pseudo_header->gsm_um.uplink ) {
 			const char *band;
-			guint downlink, uplink;
+			unsigned downlink, uplink;
 
 			decode_arfcn(pinfo->pseudo_header->gsm_um.arfcn, &band, &uplink, &downlink);
 
@@ -195,7 +185,7 @@ dissect_gsm_um(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 		case GSM_UM_CHANNEL_AGCH:
 			if( !pinfo->pseudo_header->gsm_um.uplink ) {
 				tvbuff_t *next_tvb;
-				guint8 pseudo_len, len_left, len_byte;
+				uint8_t pseudo_len, len_left, len_byte;
 
 				len_left = tvb_reported_length(tvb);
 				len_byte = tvb_get_guint8(tvb, 0);
@@ -274,7 +264,7 @@ proto_register_gsm_um(void)
 		  NULL, GSM_UM_L2_PSEUDO_LEN, NULL, HFILL }}
 
 	};
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_gsm_um
 	};
 	module_t *gsm_um_module;
@@ -289,23 +279,20 @@ proto_register_gsm_um(void)
 				   "Treat ARFCN 512-810 as DCS 1800 rather than PCS 1900",
 				   &dcs1800_gsm);
 
+	gsm_um_handle = register_dissector("gsm_um", dissect_gsm_um, proto_gsm_um);
 }
 
 void
 proto_reg_handoff_gsm_um(void)
 {
-	dissector_handle_t gsm_um_handle;
-
 	lapdm_handle = find_dissector_add_dependency("lapdm", proto_gsm_um);
 	dtap_handle = find_dissector_add_dependency("gsm_a_dtap", proto_gsm_um);
 
-	gsm_um_handle = create_dissector_handle(dissect_gsm_um, proto_gsm_um);
-
 	dissector_add_uint("wtap_encap", WTAP_ENCAP_GSM_UM, gsm_um_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
