@@ -34,6 +34,7 @@
 #include "config.h"
 
 #include <epan/packet.h>
+#include <epan/expert.h>
 #include <epan/conversation.h>
 #include "packet-gsm_rlcmac.h"
 #include <wiretap/wtap.h>
@@ -47,40 +48,42 @@ void proto_reg_handoff_gsmtap(void);
 
 static dissector_handle_t gsmtap_handle;
 
-static int proto_gsmtap = -1;
+static int proto_gsmtap;
 
-static int hf_gsmtap_version = -1;
-static int hf_gsmtap_hdrlen = -1;
-static int hf_gsmtap_type = -1;
-static int hf_gsmtap_timeslot = -1;
-static int hf_gsmtap_subslot = -1;
-static int hf_gsmtap_arfcn = -1;
-static int hf_gsmtap_uplink = -1;
-static int hf_gsmtap_pcs = -1;
-static int hf_gsmtap_signal_dbm = -1;
-static int hf_gsmtap_snr_db = -1;
-static int hf_gsmtap_frame_nr = -1;
-static int hf_gsmtap_burst_type = -1;
-static int hf_gsmtap_channel_type = -1;
-static int hf_gsmtap_tetra_channel_type = -1;
-static int hf_gsmtap_gmr1_channel_type = -1;
-static int hf_gsmtap_rrc_sub_type = -1;
-static int hf_gsmtap_e1t1_sub_type = -1;
-static int hf_gsmtap_antenna = -1;
+static int hf_gsmtap_version;
+static int hf_gsmtap_hdrlen;
+static int hf_gsmtap_type;
+static int hf_gsmtap_timeslot;
+static int hf_gsmtap_subslot;
+static int hf_gsmtap_arfcn;
+static int hf_gsmtap_uplink;
+static int hf_gsmtap_pcs;
+static int hf_gsmtap_signal_dbm;
+static int hf_gsmtap_snr_db;
+static int hf_gsmtap_frame_nr;
+static int hf_gsmtap_burst_type;
+static int hf_gsmtap_channel_type;
+static int hf_gsmtap_tetra_channel_type;
+static int hf_gsmtap_gmr1_channel_type;
+static int hf_gsmtap_rrc_sub_type;
+static int hf_gsmtap_e1t1_sub_type;
+static int hf_gsmtap_antenna;
 
-static int hf_sacch_l1h_power_lev = -1;
-static int hf_sacch_l1h_fpc = -1;
-static int hf_sacch_l1h_sro_srr = -1;
-static int hf_sacch_l1h_ta = -1;
+static int hf_sacch_l1h_power_lev;
+static int hf_sacch_l1h_fpc;
+static int hf_sacch_l1h_sro_srr;
+static int hf_sacch_l1h_ta;
 
-static int hf_ptcch_spare = -1;
-static int hf_ptcch_ta_idx = -1;
-static int hf_ptcch_ta_val = -1;
-static int hf_ptcch_padding = -1;
+static int hf_ptcch_spare;
+static int hf_ptcch_ta_idx;
+static int hf_ptcch_ta_val;
+static int hf_ptcch_padding;
 
-static int hf_um_voice_type = -1;
+static int hf_um_voice_type;
 
-static gint ett_gsmtap = -1;
+static int ett_gsmtap;
+
+static expert_field ei_gsmtap_unknown_gsmtap_version;
 
 enum {
 	GSMTAP_SUB_DATA = 0,
@@ -115,6 +118,10 @@ enum {
 	GSMTAP_SUB_FR,
 	GSMTAP_SUB_V5EF,
 	GSMTAP_SUB_GSM_RLP,
+	/* E1/T1 */
+	GSMTAP_SUB_PPP,
+	GSMTAP_SUB_V120,
+	GSMTAP_SUB_X75,
 
 	GSMTAP_SUB_MAX
 };
@@ -472,6 +479,11 @@ static const value_string gsmtap_um_e1t1_types[] = {
 	{ GSMTAP_E1T1_TRAU16,			"TRAU 16k" },	/* 16k/s sub-channels (I.460) with GSM TRAU frames */
 	{ GSMTAP_E1T1_TRAU8,			"TRAU 8k" },	/* 8k/s sub-channels (I.460) with GSM TRAU frames */
 	{ GSMTAP_E1T1_V5EF,			"V5-EF" },	/* V5 Envelope Function */
+	{ GSMTAP_E1T1_X75,			"X.75" },	/* X.75 B-channel data */
+	{ GSMTAP_E1T1_V120,			"V.120" },	/* V.120 B-channel data */
+	{ GSMTAP_E1T1_V110,			"V.110" },	/* V.110 B-channel data */
+	{ GSMTAP_E1T1_H221,			"H.221" },	/* H.221 B-channel data */
+	{ GSMTAP_E1T1_PPP,			"PPP" },	/* PPP */
 	{ 0,					NULL },
 };
 
@@ -497,7 +509,7 @@ dissect_sacch_l1h(tvbuff_t *tvb, proto_tree *tree)
 	proto_tree_add_item(l1h_tree, hf_sacch_l1h_fpc, tvb, 0, 1, ENC_BIG_ENDIAN);
 	/* SRO/SRR (SACCH Repetition) bit */
 	proto_tree_add_item(l1h_tree, hf_sacch_l1h_sro_srr, tvb, 0, 1, ENC_BIG_ENDIAN);
-	/* Acutal Timing Advance */
+	/* Actual Timing Advance */
 	proto_tree_add_item(l1h_tree, hf_sacch_l1h_ta, tvb, 1, 1, ENC_BIG_ENDIAN);
 }
 
@@ -540,7 +552,7 @@ dissect_ptcch_dl(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 }
 
 static void
-handle_lapdm(guint8 sub_type, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+handle_lapdm(uint8_t sub_type, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	lapdm_data_t ld;
 
@@ -551,7 +563,7 @@ handle_lapdm(guint8 sub_type, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 static void
 handle_rach(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	guint8 channel_type = GSMTAP_CHANNEL_RACH;
+	uint8_t channel_type = GSMTAP_CHANNEL_RACH;
 	call_dissector_with_data(sub_handles[GSMTAP_SUB_UM], tvb, pinfo, tree, &channel_type);
 }
 
@@ -559,7 +571,7 @@ static void
 dissect_um_voice(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	tvbuff_t *payload_tvb;
-	guint8 vtype = tvb_get_guint8(tvb, 0);
+	uint8_t vtype = tvb_get_guint8(tvb, 0);
 
 	col_add_fstr(pinfo->cinfo, COL_INFO, "GSM CS User Plane (Voice/CSD): %s",
 			val_to_str(vtype, gsmtap_um_voice_types, "Unknown %d"));
@@ -585,7 +597,7 @@ handle_tetra(int channel, tvbuff_t *payload_tvb, packet_info *pinfo, proto_tree
 }
 
 /* length of an EGPRS RLC data block for given MCS */
-static const guint data_block_len_by_mcs[] = {
+static const unsigned data_block_len_by_mcs[] = {
 	0,	/* MCS0 */
 	22,	/* MCS1 */
 	28,
@@ -601,10 +613,10 @@ static const guint data_block_len_by_mcs[] = {
 
 /* determine the number of rlc data blocks and their size / offsets */
 static void
-setup_rlc_mac_priv(RlcMacPrivateData_t *rm, gboolean is_uplink,
-	guint *n_calls, guint *data_block_bits, guint *data_block_offsets)
+setup_rlc_mac_priv(RlcMacPrivateData_t *rm, bool is_uplink,
+	unsigned *n_calls, unsigned *data_block_bits, unsigned *data_block_offsets)
 {
-	guint nc, dbl = 0, dbo[2] = {0,0};
+	unsigned nc, dbl = 0, dbo[2] = {0,0};
 
 	dbl = data_block_len_by_mcs[rm->mcs];
 
@@ -636,15 +648,15 @@ setup_rlc_mac_priv(RlcMacPrivateData_t *rm, gboolean is_uplink,
 /* bit-shift the entire 'src' of length 'length_bytes' by 'offset_bits'
  * and store the reuslt to caller-allocated 'buffer'.  The shifting is
  * done lsb-first, unlike tvb_new_octet_aligned() */
-static void clone_aligned_buffer_lsbf(guint offset_bits, guint length_bytes,
-	const guint8 *src, guint8 *buffer)
+static void clone_aligned_buffer_lsbf(unsigned offset_bits, unsigned length_bytes,
+	const uint8_t *src, uint8_t *buffer)
 {
-	guint hdr_bytes;
-	guint extra_bits;
-	guint i;
+	unsigned hdr_bytes;
+	unsigned extra_bits;
+	unsigned i;
 
-	guint8 c, last_c;
-	guint8 *dst;
+	uint8_t c, last_c;
+	uint8_t *dst;
 
 	hdr_bytes = offset_bits / 8;
 	extra_bits = offset_bits % 8;
@@ -668,18 +680,18 @@ static void clone_aligned_buffer_lsbf(guint offset_bits, guint length_bytes,
 
 /* obtain an (aligned) EGPRS data block with given bit-offset and
  * bit-length from the parent TVB */
-static tvbuff_t *get_egprs_data_block(tvbuff_t *tvb, guint offset_bits,
-	guint length_bits, packet_info *pinfo)
+static tvbuff_t *get_egprs_data_block(tvbuff_t *tvb, unsigned offset_bits,
+	unsigned length_bits, packet_info *pinfo)
 {
 	tvbuff_t *aligned_tvb;
-	const guint initial_spare_bits = 6;
-	guint8 *aligned_buf;
-	guint min_src_length_bytes = (offset_bits + length_bits + 7) / 8;
-	guint length_bytes = (initial_spare_bits + length_bits + 7) / 8;
+	const unsigned initial_spare_bits = 6;
+	uint8_t *aligned_buf;
+	unsigned min_src_length_bytes = (offset_bits + length_bits + 7) / 8;
+	unsigned length_bytes = (initial_spare_bits + length_bits + 7) / 8;
 
 	tvb_ensure_bytes_exist(tvb, 0, min_src_length_bytes);
 
-	aligned_buf = (guint8 *) wmem_alloc(pinfo->pool, length_bytes);
+	aligned_buf = (uint8_t *) wmem_alloc(pinfo->pool, length_bytes);
 
 	/* Copy the data out of the tvb to an aligned buffer */
 	clone_aligned_buffer_lsbf(
@@ -697,7 +709,7 @@ static tvbuff_t *get_egprs_data_block(tvbuff_t *tvb, guint offset_bits,
 	return aligned_tvb;
 }
 
-static void tvb_len_get_mcs_and_fmt(guint len, gboolean is_uplink, guint *frm, guint8 *mcs)
+static void tvb_len_get_mcs_and_fmt(unsigned len, bool is_uplink, unsigned *frm, uint8_t *mcs)
 {
 	if (len <= 5 && is_uplink) {
 		/* Assume random access burst */
@@ -731,15 +743,15 @@ static void tvb_len_get_mcs_and_fmt(guint len, gboolean is_uplink, guint *frm, g
 }
 
 static void
-handle_rlcmac(guint32 frame_nr, tvbuff_t *payload_tvb, packet_info *pinfo, proto_tree *tree)
+handle_rlcmac(uint32_t frame_nr, tvbuff_t *payload_tvb, packet_info *pinfo, proto_tree *tree)
 {
 
 	int sub_handle;
 	RlcMacPrivateData_t rlcmac_data = {0};
 	tvbuff_t *data_tvb;
-	guint data_block_bits, data_block_offsets[2];
-	guint num_calls;
-	gboolean is_uplink;
+	unsigned data_block_bits, data_block_offsets[2];
+	unsigned num_calls;
+	bool is_uplink;
 
 	if (pinfo->p2p_dir == P2P_DIR_SENT) {
 		is_uplink = 1;
@@ -753,8 +765,8 @@ handle_rlcmac(guint32 frame_nr, tvbuff_t *payload_tvb, packet_info *pinfo, proto
 	rlcmac_data.frame_number = frame_nr;
 
 	tvb_len_get_mcs_and_fmt(tvb_reported_length(payload_tvb), is_uplink,
-				(guint *) &rlcmac_data.block_format,
-				(guint8 *) &rlcmac_data.mcs);
+				(unsigned *) &rlcmac_data.block_format,
+				(uint8_t *) &rlcmac_data.mcs);
 
 	switch (rlcmac_data.block_format) {
 	case RLCMAC_HDR_TYPE_1:
@@ -794,17 +806,17 @@ handle_rlcmac(guint32 frame_nr, tvbuff_t *payload_tvb, packet_info *pinfo, proto
 	}
 }
 
-/* dissect a GSMTAP header and hand payload off to respective dissector */
+/* dissect a GSMTAP v2 header and hand payload off to respective dissector */
 static int
-dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
+dissect_gsmtap_v2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
 	int sub_handle, sub_handle_idx = 0, len, offset = 0;
 	proto_item *ti;
 	proto_tree *gsmtap_tree = NULL;
 	tvbuff_t *payload_tvb, *l1h_tvb = NULL;
-	guint8 hdr_len, type, sub_type, timeslot, subslot;
-	guint16 arfcn;
-	guint32 frame_nr;
+	uint8_t hdr_len, type, sub_type, timeslot, subslot;
+	uint16_t arfcn;
+	uint32_t frame_nr;
 
 	len = tvb_reported_length(tvb);
 
@@ -867,7 +879,7 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 	conversation_set_elements_by_id(pinfo, CONVERSATION_GSMTAP, (timeslot << 3) | subslot);
 
 	if (tree) {
-		guint8 channel;
+		uint8_t channel;
 		const char *channel_str;
 		channel = tvb_get_guint8(tvb, offset+12);
 		if (type == GSMTAP_TYPE_TETRA_I1)
@@ -1106,6 +1118,33 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 				call_dissector_with_data(sub_handles[sub_handle], payload_tvb, pinfo, tree, &isdn);
 			}
 			return tvb_captured_length(tvb);
+		case GSMTAP_E1T1_PPP:
+			sub_handle = GSMTAP_SUB_PPP;
+			if (sub_handles[sub_handle]) {
+				struct isdn_phdr isdn;
+				isdn.uton = pinfo->p2p_dir == P2P_DIR_SENT ? 1 : 0;
+				isdn.channel = 0;
+				call_dissector_with_data(sub_handles[sub_handle], payload_tvb, pinfo, tree, &isdn);
+			}
+			return tvb_captured_length(tvb);
+		case GSMTAP_E1T1_V120:
+			sub_handle = GSMTAP_SUB_V120;
+			if (sub_handles[sub_handle]) {
+				struct isdn_phdr isdn;
+				isdn.uton = pinfo->p2p_dir == P2P_DIR_SENT ? 1 : 0;
+				isdn.channel = 0;
+				call_dissector_with_data(sub_handles[sub_handle], payload_tvb, pinfo, tree, &isdn);
+			}
+			return tvb_captured_length(tvb);
+		case GSMTAP_E1T1_X75:
+			sub_handle = GSMTAP_SUB_X75;
+			if (sub_handles[sub_handle]) {
+				struct isdn_phdr isdn;
+				isdn.uton = pinfo->p2p_dir == P2P_DIR_SENT ? 1 : 0;
+				isdn.channel = 0;
+				call_dissector_with_data(sub_handles[sub_handle], payload_tvb, pinfo, tree, &isdn);
+			}
+			return tvb_captured_length(tvb);
 		default:
 			sub_handle = GSMTAP_SUB_DATA;
 			break;
@@ -1141,6 +1180,30 @@ dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 	return tvb_captured_length(tvb);
 }
 
+static int
+dissect_gsmtap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
+{
+	uint8_t version;
+	proto_tree *gsmtap_tree;
+	proto_item *ti, *tf;
+
+	version = tvb_get_guint8(tvb, 0);
+
+	if (version == 2) {
+		return dissect_gsmtap_v2(tvb, pinfo, tree, data);
+	}
+
+	/* Unknown GSMTAP version */
+	ti = proto_tree_add_protocol_format(tree, proto_gsmtap, tvb, 0, 1, "GSMTAP, unknown version (%u)", version);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, "GSMTAP");
+	col_clear(pinfo->cinfo, COL_INFO);
+	col_add_fstr(pinfo->cinfo, COL_INFO, "Unknown GSMTAP version (%u)", version);
+	gsmtap_tree = proto_item_add_subtree(ti, ett_gsmtap);
+	tf = proto_tree_add_item(gsmtap_tree, hf_gsmtap_version, tvb, 0, 1, ENC_BIG_ENDIAN);
+	expert_add_info(pinfo, tf, &ei_gsmtap_unknown_gsmtap_version);
+	return 1;
+}
+
 void
 proto_register_gsmtap(void)
 {
@@ -1203,13 +1266,20 @@ proto_register_gsmtap(void)
 		{ &hf_ptcch_padding, { "Spare Padding", "gsmtap.ptcch.padding",
 		  FT_BYTES, SEP_SPACE, NULL, 0, NULL, HFILL } },
 	};
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_gsmtap
 	};
+	static ei_register_info ei[] = {
+		{ &ei_gsmtap_unknown_gsmtap_version, { "gsmtap.version.invalid", PI_PROTOCOL, PI_WARN, "Unknown protocol version", EXPFILL }},
+	};
+
+	expert_module_t* expert_gsmtap;
 
 	proto_gsmtap = proto_register_protocol("GSM Radiotap", "GSMTAP", "gsmtap");
 	proto_register_field_array(proto_gsmtap, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	expert_gsmtap = expert_register_protocol(proto_gsmtap);
+	expert_register_field_array(expert_gsmtap, ei, array_length(ei));
 
 	gsmtap_dissector_table = register_dissector_table("gsmtap.type",
 						"GSMTAP type", proto_gsmtap, FT_UINT8, BASE_HEX);
@@ -1245,6 +1315,9 @@ proto_reg_handoff_gsmtap(void)
 	sub_handles[GSMTAP_SUB_FR] = find_dissector_add_dependency("fr", proto_gsmtap);
 	sub_handles[GSMTAP_SUB_V5EF] = find_dissector_add_dependency("v5ef", proto_gsmtap);
 	sub_handles[GSMTAP_SUB_GSM_RLP] = find_dissector_add_dependency("gsm_rlp", proto_gsmtap);
+	sub_handles[GSMTAP_SUB_PPP] = find_dissector_add_dependency("ppp", proto_gsmtap);
+	sub_handles[GSMTAP_SUB_V120] = find_dissector_add_dependency("v120", proto_gsmtap);
+	sub_handles[GSMTAP_SUB_X75] = find_dissector_add_dependency("x75", proto_gsmtap);
 
 	rrc_sub_handles[GSMTAP_RRC_SUB_DL_DCCH_Message] = find_dissector_add_dependency("rrc.dl.dcch", proto_gsmtap);
 	rrc_sub_handles[GSMTAP_RRC_SUB_UL_DCCH_Message] = find_dissector_add_dependency("rrc.ul.dcch", proto_gsmtap);
