@@ -21,13 +21,13 @@ void proto_reg_handoff_http_urlencoded(void);
 
 static dissector_handle_t form_urlencoded_handle;
 
-static int proto_urlencoded = -1;
+static int proto_urlencoded;
 
-static int hf_form_key = -1;
-static int hf_form_value = -1;
+static int hf_form_key;
+static int hf_form_value;
 
-static gint ett_form_urlencoded = -1;
-static gint ett_form_keyvalue = -1;
+static int ett_form_urlencoded;
+static int ett_form_keyvalue;
 
 static ws_mempbrk_pattern pbrk_key;
 static ws_mempbrk_pattern pbrk_value;
@@ -37,7 +37,7 @@ get_form_key_value(wmem_allocator_t *pool, tvbuff_t *tvb, char **ptr, int offset
 {
 	const int orig_offset = offset;
 	int found_offset;
-	guint8 ch;
+	uint8_t ch;
 	char *tmp;
 	int len;
 
@@ -55,12 +55,12 @@ get_form_key_value(wmem_allocator_t *pool, tvbuff_t *tvb, char **ptr, int offset
 				return -1;
 			}
 			offset++;
-			ch = tvb_get_guint8(tvb, offset);
+			ch = tvb_get_uint8(tvb, offset);
 			if (ws_xton(ch) == -1)
 				return -1;
 
 			offset++;
-			ch = tvb_get_guint8(tvb, offset);
+			ch = tvb_get_uint8(tvb, offset);
 			if (ws_xton(ch) == -1)
 				return -1;
 		} else if (ch != '+') {
@@ -88,13 +88,13 @@ get_form_key_value(wmem_allocator_t *pool, tvbuff_t *tvb, char **ptr, int offset
 		len += (found_offset - offset);
 		offset = found_offset;
 		if (ch == '%') {
-			guint8 ch1, ch2;
+			uint8_t ch1, ch2;
 
 			offset++;
-			ch1 = tvb_get_guint8(tvb, offset);
+			ch1 = tvb_get_uint8(tvb, offset);
 
 			offset++;
-			ch2 = tvb_get_guint8(tvb, offset);
+			ch2 = tvb_get_uint8(tvb, offset);
 
 			tmp[len] = ws_xton(ch1) << 4 | ws_xton(ch2);
 
@@ -119,7 +119,7 @@ dissect_form_urlencoded(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 	proto_tree	*url_tree;
 	proto_tree	*sub;
 	proto_item	*ti;
-	gint		offset = 0, next_offset, end_offset;
+	int		offset = 0, next_offset, end_offset;
 	const char	*data_name;
 	media_content_info_t *content_info;
 	tvbuff_t	*sequence_tvb;
@@ -187,8 +187,8 @@ dissect_form_urlencoded(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 		value_decoded = get_utf_8_string(pinfo->pool, value, (int)strlen(value));
 		proto_tree_add_string(sub, hf_form_value, tvb, offset, next_offset - offset, value_decoded);
 		proto_item_append_text(sub, " = \"%s\"", format_text(pinfo->pool, value, strlen(value)));
-		/* Move past the '&' */
-		offset = end_offset+1;
+
+		offset = next_offset+1;
 	}
 
 	return tvb_captured_length(tvb);
@@ -210,7 +210,7 @@ proto_register_http_urlencoded(void)
 		},
 	};
 
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_form_urlencoded,
 		&ett_form_keyvalue
 	};
