@@ -15,13 +15,13 @@
 
 #include <wiretap/wtap.h>
 
-#include <wsutil/frequency-utils.h>
+#include <wsutil/802_11-utils.h>
 
 void proto_register_netmon_802_11(void);
 void proto_reg_handoff_netmon_802_11(void);
 
 /* protocol */
-static int proto_netmon_802_11 = -1;
+static int proto_netmon_802_11;
 
 /* Dissector */
 static dissector_handle_t netmon_802_11_handle;
@@ -50,49 +50,68 @@ static dissector_handle_t netmon_802_11_handle;
 #define PHY_TYPE_HT          7 /* 802.11n */
 #define PHY_TYPE_VHT         8 /* 802.11ac */
 
-static int hf_netmon_802_11_version = -1;
-static int hf_netmon_802_11_length = -1;
-static int hf_netmon_802_11_op_mode = -1;
-static int hf_netmon_802_11_op_mode_sta = -1;
-static int hf_netmon_802_11_op_mode_ap = -1;
-static int hf_netmon_802_11_op_mode_sta_ext = -1;
-static int hf_netmon_802_11_op_mode_mon = -1;
-/* static int hf_netmon_802_11_flags = -1; */
-static int hf_netmon_802_11_phy_type = -1;
-static int hf_netmon_802_11_channel = -1;
-static int hf_netmon_802_11_frequency = -1;
-static int hf_netmon_802_11_rssi = -1;
-static int hf_netmon_802_11_datarate = -1;
-static int hf_netmon_802_11_timestamp = -1;
+static int hf_netmon_802_11_version;
+static int hf_netmon_802_11_length;
+static int hf_netmon_802_11_op_mode;
+static int hf_netmon_802_11_op_mode_sta;
+static int hf_netmon_802_11_op_mode_ap;
+static int hf_netmon_802_11_op_mode_sta_ext;
+static int hf_netmon_802_11_op_mode_mon;
+/* static int hf_netmon_802_11_flags; */
+static int hf_netmon_802_11_phy_type;
+static int hf_netmon_802_11_channel;
+static int hf_netmon_802_11_frequency;
+static int hf_netmon_802_11_rssi;
+static int hf_netmon_802_11_datarate;
+static int hf_netmon_802_11_timestamp;
 
-static gint ett_netmon_802_11 = -1;
-static gint ett_netmon_802_11_op_mode = -1;
+static int ett_netmon_802_11;
+static int ett_netmon_802_11_op_mode;
 
 static dissector_handle_t ieee80211_radio_handle;
 
 static int
-dissect_netmon_802_11(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+dissect_netmon_802_11(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
-  struct ieee_802_11_phdr *phdr = (struct ieee_802_11_phdr *)data;
+  struct ieee_802_11_phdr phdr;
   proto_tree *wlan_tree = NULL, *opmode_tree;
   proto_item *ti;
   tvbuff_t   *next_tvb;
   int         offset;
-  guint8      version;
-  guint16     length;
-  guint32     phy_type;
-  guint32     monitor_mode;
-  guint32     flags;
-  guint32     channel;
-  gint        calc_channel;
-  gint32      rssi;
-  guint8      rate;
+  uint8_t     version;
+  uint16_t    length;
+  uint32_t    phy_type;
+  uint32_t    monitor_mode;
+  uint32_t    flags;
+  uint32_t    channel;
+  int         calc_channel;
+  int32_t     rssi;
+  uint8_t     rate;
+
+  /*
+   * It appears to be the case that management frames (and control and
+   * extension frames ?) may or may not have an FCS and data frames don't.
+   * (Netmon capture files have been seen for this encapsulation
+   * management frames either completely with or without an FCS. Also:
+   * instances have been  seen where both Management and Control frames
+   * do not have an FCS).  An "FCS length" of -2 means "NetMon weirdness".
+   *
+   * The metadata header also has a bit indicating whether the adapter
+   * was in monitor mode or not; if it isn't, we set "decrypted" to true,
+   * as, for those frames, the Protected bit is preserved in received
+   * frames, but the frame is decrypted.
+   */
+  memset(&phdr, 0, sizeof(phdr));
+  phdr.fcs_len = -2;
+  phdr.decrypted = false;
+  phdr.datapad = false;
+  phdr.phy = PHDR_802_11_PHY_UNKNOWN;
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, "WLAN");
   col_clear(pinfo->cinfo, COL_INFO);
   offset = 0;
 
-  version = tvb_get_guint8(tvb, offset);
+  version = tvb_get_uint8(tvb, offset);
   length = tvb_get_letohs(tvb, offset+1);
   col_add_fstr(pinfo->cinfo, COL_INFO, "NetMon WLAN Capture v%u, Length %u",
                version, length);
@@ -152,14 +171,14 @@ dissect_netmon_802_11(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
      * the "monitor mode" flag wasn't set, so supporess treating the
      * Protect flag as an indication that the frame was encrypted.
      */
-    phdr->decrypted = TRUE;
+    phdr.decrypted = true;
 
     /*
      * Furthermore, we may see frames with the A-MSDU Present flag set
-     * in the QoS Control field but that have a regular frame, nto a
+     * in the QoS Control field but that have a regular frame, not a
      * sequence of A-MSDUs, in the payload.
      */
-    phdr->no_a_msdus = TRUE;
+    phdr.no_a_msdus = true;
   }
   offset += 4;
 
@@ -173,48 +192,53 @@ dissect_netmon_802_11(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
      * uPhyId?
      */
     phy_type = tvb_get_letohl(tvb, offset);
-    memset(&phdr->phy_info, 0, sizeof(phdr->phy_info));
+    memset(&phdr.phy_info, 0, sizeof(phdr.phy_info));
 
+    /*
+     * Unlike the channel flags in radiotap, this appears
+     * to correctly indicate the modulation for this packet
+     * (no cases seen where this doesn't match the data rate).
+     */
     switch (phy_type) {
 
     case PHY_TYPE_UNKNOWN:
-        phdr->phy = PHDR_802_11_PHY_UNKNOWN;
+        phdr.phy = PHDR_802_11_PHY_UNKNOWN;
         break;
 
     case PHY_TYPE_FHSS:
-        phdr->phy = PHDR_802_11_PHY_11_FHSS;
+        phdr.phy = PHDR_802_11_PHY_11_FHSS;
         break;
 
     case PHY_TYPE_IR_BASEBAND:
-        phdr->phy = PHDR_802_11_PHY_11_IR;
+        phdr.phy = PHDR_802_11_PHY_11_IR;
         break;
 
     case PHY_TYPE_DSSS:
-        phdr->phy = PHDR_802_11_PHY_11_DSSS;
+        phdr.phy = PHDR_802_11_PHY_11_DSSS;
         break;
 
     case PHY_TYPE_HR_DSSS:
-        phdr->phy = PHDR_802_11_PHY_11B;
+        phdr.phy = PHDR_802_11_PHY_11B;
         break;
 
     case PHY_TYPE_OFDM:
-        phdr->phy = PHDR_802_11_PHY_11A;
+        phdr.phy = PHDR_802_11_PHY_11A;
         break;
 
     case PHY_TYPE_ERP:
-        phdr->phy = PHDR_802_11_PHY_11G;
+        phdr.phy = PHDR_802_11_PHY_11G;
         break;
 
     case PHY_TYPE_HT:
-        phdr->phy = PHDR_802_11_PHY_11N;
+        phdr.phy = PHDR_802_11_PHY_11N;
         break;
 
     case PHY_TYPE_VHT:
-        phdr->phy = PHDR_802_11_PHY_11AC;
+        phdr.phy = PHDR_802_11_PHY_11AC;
         break;
 
     default:
-        phdr->phy = PHDR_802_11_PHY_UNKNOWN;
+        phdr.phy = PHDR_802_11_PHY_UNKNOWN;
         break;
     }
     proto_tree_add_item(wlan_tree, hf_netmon_802_11_phy_type, tvb, offset, 4,
@@ -231,23 +255,23 @@ dissect_netmon_802_11(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
                                          tvb, offset, 4, channel,
                                          "Unknown");
       } else {
-        guint frequency;
+        unsigned frequency;
 
-        phdr->has_channel = TRUE;
-        phdr->channel = channel;
+        phdr.has_channel = true;
+        phdr.channel = channel;
         proto_tree_add_uint(wlan_tree, hf_netmon_802_11_channel,
                             tvb, offset, 4, channel);
-        switch (phdr->phy) {
+        switch (phdr.phy) {
 
         case PHDR_802_11_PHY_11B:
         case PHDR_802_11_PHY_11G:
           /* 2.4 GHz channel */
-          frequency = ieee80211_chan_to_mhz(channel, TRUE);
+          frequency = ieee80211_chan_to_mhz(channel, true);
           break;
 
         case PHDR_802_11_PHY_11A:
           /* 5 GHz channel */
-          frequency = ieee80211_chan_to_mhz(channel, FALSE);
+          frequency = ieee80211_chan_to_mhz(channel, false);
           break;
 
         default:
@@ -255,19 +279,19 @@ dissect_netmon_802_11(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
           break;
         }
         if (frequency != 0) {
-          phdr->has_frequency = TRUE;
-          phdr->frequency = frequency;
+          phdr.has_frequency = true;
+          phdr.frequency = frequency;
         }
       }
     } else {
-      phdr->has_frequency = TRUE;
-      phdr->frequency = channel;
+      phdr.has_frequency = true;
+      phdr.frequency = channel;
       proto_tree_add_uint(wlan_tree, hf_netmon_802_11_frequency,
                                        tvb, offset, 4, channel);
       calc_channel = ieee80211_mhz_to_chan(channel);
       if (calc_channel != -1) {
-        phdr->has_channel = TRUE;
-        phdr->channel = calc_channel;
+        phdr.has_channel = true;
+        phdr.channel = calc_channel;
       }
     }
     offset += 4;
@@ -285,8 +309,8 @@ dissect_netmon_802_11(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
                                       tvb, offset, 4, rssi,
                                       "Unknown");
     } else {
-      phdr->has_signal_dbm = TRUE;
-      phdr->signal_dbm = rssi;
+      phdr.has_signal_dbm = true;
+      phdr.signal_dbm = rssi;
       proto_tree_add_int_format_value(wlan_tree, hf_netmon_802_11_rssi,
                                       tvb, offset, 4, rssi,
                                       "%d dBm", rssi);
@@ -296,14 +320,14 @@ dissect_netmon_802_11(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
     /*
      * ucDataRate?
      */
-    rate = tvb_get_guint8(tvb, offset);
+    rate = tvb_get_uint8(tvb, offset);
     if (rate == 0) {
       proto_tree_add_uint_format_value(wlan_tree, hf_netmon_802_11_datarate,
                                        tvb, offset, 1, rate,
                                        "Unknown");
     } else {
-      phdr->has_data_rate = TRUE;
-      phdr->data_rate = rate;
+      phdr.has_data_rate = true;
+      phdr.data_rate = rate;
       proto_tree_add_uint_format_value(wlan_tree, hf_netmon_802_11_datarate,
                                        tvb, offset, 1, rate,
                                        "%f Mb/s", rate*.5);
@@ -315,10 +339,10 @@ dissect_netmon_802_11(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
   /*
    * ullTimestamp?
    *
-   * If so, should this check the presense flag in flags?
+   * If so, should this check the presence flag in flags?
    */
-  phdr->has_tsf_timestamp = TRUE;
-  phdr->tsf_timestamp = tvb_get_letoh64(tvb, offset);
+  phdr.has_tsf_timestamp = true;
+  phdr.tsf_timestamp = tvb_get_letoh64(tvb, offset);
   proto_tree_add_item(wlan_tree, hf_netmon_802_11_timestamp, tvb, offset, 8,
                       ENC_LITTLE_ENDIAN);
   /*offset += 8;*/
@@ -328,7 +352,7 @@ skip:
 
   /* dissect the 802.11 packet next */
   next_tvb = tvb_new_subset_remaining(tvb, offset);
-  call_dissector_with_data(ieee80211_radio_handle, next_tvb, pinfo, tree, phdr);
+  call_dissector_with_data(ieee80211_radio_handle, next_tvb, pinfo, tree, &phdr);
   return offset;
 }
 
@@ -384,7 +408,7 @@ proto_register_netmon_802_11(void)
     { &hf_netmon_802_11_timestamp, { "Timestamp", "netmon_802_11.timestamp", FT_UINT64,
                           BASE_DEC, NULL, 0x0, NULL, HFILL } },
   };
-  static gint *ett[] = {
+  static int *ett[] = {
     &ett_netmon_802_11,
     &ett_netmon_802_11_op_mode
   };
