@@ -32,7 +32,7 @@
 void proto_register_ipx(void);
 void proto_reg_handoff_ipx(void);
 
-static int ipx_tap = -1;
+static int ipx_tap;
 
 /* The information in this module (IPX, SPX, NCP) comes from:
 	NetWare LAN Analysis, Second Edition
@@ -45,88 +45,92 @@ static int ipx_tap = -1;
 
 */
 
-static int proto_ipx = -1;
-static int hf_ipx_checksum = -1;
-static int hf_ipx_len = -1;
-static int hf_ipx_src = -1;
-static int hf_ipx_dst = -1;
-static int hf_ipx_addr = -1;
-static int hf_ipx_hops = -1;
-static int hf_ipx_packet_type = -1;
-static int hf_ipx_dnet = -1;
-static int hf_ipx_dnode = -1;
-static int hf_ipx_dsocket = -1;
-static int hf_ipx_snet = -1;
-static int hf_ipx_snode = -1;
-static int hf_ipx_ssocket = -1;
-static int hf_ipx_net = -1;
-static int hf_ipx_node = -1;
-static int hf_ipx_socket = -1;
+static int proto_ipx;
+static int hf_ipx_checksum;
+static int hf_ipx_len;
+static int hf_ipx_src;
+static int hf_ipx_dst;
+static int hf_ipx_addr;
+static int hf_ipx_hops;
+static int hf_ipx_packet_type;
+static int hf_ipx_dnet;
+static int hf_ipx_dnode;
+static int hf_ipx_dsocket;
+static int hf_ipx_snet;
+static int hf_ipx_snode;
+static int hf_ipx_ssocket;
+static int hf_ipx_net;
+static int hf_ipx_node;
+static int hf_ipx_socket;
 
-static gint ett_ipx = -1;
+static int ett_ipx;
 
 static dissector_table_t ipx_type_dissector_table;
 static dissector_table_t ipx_socket_dissector_table;
 static dissector_table_t spx_socket_dissector_table;
 static dissector_handle_t ipx_handle;
 static dissector_handle_t ipxsap_handle;
+static dissector_handle_t spx_handle;
+static dissector_handle_t ipxrip_handle;
+static dissector_handle_t serialization_handle;
+static dissector_handle_t ipxmsg_handle;
 
-static int proto_spx = -1;
-static int hf_spx_connection_control = -1;
-static int hf_spx_connection_control_sys = -1;
-static int hf_spx_connection_control_send_ack = -1;
-static int hf_spx_connection_control_attn = -1;
-static int hf_spx_connection_control_eom = -1;
-static int hf_spx_connection_control_v2 = -1;
-static int hf_spx_connection_control_neg_size = -1;
-static int hf_spx_connection_control_reserved = -1;
-static int hf_spx_connection_control_ext_header = -1;
-static int hf_spx_datastream_type = -1;
-static int hf_spx_src_id = -1;
-static int hf_spx_dst_id = -1;
-static int hf_spx_seq_nr = -1;
-static int hf_spx_ack_nr = -1;
-static int hf_spx_all_nr = -1;
-static int hf_spx_neg_size = -1;
-static int hf_spx_rexmt_frame = -1;
-static int hf_spx_rexmt_data = -1;
+static int proto_spx;
+static int hf_spx_connection_control;
+static int hf_spx_connection_control_sys;
+static int hf_spx_connection_control_send_ack;
+static int hf_spx_connection_control_attn;
+static int hf_spx_connection_control_eom;
+static int hf_spx_connection_control_v2;
+static int hf_spx_connection_control_neg_size;
+static int hf_spx_connection_control_reserved;
+static int hf_spx_connection_control_ext_header;
+static int hf_spx_datastream_type;
+static int hf_spx_src_id;
+static int hf_spx_dst_id;
+static int hf_spx_seq_nr;
+static int hf_spx_ack_nr;
+static int hf_spx_all_nr;
+static int hf_spx_neg_size;
+static int hf_spx_rexmt_frame;
+static int hf_spx_rexmt_data;
 
-static gint ett_spx = -1;
-static gint ett_spx_connctrl = -1;
+static int ett_spx;
+static int ett_spx_connctrl;
 
-static int proto_ipxrip = -1;
-static int hf_ipxrip_request = -1;
-static int hf_ipxrip_response = -1;
-static int hf_ipxrip_packet_type = -1;
-static int hf_ipxrip_route_vector = -1;
-static int hf_ipxrip_hops = -1;
-static int hf_ipxrip_ticks = -1;
+static int proto_ipxrip;
+static int hf_ipxrip_request;
+static int hf_ipxrip_response;
+static int hf_ipxrip_packet_type;
+static int hf_ipxrip_route_vector;
+static int hf_ipxrip_hops;
+static int hf_ipxrip_ticks;
 
-static gint ett_ipxrip = -1;
+static int ett_ipxrip;
 
-static int proto_serialization = -1;
-static int hf_serial_number = -1;
-static gint ett_serialization = -1;
+static int proto_serialization;
+static int hf_serial_number;
+static int ett_serialization;
 
-static int proto_sap = -1;
-static int hf_sap_request = -1;
-static int hf_sap_response = -1;
-static int hf_sap_packet_type = -1;
-static int hf_sap_server = -1;
-static int hf_sap_server_type = -1;
-static int hf_sap_server_name = -1;
-static int hf_sap_server_network = -1;
-static int hf_sap_server_node = -1;
-static int hf_sap_server_socket = -1;
-static int hf_sap_server_intermediate_networks = -1;
+static int proto_sap;
+static int hf_sap_request;
+static int hf_sap_response;
+static int hf_sap_packet_type;
+static int hf_sap_server;
+static int hf_sap_server_type;
+static int hf_sap_server_name;
+static int hf_sap_server_network;
+static int hf_sap_server_node;
+static int hf_sap_server_socket;
+static int hf_sap_server_intermediate_networks;
 
-static gint ett_ipxsap = -1;
-static gint ett_ipxsap_server = -1;
+static int ett_ipxsap;
+static int ett_ipxsap_server;
 
-static gint ett_ipxmsg = -1;
-static int proto_ipxmsg = -1;
-static int hf_msg_conn = -1;
-static int hf_msg_sigchar = -1;
+static int ett_ipxmsg;
+static int proto_ipxmsg;
+static int hf_msg_conn;
+static int hf_msg_sigchar;
 
 #define UDP_PORT_IPX    213		/* RFC 1234 */
 
@@ -182,8 +186,8 @@ ipx_endpoint_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, cons
 	/* Take two "add" passes per packet, adding for each direction, ensures that all
 	packets are counted properly (even if address is sending to itself)
 	XXX - this could probably be done more efficiently inside endpoint_table */
-	add_endpoint_table_data(hash, &ipxh->ipx_src, 0, TRUE, 1, pinfo->fd->pkt_len, &ipx_endpoint_dissector_info, ENDPOINT_NONE);
-	add_endpoint_table_data(hash, &ipxh->ipx_dst, 0, FALSE, 1, pinfo->fd->pkt_len, &ipx_endpoint_dissector_info, ENDPOINT_NONE);
+	add_endpoint_table_data(hash, &ipxh->ipx_src, 0, true, 1, pinfo->fd->pkt_len, &ipx_endpoint_dissector_info, ENDPOINT_NONE);
+	add_endpoint_table_data(hash, &ipxh->ipx_dst, 0, false, 1, pinfo->fd->pkt_len, &ipx_endpoint_dissector_info, ENDPOINT_NONE);
 
 	return TAP_PACKET_REDRAW;
 }
@@ -267,11 +271,11 @@ static const value_string ipxmsg_sigchar_vals[] = {
 	{ 0, NULL }
 };
 
-static gboolean
-capture_ipx(const guchar *pd _U_, int offset _U_, int len _U_, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header _U_)
+static bool
+capture_ipx(const unsigned char *pd _U_, int offset _U_, int len _U_, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header _U_)
 {
 	capture_dissector_increment_count(cpinfo, proto_ipx);
-	return TRUE;
+	return true;
 }
 
 static int
@@ -282,10 +286,10 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 	proto_tree	*ipx_tree = NULL;
 	proto_item	*ti = NULL, *hidden_item;
 
-	guint8		ipx_hops;
+	uint8_t		ipx_hops;
 	char 		*str;
-	guint16		first_socket, second_socket;
-	guint32		ipx_snet, ipx_dnet;
+	uint16_t		first_socket, second_socket;
+	uint32_t		ipx_snet, ipx_dnet;
 	static ipxhdr_t ipxh_arr[4];
 	static int ipx_current=0;
 	ipxhdr_t *ipxh;
@@ -303,7 +307,7 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 	/* Calculate here for use in pinfo and in tree */
 	ipxh->ipx_dsocket = tvb_get_ntohs(tvb, 16);
 	ipxh->ipx_ssocket = tvb_get_ntohs(tvb, 28);
-	ipxh->ipx_type    = tvb_get_guint8(tvb, 5);
+	ipxh->ipx_type    = tvb_get_uint8(tvb, 5);
 	ipxh->ipx_length  = tvb_get_ntohs(tvb, 2);
 
 	pinfo->ptype = PT_IPX;
@@ -341,7 +345,7 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 
 	proto_tree_add_checksum(ipx_tree, tvb, 0, hf_ipx_checksum, -1, NULL, pinfo, 0, ENC_BIG_ENDIAN, PROTO_CHECKSUM_NO_FLAGS);
 	proto_tree_add_uint(ipx_tree, hf_ipx_len, tvb, 2, 2, ipxh->ipx_length);
-	ipx_hops = tvb_get_guint8(tvb, 4);
+	ipx_hops = tvb_get_uint8(tvb, 4);
 	proto_tree_add_uint_format(ipx_tree, hf_ipx_hops, tvb, 4, 1, ipx_hops,
 		"Transport Control: %d hops", ipx_hops);
 	proto_tree_add_uint(ipx_tree, hf_ipx_packet_type, tvb, 5, 1, ipxh->ipx_type);
@@ -420,11 +424,11 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 
 	if (second_socket != IPX_SOCKET_NWLINK_SMB_NAMEQUERY) {
 		if (dissector_try_uint_new(ipx_socket_dissector_table, first_socket,
-			next_tvb, pinfo, tree, FALSE, ipxh))
+			next_tvb, pinfo, tree, false, ipxh))
 			return tvb_captured_length(tvb);
 	}
 	if (dissector_try_uint_new(ipx_socket_dissector_table, second_socket,
-		next_tvb, pinfo, tree, FALSE, ipxh))
+		next_tvb, pinfo, tree, false, ipxh))
 		return tvb_captured_length(tvb);
 
 	/*
@@ -432,7 +436,7 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 	 * at least let us, for example, dissect SPX packets as SPX.
 	 */
 	if (dissector_try_uint_new(ipx_type_dissector_table, ipxh->ipx_type, next_tvb,
-		pinfo, tree, FALSE, ipxh))
+		pinfo, tree, false, ipxh))
 		return tvb_captured_length(tvb);
 
 	call_data_dissector(next_tvb, pinfo, tree);
@@ -444,14 +448,14 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 
 typedef struct {
 	conversation_t	*conversation;
-	guint32         spx_src;
-	guint16         spx_seq;
+	uint32_t        spx_src;
+	uint16_t        spx_seq;
 } spx_hash_key;
 
 typedef struct {
-	guint16             spx_ack;
-	guint16             spx_all;
-	guint32             num;
+	uint16_t            spx_ack;
+	uint16_t            spx_all;
+	uint32_t            num;
 } spx_hash_value;
 
 /*
@@ -459,14 +463,14 @@ typedef struct {
  * frame number of the original transmission.
  */
 typedef struct {
-	guint32             num;
+	uint32_t            num;
 } spx_rexmit_info;
 
-static wmem_map_t *spx_hash = NULL;
+static wmem_map_t *spx_hash;
 
 /* Hash Functions */
-static gint
-spx_equal(gconstpointer v, gconstpointer v2)
+static int
+spx_equal(const void *v, const void *v2)
 {
 	const spx_hash_key	*val1 = (const spx_hash_key*)v;
 	const spx_hash_key	*val2 = (const spx_hash_key*)v2;
@@ -479,15 +483,15 @@ spx_equal(gconstpointer v, gconstpointer v2)
 	return 0;
 }
 
-static guint
-spx_hash_func(gconstpointer v)
+static unsigned
+spx_hash_func(const void *v)
 {
 	const spx_hash_key	*spx_key = (const spx_hash_key*)v;
 	return GPOINTER_TO_UINT(spx_key->conversation) + spx_key->spx_src;
 }
 
 static spx_hash_value*
-spx_hash_insert(conversation_t *conversation, guint32 spx_src, guint16 spx_seq)
+spx_hash_insert(conversation_t *conversation, uint32_t spx_src, uint16_t spx_seq)
 {
 	spx_hash_key		*key;
 	spx_hash_value		*value;
@@ -507,7 +511,7 @@ spx_hash_insert(conversation_t *conversation, guint32 spx_src, guint16 spx_seq)
 
 /* Returns the spx_hash_value*, or NULL if not found. */
 static spx_hash_value*
-spx_hash_lookup(conversation_t *conversation, guint32 spx_src, guint32 spx_seq)
+spx_hash_lookup(conversation_t *conversation, uint32_t spx_src, uint32_t spx_seq)
 {
 	spx_hash_key		key;
 
@@ -543,7 +547,7 @@ static const value_string conn_vals[] = {
 };
 
 static const char*
-spx_datastream(guint8 type)
+spx_datastream(uint8_t type)
 {
 	switch (type) {
 		case 0xfe:
@@ -564,14 +568,14 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 	proto_tree	*spx_tree;
 	proto_item	*ti;
 	tvbuff_t	*next_tvb;
-	guint8		conn_ctrl;
-	guint8		hdr_len = SPX_HEADER_LEN;
-	guint8		datastream_type;
+	uint8_t		conn_ctrl;
+	uint8_t		hdr_len = SPX_HEADER_LEN;
+	uint8_t		datastream_type;
 	const char	*datastream_type_string;
-	guint16         spx_seq;
+	uint16_t        spx_seq;
 	const char	*spx_msg_string;
-	guint16		low_socket, high_socket;
-	guint32		src;
+	uint16_t		low_socket, high_socket;
+	uint32_t		src;
 	conversation_t	*conversation;
 	spx_hash_value	*pkt_value;
 	spx_rexmit_info	*spx_rexmit_info_p;
@@ -580,7 +584,7 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "SPX");
 	col_set_str(pinfo->cinfo, COL_INFO, "SPX");
 
-	conn_ctrl = tvb_get_guint8(tvb, 0);
+	conn_ctrl = tvb_get_uint8(tvb, 0);
 	if ((conn_ctrl & SPX_VII_PACKET) && tvb_get_ntohs(tvb, 4) != 0xffff) {
 		/* SPX2 packets have an extra two-byte field, unless they have
 		 * a dest-ID of 0xffff... */
@@ -622,7 +626,7 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 		}
 	}
 
-	datastream_type = tvb_get_guint8(tvb, 1);
+	datastream_type = tvb_get_uint8(tvb, 1);
 	datastream_type_string = spx_datastream(datastream_type);
 	if (datastream_type_string != NULL) {
 		col_append_fstr(pinfo->cinfo, COL_INFO, " (%s)",
@@ -818,12 +822,12 @@ dissect_spx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 
 		next_tvb = tvb_new_subset_remaining(tvb, hdr_len);
 		if (dissector_try_uint_new(spx_socket_dissector_table, low_socket,
-		    next_tvb, pinfo, tree, FALSE, &spx_infox))
+		    next_tvb, pinfo, tree, false, &spx_infox))
 		{
 			return tvb_captured_length(tvb);
 		}
 		if (dissector_try_uint_new(spx_socket_dissector_table, high_socket,
-		    next_tvb, pinfo, tree, FALSE, &spx_infox))
+		    next_tvb, pinfo, tree, false, &spx_infox))
 		{
 			return tvb_captured_length(tvb);
 		}
@@ -840,13 +844,13 @@ dissect_ipxmsg(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 {
 	proto_tree	*msg_tree;
 	proto_item	*ti;
-	guint8		conn_number, sig_char;
+	uint8_t		conn_number, sig_char;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX MSG");
 	col_clear(pinfo->cinfo, COL_INFO);
 
-	conn_number = tvb_get_guint8(tvb, 0);
-	sig_char = tvb_get_guint8(tvb, 1);
+	conn_number = tvb_get_uint8(tvb, 0);
+	sig_char = tvb_get_uint8(tvb, 1);
 
 	col_add_fstr(pinfo->cinfo, COL_INFO,
 			"%s, Connection %d",
@@ -877,9 +881,9 @@ dissect_ipxrip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 {
 	proto_tree	*rip_tree;
 	proto_item	*ti, *hidden_item;
-	guint16		operation, ticks;
-	guint		cursor;
-	guint		available_length;
+	uint16_t		operation, ticks;
+	unsigned		cursor;
+	unsigned		available_length;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX RIP");
 	col_clear(pinfo->cinfo, COL_INFO);
@@ -1205,7 +1209,7 @@ dissect_ipxsap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 {
 	proto_tree	*sap_tree, *s_tree;
 	proto_item	*ti, *hidden_item;
-	guint		cursor;
+	unsigned		cursor;
 	struct sap_query query;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "IPX SAP");
@@ -1243,9 +1247,9 @@ dissect_ipxsap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 		if (query.query_type == IPX_SAP_GENERAL_RESPONSE ||
 				query.query_type == IPX_SAP_NEAREST_RESPONSE) { /* responses */
 
-			guint available_length = tvb_reported_length(tvb);
+			unsigned available_length = tvb_reported_length(tvb);
 			for (cursor =  2; cursor < available_length; cursor += 64) {
-				const guint8 *server_name;
+				const uint8_t *server_name;
 
 				ti = proto_tree_add_item(sap_tree, hf_sap_server, tvb, cursor, 64, ENC_NA);
 				s_tree = proto_item_add_subtree(ti, ett_ipxsap_server);
@@ -1341,7 +1345,7 @@ proto_register_ipx(void)
 	static hf_register_info hf_spx[] = {
 		{ &hf_spx_connection_control,
 		{ "Connection Control",	"spx.ctl",
-		  FT_UINT8,	BASE_HEX,	VALS(conn_vals),	0xF0,
+		  FT_UINT8,	BASE_HEX,	VALS(conn_vals),	0x0,
 		  NULL, HFILL }},
 
 		{ &hf_spx_connection_control_sys,
@@ -1434,12 +1438,12 @@ proto_register_ipx(void)
 		{ &hf_ipxrip_request,
 		{ "Request",			"ipxrip.request",
 		  FT_BOOLEAN,	BASE_NONE,	NULL,	0x0,
-		  "TRUE if IPX RIP request", HFILL }},
+		  "true if IPX RIP request", HFILL }},
 
 		{ &hf_ipxrip_response,
 		{ "Response",			"ipxrip.response",
 		  FT_BOOLEAN,	BASE_NONE,	NULL,	0x0,
-		  "TRUE if IPX RIP response", HFILL }},
+		  "true if IPX RIP response", HFILL }},
 
 		{ &hf_ipxrip_packet_type,
 		{ "RIP packet type",			"ipxrip.packet_type",
@@ -1466,12 +1470,12 @@ proto_register_ipx(void)
 		{ &hf_sap_request,
 		{ "Request",			"ipxsap.request",
 		  FT_BOOLEAN,	BASE_NONE,	NULL,	0x0,
-		  "TRUE if SAP request", HFILL }},
+		  "true if SAP request", HFILL }},
 
 		{ &hf_sap_response,
 		{ "Response",			"ipxsap.response",
 		  FT_BOOLEAN,	BASE_NONE,	NULL,	0x0,
-		  "TRUE if SAP response", HFILL }},
+		  "true if SAP response", HFILL }},
 
 		{ &hf_sap_packet_type,
 		{ "SAP packet type",		"ipxsap.packet_type",
@@ -1533,7 +1537,7 @@ proto_register_ipx(void)
 		  NULL, HFILL }},
 	};
 
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_ipx,
 		&ett_spx,
 		&ett_spx_connctrl,
@@ -1547,24 +1551,28 @@ proto_register_ipx(void)
 	proto_ipx = proto_register_protocol("Internetwork Packet eXchange",
 	    "IPX", "ipx");
 	proto_register_field_array(proto_ipx, hf_ipx, array_length(hf_ipx));
-
 	ipx_handle = register_dissector("ipx", dissect_ipx, proto_ipx);
 
 	proto_spx = proto_register_protocol("Sequenced Packet eXchange",
 	    "SPX", "spx");
 	proto_register_field_array(proto_spx, hf_spx, array_length(hf_spx));
+	spx_handle = register_dissector("spx", dissect_spx, proto_spx);
 
 	proto_ipxrip = proto_register_protocol("IPX Routing Information Protocol",
 	    "IPX RIP", "ipxrip");
 	proto_register_field_array(proto_ipxrip, hf_ipxrip, array_length(hf_ipxrip));
+	ipxrip_handle = register_dissector("ipxrip", dissect_ipxrip, proto_ipxrip);
 
 	proto_serialization = proto_register_protocol("NetWare Serialization Protocol",
 	    "NW_SERIAL", "nw_serial");
 	proto_register_field_array(proto_serialization, hf_serial, array_length(hf_serial));
+	serialization_handle = register_dissector("nw_serial", dissect_serialization,
+	    proto_serialization);
 
 	proto_ipxmsg = proto_register_protocol("IPX Message", "IPX MSG",
 	    "ipxmsg");
 	proto_register_field_array(proto_ipxmsg, hf_ipxmsg, array_length(hf_ipxmsg));
+	ipxmsg_handle = register_dissector("ipxmsg", dissect_ipxmsg, proto_ipxmsg);
 
 	proto_sap = proto_register_protocol("Service Advertisement Protocol",
 	    "IPX SAP", "ipxsap");
@@ -1584,7 +1592,7 @@ proto_register_ipx(void)
 	spx_hash = wmem_map_new_autoreset(wmem_epan_scope(), wmem_file_scope(), spx_hash_func, spx_equal);
 	ipx_tap=register_tap("ipx");
 
-	register_conversation_table(proto_ipx, TRUE, ipx_conversation_packet, ipx_endpoint_packet);
+	register_conversation_table(proto_ipx, true, ipx_conversation_packet, ipx_endpoint_packet);
 
 	register_capture_dissector("ipx", capture_ipx, proto_ipx);
 }
@@ -1592,9 +1600,6 @@ proto_register_ipx(void)
 void
 proto_reg_handoff_ipx(void)
 {
-	dissector_handle_t spx_handle;
-	dissector_handle_t ipxrip_handle;
-	dissector_handle_t serialization_handle, ipxmsg_handle;
 	capture_dissector_handle_t ipx_cap_handle;
 
 	dissector_add_uint_with_preference("udp.port", UDP_PORT_IPX, ipx_handle);
@@ -1609,20 +1614,15 @@ proto_reg_handoff_ipx(void)
 	dissector_add_uint("arcnet.protocol_id", ARCNET_PROTO_IPX, ipx_handle);
 	dissector_add_uint("arcnet.protocol_id", ARCNET_PROTO_NOVELL_EC, ipx_handle);
 
-	spx_handle = create_dissector_handle(dissect_spx, proto_spx);
 	dissector_add_uint("ipx.packet_type", IPX_PACKET_TYPE_SPX, spx_handle);
 
 	dissector_add_uint("ipx.socket", IPX_SOCKET_SAP, ipxsap_handle);
 
-	ipxrip_handle = create_dissector_handle(dissect_ipxrip, proto_ipxrip);
 	dissector_add_uint("ipx.socket", IPX_SOCKET_IPXRIP, ipxrip_handle);
 
-	serialization_handle = create_dissector_handle(dissect_serialization,
-	    proto_serialization);
 	dissector_add_uint("ipx.socket", IPX_SOCKET_SERIALIZATION,
 	    serialization_handle);
 
-	ipxmsg_handle = create_dissector_handle(dissect_ipxmsg, proto_ipxmsg);
 	dissector_add_uint("ipx.socket", IPX_SOCKET_IPX_MESSAGE, ipxmsg_handle);
 	dissector_add_uint("ipx.socket", IPX_SOCKET_IPX_MESSAGE1, ipxmsg_handle);
 
