@@ -22,23 +22,25 @@
 void proto_register_j1939(void);
 void proto_reg_handoff_j1939(void);
 
-static int proto_j1939 = -1;
+static dissector_handle_t j1939_handle;
 
-static int hf_j1939_can_id = -1;
-static int hf_j1939_priority = -1;
-static int hf_j1939_pgn = -1;
-static int hf_j1939_data_page = -1;
-static int hf_j1939_extended_data_page = -1;
-static int hf_j1939_pdu_format = -1;
-static int hf_j1939_pdu_specific = -1;
-static int hf_j1939_src_addr = -1;
-static int hf_j1939_dst_addr = -1;
-static int hf_j1939_group_extension = -1;
-static int hf_j1939_data = -1;
+static int proto_j1939;
 
-static gint ett_j1939 = -1;
-static gint ett_j1939_can = -1;
-static gint ett_j1939_message = -1;
+static int hf_j1939_can_id;
+static int hf_j1939_priority;
+static int hf_j1939_pgn;
+static int hf_j1939_data_page;
+static int hf_j1939_extended_data_page;
+static int hf_j1939_pdu_format;
+static int hf_j1939_pdu_specific;
+static int hf_j1939_src_addr;
+static int hf_j1939_dst_addr;
+static int hf_j1939_group_extension;
+static int hf_j1939_data;
+
+static int ett_j1939;
+static int ett_j1939_can;
+static int ett_j1939_message;
 
 static int j1939_address_type = -1;
 static dissector_table_t   subdissector_pgn_table;
@@ -145,15 +147,15 @@ static const value_string j1939_address_vals[] = {
     { 0, NULL }
 };
 
-value_string_ext j1939_address_vals_ext = VALUE_STRING_EXT_INIT(j1939_address_vals);
+static value_string_ext j1939_address_vals_ext = VALUE_STRING_EXT_INIT(j1939_address_vals);
 
 static void
-j1939_fmt_address(gchar *result, guint32 addr )
+j1939_fmt_address(char *result, uint32_t addr )
 {
     if ((addr < 128) || (addr > 247))
-        g_snprintf(result, ITEM_LABEL_LENGTH, "%d (%s)", addr, val_to_str_ext_const(addr, &j1939_address_vals_ext, "Reserved"));
+        snprintf(result, ITEM_LABEL_LENGTH, "%d (%s)", addr, val_to_str_ext_const(addr, &j1939_address_vals_ext, "Reserved"));
     else
-        g_snprintf(result, ITEM_LABEL_LENGTH, "%d (Arbitrary)", addr);
+        snprintf(result, ITEM_LABEL_LENGTH, "%d (Arbitrary)", addr);
 }
 
 static int dissect_j1939(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data)
@@ -161,17 +163,17 @@ static int dissect_j1939(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, vo
     proto_item *ti, *can_id_item;
     proto_tree *j1939_tree, *can_tree, *msg_tree;
 
-    gint offset = 0;
-    struct can_identifier can_id;
-    guint32 data_length = tvb_reported_length(tvb);
-    guint32 pgn;
-    guint8 *src_addr, *dest_addr;
+    int offset = 0;
+    struct can_info can_info;
+    uint32_t data_length = tvb_reported_length(tvb);
+    uint32_t pgn;
+    uint8_t *src_addr, *dest_addr;
 
     DISSECTOR_ASSERT(data);
-    can_id = *((struct can_identifier*)data);
+    can_info = *((struct can_info*)data);
 
-    if ((can_id.id & CAN_ERR_FLAG) ||
-        !(can_id.id & CAN_EFF_FLAG))
+    if ((can_info.id & CAN_ERR_FLAG) ||
+        !(can_info.id & CAN_EFF_FLAG))
     {
         /* Error frames and frames with standards ids are not for us */
         return 0;
@@ -184,51 +186,51 @@ static int dissect_j1939(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, vo
     j1939_tree = proto_item_add_subtree(ti, ett_j1939);
 
     can_tree = proto_tree_add_subtree_format(j1939_tree, tvb, 0, 0,
-                    ett_j1939_can, NULL, "CAN Identifier: 0x%08x", can_id.id);
-    can_id_item = proto_tree_add_uint(can_tree, hf_j1939_can_id, tvb, 0, 0, can_id.id);
+                    ett_j1939_can, NULL, "CAN Identifier: 0x%08x", can_info.id);
+    can_id_item = proto_tree_add_uint(can_tree, hf_j1939_can_id, tvb, 0, 0, can_info.id);
     proto_item_set_generated(can_id_item);
-    ti = proto_tree_add_uint(can_tree, hf_j1939_priority, tvb, 0, 0, can_id.id);
+    ti = proto_tree_add_uint(can_tree, hf_j1939_priority, tvb, 0, 0, can_info.id);
     proto_item_set_generated(ti);
-    ti = proto_tree_add_uint(can_tree, hf_j1939_extended_data_page, tvb, 0, 0, can_id.id);
+    ti = proto_tree_add_uint(can_tree, hf_j1939_extended_data_page, tvb, 0, 0, can_info.id);
     proto_item_set_generated(ti);
-    ti = proto_tree_add_uint(can_tree, hf_j1939_data_page, tvb, 0, 0, can_id.id);
+    ti = proto_tree_add_uint(can_tree, hf_j1939_data_page, tvb, 0, 0, can_info.id);
     proto_item_set_generated(ti);
-    ti = proto_tree_add_uint(can_tree, hf_j1939_pdu_format, tvb, 0, 0, can_id.id);
+    ti = proto_tree_add_uint(can_tree, hf_j1939_pdu_format, tvb, 0, 0, can_info.id);
     proto_item_set_generated(ti);
-    ti = proto_tree_add_uint(can_tree, hf_j1939_pdu_specific, tvb, 0, 0, can_id.id);
+    ti = proto_tree_add_uint(can_tree, hf_j1939_pdu_specific, tvb, 0, 0, can_info.id);
     proto_item_set_generated(ti);
-    ti = proto_tree_add_uint(can_tree, hf_j1939_src_addr, tvb, 0, 0, can_id.id);
+    ti = proto_tree_add_uint(can_tree, hf_j1939_src_addr, tvb, 0, 0, can_info.id);
     proto_item_set_generated(ti);
 
     /* Set source address */
-    src_addr = (guint8*)wmem_alloc(pinfo->pool, 1);
-    *src_addr = (guint8)(can_id.id & 0xFF);
+    src_addr = (uint8_t*)wmem_alloc(pinfo->pool, 1);
+    *src_addr = (uint8_t)(can_info.id & 0xFF);
     set_address(&pinfo->src, j1939_address_type, 1, (const void*)src_addr);
 
-    pgn = (can_id.id & 0x3FFFF00) >> 8;
+    pgn = (can_info.id & 0x3FFFF00) >> 8;
 
     /* If PF < 240, PS is destination address, last byte of PGN is cleared */
-    if (((can_id.id & 0xFF0000) >> 16) < 240)
+    if (((can_info.id & 0xFF0000) >> 16) < 240)
     {
         pgn &= 0x3FF00;
 
-        ti = proto_tree_add_uint(can_tree, hf_j1939_dst_addr, tvb, 0, 0, can_id.id);
+        ti = proto_tree_add_uint(can_tree, hf_j1939_dst_addr, tvb, 0, 0, can_info.id);
         proto_item_set_generated(ti);
     }
     else
     {
-        ti = proto_tree_add_uint(can_tree, hf_j1939_group_extension, tvb, 0, 0, can_id.id);
+        ti = proto_tree_add_uint(can_tree, hf_j1939_group_extension, tvb, 0, 0, can_info.id);
         proto_item_set_generated(ti);
     }
 
     /* Fill in "destination" address even if its "broadcast" */
-    dest_addr = (guint8*)wmem_alloc(pinfo->pool, 1);
-    *dest_addr = (guint8)((can_id.id & 0xFF00) >> 8);
+    dest_addr = (uint8_t*)wmem_alloc(pinfo->pool, 1);
+    *dest_addr = (uint8_t)((can_info.id & 0xFF00) >> 8);
     set_address(&pinfo->dst, j1939_address_type, 1, (const void*)dest_addr);
 
     col_add_fstr(pinfo->cinfo, COL_INFO, "PGN: %-6"  PRIu32, pgn);
 
-    if (can_id.id & CAN_RTR_FLAG)
+    if (can_info.id & CAN_RTR_FLAG)
     {
         /* RTR frames don't have payload */
         col_append_fstr(pinfo->cinfo, COL_INFO, "   %s", "(Remote Transmission Request)");
@@ -236,7 +238,7 @@ static int dissect_j1939(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, vo
     else
     {
         /* For now just include raw bytes */
-        col_append_fstr(pinfo->cinfo, COL_INFO, "   %s", tvb_bytes_to_str_punct(wmem_packet_scope(), tvb, 0, data_length, ' '));
+        col_append_fstr(pinfo->cinfo, COL_INFO, "   %s", tvb_bytes_to_str_punct(pinfo->pool, tvb, 0, data_length, ' '));
     }
 
     msg_tree = proto_tree_add_subtree(j1939_tree, tvb, 0, tvb_reported_length(tvb), ett_j1939_message, NULL, "Message");
@@ -244,7 +246,7 @@ static int dissect_j1939(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, vo
     ti = proto_tree_add_uint(msg_tree, hf_j1939_pgn, tvb, 0, 0, pgn);
     proto_item_set_generated(ti);
 
-    if (!dissector_try_uint_new(subdissector_pgn_table, pgn, tvb, pinfo, msg_tree, TRUE, data))
+    if (!dissector_try_uint_new(subdissector_pgn_table, pgn, tvb, pinfo, msg_tree, true, data))
     {
         proto_tree_add_item(msg_tree, hf_j1939_data, tvb, 0, tvb_reported_length(tvb), ENC_NA);
     }
@@ -252,9 +254,9 @@ static int dissect_j1939(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, vo
     return tvb_captured_length(tvb);
 }
 
-static int J1939_addr_to_str(const address* addr, gchar *buf, int buf_len)
+static int J1939_addr_to_str(const address* addr, char *buf, int buf_len)
 {
-    const guint8 *addrdata = (const guint8 *)addr->data;
+    const uint8_t *addrdata = (const uint8_t *)addr->data;
 
     guint32_to_str_buf(*addrdata, buf, buf_len);
     return (int)strlen(buf);
@@ -265,7 +267,7 @@ static int J1939_addr_str_len(const address* addr _U_)
     return 11; /* Leaves required space (10 bytes) for uint_to_str_back() */
 }
 
-static const char* J1939_col_filter_str(const address* addr _U_, gboolean is_src)
+static const char* J1939_col_filter_str(const address* addr _U_, bool is_src)
 {
     if (is_src)
         return "j1939.src_addr";
@@ -291,7 +293,7 @@ void proto_register_j1939(void)
         },
         { &hf_j1939_pgn,
             {"PGN", "j1939.pgn",
-            FT_UINT32, BASE_DEC, NULL, 0x3FFFFFF, NULL, HFILL }
+            FT_UINT32, BASE_DEC, NULL, 0x03FFFFFF, NULL, HFILL }
         },
         { &hf_j1939_extended_data_page,
             {"Extended Data Page", "j1939.ex_data_page",
@@ -327,7 +329,7 @@ void proto_register_j1939(void)
         },
     };
 
-    static gint *ett[] = {
+    static int *ett[] = {
         &ett_j1939,
         &ett_j1939_can,
         &ett_j1939_message
@@ -341,14 +343,13 @@ void proto_register_j1939(void)
     subdissector_pgn_table = register_dissector_table("j1939.pgn", "PGN Handle", proto_j1939, FT_UINT32, BASE_DEC);
 
     j1939_address_type = address_type_dissector_register("AT_J1939", "J1939 Address", J1939_addr_to_str, J1939_addr_str_len, NULL, J1939_col_filter_str, J1939_addr_len, NULL, NULL);
+
+    j1939_handle = register_dissector("j1939",  dissect_j1939, proto_j1939 );
 }
 
 void
 proto_reg_handoff_j1939(void)
 {
-    dissector_handle_t j1939_handle;
-
-    j1939_handle = create_dissector_handle( dissect_j1939, proto_j1939 );
     dissector_add_for_decode_as("can.subdissector", j1939_handle );
 }
 
