@@ -39,38 +39,38 @@
 void proto_register_lapd(void);
 void proto_reg_handoff_lapd(void);
 
-static int proto_lapd = -1;
-static int hf_lapd_direction = -1;
-static int hf_lapd_address = -1;
-static int hf_lapd_sapi = -1;
-static int hf_lapd_gsm_sapi = -1;
-static int hf_lapd_cr = -1;
-static int hf_lapd_ea1 = -1;
-static int hf_lapd_tei = -1;
-static int hf_lapd_ea2 = -1;
-static int hf_lapd_control = -1;
-static int hf_lapd_n_r = -1;
-static int hf_lapd_n_s = -1;
-static int hf_lapd_p = -1;
-static int hf_lapd_p_ext = -1;
-static int hf_lapd_f = -1;
-static int hf_lapd_f_ext = -1;
-static int hf_lapd_s_ftype = -1;
-static int hf_lapd_u_modifier_cmd = -1;
-static int hf_lapd_u_modifier_resp = -1;
-static int hf_lapd_ftype_i = -1;
-static int hf_lapd_ftype_s_u = -1;
-static int hf_lapd_ftype_s_u_ext = -1;
-static int hf_lapd_checksum = -1;
-static int hf_lapd_checksum_status = -1;
+static int proto_lapd;
+static int hf_lapd_direction;
+static int hf_lapd_address;
+static int hf_lapd_sapi;
+static int hf_lapd_gsm_sapi;
+static int hf_lapd_cr;
+static int hf_lapd_ea1;
+static int hf_lapd_tei;
+static int hf_lapd_ea2;
+static int hf_lapd_control;
+static int hf_lapd_n_r;
+static int hf_lapd_n_s;
+static int hf_lapd_p;
+static int hf_lapd_p_ext;
+static int hf_lapd_f;
+static int hf_lapd_f_ext;
+static int hf_lapd_s_ftype;
+static int hf_lapd_u_modifier_cmd;
+static int hf_lapd_u_modifier_resp;
+static int hf_lapd_ftype_i;
+static int hf_lapd_ftype_s_u;
+static int hf_lapd_ftype_s_u_ext;
+static int hf_lapd_checksum;
+static int hf_lapd_checksum_status;
 
-static gint ett_lapd = -1;
-static gint ett_lapd_address = -1;
-static gint ett_lapd_control = -1;
-static gint ett_lapd_checksum = -1;
+static gint ett_lapd;
+static gint ett_lapd_address;
+static gint ett_lapd_control;
+static gint ett_lapd_checksum;
 
-static expert_field ei_lapd_abort = EI_INIT;
-static expert_field ei_lapd_checksum_bad = EI_INIT;
+static expert_field ei_lapd_abort;
+static expert_field ei_lapd_checksum_bad;
 
 static dissector_handle_t lapd_handle;
 static dissector_handle_t lapd_phdr_handle;
@@ -81,7 +81,7 @@ static dissector_table_t lapd_sapi_dissector_table;
 static dissector_table_t lapd_gsm_sapi_dissector_table;
 
 /* Whether to use GSM SAPI vals or not */
-static gboolean global_lapd_gsm_sapis = FALSE;
+static bool global_lapd_gsm_sapis;
 
 /*
  * Bits in the address field.
@@ -538,8 +538,6 @@ dissect_lapd_full(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 f
 	sapi = (addr & LAPD_SAPI) >> LAPD_SAPI_SHIFT;
 	lapd_header_len = 2;	/* addr */
 
-	col_add_fstr(pinfo->cinfo, COL_TEI, "%u", tei);
-
 	/* Append TEI to info field */
 	col_append_fstr(pinfo->cinfo, COL_INFO, "TEI:%02u ", tei);
 	col_set_fence(pinfo->cinfo, COL_INFO);
@@ -569,8 +567,10 @@ dissect_lapd_full(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 f
 			}
 		}
 	}
-	col_set_str(pinfo->cinfo, COL_RES_DL_SRC, srcname);
-	col_set_str(pinfo->cinfo, COL_RES_DL_DST, dstname);
+	set_address(&pinfo->dl_dst, AT_STRINGZ, (int)strlen(dstname) + 1, dstname);
+	set_address(&pinfo->dl_src, AT_STRINGZ, (int)strlen(srcname) + 1, srcname);
+	copy_address_shallow(&pinfo->dst, &pinfo->dl_dst);
+	copy_address_shallow(&pinfo->src, &pinfo->dl_src);
 
 	if (tree) {
 		proto_item *direction_ti;
@@ -659,7 +659,7 @@ proto_register_lapd(void)
 
 		{ &hf_lapd_address,
 		  { "Address Field", "lapd.address", FT_UINT16, BASE_HEX, NULL, 0x0,
-		    "Address", HFILL }},
+		    NULL, HFILL }},
 
 		{ &hf_lapd_sapi,
 		  { "SAPI", "lapd.sapi", FT_UINT16, BASE_DEC, VALS(lapd_sapi_vals), LAPD_SAPI,
@@ -767,7 +767,7 @@ proto_register_lapd(void)
 	expert_lapd = expert_register_protocol(proto_lapd);
 	expert_register_field_array(expert_lapd, ei, array_length(ei));
 
-	lapd_handle = create_dissector_handle(dissect_lapd, proto_lapd);
+	lapd_handle = register_dissector("lapd", dissect_lapd, proto_lapd);
 	lapd_phdr_handle = register_dissector("lapd-phdr", dissect_lapd_phdr, proto_lapd);
 	linux_lapd_handle = register_dissector("linux-lapd", dissect_linux_lapd, proto_lapd);
 	lapd_bitstream_handle = register_dissector("lapd-bitstream", dissect_lapd_bitstream, proto_lapd);
