@@ -26,15 +26,15 @@ static dissector_handle_t laplink_tcp_handle;
 #define UDP_PORT_LAPLINK 1547
 
 /* Initialize the protocol and registered fields */
-static int proto_laplink = -1;
-static int hf_laplink_udp_ident = -1;
-static int hf_laplink_udp_name = -1;
-static int hf_laplink_tcp_ident = -1;
-static int hf_laplink_tcp_length = -1;
-static int hf_laplink_tcp_data = -1;
+static int proto_laplink;
+static int hf_laplink_udp_ident;
+static int hf_laplink_udp_name;
+static int hf_laplink_tcp_ident;
+static int hf_laplink_tcp_length;
+static int hf_laplink_tcp_data;
 
 /* Initialize the subtree pointers */
-static gint ett_laplink = -1;
+static gint ett_laplink;
 
 static const value_string laplink_udp_magic[] = {
 	{ 0x0f010000, "Name Solicitation" },
@@ -57,7 +57,7 @@ static const value_string laplink_tcp_magic[] = {
 	{ 0, NULL }
 };
 
-static gboolean laplink_desegment = TRUE;
+static bool laplink_desegment = true;
 
 /* Code to actually dissect the packets - UDP */
 static gint
@@ -188,7 +188,7 @@ proto_register_laplink(void)
 		{ &hf_laplink_tcp_data,
 			{ "Unknown TCP data", "laplink.tcp_data",
 			FT_BYTES, BASE_NONE, NULL, 0x0,
-			"TCP data", HFILL }
+			NULL, HFILL }
 		},
 	};
 
@@ -200,8 +200,7 @@ proto_register_laplink(void)
 	module_t *laplink_module;
 
 /* Register the protocol name and description */
-	proto_laplink = proto_register_protocol("Laplink",
-	    "Laplink", "laplink");
+	proto_laplink = proto_register_protocol("Laplink", "Laplink", "laplink");
 
 /* Required function calls to register the header fields and subtrees used */
 	proto_register_field_array(proto_laplink, hf, array_length(hf));
