@@ -109,12 +109,12 @@ static lbmtcp_transport_t * lbmtcp_transport_add(const address * address1, guint
 /* Global preferences variables (altered by the preferences dialog). */
 static guint32 global_lbmpdm_tcp_port_low   = LBMPDM_TCP_DEFAULT_PORT_LOW;
 static guint32 global_lbmpdm_tcp_port_high  = LBMPDM_TCP_DEFAULT_PORT_HIGH;
-static gboolean global_lbmpdm_tcp_use_tag   = FALSE;
+static bool global_lbmpdm_tcp_use_tag;
 
 /* Local preferences variables (used by the dissector). */
 static guint32 lbmpdm_tcp_port_low  = LBMPDM_TCP_DEFAULT_PORT_LOW;
 static guint32 lbmpdm_tcp_port_high = LBMPDM_TCP_DEFAULT_PORT_HIGH;
-static gboolean lbmpdm_tcp_use_tag  = FALSE;
+static gboolean lbmpdm_tcp_use_tag;
 
 /* Tag definitions. */
 typedef struct
@@ -124,8 +124,8 @@ typedef struct
     guint32 port_high;
 } lbmpdm_tcp_tag_entry_t;
 
-static lbmpdm_tcp_tag_entry_t * lbmpdm_tcp_tag_entry = NULL;
-static guint lbmpdm_tcp_tag_count  = 0;
+static lbmpdm_tcp_tag_entry_t * lbmpdm_tcp_tag_entry;
+static guint lbmpdm_tcp_tag_count;
 
 UAT_CSTRING_CB_DEF(lbmpdm_tcp_tag, name, lbmpdm_tcp_tag_entry_t)
 UAT_DEC_CB_DEF(lbmpdm_tcp_tag, port_low, lbmpdm_tcp_tag_entry_t)
@@ -141,7 +141,7 @@ static uat_field_t lbmpdm_tcp_tag_array[] =
 /*----------------------------------------------------------------------------*/
 /* UAT callback functions.                                                    */
 /*----------------------------------------------------------------------------*/
-static gboolean lbmpdm_tcp_tag_update_cb(void * record, char * * error_string)
+static bool lbmpdm_tcp_tag_update_cb(void * record, char * * error_string)
 {
     lbmpdm_tcp_tag_entry_t * tag = (lbmpdm_tcp_tag_entry_t *)record;
 
@@ -228,11 +228,11 @@ static char * lbmpdm_tcp_tag_find(packet_info * pinfo)
 /*----------------------------------------------------------------------------*/
 
 /* Dissector tree handles */
-static int ett_lbmpdm_tcp = -1;
+static int ett_lbmpdm_tcp;
 
 /* Dissector field handles */
-static int hf_lbmpdm_tcp_tag = -1;
-static int hf_lbmpdm_tcp_channel = -1;
+static int hf_lbmpdm_tcp_tag;
+static int hf_lbmpdm_tcp_channel;
 
 static guint get_lbmpdm_tcp_pdu_length(packet_info * pinfo _U_, tvbuff_t * tvb,
                                        int offset, void *data _U_)
@@ -315,7 +315,7 @@ static int dissect_lbmpdm_tcp(tvbuff_t * tvb, packet_info * pinfo, proto_tree *
     return tvb_captured_length(tvb);
 }
 
-static gboolean test_lbmpdm_tcp_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * user_data _U_)
+static bool test_lbmpdm_tcp_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * user_data _U_)
 {
     int encoding = 0;
     int packet_len = 0;
@@ -323,27 +323,27 @@ static gboolean test_lbmpdm_tcp_packet(tvbuff_t * tvb, packet_info * pinfo, prot
     /* Must be a TCP packet. */
     if (pinfo->ptype != PT_TCP)
     {
-        return (FALSE);
+        return false;
     }
     /* Destination address must be IPV4 and 4 bytes in length. */
     if ((pinfo->dst.type != AT_IPv4) || (pinfo->dst.len != 4))
     {
-        return (FALSE);
+        return false;
     }
     if (!lbmpdm_verify_payload(tvb, 0, &encoding, &packet_len))
     {
-        return (FALSE);
+        return false;
     }
     if (lbmpdm_tcp_use_tag)
     {
         if (lbmpdm_tcp_tag_find(pinfo) != NULL)
         {
             dissect_lbmpdm_tcp(tvb, pinfo, tree, user_data);
-            return (TRUE);
+            return true;
         }
         else
         {
-            return (FALSE);
+            return false;
         }
     }
 
@@ -351,11 +351,11 @@ static gboolean test_lbmpdm_tcp_packet(tvbuff_t * tvb, packet_info * pinfo, prot
     if (!(((pinfo->srcport >= lbmpdm_tcp_port_low) && (pinfo->srcport <= lbmpdm_tcp_port_high))
           || ((pinfo->destport >= lbmpdm_tcp_port_low) && (pinfo->destport <= lbmpdm_tcp_port_high))))
     {
-        return (FALSE);
+        return false;
     }
     /* One of ours. Probably. */
     dissect_lbmpdm_tcp(tvb, pinfo, tree, user_data);
-    return (TRUE);
+    return true;
 }
 
 /* Register all the bits needed with the filtering engine */
