@@ -27,7 +27,7 @@ void proto_register_lbtrm(void);
 void proto_reg_handoff_lbtrm(void);
 
 /* Protocol handle */
-static int proto_lbtrm = -1;
+static int proto_lbtrm;
 
 /* Dissector handle */
 static dissector_handle_t lbtrm_dissector_handle;
@@ -557,26 +557,26 @@ static guint32 global_mim_incoming_dest_port = MIM_DEFAULT_INCOMING_DPORT;
 static guint32 global_mim_outgoing_dest_port = MIM_DEFAULT_OUTGOING_DPORT;
 static const char * global_mim_incoming_mc_address = MIM_DEFAULT_MC_INCOMING_ADDRESS;
 static const char * global_mim_outgoing_mc_address = MIM_DEFAULT_MC_OUTGOING_ADDRESS;
-static gboolean global_lbtrm_expert_separate_naks = FALSE;
-static gboolean global_lbtrm_expert_separate_ncfs = FALSE;
-static gboolean global_lbtrm_use_tag = FALSE;
-static gboolean global_lbtrm_sequence_analysis = FALSE;
+static bool global_lbtrm_expert_separate_naks;
+static bool global_lbtrm_expert_separate_ncfs;
+static bool global_lbtrm_use_tag;
+static bool global_lbtrm_sequence_analysis;
 
 /* Local preferences variables (used by the dissector). */
-static guint32 lbtrm_mc_address_low_host = 0;
-static guint32 lbtrm_mc_address_high_host = 0;
+static guint32 lbtrm_mc_address_low_host;
+static guint32 lbtrm_mc_address_high_host;
 static guint32 lbtrm_dest_port_low = LBTRM_DEFAULT_DPORT_LOW;
 static guint32 lbtrm_dest_port_high = LBTRM_DEFAULT_DPORT_HIGH;
 static guint32 lbtrm_src_port_low = LBTRM_DEFAULT_SPORT_LOW;
 static guint32 lbtrm_src_port_high = LBTRM_DEFAULT_SPORT_HIGH;
 static guint32 mim_incoming_dest_port = MIM_DEFAULT_INCOMING_DPORT;
 static guint32 mim_outgoing_dest_port = MIM_DEFAULT_OUTGOING_DPORT;
-static guint32 mim_incoming_mc_address_host = 0;
-static guint32 mim_outgoing_mc_address_host = 0;
-static gboolean lbtrm_expert_separate_naks = FALSE;
-static gboolean lbtrm_expert_separate_ncfs = FALSE;
-static gboolean lbtrm_use_tag = FALSE;
-static gboolean lbtrm_sequence_analysis = FALSE;
+static guint32 mim_incoming_mc_address_host;
+static guint32 mim_outgoing_mc_address_host;
+static gboolean lbtrm_expert_separate_naks;
+static gboolean lbtrm_expert_separate_ncfs;
+static gboolean lbtrm_use_tag;
+static gboolean lbtrm_sequence_analysis;
 
 /*----------------------------------------------------------------------------*/
 /* Tag management.                                                            */
@@ -600,8 +600,8 @@ typedef struct
     guint32 mim_mc_outgoing_address_val_h;
 } lbtrm_tag_entry_t;
 
-static lbtrm_tag_entry_t * lbtrm_tag_entry = NULL;
-static guint lbtrm_tag_count = 0;
+static lbtrm_tag_entry_t * lbtrm_tag_entry;
+static guint lbtrm_tag_count;
 
 UAT_CSTRING_CB_DEF(lbtrm_tag, name, lbtrm_tag_entry_t)
 UAT_IPV4_MC_CB_DEF(lbtrm_tag, mc_address_low, lbtrm_tag_entry_t)
@@ -770,93 +770,93 @@ static char * lbtrm_tag_find(packet_info * pinfo)
 /*----------------------------------------------------------------------------*/
 
 /* Dissector tree handles */
-static gint ett_lbtrm = -1;
-static gint ett_lbtrm_hdr = -1;
-static gint ett_lbtrm_data = -1;
-static gint ett_lbtrm_data_flags_fec_type = -1;
-static gint ett_lbtrm_sm = -1;
-static gint ett_lbtrm_sm_flags_fec_type = -1;
-static gint ett_lbtrm_nak = -1;
-static gint ett_lbtrm_nak_list = -1;
-static gint ett_lbtrm_ncf = -1;
-static gint ett_lbtrm_ncf_list = -1;
-static gint ett_lbtrm_transport = -1;
-static gint ett_lbtrm_transport_sqn = -1;
+static gint ett_lbtrm;
+static gint ett_lbtrm_hdr;
+static gint ett_lbtrm_data;
+static gint ett_lbtrm_data_flags_fec_type;
+static gint ett_lbtrm_sm;
+static gint ett_lbtrm_sm_flags_fec_type;
+static gint ett_lbtrm_nak;
+static gint ett_lbtrm_nak_list;
+static gint ett_lbtrm_ncf;
+static gint ett_lbtrm_ncf_list;
+static gint ett_lbtrm_transport;
+static gint ett_lbtrm_transport_sqn;
 
 /* Dissector field handles */
-static int hf_lbtrm_channel = -1;
-static int hf_lbtrm_tag = -1;
-static int hf_lbtrm_hdr = -1;
-static int hf_lbtrm_hdr_ver = -1;
-static int hf_lbtrm_hdr_type = -1;
-static int hf_lbtrm_hdr_next_hdr = -1;
-static int hf_lbtrm_hdr_ucast_port = -1;
-static int hf_lbtrm_hdr_session_id = -1;
-static int hf_lbtrm_data = -1;
-static int hf_lbtrm_data_sqn = -1;
-static int hf_lbtrm_data_trail_sqn = -1;
-static int hf_lbtrm_data_flags_fec_type = -1;
-static int hf_lbtrm_data_flags_fec_type_ucast_naks = -1;
-static int hf_lbtrm_data_flags_fec_type_rx = -1;
-static int hf_lbtrm_data_flags_tgsz = -1;
-static int hf_lbtrm_data_fec_symbol = -1;
-static int hf_lbtrm_sm = -1;
-static int hf_lbtrm_sm_sm_sqn = -1;
-static int hf_lbtrm_sm_lead_sqn = -1;
-static int hf_lbtrm_sm_trail_sqn = -1;
-static int hf_lbtrm_sm_flags_fec_type = -1;
-static int hf_lbtrm_sm_flags_fec_type_ucast_naks = -1;
-static int hf_lbtrm_sm_flags_tgsz = -1;
-static int hf_lbtrm_sm_reserved = -1;
-static int hf_lbtrm_nak = -1;
-static int hf_lbtrm_nak_num_naks = -1;
-static int hf_lbtrm_nak_format = -1;
-static int hf_lbtrm_nak_list = -1;
-static int hf_lbtrm_nak_list_nak = -1;
-static int hf_lbtrm_ncf = -1;
-static int hf_lbtrm_ncf_trail_sqn = -1;
-static int hf_lbtrm_ncf_num_ncfs = -1;
-static int hf_lbtrm_ncf_reserved = -1;
-static int hf_lbtrm_ncf_reason = -1;
-static int hf_lbtrm_ncf_format = -1;
-static int hf_lbtrm_ncf_list = -1;
-static int hf_lbtrm_ncf_list_ncf = -1;
-static int hf_lbtrm_analysis = -1;
-static int hf_lbtrm_analysis_prev_frame = -1;
-static int hf_lbtrm_analysis_prev_data_frame = -1;
-static int hf_lbtrm_analysis_prev_sm_frame = -1;
-static int hf_lbtrm_analysis_prev_nak_frame = -1;
-static int hf_lbtrm_analysis_prev_ncf_frame = -1;
-static int hf_lbtrm_analysis_next_frame = -1;
-static int hf_lbtrm_analysis_next_data_frame = -1;
-static int hf_lbtrm_analysis_next_sm_frame = -1;
-static int hf_lbtrm_analysis_next_nak_frame = -1;
-static int hf_lbtrm_analysis_next_ncf_frame = -1;
-static int hf_lbtrm_analysis_sqn = -1;
-static int hf_lbtrm_analysis_sqn_frame = -1;
-static int hf_lbtrm_analysis_data_retransmission = -1;
-static int hf_lbtrm_analysis_data_sqn_gap = -1;
-static int hf_lbtrm_analysis_data_ooo_gap = -1;
-static int hf_lbtrm_analysis_data_duplicate = -1;
-static int hf_lbtrm_analysis_sm_sqn_gap = -1;
-static int hf_lbtrm_analysis_sm_ooo_gap = -1;
-static int hf_lbtrm_analysis_sm_duplicate = -1;
+static int hf_lbtrm_channel;
+static int hf_lbtrm_tag;
+static int hf_lbtrm_hdr;
+static int hf_lbtrm_hdr_ver;
+static int hf_lbtrm_hdr_type;
+static int hf_lbtrm_hdr_next_hdr;
+static int hf_lbtrm_hdr_ucast_port;
+static int hf_lbtrm_hdr_session_id;
+static int hf_lbtrm_data;
+static int hf_lbtrm_data_sqn;
+static int hf_lbtrm_data_trail_sqn;
+static int hf_lbtrm_data_flags_fec_type;
+static int hf_lbtrm_data_flags_fec_type_ucast_naks;
+static int hf_lbtrm_data_flags_fec_type_rx;
+static int hf_lbtrm_data_flags_tgsz;
+static int hf_lbtrm_data_fec_symbol;
+static int hf_lbtrm_sm;
+static int hf_lbtrm_sm_sm_sqn;
+static int hf_lbtrm_sm_lead_sqn;
+static int hf_lbtrm_sm_trail_sqn;
+static int hf_lbtrm_sm_flags_fec_type;
+static int hf_lbtrm_sm_flags_fec_type_ucast_naks;
+static int hf_lbtrm_sm_flags_tgsz;
+static int hf_lbtrm_sm_reserved;
+static int hf_lbtrm_nak;
+static int hf_lbtrm_nak_num_naks;
+static int hf_lbtrm_nak_format;
+static int hf_lbtrm_nak_list;
+static int hf_lbtrm_nak_list_nak;
+static int hf_lbtrm_ncf;
+static int hf_lbtrm_ncf_trail_sqn;
+static int hf_lbtrm_ncf_num_ncfs;
+static int hf_lbtrm_ncf_reserved;
+static int hf_lbtrm_ncf_reason;
+static int hf_lbtrm_ncf_format;
+static int hf_lbtrm_ncf_list;
+static int hf_lbtrm_ncf_list_ncf;
+static int hf_lbtrm_analysis;
+static int hf_lbtrm_analysis_prev_frame;
+static int hf_lbtrm_analysis_prev_data_frame;
+static int hf_lbtrm_analysis_prev_sm_frame;
+static int hf_lbtrm_analysis_prev_nak_frame;
+static int hf_lbtrm_analysis_prev_ncf_frame;
+static int hf_lbtrm_analysis_next_frame;
+static int hf_lbtrm_analysis_next_data_frame;
+static int hf_lbtrm_analysis_next_sm_frame;
+static int hf_lbtrm_analysis_next_nak_frame;
+static int hf_lbtrm_analysis_next_ncf_frame;
+static int hf_lbtrm_analysis_sqn;
+static int hf_lbtrm_analysis_sqn_frame;
+static int hf_lbtrm_analysis_data_retransmission;
+static int hf_lbtrm_analysis_data_sqn_gap;
+static int hf_lbtrm_analysis_data_ooo_gap;
+static int hf_lbtrm_analysis_data_duplicate;
+static int hf_lbtrm_analysis_sm_sqn_gap;
+static int hf_lbtrm_analysis_sm_ooo_gap;
+static int hf_lbtrm_analysis_sm_duplicate;
 
 /* Expert info handles */
-static expert_field ei_lbtrm_analysis_ncf = EI_INIT;
-static expert_field ei_lbtrm_analysis_ncf_ncf = EI_INIT;
-static expert_field ei_lbtrm_analysis_nak = EI_INIT;
-static expert_field ei_lbtrm_analysis_nak_nak = EI_INIT;
-static expert_field ei_lbtrm_analysis_sm = EI_INIT;
-static expert_field ei_lbtrm_analysis_rx = EI_INIT;
-static expert_field ei_lbtrm_analysis_invalid_value = EI_INIT;
-static expert_field ei_lbtrm_analysis_data_rx = EI_INIT;
-static expert_field ei_lbtrm_analysis_data_gap = EI_INIT;
-static expert_field ei_lbtrm_analysis_data_ooo = EI_INIT;
-static expert_field ei_lbtrm_analysis_data_dup = EI_INIT;
-static expert_field ei_lbtrm_analysis_sm_gap = EI_INIT;
-static expert_field ei_lbtrm_analysis_sm_ooo = EI_INIT;
-static expert_field ei_lbtrm_analysis_sm_dup = EI_INIT;
+static expert_field ei_lbtrm_analysis_ncf;
+static expert_field ei_lbtrm_analysis_ncf_ncf;
+static expert_field ei_lbtrm_analysis_nak;
+static expert_field ei_lbtrm_analysis_nak_nak;
+static expert_field ei_lbtrm_analysis_sm;
+static expert_field ei_lbtrm_analysis_rx;
+static expert_field ei_lbtrm_analysis_invalid_value;
+static expert_field ei_lbtrm_analysis_data_rx;
+static expert_field ei_lbtrm_analysis_data_gap;
+static expert_field ei_lbtrm_analysis_data_ooo;
+static expert_field ei_lbtrm_analysis_data_dup;
+static expert_field ei_lbtrm_analysis_sm_gap;
+static expert_field ei_lbtrm_analysis_sm_ooo;
+static expert_field ei_lbtrm_analysis_sm_dup;
 
 /*----------------------------------------------------------------------------*/
 /* LBT-RM data payload dissection functions.                                  */
@@ -1090,7 +1090,7 @@ static bool dissect_lbtrm_sqn_frame_list_callback(const void *key _U_, void * fr
         }
         proto_item_set_generated(transport_item);
     }
-    return (FALSE);
+    return FALSE;
 }
 
 static int dissect_lbtrm(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * user_data _U_)
@@ -1458,7 +1458,7 @@ static int dissect_lbtrm(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
     return (total_dissected_len);
 }
 
-static gboolean test_lbtrm_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * user_data)
+static bool test_lbtrm_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * user_data)
 {
     guint32 dest_addr_h;
     gboolean valid_packet = FALSE;
@@ -1470,16 +1470,16 @@ static gboolean test_lbtrm_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tre
     /* Must be a UDP packet. */
     if (pinfo->ptype != PT_UDP)
     {
-        return (FALSE);
+        return false;
     }
     /* Destination address must be IPV4 and 4 bytes in length. */
     if ((pinfo->dst.type != AT_IPv4) || (pinfo->dst.len != 4))
     {
-        return (FALSE);
+        return false;
     }
     if (tvb_reported_length_remaining(tvb, 0) < L_LBTRM_HDR_T)
     {
-        return (FALSE);
+        return false;
     }
     ver_type = tvb_get_guint8(tvb, O_LBTRM_HDR_T_VER_TYPE);
     packet_type = LBTRM_HDR_TYPE(ver_type);
@@ -1491,17 +1491,17 @@ static gboolean test_lbtrm_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tre
         case LBTRM_PACKET_TYPE_NCF:
             break;
         default:
-            return (FALSE);
+            return false;
     }
     packet_ver = LBTRM_HDR_VER(ver_type);
     if (packet_ver != LBTRM_VERSION)
     {
-        return (FALSE);
+        return false;
     }
     next_hdr = tvb_get_guint8(tvb, O_LBTRM_HDR_T_NEXT_HDR);
     if (next_hdr != LBTRM_NHDR_DATA)
     {
-        return (FALSE);
+        return false;
     }
     if (lbtrm_use_tag)
     {
@@ -1550,9 +1550,9 @@ static gboolean test_lbtrm_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tre
     if (valid_packet)
     {
         dissect_lbtrm(tvb, pinfo, tree, user_data);
-        return (TRUE);
+        return true;
     }
-    return (FALSE);
+    return false;
 }
 
 /* Register all the bits needed with the filtering engine */
@@ -1843,6 +1843,8 @@ void proto_register_lbtrm(void)
         "LBT-RM Tags",
         "A table to define LBT-RM tags",
         tag_uat);
+
+    lbtrm_tap_handle = register_tap("lbm_lbtrm");
 }
 
 /* The registration hand-off routine */
@@ -1857,7 +1859,6 @@ void proto_reg_handoff_lbtrm(void)
     {
         dissector_add_for_decode_as_with_preference("udp.port", lbtrm_dissector_handle);
         heur_dissector_add("udp", test_lbtrm_packet, "LBT Reliable Multicast over UDP", "lbtrm_udp", proto_lbtrm, HEURISTIC_ENABLE);
-        lbtrm_tap_handle = register_tap("lbm_lbtrm");
     }
 
     /* Make sure the low MC address is <= the high MC address. If not, don't change them. */
