@@ -25,7 +25,7 @@ void proto_register_lbtru(void);
 void proto_reg_handoff_lbtru(void);
 
 /* Protocol handle */
-static int proto_lbtru = -1;
+static int proto_lbtru;
 
 /* Dissector handle */
 static dissector_handle_t lbtru_dissector_handle;
@@ -391,18 +391,17 @@ static lbm_transport_frame_t * lbtru_client_transport_frame_add(lbtru_client_tra
     return (frame_entry);
 }
 
-static char * lbtru_transport_source_string_format(const address * source_address, guint16 source_port, guint32 session_id)
+static char * lbtru_transport_source_string_format(wmem_allocator_t *scope, const address * source_address, guint16 source_port, guint32 session_id)
 {
-    /* Returns a packet-scoped string. */
     char * bufptr = NULL;
 
     if (session_id == 0)
     {
-        bufptr = wmem_strdup_printf(wmem_packet_scope(), "LBT-RU:%s:%" PRIu16, address_to_str(wmem_packet_scope(), source_address), source_port);
+        bufptr = wmem_strdup_printf(scope, "LBT-RU:%s:%" PRIu16, address_to_str(scope, source_address), source_port);
     }
     else
     {
-        bufptr = wmem_strdup_printf(wmem_packet_scope(), "LBT-RU:%s:%" PRIu16 ":%08x", address_to_str(wmem_packet_scope(), source_address), source_port, session_id);
+        bufptr = wmem_strdup_printf(scope, "LBT-RU:%s:%" PRIu16 ":%08x", address_to_str(scope, source_address), source_port, session_id);
     }
     return (bufptr);
 }
@@ -410,13 +409,12 @@ static char * lbtru_transport_source_string_format(const address * source_addres
 char * lbtru_transport_source_string(const address * source_address, guint16 source_port, guint32 session_id)
 {
     /* Returns a file-scoped string. */
-    return (wmem_strdup(wmem_file_scope(), lbtru_transport_source_string_format(source_address, source_port, session_id)));
+    return lbtru_transport_source_string_format(wmem_file_scope(), source_address, source_port, session_id);
 }
 
-static char * lbtru_transport_source_string_transport(lbtru_transport_t * transport)
+static char * lbtru_transport_source_string_transport(wmem_allocator_t *scope, lbtru_transport_t * transport)
 {
-    /* Returns a packet-scoped string. */
-    return (lbtru_transport_source_string(&(transport->source_address), transport->source_port, transport->session_id));
+    return lbtru_transport_source_string_format(scope, &(transport->source_address), transport->source_port, transport->session_id);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -635,20 +633,20 @@ static guint32 global_lbtru_source_port_low = LBTRU_DEFAULT_SOURCE_PORT_LOW;
 static guint32 global_lbtru_source_port_high = LBTRU_DEFAULT_SOURCE_PORT_HIGH;
 static guint32 global_lbtru_receiver_port_low = LBTRU_DEFAULT_RECEIVER_PORT_LOW;
 static guint32 global_lbtru_receiver_port_high = LBTRU_DEFAULT_RECEIVER_PORT_HIGH;
-static gboolean global_lbtru_expert_separate_naks = FALSE;
-static gboolean global_lbtru_expert_separate_ncfs = FALSE;
-static gboolean global_lbtru_use_tag = FALSE;
-static gboolean global_lbtru_sequence_analysis = FALSE;
+static bool global_lbtru_expert_separate_naks;
+static bool global_lbtru_expert_separate_ncfs;
+static bool global_lbtru_use_tag;
+static bool global_lbtru_sequence_analysis;
 
 /* Local preferences variables (used by the dissector). */
 static guint32 lbtru_source_port_low = LBTRU_DEFAULT_SOURCE_PORT_LOW;
 static guint32 lbtru_source_port_high = LBTRU_DEFAULT_SOURCE_PORT_HIGH;
 static guint32 lbtru_receiver_port_low = LBTRU_DEFAULT_RECEIVER_PORT_LOW;
 static guint32 lbtru_receiver_port_high = LBTRU_DEFAULT_RECEIVER_PORT_HIGH;
-static gboolean lbtru_expert_separate_naks = FALSE;
-static gboolean lbtru_expert_separate_ncfs = FALSE;
-static gboolean lbtru_use_tag = FALSE;
-static gboolean lbtru_sequence_analysis = FALSE;
+static gboolean lbtru_expert_separate_naks;
+static gboolean lbtru_expert_separate_ncfs;
+static gboolean lbtru_use_tag;
+static gboolean lbtru_sequence_analysis;
 
 /*----------------------------------------------------------------------------*/
 /* Tag management.                                                            */
@@ -662,8 +660,8 @@ typedef struct
     guint32 receiver_port_high;
 } lbtru_tag_entry_t;
 
-static lbtru_tag_entry_t * lbtru_tag_entry = NULL;
-static guint lbtru_tag_count = 0;
+static lbtru_tag_entry_t * lbtru_tag_entry;
+static guint lbtru_tag_count;
 
 UAT_CSTRING_CB_DEF(lbtru_tag, name, lbtru_tag_entry_t)
 UAT_DEC_CB_DEF(lbtru_tag, source_port_low, lbtru_tag_entry_t)
@@ -683,7 +681,7 @@ static uat_field_t lbtru_tag_array[] =
 /*----------------------------------------------------------------------------*/
 /* UAT callback functions.                                                    */
 /*----------------------------------------------------------------------------*/
-static gboolean lbtru_tag_update_cb(void * record, char * * error_string)
+static bool lbtru_tag_update_cb(void * record, char * * error_string)
 {
     lbtru_tag_entry_t * tag = (lbtru_tag_entry_t *)record;
 
@@ -762,122 +760,122 @@ static char * lbtru_tag_find(packet_info * pinfo)
 /*----------------------------------------------------------------------------*/
 
 /* Dissector tree handles */
-static gint ett_lbtru = -1;
-static gint ett_lbtru_channel = -1;
-static gint ett_lbtru_hdr = -1;
-static gint ett_lbtru_hdr_flags = -1;
-static gint ett_lbtru_data = -1;
-static gint ett_lbtru_sm = -1;
-static gint ett_lbtru_nak = -1;
-static gint ett_lbtru_nak_list = -1;
-static gint ett_lbtru_ncf = -1;
-static gint ett_lbtru_ncf_list = -1;
-static gint ett_lbtru_ack = -1;
-static gint ett_lbtru_opt = -1;
-static gint ett_lbtru_opt_sid_flags = -1;
-static gint ett_lbtru_opt_cid_flags = -1;
-static gint ett_lbtru_transport = -1;
-static gint ett_lbtru_transport_sqn = -1;
+static gint ett_lbtru;
+static gint ett_lbtru_channel;
+static gint ett_lbtru_hdr;
+static gint ett_lbtru_hdr_flags;
+static gint ett_lbtru_data;
+static gint ett_lbtru_sm;
+static gint ett_lbtru_nak;
+static gint ett_lbtru_nak_list;
+static gint ett_lbtru_ncf;
+static gint ett_lbtru_ncf_list;
+static gint ett_lbtru_ack;
+static gint ett_lbtru_opt;
+static gint ett_lbtru_opt_sid_flags;
+static gint ett_lbtru_opt_cid_flags;
+static gint ett_lbtru_transport;
+static gint ett_lbtru_transport_sqn;
 
 /* Dissector field handles */
-static int hf_lbtru_channel = -1;
-static int hf_lbtru_channel_id = -1;
-static int hf_lbtru_channel_client = -1;
-static int hf_lbtru_tag = -1;
-static int hf_lbtru_hdr = -1;
-static int hf_lbtru_hdr_ver = -1;
-static int hf_lbtru_hdr_type = -1;
-static int hf_lbtru_hdr_next_hdr = -1;
-static int hf_lbtru_hdr_res = -1;
-static int hf_lbtru_hdr_flags = -1;
-static int hf_lbtru_hdr_flags_syn = -1;
-static int hf_lbtru_hdr_flags_rx = -1;
-static int hf_lbtru_hdr_request = -1;
-static int hf_lbtru_hdr_reason = -1;
-static int hf_lbtru_data = -1;
-static int hf_lbtru_data_sqn = -1;
-static int hf_lbtru_data_trail_sqn = -1;
-static int hf_lbtru_sm = -1;
-static int hf_lbtru_sm_sqn = -1;
-static int hf_lbtru_sm_lead_sqn = -1;
-static int hf_lbtru_sm_trail_sqn = -1;
-static int hf_lbtru_nak = -1;
-static int hf_lbtru_nak_num = -1;
-static int hf_lbtru_nak_format = -1;
-static int hf_lbtru_nak_list = -1;
-static int hf_lbtru_nak_list_nak = -1;
-static int hf_lbtru_ncf = -1;
-static int hf_lbtru_ncf_trail_sqn = -1;
-static int hf_lbtru_ncf_num = -1;
-static int hf_lbtru_ncf_reserved = -1;
-static int hf_lbtru_ncf_reason = -1;
-static int hf_lbtru_ncf_format = -1;
-static int hf_lbtru_ncf_list = -1;
-static int hf_lbtru_ncf_list_ncf = -1;
-static int hf_lbtru_ack = -1;
-static int hf_lbtru_ack_sqn = -1;
-static int hf_lbtru_opt_sid = -1;
-static int hf_lbtru_opt_sid_next_hdr = -1;
-static int hf_lbtru_opt_sid_hdr_len = -1;
-static int hf_lbtru_opt_sid_flags = -1;
-static int hf_lbtru_opt_sid_flags_ignore = -1;
-static int hf_lbtru_opt_sid_session_id = -1;
-static int hf_lbtru_opt_cid = -1;
-static int hf_lbtru_opt_cid_next_hdr = -1;
-static int hf_lbtru_opt_cid_hdr_len = -1;
-static int hf_lbtru_opt_cid_flags = -1;
-static int hf_lbtru_opt_cid_flags_ignore = -1;
-static int hf_lbtru_opt_cid_client_id = -1;
-static int hf_lbtru_opt_unknown = -1;
-static int hf_lbtru_opt_unknown_next_hdr = -1;
-static int hf_lbtru_opt_unknown_hdr_len = -1;
-static int hf_lbtru_analysis = -1;
-static int hf_lbtru_analysis_prev_frame = -1;
-static int hf_lbtru_analysis_prev_data_frame = -1;
-static int hf_lbtru_analysis_prev_sm_frame = -1;
-static int hf_lbtru_analysis_prev_nak_frame = -1;
-static int hf_lbtru_analysis_prev_ncf_frame = -1;
-static int hf_lbtru_analysis_prev_ack_frame = -1;
-static int hf_lbtru_analysis_prev_creq_frame = -1;
-static int hf_lbtru_analysis_prev_rst_frame = -1;
-static int hf_lbtru_analysis_next_frame = -1;
-static int hf_lbtru_analysis_next_data_frame = -1;
-static int hf_lbtru_analysis_next_sm_frame = -1;
-static int hf_lbtru_analysis_next_nak_frame = -1;
-static int hf_lbtru_analysis_next_ncf_frame = -1;
-static int hf_lbtru_analysis_next_ack_frame = -1;
-static int hf_lbtru_analysis_next_creq_frame = -1;
-static int hf_lbtru_analysis_next_rst_frame = -1;
-static int hf_lbtru_analysis_sqn = -1;
-static int hf_lbtru_analysis_sqn_frame = -1;
-static int hf_lbtru_analysis_data_retransmission = -1;
-static int hf_lbtru_analysis_data_sqn_gap = -1;
-static int hf_lbtru_analysis_data_ooo_gap = -1;
-static int hf_lbtru_analysis_data_duplicate = -1;
-static int hf_lbtru_analysis_sm_sqn_gap = -1;
-static int hf_lbtru_analysis_sm_ooo_gap = -1;
-static int hf_lbtru_analysis_sm_duplicate = -1;
+static int hf_lbtru_channel;
+static int hf_lbtru_channel_id;
+static int hf_lbtru_channel_client;
+static int hf_lbtru_tag;
+static int hf_lbtru_hdr;
+static int hf_lbtru_hdr_ver;
+static int hf_lbtru_hdr_type;
+static int hf_lbtru_hdr_next_hdr;
+static int hf_lbtru_hdr_res;
+static int hf_lbtru_hdr_flags;
+static int hf_lbtru_hdr_flags_syn;
+static int hf_lbtru_hdr_flags_rx;
+static int hf_lbtru_hdr_request;
+static int hf_lbtru_hdr_reason;
+static int hf_lbtru_data;
+static int hf_lbtru_data_sqn;
+static int hf_lbtru_data_trail_sqn;
+static int hf_lbtru_sm;
+static int hf_lbtru_sm_sqn;
+static int hf_lbtru_sm_lead_sqn;
+static int hf_lbtru_sm_trail_sqn;
+static int hf_lbtru_nak;
+static int hf_lbtru_nak_num;
+static int hf_lbtru_nak_format;
+static int hf_lbtru_nak_list;
+static int hf_lbtru_nak_list_nak;
+static int hf_lbtru_ncf;
+static int hf_lbtru_ncf_trail_sqn;
+static int hf_lbtru_ncf_num;
+static int hf_lbtru_ncf_reserved;
+static int hf_lbtru_ncf_reason;
+static int hf_lbtru_ncf_format;
+static int hf_lbtru_ncf_list;
+static int hf_lbtru_ncf_list_ncf;
+static int hf_lbtru_ack;
+static int hf_lbtru_ack_sqn;
+static int hf_lbtru_opt_sid;
+static int hf_lbtru_opt_sid_next_hdr;
+static int hf_lbtru_opt_sid_hdr_len;
+static int hf_lbtru_opt_sid_flags;
+static int hf_lbtru_opt_sid_flags_ignore;
+static int hf_lbtru_opt_sid_session_id;
+static int hf_lbtru_opt_cid;
+static int hf_lbtru_opt_cid_next_hdr;
+static int hf_lbtru_opt_cid_hdr_len;
+static int hf_lbtru_opt_cid_flags;
+static int hf_lbtru_opt_cid_flags_ignore;
+static int hf_lbtru_opt_cid_client_id;
+static int hf_lbtru_opt_unknown;
+static int hf_lbtru_opt_unknown_next_hdr;
+static int hf_lbtru_opt_unknown_hdr_len;
+static int hf_lbtru_analysis;
+static int hf_lbtru_analysis_prev_frame;
+static int hf_lbtru_analysis_prev_data_frame;
+static int hf_lbtru_analysis_prev_sm_frame;
+static int hf_lbtru_analysis_prev_nak_frame;
+static int hf_lbtru_analysis_prev_ncf_frame;
+static int hf_lbtru_analysis_prev_ack_frame;
+static int hf_lbtru_analysis_prev_creq_frame;
+static int hf_lbtru_analysis_prev_rst_frame;
+static int hf_lbtru_analysis_next_frame;
+static int hf_lbtru_analysis_next_data_frame;
+static int hf_lbtru_analysis_next_sm_frame;
+static int hf_lbtru_analysis_next_nak_frame;
+static int hf_lbtru_analysis_next_ncf_frame;
+static int hf_lbtru_analysis_next_ack_frame;
+static int hf_lbtru_analysis_next_creq_frame;
+static int hf_lbtru_analysis_next_rst_frame;
+static int hf_lbtru_analysis_sqn;
+static int hf_lbtru_analysis_sqn_frame;
+static int hf_lbtru_analysis_data_retransmission;
+static int hf_lbtru_analysis_data_sqn_gap;
+static int hf_lbtru_analysis_data_ooo_gap;
+static int hf_lbtru_analysis_data_duplicate;
+static int hf_lbtru_analysis_sm_sqn_gap;
+static int hf_lbtru_analysis_sm_ooo_gap;
+static int hf_lbtru_analysis_sm_duplicate;
 
 /* Expert info handles */
-static expert_field ei_lbtru_analysis_unknown_type = EI_INIT;
-static expert_field ei_lbtru_analysis_unknown_header = EI_INIT;
-static expert_field ei_lbtru_analysis_zero_length_header = EI_INIT;
-static expert_field ei_lbtru_analysis_ack = EI_INIT;
-static expert_field ei_lbtru_analysis_ncf = EI_INIT;
-static expert_field ei_lbtru_analysis_ncf_ncf = EI_INIT;
-static expert_field ei_lbtru_analysis_nak = EI_INIT;
-static expert_field ei_lbtru_analysis_nak_nak = EI_INIT;
-static expert_field ei_lbtru_analysis_sm = EI_INIT;
-static expert_field ei_lbtru_analysis_sm_syn = EI_INIT;
-static expert_field ei_lbtru_analysis_creq = EI_INIT;
-static expert_field ei_lbtru_analysis_rst = EI_INIT;
-static expert_field ei_lbtru_analysis_data_rx = EI_INIT;
-static expert_field ei_lbtru_analysis_data_gap = EI_INIT;
-static expert_field ei_lbtru_analysis_data_ooo = EI_INIT;
-static expert_field ei_lbtru_analysis_data_dup = EI_INIT;
-static expert_field ei_lbtru_analysis_sm_gap = EI_INIT;
-static expert_field ei_lbtru_analysis_sm_ooo = EI_INIT;
-static expert_field ei_lbtru_analysis_sm_dup = EI_INIT;
+static expert_field ei_lbtru_analysis_unknown_type;
+static expert_field ei_lbtru_analysis_unknown_header;
+static expert_field ei_lbtru_analysis_zero_length_header;
+static expert_field ei_lbtru_analysis_ack;
+static expert_field ei_lbtru_analysis_ncf;
+static expert_field ei_lbtru_analysis_ncf_ncf;
+static expert_field ei_lbtru_analysis_nak;
+static expert_field ei_lbtru_analysis_nak_nak;
+static expert_field ei_lbtru_analysis_sm;
+static expert_field ei_lbtru_analysis_sm_syn;
+static expert_field ei_lbtru_analysis_creq;
+static expert_field ei_lbtru_analysis_rst;
+static expert_field ei_lbtru_analysis_data_rx;
+static expert_field ei_lbtru_analysis_data_gap;
+static expert_field ei_lbtru_analysis_data_ooo;
+static expert_field ei_lbtru_analysis_data_dup;
+static expert_field ei_lbtru_analysis_sm_gap;
+static expert_field ei_lbtru_analysis_sm_ooo;
+static expert_field ei_lbtru_analysis_sm_dup;
 
 /*----------------------------------------------------------------------------*/
 /* LBT-RU data payload dissection functions.                                  */
@@ -960,9 +958,9 @@ static int dissect_lbtru_ncf(tvbuff_t * tvb, int offset, packet_info * pinfo, pr
     {
         expert_add_info_format(pinfo, ncf_item, &ei_lbtru_analysis_ncf, "NCF %s", val_to_str(LBTRU_NCF_HDR_REASON(reason_format), lbtru_ncf_reason, "Unknown (0x%02x)"));
     }
-    tap_info->ncf_reason = LBTRU_NCF_HDR_REASON(reason_format);;
+    tap_info->ncf_reason = LBTRU_NCF_HDR_REASON(reason_format);
     tap_info->num_sqns = num_ncfs;
-    tap_info->sqns = wmem_alloc_array(wmem_packet_scope(), guint32, num_ncfs);
+    tap_info->sqns = wmem_alloc_array(pinfo->pool, guint32, num_ncfs);
     len_dissected += dissect_lbtru_ncf_list(tvb, offset + L_LBTRU_NCF_HDR_T, pinfo, ncf_tree, num_ncfs, LBTRU_NCF_HDR_REASON(reason_format), tap_info);
     proto_item_set_len(ncf_item, len_dissected);
     return (len_dissected);
@@ -1017,7 +1015,7 @@ static int dissect_lbtru_nak(tvbuff_t * tvb, int offset, packet_info * pinfo, pr
         expert_add_info(pinfo, nak_item, &ei_lbtru_analysis_nak);
     }
     tap_info->num_sqns = num_naks;
-    tap_info->sqns = wmem_alloc_array(wmem_packet_scope(), guint32, num_naks);
+    tap_info->sqns = wmem_alloc_array(pinfo->pool, guint32, num_naks);
     len_dissected += dissect_lbtru_nak_list(tvb, offset + L_LBTRU_NAK_HDR_T, pinfo, nak_tree, num_naks, tap_info);
     proto_item_set_len(nak_item, len_dissected);
     return (len_dissected);
@@ -1093,7 +1091,7 @@ static bool dissect_lbtru_sqn_frame_list_callback(const void *key _U_, void * fr
         }
         proto_item_set_generated(transport_item);
     }
-    return (FALSE);
+    return FALSE;
 }
 
 static int dissect_lbtru(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * user_data _U_)
@@ -1180,7 +1178,7 @@ static int dissect_lbtru(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
     proto_item_set_generated(channel_item);
     channel_tree = proto_item_add_subtree(channel_item, ett_lbtru_channel);
 
-    tapinfo = wmem_new0(wmem_packet_scope(), lbm_lbtru_tap_info_t);
+    tapinfo = wmem_new0(pinfo->pool, lbm_lbtru_tap_info_t);
     tapinfo->type = packet_type;
 
     header_item = proto_tree_add_item(lbtru_tree, hf_lbtru_hdr, tvb, 0, -1, ENC_NA);
@@ -1431,7 +1429,7 @@ static int dissect_lbtru(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
         {
             client = lbtru_client_transport_find(transport, &receiver_address, receiver_port, pinfo->num);
         }
-        tapinfo->transport = lbtru_transport_source_string_transport(transport);
+        tapinfo->transport = lbtru_transport_source_string_transport(pinfo->pool, transport);
         channel = transport->channel;
         fld_item = proto_tree_add_uint64(channel_tree, hf_lbtru_channel_id, tvb, 0, 0, channel);
         proto_item_set_generated(fld_item);
@@ -1647,19 +1645,19 @@ static int dissect_lbtru(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree,
     return (total_dissected_len);
 }
 
-static gboolean test_lbtru_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * user_data)
+static bool test_lbtru_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * user_data)
 {
     gboolean valid_packet = FALSE;
 
     /* Must be a UDP packet. */
     if (pinfo->ptype != PT_UDP)
     {
-        return (FALSE);
+        return false;
     }
     /* Destination address must be IPV4 and 4 bytes in length. */
     if ((pinfo->dst.type != AT_IPv4) || (pinfo->dst.len != 4))
     {
-        return (FALSE);
+        return false;
     }
 
     if (lbtru_use_tag)
@@ -1691,10 +1689,10 @@ static gboolean test_lbtru_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tre
     if (valid_packet)
     {
         dissect_lbtru(tvb, pinfo, tree, user_data);
-        return (TRUE);
+        return true;
     }
     /* Not one of ours. */
-    return (FALSE);
+    return false;
 }
 
 /* Register all the bits needed with the filtering engine */
@@ -1912,6 +1910,8 @@ void proto_register_lbtru(void)
 
     lbtru_dissector_handle = register_dissector("lbtru", dissect_lbtru, proto_lbtru);
 
+    lbtru_tap_handle = register_tap("lbm_lbtru");
+
     lbtru_module = prefs_register_protocol_subtree("29West", proto_lbtru, proto_reg_handoff_lbtru);
     prefs_register_uint_preference(lbtru_module,
         "source_port_low",
@@ -1996,7 +1996,6 @@ void proto_reg_handoff_lbtru(void)
     {
         dissector_add_for_decode_as_with_preference("udp.port", lbtru_dissector_handle);
         heur_dissector_add("udp", test_lbtru_packet, "LBT Reliable Unicast over UDP", "lbtru_udp", proto_lbtru, HEURISTIC_ENABLE);
-        lbtru_tap_handle = register_tap("lbm_lbtru");
     }
 
     /* Make sure the low source port is <= the high source port. If not, don't change them. */
