@@ -24,7 +24,7 @@ void proto_register_lbttcp(void);
 void proto_reg_handoff_lbttcp(void);
 
 /* Protocol handle */
-static int proto_lbttcp = -1;
+static int proto_lbttcp;
 
 /* Dissector handle */
 static dissector_handle_t lbttcp_dissector_handle;
@@ -191,24 +191,24 @@ gboolean lbttcp_transport_sid_find(const address * source_address, guint16 sourc
     conv = find_conversation(frame, source_address, &lbttcp_null_address, CONVERSATION_TCP, source_port, 0, 0);
     if (conv == NULL)
     {
-        return (FALSE);
+        return FALSE;
     }
     conv_data = (lbttcp_transport_conv_data_t *) conversation_get_proto_data(conv, proto_lbttcp);
     if (conv_data == NULL)
     {
-        return (FALSE);
+        return FALSE;
     }
     if (conv_data->frame_tree == NULL)
     {
-        return (FALSE);
+        return FALSE;
     }
     transport = (lbttcp_transport_t *)wmem_tree_lookup32_le(conv_data->frame_tree, frame);
     if (transport == NULL)
     {
-        return (FALSE);
+        return FALSE;
     }
     *session_id = transport->session_id;
-    return (TRUE);
+    return TRUE;
 }
 
 void lbttcp_transport_sid_add(const address * source_address, guint16 source_port, guint32 frame, guint32 session_id)
@@ -266,7 +266,7 @@ static guint32 global_lbttcp_request_port_low = LBTTCP_DEFAULT_REQUEST_PORT_LOW;
 static guint32 global_lbttcp_request_port_high = LBTTCP_DEFAULT_REQUEST_PORT_HIGH;
 static guint32 global_lbttcp_store_port_low = LBTTCP_DEFAULT_STORE_PORT_LOW;
 static guint32 global_lbttcp_store_port_high = LBTTCP_DEFAULT_STORE_PORT_HIGH;
-static gboolean global_lbttcp_use_tag = FALSE;
+static bool global_lbttcp_use_tag;
 
 /* Local preferences variables (used by the dissector). */
 static guint32 lbttcp_source_port_low = LBTTCP_DEFAULT_SOURCE_PORT_LOW;
@@ -275,7 +275,7 @@ static guint32 lbttcp_request_port_low = LBTTCP_DEFAULT_REQUEST_PORT_LOW;
 static guint32 lbttcp_request_port_high = LBTTCP_DEFAULT_REQUEST_PORT_HIGH;
 static guint32 lbttcp_store_port_low = LBTTCP_DEFAULT_STORE_PORT_LOW;
 static guint32 lbttcp_store_port_high = LBTTCP_DEFAULT_STORE_PORT_HIGH;
-static gboolean lbttcp_use_tag = FALSE;
+static gboolean lbttcp_use_tag;
 
 /* Tag definitions. */
 typedef struct
@@ -289,8 +289,8 @@ typedef struct
     guint32 store_port_high;
 } lbttcp_tag_entry_t;
 
-static lbttcp_tag_entry_t * lbttcp_tag_entry = NULL;
-static guint lbttcp_tag_count  = 0;
+static lbttcp_tag_entry_t * lbttcp_tag_entry;
+static guint lbttcp_tag_count;
 
 UAT_CSTRING_CB_DEF(lbttcp_tag, name, lbttcp_tag_entry_t)
 UAT_DEC_CB_DEF(lbttcp_tag, source_port_low, lbttcp_tag_entry_t)
@@ -314,7 +314,7 @@ static uat_field_t lbttcp_tag_array[] =
 /*----------------------------------------------------------------------------*/
 /* UAT callback functions.                                                    */
 /*----------------------------------------------------------------------------*/
-static gboolean lbttcp_tag_update_cb(void * record, char * * error_string)
+static bool lbttcp_tag_update_cb(void * record, char * * error_string)
 {
     lbttcp_tag_entry_t * tag = (lbttcp_tag_entry_t *)record;
 
@@ -409,14 +409,14 @@ static char * lbttcp_tag_find(packet_info * pinfo)
 /*----------------------------------------------------------------------------*/
 
 /* Dissector tree handles */
-static gint ett_lbttcp = -1;
-static gint ett_lbttcp_channel = -1;
+static gint ett_lbttcp;
+static gint ett_lbttcp_channel;
 
 /* Dissector field handles */
-static int hf_lbttcp_tag = -1;
-static int hf_lbttcp_channel = -1;
-static int hf_lbttcp_channel_id = -1;
-static int hf_lbttcp_channel_client = -1;
+static int hf_lbttcp_tag;
+static int hf_lbttcp_channel;
+static int hf_lbttcp_channel_id;
+static int hf_lbttcp_channel_client;
 
 static gboolean lbttcp_packet_is_transport_source(packet_info * pinfo, const lbttcp_tag_entry_t * tag)
 {
@@ -644,12 +644,12 @@ static int dissect_lbttcp(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree
     return dissect_lbttcp_real(tvb, pinfo, tree, data);
 }
 
-static gboolean test_lbttcp_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * data)
+static bool test_lbttcp_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * data)
 {
     /* Destination address must be IPV4 and 4 bytes in length. */
     if ((pinfo->dst.type != AT_IPv4) || (pinfo->dst.len != 4))
     {
-        return (FALSE);
+        return false;
     }
 
     if (lbttcp_use_tag)
@@ -657,11 +657,11 @@ static gboolean test_lbttcp_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tr
         if (lbttcp_tag_find(pinfo) != NULL)
         {
             dissect_lbttcp_real(tvb, pinfo, tree, data);
-            return (TRUE);
+            return true;
         }
         else
         {
-            return (FALSE);
+            return false;
         }
     }
 
@@ -676,15 +676,15 @@ static gboolean test_lbttcp_packet(tvbuff_t * tvb, packet_info * pinfo, proto_tr
           || ((pinfo->srcport >= lbttcp_store_port_low) && (pinfo->srcport <= lbttcp_store_port_high))
           || ((pinfo->destport >= lbttcp_store_port_low) && (pinfo->destport <= lbttcp_store_port_high))))
     {
-        return (FALSE);
+        return false;
     }
 
     if (!lbmc_test_lbmc_header(tvb, 0))
-        return FALSE;
+        return false;
 
     /* One of ours. Probably. */
     dissect_lbttcp_real(tvb, pinfo, tree, data);
-    return (TRUE);
+    return true;
 }
 
 /* Register all the bits needed with the filtering engine */
