@@ -41,51 +41,51 @@ void proto_reg_handoff_lisp_tcp(void);
 static gboolean lisp_tcp_desegment = TRUE;
 
 /* Initialize the protocol and registered fields */
-static int proto_lisp_tcp = -1;
-static int hf_lisp_tcp_message_type = -1;
-static int hf_lisp_tcp_message_length = -1;
-static int hf_lisp_tcp_message_id = -1;
-static int hf_lisp_tcp_message_data = -1;
-static int hf_lisp_tcp_message_eid_afi = -1;
-static int hf_lisp_tcp_message_iid = -1;
-static int hf_lisp_tcp_message_sid = -1;
-static int hf_lisp_tcp_message_err = -1;
-static int hf_lisp_tcp_message_err_code = -1;
-static int hf_lisp_tcp_message_err_reserved = -1;
-static int hf_lisp_tcp_message_err_offending_msg_type = -1;
-static int hf_lisp_tcp_message_err_offending_msg_len = -1;
-static int hf_lisp_tcp_message_err_offending_msg_id = -1;
-static int hf_lisp_tcp_message_err_offending_msg_data = -1;
-static int hf_lisp_tcp_message_registration_reject_reason = -1;
-static int hf_lisp_tcp_message_registration_reject_res = -1;
-static int hf_lisp_tcp_message_registration_refresh_scope = -1;
-static int hf_lisp_tcp_message_registration_refresh_flags_rejected = -1;
-static int hf_lisp_tcp_message_registration_refresh_res = -1;
-static int hf_lisp_tcp_message_xtr_id = -1;
-static int hf_lisp_tcp_message_site_id = -1;
-static int hf_lisp_tcp_message_eid_prefix_length = -1;
-static int hf_lisp_tcp_message_eid_prefix_afi = -1;
-static int hf_lisp_tcp_message_eid_ipv4 = -1;
-static int hf_lisp_tcp_message_eid_ipv6 = -1;
-static int hf_lisp_tcp_message_eid_mac = -1;
-static int hf_lisp_tcp_message_eid_dn = -1;
-static int hf_lisp_tcp_message_rloc_afi = -1;
-static int hf_lisp_tcp_message_rloc_ipv4 = -1;
-static int hf_lisp_tcp_message_rloc_ipv6 = -1;
-static int hf_lisp_tcp_message_rid = -1;
-static int hf_lisp_tcp_message_end_marker = -1;
+static int proto_lisp_tcp;
+static int hf_lisp_tcp_message_type;
+static int hf_lisp_tcp_message_length;
+static int hf_lisp_tcp_message_id;
+static int hf_lisp_tcp_message_data;
+static int hf_lisp_tcp_message_eid_afi;
+static int hf_lisp_tcp_message_iid;
+static int hf_lisp_tcp_message_sid;
+static int hf_lisp_tcp_message_err;
+static int hf_lisp_tcp_message_err_code;
+static int hf_lisp_tcp_message_err_reserved;
+static int hf_lisp_tcp_message_err_offending_msg_type;
+static int hf_lisp_tcp_message_err_offending_msg_len;
+static int hf_lisp_tcp_message_err_offending_msg_id;
+static int hf_lisp_tcp_message_err_offending_msg_data;
+static int hf_lisp_tcp_message_registration_reject_reason;
+static int hf_lisp_tcp_message_registration_reject_res;
+static int hf_lisp_tcp_message_registration_refresh_scope;
+static int hf_lisp_tcp_message_registration_refresh_flags_rejected;
+static int hf_lisp_tcp_message_registration_refresh_res;
+static int hf_lisp_tcp_message_xtr_id;
+static int hf_lisp_tcp_message_site_id;
+static int hf_lisp_tcp_message_eid_prefix_length;
+static int hf_lisp_tcp_message_eid_prefix_afi;
+static int hf_lisp_tcp_message_eid_ipv4;
+static int hf_lisp_tcp_message_eid_ipv6;
+static int hf_lisp_tcp_message_eid_mac;
+static int hf_lisp_tcp_message_eid_dn;
+static int hf_lisp_tcp_message_rloc_afi;
+static int hf_lisp_tcp_message_rloc_ipv4;
+static int hf_lisp_tcp_message_rloc_ipv6;
+static int hf_lisp_tcp_message_rid;
+static int hf_lisp_tcp_message_end_marker;
 
 /* Initialize the subtree pointers */
-static gint ett_lisp_tcp = -1;
-static gint ett_lisp_tcp_lcaf = -1;
-static gint ett_lisp_tcp_eid_prefix = -1;
-static gint ett_lisp_tcp_map_register = -1;
+static gint ett_lisp_tcp;
+static gint ett_lisp_tcp_lcaf;
+static gint ett_lisp_tcp_eid_prefix;
+static gint ett_lisp_tcp_map_register;
 
 /* Initialize expert fields */
-static expert_field ei_lisp_tcp_undecoded = EI_INIT;
-static expert_field ei_lisp_tcp_invalid_length = EI_INIT;
-static expert_field ei_lisp_tcp_invalid_marker = EI_INIT;
-static expert_field ei_lisp_tcp_unexpected_afi = EI_INIT;
+static expert_field ei_lisp_tcp_undecoded;
+static expert_field ei_lisp_tcp_invalid_length;
+static expert_field ei_lisp_tcp_invalid_marker;
+static expert_field ei_lisp_tcp_unexpected_afi;
 
 static dissector_handle_t lisp_tcp_handle;
 
@@ -192,7 +192,7 @@ dissect_lisp_tcp_message_eid_prefix(tvbuff_t *tvb, packet_info *pinfo, proto_tre
             break;
         case AFNUM_DISTNAME:
             str_len = tvb_strsize(tvb, offset);
-            proto_tree_add_item(prefix_tree, hf_lisp_tcp_message_eid_dn, tvb, offset, str_len, ENC_ASCII|ENC_NA);
+            proto_tree_add_item(prefix_tree, hf_lisp_tcp_message_eid_dn, tvb, offset, str_len, ENC_ASCII);
             offset += str_len;
             break;
     }
@@ -401,7 +401,7 @@ dissect_lisp_tcp_membership_message(tvbuff_t *tvb, packet_info *pinfo, proto_tre
         proto_tree_add_item(message_tree, hf_lisp_tcp_message_site_id, tvb, offset, LISP_SITEID_LEN, ENC_NA);
         offset += 8;
         data_len -= 8;
-        proto_item_append_text(tim, ", Site-ID: %"G_GINT64_MODIFIER"u", siteid);
+        proto_item_append_text(tim, ", Site-ID: %"PRIu64, siteid);
 
         /* RLOC AFI (2 bytes) */
         afi = tvb_get_ntohs(tvb, offset);
@@ -529,7 +529,7 @@ get_lisp_tcp_message_len(packet_info *pinfo _U_, tvbuff_t *tvb,
 {
     guint16 mlen;
 
-    /* Get length of memebership message */
+    /* Get length of membership message */
     mlen = tvb_get_ntohs(tvb, offset + 2);
 
     return mlen;
