@@ -20,131 +20,131 @@ void proto_reg_handoff_lltd(void);
 
 static dissector_handle_t lltd_handle;
 
-static int proto_lltd = -1;
+static int proto_lltd;
 
-static int hf_lltd_version                  = -1;
-static int hf_lltd_type_of_service          = -1;
-static int hf_lltd_reserved                 = -1;
-static int hf_lltd_discovery_func           = -1;
-static int hf_lltd_discovery_real_dest_addr = -1;
-static int hf_lltd_discovery_real_src_addr  = -1;
-static int hf_lltd_discovery_xid            = -1;
-static int hf_lltd_discovery_seq_num        = -1;
-static int hf_lltd_discover_gen_num         = -1;
-static int hf_lltd_discover_num_stations    = -1;
-static int hf_lltd_discover_station         = -1;
-static int hf_lltd_hello_gen_num            = -1;
-static int hf_lltd_hello_current_address    = -1;
-static int hf_lltd_hello_apparent_address   = -1;
-static int hf_lltd_tlv_type                 = -1;
-static int hf_lltd_tlv_length               = -1;
-static int hf_lltd_host_id                  = -1;
-static int hf_lltd_char_p                   = -1;
-static int hf_lltd_char_x                   = -1;
-static int hf_lltd_char_f                   = -1;
-static int hf_lltd_char_m                   = -1;
-static int hf_lltd_char_l                   = -1;
-static int hf_lltd_char_reserved            = -1;
-static int hf_lltd_physical_medium          = -1;
-static int hf_lltd_wireless_mode            = -1;
-static int hf_lltd_bssid                    = -1;
-static int hf_lltd_ssid                     = -1;
-static int hf_lltd_ipv4_address             = -1;
-static int hf_lltd_ipv6_address             = -1;
-static int hf_lltd_max_operation_rate       = -1;
-static int hf_lltd_performance_count_freq   = -1;
-static int hf_lltd_link_speed               = -1;
-static int hf_lltd_rssi                     = -1;
-static int hf_lltd_machine_name             = -1;
-static int hf_lltd_support_info             = -1;
-static int hf_lltd_device_uuid              = -1;
-static int hf_lltd_qos_char_e               = -1;
-static int hf_lltd_qos_char_q               = -1;
-static int hf_lltd_qos_char_p               = -1;
-static int hf_lltd_qos_char_reserved        = -1;
-static int hf_lltd_80211_physical_medium    = -1;
-static int hf_lltd_sees_list_working_set    = -1;
-static int hf_lltd_repeater_ap_lineage      = -1;
-static int hf_lltd_emit_num_descs           = -1;
-static int hf_lltd_emit_type                = -1;
-static int hf_lltd_emit_pause               = -1;
-static int hf_lltd_emit_src_addr            = -1;
-static int hf_lltd_emit_dest_addr           = -1;
-static int hf_lltd_queryresp_more_descs     = -1;
-static int hf_lltd_queryresp_memory_descs   = -1;
-static int hf_lltd_queryresp_num_descs      = -1;
-static int hf_lltd_queryresp_type           = -1;
-static int hf_lltd_queryresp_real_src_addr  = -1;
-static int hf_lltd_queryresp_ethernet_src_addr  = -1;
-static int hf_lltd_queryresp_ethernet_dest_addr = -1;
-static int hf_lltd_flat_crc_bytes           = -1;
-static int hf_lltd_flat_crc_packets         = -1;
-static int hf_lltd_query_large_tlv_type     = -1;
-static int hf_lltd_query_large_tlv_offset   = -1;
-static int hf_lltd_querylargeresp_more_descs    = -1;
-static int hf_lltd_querylargeresp_memory_descs  = -1;
-static int hf_lltd_querylargeresp_num_descs = -1;
-static int hf_lltd_querylargeresp_data      = -1;
+static int hf_lltd_version;
+static int hf_lltd_type_of_service;
+static int hf_lltd_reserved;
+static int hf_lltd_discovery_func;
+static int hf_lltd_discovery_real_dest_addr;
+static int hf_lltd_discovery_real_src_addr;
+static int hf_lltd_discovery_xid;
+static int hf_lltd_discovery_seq_num;
+static int hf_lltd_discover_gen_num;
+static int hf_lltd_discover_num_stations;
+static int hf_lltd_discover_station;
+static int hf_lltd_hello_gen_num;
+static int hf_lltd_hello_current_address;
+static int hf_lltd_hello_apparent_address;
+static int hf_lltd_tlv_type;
+static int hf_lltd_tlv_length;
+static int hf_lltd_host_id;
+static int hf_lltd_char_p;
+static int hf_lltd_char_x;
+static int hf_lltd_char_f;
+static int hf_lltd_char_m;
+static int hf_lltd_char_l;
+static int hf_lltd_char_reserved;
+static int hf_lltd_physical_medium;
+static int hf_lltd_wireless_mode;
+static int hf_lltd_bssid;
+static int hf_lltd_ssid;
+static int hf_lltd_ipv4_address;
+static int hf_lltd_ipv6_address;
+static int hf_lltd_max_operation_rate;
+static int hf_lltd_performance_count_freq;
+static int hf_lltd_link_speed;
+static int hf_lltd_rssi;
+static int hf_lltd_machine_name;
+static int hf_lltd_support_info;
+static int hf_lltd_device_uuid;
+static int hf_lltd_qos_char_e;
+static int hf_lltd_qos_char_q;
+static int hf_lltd_qos_char_p;
+static int hf_lltd_qos_char_reserved;
+static int hf_lltd_80211_physical_medium;
+static int hf_lltd_sees_list_working_set;
+static int hf_lltd_repeater_ap_lineage;
+static int hf_lltd_emit_num_descs;
+static int hf_lltd_emit_type;
+static int hf_lltd_emit_pause;
+static int hf_lltd_emit_src_addr;
+static int hf_lltd_emit_dest_addr;
+static int hf_lltd_queryresp_more_descs;
+static int hf_lltd_queryresp_memory_descs;
+static int hf_lltd_queryresp_num_descs;
+static int hf_lltd_queryresp_type;
+static int hf_lltd_queryresp_real_src_addr;
+static int hf_lltd_queryresp_ethernet_src_addr;
+static int hf_lltd_queryresp_ethernet_dest_addr;
+static int hf_lltd_flat_crc_bytes;
+static int hf_lltd_flat_crc_packets;
+static int hf_lltd_query_large_tlv_type;
+static int hf_lltd_query_large_tlv_offset;
+static int hf_lltd_querylargeresp_more_descs;
+static int hf_lltd_querylargeresp_memory_descs;
+static int hf_lltd_querylargeresp_num_descs;
+static int hf_lltd_querylargeresp_data;
 
-static int hf_lltd_qos_diag_func            = -1;
-static int hf_lltd_qos_real_dest_addr       = -1;
-static int hf_lltd_qos_real_src_addr        = -1;
-static int hf_lltd_qos_seq_num              = -1;
-static int hf_lltd_qos_initialize_interrupt_mod = -1;
-static int hf_lltd_qos_ready_sink_link_speed = -1;
-static int hf_lltd_qos_ready_perf_count_freq = -1;
-static int hf_lltd_qos_probe_controller_transmit_timestamp = -1;
-static int hf_lltd_qos_probe_sink_receive_timestamp = -1;
-static int hf_lltd_qos_probe_sink_transmit_timestamp = -1;
-static int hf_lltd_qos_probe_test_type      = -1;
-static int hf_lltd_qos_probe_packet_id      = -1;
-static int hf_lltd_qos_probe_t              = -1;
-static int hf_lltd_qos_probe_8021p_value    = -1;
-static int hf_lltd_qos_probe_payload        = -1;
-static int hf_lltd_qos_error_value          = -1;
-static int hf_lltd_qos_count_snapshot_history = -1;
-static int hf_lltd_qos_query_resp_r         = -1;
-static int hf_lltd_qos_query_resp_e         = -1;
-static int hf_lltd_qos_query_resp_num_events = -1;
-static int hf_lltd_qos_query_resp_controller_timestamp = -1;
-static int hf_lltd_qos_query_resp_sink_timestamp = -1;
-static int hf_lltd_qos_query_resp_packet_id = -1;
-static int hf_lltd_qos_query_resp_reserved  = -1;
-static int hf_lltd_qos_counter_result_subsec_span = -1;
-static int hf_lltd_qos_counter_result_byte_scale = -1;
-static int hf_lltd_qos_counter_result_packet_scale = -1;
-static int hf_lltd_qos_counter_result_history_size = -1;
-static int hf_lltd_qos_snapshot_bytes_recv  = -1;
-static int hf_lltd_qos_snapshot_packets_recv= -1;
-static int hf_lltd_qos_snapshot_bytes_sent  = -1;
-static int hf_lltd_qos_snapshot_packets_sent= -1;
+static int hf_lltd_qos_diag_func;
+static int hf_lltd_qos_real_dest_addr;
+static int hf_lltd_qos_real_src_addr;
+static int hf_lltd_qos_seq_num;
+static int hf_lltd_qos_initialize_interrupt_mod;
+static int hf_lltd_qos_ready_sink_link_speed;
+static int hf_lltd_qos_ready_perf_count_freq;
+static int hf_lltd_qos_probe_controller_transmit_timestamp;
+static int hf_lltd_qos_probe_sink_receive_timestamp;
+static int hf_lltd_qos_probe_sink_transmit_timestamp;
+static int hf_lltd_qos_probe_test_type;
+static int hf_lltd_qos_probe_packet_id;
+static int hf_lltd_qos_probe_t;
+static int hf_lltd_qos_probe_8021p_value;
+static int hf_lltd_qos_probe_payload;
+static int hf_lltd_qos_error_value;
+static int hf_lltd_qos_count_snapshot_history;
+static int hf_lltd_qos_query_resp_r;
+static int hf_lltd_qos_query_resp_e;
+static int hf_lltd_qos_query_resp_num_events;
+static int hf_lltd_qos_query_resp_controller_timestamp;
+static int hf_lltd_qos_query_resp_sink_timestamp;
+static int hf_lltd_qos_query_resp_packet_id;
+static int hf_lltd_qos_query_resp_reserved;
+static int hf_lltd_qos_counter_result_subsec_span;
+static int hf_lltd_qos_counter_result_byte_scale;
+static int hf_lltd_qos_counter_result_packet_scale;
+static int hf_lltd_qos_counter_result_history_size;
+static int hf_lltd_qos_snapshot_bytes_recv;
+static int hf_lltd_qos_snapshot_packets_recv;
+static int hf_lltd_qos_snapshot_bytes_sent;
+static int hf_lltd_qos_snapshot_packets_sent;
 
 
-static gint ett_lltd                = -1;
-static gint ett_base_header         = -1;
-static gint ett_discover_stations   = -1;
-static gint ett_tlv                 = -1;
-static gint ett_tlv_item            = -1;
-static gint ett_characteristics     = -1;
-static gint ett_qos_characteristics = -1;
-static gint ett_repeater_ap_lineage = -1;
-static gint ett_emitee_descs        = -1;
-static gint ett_emitee_descs_item   = -1;
-static gint ett_recvee_descs        = -1;
-static gint ett_recvee_descs_item   = -1;
-static gint ett_qos_event_descs     = -1;
-static gint ett_qos_event_item      = -1;
-static gint ett_qos_snapshot_list   = -1;
-static gint ett_qos_snapshot_item   = -1;
+static gint ett_lltd;
+static gint ett_base_header;
+static gint ett_discover_stations;
+static gint ett_tlv;
+static gint ett_tlv_item;
+static gint ett_characteristics;
+static gint ett_qos_characteristics;
+static gint ett_repeater_ap_lineage;
+static gint ett_emitee_descs;
+static gint ett_emitee_descs_item;
+static gint ett_recvee_descs;
+static gint ett_recvee_descs_item;
+static gint ett_qos_event_descs;
+static gint ett_qos_event_item;
+static gint ett_qos_snapshot_list;
+static gint ett_qos_snapshot_item;
 
-static expert_field ei_lltd_tlv_length_invalid = EI_INIT;
-static expert_field ei_lltd_too_many_paths = EI_INIT;
-static expert_field ei_lltd_type_of_service = EI_INIT;
-static expert_field ei_lltd_char_reserved = EI_INIT;
-static expert_field ei_lltd_qos_seq_num = EI_INIT;
-static expert_field ei_lltd_discovery_func = EI_INIT;
-static expert_field ei_lltd_tlv_type = EI_INIT;
-static expert_field ei_lltd_qos_diag_func = EI_INIT;
+static expert_field ei_lltd_tlv_length_invalid;
+static expert_field ei_lltd_too_many_paths;
+static expert_field ei_lltd_type_of_service;
+static expert_field ei_lltd_char_reserved;
+static expert_field ei_lltd_qos_seq_num;
+static expert_field ei_lltd_discovery_func;
+static expert_field ei_lltd_tlv_type;
+static expert_field ei_lltd_qos_diag_func;
 
 #define LLTD_CHARACTERISTIC_P_MASK          0x80000000
 #define LLTD_CHARACTERISTIC_X_MASK          0x40000000
@@ -826,11 +826,11 @@ proto_register_lltd(void)
         { &hf_lltd_tlv_type, {"Type", "lltd.tlv.type", FT_UINT8, BASE_HEX, VALS(lltd_tlv_type_vals), 0, NULL, HFILL }},
         { &hf_lltd_tlv_length, {"Length", "lltd.tlv.length", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
         { &hf_lltd_host_id, { "Host ID", "lltd.host_id", FT_ETHER, BASE_NONE, NULL, 0, NULL, HFILL }},
-        { &hf_lltd_char_p, {"Public NAT", "lltd.characteristic.public_nat", FT_BOOLEAN, 32, TFS(&tfs_true_false), LLTD_CHARACTERISTIC_P_MASK, NULL, HFILL }},
-        { &hf_lltd_char_x, {"Private NAT", "lltd.characteristic.private_nat", FT_BOOLEAN, 32, TFS(&tfs_true_false), LLTD_CHARACTERISTIC_X_MASK, NULL, HFILL }},
+        { &hf_lltd_char_p, {"Public NAT", "lltd.characteristic.public_nat", FT_BOOLEAN, 32, NULL, LLTD_CHARACTERISTIC_P_MASK, NULL, HFILL }},
+        { &hf_lltd_char_x, {"Private NAT", "lltd.characteristic.private_nat", FT_BOOLEAN, 32, NULL, LLTD_CHARACTERISTIC_X_MASK, NULL, HFILL }},
         { &hf_lltd_char_f, {"Duplex", "lltd.characteristic.duplex", FT_BOOLEAN, 32, TFS(&tfs_full_half_duplex), LLTD_CHARACTERISTIC_F_MASK, NULL, HFILL }},
         { &hf_lltd_char_m, {"Management Web Page", "lltd.characteristic.web_page", FT_BOOLEAN, 32, TFS(&tfs_present_absent), LLTD_CHARACTERISTIC_M_MASK, NULL, HFILL }},
-        { &hf_lltd_char_l, {"Looping Outbound Packets", "lltd.characteristic.loop", FT_BOOLEAN, 32, TFS(&tfs_true_false), LLTD_CHARACTERISTIC_L_MASK, NULL, HFILL }},
+        { &hf_lltd_char_l, {"Looping Outbound Packets", "lltd.characteristic.loop", FT_BOOLEAN, 32, NULL, LLTD_CHARACTERISTIC_L_MASK, NULL, HFILL }},
         { &hf_lltd_char_reserved, {"Reserved", "lltd.characteristic.reserved", FT_UINT32, BASE_HEX, NULL, LLTD_CHARACTERISTIC_RESERVE_MASK, NULL, HFILL }},
         { &hf_lltd_physical_medium, {"Physical Medium", "lltd.physical_medium", FT_UINT32, BASE_DEC, NULL, 0, NULL, HFILL }},
         { &hf_lltd_wireless_mode, {"Wireless Mode", "lltd.wireless_mode", FT_UINT8, BASE_HEX, VALS(lltd_wireless_mode_vals), 0, NULL, HFILL }},
@@ -845,7 +845,7 @@ proto_register_lltd(void)
         { &hf_lltd_machine_name, { "Machine Name", "lltd.machine_name", FT_STRING /*FT_UCS2_LE */, BASE_NONE, NULL, 0, NULL, HFILL }},
         { &hf_lltd_support_info, { "Support Information", "lltd.support_info", FT_STRING /*FT_UCS2_LE */, BASE_NONE, NULL, 0, NULL, HFILL }},
         { &hf_lltd_device_uuid, { "Device UUID", "lltd.device_uuid", FT_GUID, BASE_NONE, NULL, 0, NULL, HFILL }},
-        { &hf_lltd_qos_char_e, {"Layer 2 Forwarding", "lltd.qos_characteristic.layer2_forwarding", FT_BOOLEAN, 32, TFS(&tfs_true_false), LLTD_QOS_CHARACTERISTIC_E_MASK, NULL, HFILL }},
+        { &hf_lltd_qos_char_e, {"Layer 2 Forwarding", "lltd.qos_characteristic.layer2_forwarding", FT_BOOLEAN, 32, NULL, LLTD_QOS_CHARACTERISTIC_E_MASK, NULL, HFILL }},
         { &hf_lltd_qos_char_q, {"802.1q VLAN", "lltd.qos_characteristic.vlan", FT_BOOLEAN, 32, TFS(&tfs_supported_not_supported), LLTD_QOS_CHARACTERISTIC_Q_MASK, NULL, HFILL }},
         { &hf_lltd_qos_char_p, {"802.1q Priority Tagging", "lltd.qos_characteristic.tagging", FT_BOOLEAN, 32, TFS(&tfs_supported_not_supported), LLTD_QOS_CHARACTERISTIC_P_MASK, NULL, HFILL }},
         { &hf_lltd_qos_char_reserved, {"Reserved", "lltd.qos_characteristic.reserved", FT_UINT32, BASE_HEX, NULL, LLTD_QOS_CHARACTERISTIC_RESERVE_MASK, NULL, HFILL }},
@@ -857,8 +857,8 @@ proto_register_lltd(void)
         { &hf_lltd_emit_pause, {"Pause (ms)", "lltd.emit.pause", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
         { &hf_lltd_emit_src_addr, { "Source Address", "lltd.emit.src_addr", FT_ETHER, BASE_NONE, NULL, 0, NULL, HFILL }},
         { &hf_lltd_emit_dest_addr, { "Destination Address", "lltd.emit.dest_addr", FT_ETHER, BASE_NONE, NULL, 0, NULL, HFILL }},
-        { &hf_lltd_queryresp_more_descs, {"More RecveeDescs", "lltd.queryresp.more", FT_BOOLEAN, 16, TFS(&tfs_true_false), LLTD_QUERY_RESP_M_MASK, NULL, HFILL }},
-        { &hf_lltd_queryresp_memory_descs, {"No memory left", "lltd.queryresp.memory", FT_BOOLEAN, 16, TFS(&tfs_true_false), LLTD_QUERY_RESP_E_MASK, NULL, HFILL }},
+        { &hf_lltd_queryresp_more_descs, {"More RecveeDescs", "lltd.queryresp.more", FT_BOOLEAN, 16, NULL, LLTD_QUERY_RESP_M_MASK, NULL, HFILL }},
+        { &hf_lltd_queryresp_memory_descs, {"No memory left", "lltd.queryresp.memory", FT_BOOLEAN, 16, NULL, LLTD_QUERY_RESP_E_MASK, NULL, HFILL }},
         { &hf_lltd_queryresp_num_descs, {"Number of RecveeDescs", "lltd.queryresp.num_descs", FT_UINT16, BASE_DEC, NULL, LLTD_QUERY_RESP_NUM_DESCS_MASK, NULL, HFILL }},
         { &hf_lltd_queryresp_type, {"Type", "lltd.queryresp.type", FT_UINT16, BASE_HEX, VALS(lltd_queryresp_type_vals), 0, NULL, HFILL }},
         { &hf_lltd_queryresp_real_src_addr, { "Real Source Address", "lltd.queryresp.real_src_addr", FT_ETHER, BASE_NONE, NULL, 0, NULL, HFILL }},
@@ -868,8 +868,8 @@ proto_register_lltd(void)
         { &hf_lltd_flat_crc_packets, {"Current Transmit Credit (packets)", "lltd.flat.crc_packets", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
         { &hf_lltd_query_large_tlv_type, {"Type", "lltd.query_large_tlv.type", FT_UINT8, BASE_HEX, VALS(lltd_query_large_tlv_type_vals), 0, NULL, HFILL }},
         { &hf_lltd_query_large_tlv_offset, {"Offset", "lltd.query_large_tlv.offset", FT_UINT24, BASE_DEC, NULL, 0, NULL, HFILL }},
-        { &hf_lltd_querylargeresp_more_descs, {"More RecveeDescs", "lltd.querylargeresp.more", FT_BOOLEAN, 16, TFS(&tfs_true_false), LLTD_QUERY_RESP_M_MASK, NULL, HFILL }},
-        { &hf_lltd_querylargeresp_memory_descs, {"No memory left", "lltd.querylargeresp.memory", FT_BOOLEAN, 16, TFS(&tfs_true_false), LLTD_QUERY_RESP_E_MASK, NULL, HFILL }},
+        { &hf_lltd_querylargeresp_more_descs, {"More RecveeDescs", "lltd.querylargeresp.more", FT_BOOLEAN, 16, NULL, LLTD_QUERY_RESP_M_MASK, NULL, HFILL }},
+        { &hf_lltd_querylargeresp_memory_descs, {"No memory left", "lltd.querylargeresp.memory", FT_BOOLEAN, 16, NULL, LLTD_QUERY_RESP_E_MASK, NULL, HFILL }},
         { &hf_lltd_querylargeresp_num_descs, {"Number of RecveeDescs", "lltd.querylargeresp.num_descs", FT_UINT16, BASE_DEC, NULL, LLTD_QUERY_RESP_NUM_DESCS_MASK, NULL, HFILL }},
         { &hf_lltd_querylargeresp_data, { "Data", "lltd.querylargeresp.data", FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL }},
 
@@ -890,8 +890,8 @@ proto_register_lltd(void)
         { &hf_lltd_qos_probe_payload, {"Payload", "lltd.qos_probe.payload", FT_BYTES, BASE_NONE, NULL, 0, NULL, HFILL }},
         { &hf_lltd_qos_error_value, {"Error Code", "lltd.qos_error", FT_UINT16, BASE_DEC, VALS(lltd_qos_error_vals), 0, NULL, HFILL }},
         { &hf_lltd_qos_count_snapshot_history, {"History Size", "lltd.qos_count_snapshot.history", FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL }},
-        { &hf_lltd_qos_query_resp_r, {"Receipt", "lltd.qos_query_resp.receipt", FT_BOOLEAN, 16, TFS(&tfs_true_false), LLTD_QUERY_RESP_M_MASK, NULL, HFILL }},
-        { &hf_lltd_qos_query_resp_e, {"No memory left", "lltd.qos_query_resp.memory", FT_BOOLEAN, 16, TFS(&tfs_true_false), LLTD_QUERY_RESP_E_MASK, NULL, HFILL }},
+        { &hf_lltd_qos_query_resp_r, {"Receipt", "lltd.qos_query_resp.receipt", FT_BOOLEAN, 16, NULL, LLTD_QUERY_RESP_M_MASK, NULL, HFILL }},
+        { &hf_lltd_qos_query_resp_e, {"No memory left", "lltd.qos_query_resp.memory", FT_BOOLEAN, 16, NULL, LLTD_QUERY_RESP_E_MASK, NULL, HFILL }},
         { &hf_lltd_qos_query_resp_num_events, {"Number of Events", "lltd.qos_query_resp.num_events", FT_UINT16, BASE_DEC, NULL, LLTD_QUERY_RESP_NUM_DESCS_MASK, NULL, HFILL }},
         { &hf_lltd_qos_query_resp_controller_timestamp, {"Controller Transmit Timestamp", "lltd.qos_query_resp.controller_timestamp", FT_UINT64, BASE_DEC, NULL, 0, NULL, HFILL }},
         { &hf_lltd_qos_query_resp_sink_timestamp, {"Sink Receive Timestamp", "lltd.qos_query_resp.sink_timestamp", FT_UINT64, BASE_DEC, NULL, 0, NULL, HFILL }},
