@@ -16,7 +16,7 @@
 #include <epan/packet.h>
 #include <epan/prefs.h>
 #include <epan/proto_data.h>
-
+#include <wiretap/wtap.h>
 #include <wsutil/strtoi.h>
 
 #include "packet-mac-lte.h"
@@ -30,18 +30,18 @@ void proto_register_log3gpp(void);
 void proto_reg_handoff_log3gpp(void);
 
 /* Protocol and registered fields. */
-static int proto_log3gpp = -1;
+static int proto_log3gpp;
 
 
-static int hf_log3gpp_timestamp = -1;
-static int hf_log3gpp_protocol = -1;
-static int hf_log3gpp_direction = -1;
-static int hf_log3gpp_dissector_option = -1;
-static int hf_log3gpp_unparsed_data = -1;
-static int hf_log3gpp_dissected_length = -1;
+static int hf_log3gpp_timestamp;
+static int hf_log3gpp_protocol;
+static int hf_log3gpp_direction;
+static int hf_log3gpp_dissector_option;
+static int hf_log3gpp_unparsed_data;
+static int hf_log3gpp_dissected_length;
 
 /* Protocol subtree. */
-static int ett_log3gpp = -1;
+static int ett_log3gpp;
 
 /* Variables used to select a version for RRC and NAS */
 static int lte_rrc_prot_version = REL8;
@@ -176,8 +176,8 @@ look_for_dissector(char* protocol_name, packet_direction_t direction, pseudo_hdr
 
     element_ptr = (lookup_dissector_element_t*)bsearch((void*)protocol_name,
         (void*)dissector_lookup_table,
-        sizeof(dissector_lookup_table) / sizeof(lookup_dissector_element_t),
-        sizeof(lookup_dissector_element_t),
+        array_length(dissector_lookup_table),
+        sizeof dissector_lookup_table[0],
         dissector_element_compare);
     if (element_ptr != NULL) {
         if (direction == UPLINK)
@@ -209,8 +209,8 @@ update_dissector_name(const char* protocol_name, packet_direction_t direction, c
 
     element_ptr = (lookup_dissector_element_t*)bsearch((void*)protocol_name,
         (void*)dissector_lookup_table,
-        sizeof(dissector_lookup_table) / sizeof(lookup_dissector_element_t),
-        sizeof(lookup_dissector_element_t),
+        array_length(dissector_lookup_table),
+        sizeof dissector_lookup_table[0],
         dissector_element_compare);
     if (element_ptr != NULL) {
         if (direction == UPLINK)
@@ -452,7 +452,7 @@ lte_rlc_pseudo_hdr(char* option_str, packet_info* pinfo, guint16 length, packet_
     /* Store info in packet */
     p_add_proto_data(wmem_file_scope(), pinfo, proto_rlc_lte, 0, p_rlc_lte_info);
 
-    return (1);
+    return 1;
 }
 
 /* In the optional string, PDCP info should be set as follow (M = mandatory, O = optional):
@@ -526,7 +526,7 @@ lte_pdcp_pseudo_hdr(char* option_str, packet_info* pinfo, guint16 length _U_, pa
     /* Store info in packet */
     p_add_proto_data(wmem_file_scope(), pinfo, proto_pdcp_lte, 0, p_pdcp_lte_info);
 
-    return (1);
+    return 1;
 }
 
 
@@ -557,7 +557,7 @@ dissect_log3gpp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, void* data
     col_clear(pinfo->cinfo, COL_INFO);
 
     /* Create root (protocol) tree. */
-    ti = proto_tree_add_item(tree, proto_log3gpp, tvb, offset, -1, FALSE);
+    ti = proto_tree_add_item(tree, proto_log3gpp, tvb, offset, -1, ENC_NA);
     prot3gpp_tree = proto_item_add_subtree(ti, ett_log3gpp);
 
     /*********************************************************************/
@@ -679,7 +679,7 @@ dissect_log3gpp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, void* data
         proto_item* ti_local = proto_tree_add_uint(prot3gpp_tree,
             hf_log3gpp_dissected_length,
             tvb, 0, 0, tvb_reported_length(tvb) - offset);
-        PROTO_ITEM_SET_GENERATED(ti_local);
+        proto_item_set_generated(ti_local);
     }
     return tvb_reported_length(tvb);
 }
