@@ -22,19 +22,19 @@
 
 extern const value_string priority_vals[];
 
-static int proto_logcat_text = -1;
+static int proto_logcat_text;
 
-static int hf_logcat_text_pid = -1;
-static int hf_logcat_text_tid = -1;
-static int hf_logcat_text_timestamp = -1;
-static int hf_logcat_text_priority = -1;
-static int hf_logcat_text_tag = -1;
-static int hf_logcat_text_log = -1;
+static int hf_logcat_text_pid;
+static int hf_logcat_text_tid;
+static int hf_logcat_text_timestamp;
+static int hf_logcat_text_priority;
+static int hf_logcat_text_tag;
+static int hf_logcat_text_log;
 
-static gint ett_logcat = -1;
+static gint ett_logcat;
 
-static expert_field ei_malformed_time = EI_INIT;
-static expert_field ei_malformed_token = EI_INIT;
+static expert_field ei_malformed_time;
+static expert_field ei_malformed_token;
 
 static dissector_handle_t logcat_text_brief_handle;
 static dissector_handle_t logcat_text_tag_handle;
@@ -46,14 +46,14 @@ static dissector_handle_t logcat_text_long_handle;
 
 static gint exported_pdu_tap = -1;
 
-static GRegex *special_regex = NULL;
-static GRegex *brief_regex = NULL;
-static GRegex *tag_regex = NULL;
-static GRegex *time_regex = NULL;
-static GRegex *process_regex = NULL;
-static GRegex *thread_regex = NULL;
-static GRegex *threadtime_regex = NULL;
-static GRegex *long_regex = NULL;
+static GRegex *special_regex;
+static GRegex *brief_regex;
+static GRegex *tag_regex;
+static GRegex *time_regex;
+static GRegex *process_regex;
+static GRegex *thread_regex;
+static GRegex *threadtime_regex;
+static GRegex *long_regex;
 
 static const gchar dissector_name[] = "Logcat Text";
 
@@ -70,16 +70,11 @@ void proto_register_logcat_text(void);
 void proto_reg_handoff_logcat_text(void);
 
 static int get_priority(const gchar *frame, const gchar *token, tvbuff_t *tvb,
-        proto_tree *maintree, gint start_offset, packet_info *pinfo) {
+        proto_tree *maintree, gint start_offset, packet_info *pinfo _U_) {
     int prio;
     gchar *p = g_strstr_len(frame + start_offset, -1, token);
     int offset = (int)(p - frame);
 
-    if (!p) {
-        proto_tree_add_expert(maintree, pinfo, &ei_malformed_token, tvb, start_offset, -1);
-        return (start_offset + 1);
-    }
-
     switch (*p) {
     case 'I':
         prio = 4;
