@@ -26,107 +26,107 @@ void proto_register_lorawan(void);
 
 static dissector_handle_t lorawan_handle;
 
-static int proto_lorawan = -1;
-static int hf_lorawan_msgtype_type = -1;
-static int hf_lorawan_mac_header_type = -1;
-static int hf_lorawan_mac_header_ftype_type = -1;
-static int hf_lorawan_mac_header_rfu_type = -1;
-static int hf_lorawan_mac_header_major_type = -1;
-static int hf_lorawan_mac_commands_type = -1;
-static int hf_lorawan_mac_command_uplink_type = -1;
-static int hf_lorawan_mac_command_downlink_type = -1;
-static int hf_lorawan_mac_command_down_link_check_ans_type = -1;
-static int hf_lorawan_mac_command_down_link_check_ans_margin_type = -1;
-static int hf_lorawan_mac_command_down_link_check_ans_gwcnt_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_datarate_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_txpower_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel1_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel2_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel3_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel4_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel5_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel6_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel7_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel8_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel9_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel10_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel11_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel12_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel13_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel14_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel15_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel16_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_channel_mask_control_type = -1;
-static int hf_lorawan_mac_command_down_link_adr_req_repetitions_type = -1;
-static int hf_lorawan_mac_command_up_link_adr_ans_txpower_type = -1;
-static int hf_lorawan_mac_command_up_link_adr_ans_datarate_type = -1;
-static int hf_lorawan_mac_command_up_link_adr_ans_channel_mask_type = -1;
-static int hf_lorawan_mac_command_down_dutycycle_type = -1;
-static int hf_lorawan_mac_command_down_rx_setup_req_rx1droffset_type = -1;
-static int hf_lorawan_mac_command_down_rx_setup_req_rx2datarate_type = -1;
-static int hf_lorawan_mac_command_down_rx_setup_req_frequency_type = -1;
-static int hf_lorawan_mac_command_up_rx_setup_ans_type = -1;
-static int hf_lorawan_mac_command_up_rx_setup_ans_rx1droffset_type = -1;
-static int hf_lorawan_mac_command_up_rx_setup_ans_rx2datarate_type = -1;
-static int hf_lorawan_mac_command_up_rx_setup_ans_frequency_type = -1;
-static int hf_lorawan_mac_command_up_device_status_ans_battery_type = -1;
-static int hf_lorawan_mac_command_up_device_status_ans_margin_type = -1;
-static int hf_lorawan_mac_command_down_new_channel_req_index_type = -1;
-static int hf_lorawan_mac_command_down_new_channel_req_frequency_type = -1;
-static int hf_lorawan_mac_command_down_new_channel_req_drrange_max_type = -1;
-static int hf_lorawan_mac_command_down_new_channel_req_drrange_min_type = -1;
-static int hf_lorawan_mac_command_up_new_channel_ans_type = -1;
-static int hf_lorawan_mac_command_up_new_channel_ans_datarate_type = -1;
-static int hf_lorawan_mac_command_up_new_channel_ans_frequency_type = -1;
-static int hf_lorawan_mac_command_down_rx_timing_req_delay_type = -1;
-static int hf_lorawan_mac_command_up_di_channel_ans_type = -1;
-static int hf_lorawan_mac_command_up_ping_slot_info_req_type = -1;
-static int hf_lorawan_mac_command_up_ping_slot_channel_ans_type = -1;
-static int hf_lorawan_mac_command_up_beacon_freq_ans_type = -1;
-static int hf_lorawan_mac_command_down_tx_param_setup_req_type = -1;
-static int hf_lorawan_mac_command_down_di_channel_req_type = -1;
-static int hf_lorawan_mac_command_down_device_time_ans_type = -1;
-static int hf_lorawan_mac_command_down_ping_slot_channel_req_type = -1;
-static int hf_lorawan_mac_command_down_beacon_freq_req_type = -1;
-static int hf_lorawan_join_request_type = -1;
-static int hf_lorawan_join_request_joineui_type = -1;
-static int hf_lorawan_join_request_deveui_type = -1;
-static int hf_lorawan_join_request_devnonce_type = -1;
-static int hf_lorawan_join_accept_type = -1;
-static int hf_lorawan_join_accept_joinnonce_type = -1;
-static int hf_lorawan_join_accept_netid_type = -1;
-static int hf_lorawan_join_accept_devaddr_type = -1;
-static int hf_lorawan_join_accept_dlsettings_type = -1;
-static int hf_lorawan_join_accept_dlsettings_rx1droffset_type = -1;
-static int hf_lorawan_join_accept_dlsettings_rx2dr_type = -1;
-static int hf_lorawan_join_accept_rxdelay_type = -1;
-static int hf_lorawan_join_accept_cflist_type = -1;
-static int hf_lorawan_frame_header_type = -1;
-static int hf_lorawan_frame_header_address_type = -1;
-static int hf_lorawan_frame_header_frame_control_adr_type = -1;
-static int hf_lorawan_frame_header_frame_control_adrackreq_type = -1;
-static int hf_lorawan_frame_header_frame_control_ack_type = -1;
-static int hf_lorawan_frame_header_frame_control_fpending_type = -1;
-static int hf_lorawan_frame_header_frame_control_foptslen_type = -1;
-static int hf_lorawan_frame_header_frame_control_type = -1;
-static int hf_lorawan_frame_header_frame_counter_type = -1;
-static int hf_lorawan_frame_fport_type = -1;
-static int hf_lorawan_frame_payload_type = -1;
-static int hf_lorawan_frame_payload_decrypted_type = -1;
-static int hf_lorawan_mic_type = -1;
-static int hf_lorawan_mic_status_type = -1;
-static int hf_lorawan_beacon_rfu1_type = -1;
-static int hf_lorawan_beacon_time_type = -1;
-static int hf_lorawan_beacon_crc1_type = -1;
-static int hf_lorawan_beacon_crc1_status_type = -1;
-static int hf_lorawan_beacon_gwspecific_type = -1;
-static int hf_lorawan_beacon_gwspecific_infodesc_type = -1;
-static int hf_lorawan_beacon_gwspecific_lat_type = -1;
-static int hf_lorawan_beacon_gwspecific_lng_type = -1;
-static int hf_lorawan_beacon_rfu2_type = -1;
-static int hf_lorawan_beacon_crc2_type = -1;
-static int hf_lorawan_beacon_crc2_status_type = -1;
+static int proto_lorawan;
+static int hf_lorawan_msgtype_type;
+static int hf_lorawan_mac_header_type;
+static int hf_lorawan_mac_header_ftype_type;
+static int hf_lorawan_mac_header_rfu_type;
+static int hf_lorawan_mac_header_major_type;
+static int hf_lorawan_mac_commands_type;
+static int hf_lorawan_mac_command_uplink_type;
+static int hf_lorawan_mac_command_downlink_type;
+static int hf_lorawan_mac_command_down_link_check_ans_type;
+static int hf_lorawan_mac_command_down_link_check_ans_margin_type;
+static int hf_lorawan_mac_command_down_link_check_ans_gwcnt_type;
+static int hf_lorawan_mac_command_down_link_adr_req_datarate_type;
+static int hf_lorawan_mac_command_down_link_adr_req_txpower_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel1_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel2_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel3_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel4_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel5_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel6_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel7_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel8_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel9_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel10_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel11_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel12_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel13_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel14_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel15_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel16_type;
+static int hf_lorawan_mac_command_down_link_adr_req_channel_mask_control_type;
+static int hf_lorawan_mac_command_down_link_adr_req_repetitions_type;
+static int hf_lorawan_mac_command_up_link_adr_ans_txpower_type;
+static int hf_lorawan_mac_command_up_link_adr_ans_datarate_type;
+static int hf_lorawan_mac_command_up_link_adr_ans_channel_mask_type;
+static int hf_lorawan_mac_command_down_dutycycle_type;
+static int hf_lorawan_mac_command_down_rx_setup_req_rx1droffset_type;
+static int hf_lorawan_mac_command_down_rx_setup_req_rx2datarate_type;
+static int hf_lorawan_mac_command_down_rx_setup_req_frequency_type;
+static int hf_lorawan_mac_command_up_rx_setup_ans_type;
+static int hf_lorawan_mac_command_up_rx_setup_ans_rx1droffset_type;
+static int hf_lorawan_mac_command_up_rx_setup_ans_rx2datarate_type;
+static int hf_lorawan_mac_command_up_rx_setup_ans_frequency_type;
+static int hf_lorawan_mac_command_up_device_status_ans_battery_type;
+static int hf_lorawan_mac_command_up_device_status_ans_margin_type;
+static int hf_lorawan_mac_command_down_new_channel_req_index_type;
+static int hf_lorawan_mac_command_down_new_channel_req_frequency_type;
+static int hf_lorawan_mac_command_down_new_channel_req_drrange_max_type;
+static int hf_lorawan_mac_command_down_new_channel_req_drrange_min_type;
+static int hf_lorawan_mac_command_up_new_channel_ans_type;
+static int hf_lorawan_mac_command_up_new_channel_ans_datarate_type;
+static int hf_lorawan_mac_command_up_new_channel_ans_frequency_type;
+static int hf_lorawan_mac_command_down_rx_timing_req_delay_type;
+static int hf_lorawan_mac_command_up_di_channel_ans_type;
+static int hf_lorawan_mac_command_up_ping_slot_info_req_type;
+static int hf_lorawan_mac_command_up_ping_slot_channel_ans_type;
+static int hf_lorawan_mac_command_up_beacon_freq_ans_type;
+static int hf_lorawan_mac_command_down_tx_param_setup_req_type;
+static int hf_lorawan_mac_command_down_di_channel_req_type;
+static int hf_lorawan_mac_command_down_device_time_ans_type;
+static int hf_lorawan_mac_command_down_ping_slot_channel_req_type;
+static int hf_lorawan_mac_command_down_beacon_freq_req_type;
+static int hf_lorawan_join_request_type;
+static int hf_lorawan_join_request_joineui_type;
+static int hf_lorawan_join_request_deveui_type;
+static int hf_lorawan_join_request_devnonce_type;
+static int hf_lorawan_join_accept_type;
+static int hf_lorawan_join_accept_joinnonce_type;
+static int hf_lorawan_join_accept_netid_type;
+static int hf_lorawan_join_accept_devaddr_type;
+static int hf_lorawan_join_accept_dlsettings_type;
+static int hf_lorawan_join_accept_dlsettings_rx1droffset_type;
+static int hf_lorawan_join_accept_dlsettings_rx2dr_type;
+static int hf_lorawan_join_accept_rxdelay_type;
+static int hf_lorawan_join_accept_cflist_type;
+static int hf_lorawan_frame_header_type;
+static int hf_lorawan_frame_header_address_type;
+static int hf_lorawan_frame_header_frame_control_adr_type;
+static int hf_lorawan_frame_header_frame_control_adrackreq_type;
+static int hf_lorawan_frame_header_frame_control_ack_type;
+static int hf_lorawan_frame_header_frame_control_fpending_type;
+static int hf_lorawan_frame_header_frame_control_foptslen_type;
+static int hf_lorawan_frame_header_frame_control_type;
+static int hf_lorawan_frame_header_frame_counter_type;
+static int hf_lorawan_frame_fport_type;
+static int hf_lorawan_frame_payload_type;
+static int hf_lorawan_frame_payload_decrypted_type;
+static int hf_lorawan_mic_type;
+static int hf_lorawan_mic_status_type;
+static int hf_lorawan_beacon_rfu1_type;
+static int hf_lorawan_beacon_time_type;
+static int hf_lorawan_beacon_crc1_type;
+static int hf_lorawan_beacon_crc1_status_type;
+static int hf_lorawan_beacon_gwspecific_type;
+static int hf_lorawan_beacon_gwspecific_infodesc_type;
+static int hf_lorawan_beacon_gwspecific_lat_type;
+static int hf_lorawan_beacon_gwspecific_lng_type;
+static int hf_lorawan_beacon_rfu2_type;
+static int hf_lorawan_beacon_crc2_type;
+static int hf_lorawan_beacon_crc2_status_type;
 
 static int * const hfx_lorawan_mac_command_link_check_ans[] = {
 	&hf_lorawan_mac_command_up_link_adr_ans_txpower_type,
@@ -180,22 +180,22 @@ static int * const hfx_lorawan_join_accept_dlsettings[] = {
 	NULL
 };
 
-static gint ett_lorawan = -1;
-static gint ett_lorawan_mac_header = -1;
-static gint ett_lorawan_mac_commands = -1;
-static gint ett_lorawan_mac_command = -1;
-static gint ett_lorawan_mac_command_link_check_ans = -1;
-static gint ett_lorawan_mac_command_link_adr_req_channel = -1;
-static gint ett_lorawan_mac_command_rx_setup_ans = -1;
-static gint ett_lorawan_mac_command_new_channel_ans = -1;
-static gint ett_lorawan_join_request = -1;
-static gint ett_lorawan_join_accept = -1;
-static gint ett_lorawan_join_accept_dlsettings = -1;
-static gint ett_lorawan_frame_header = -1;
-static gint ett_lorawan_frame_header_control = -1;
-static gint ett_lorawan_frame_payload_decrypted = -1;
-static gint ett_lorawan_beacon = -1;
-static gint ett_lorawan_beacon_gwspecific = -1;
+static gint ett_lorawan;
+static gint ett_lorawan_mac_header;
+static gint ett_lorawan_mac_commands;
+static gint ett_lorawan_mac_command;
+static gint ett_lorawan_mac_command_link_check_ans;
+static gint ett_lorawan_mac_command_link_adr_req_channel;
+static gint ett_lorawan_mac_command_rx_setup_ans;
+static gint ett_lorawan_mac_command_new_channel_ans;
+static gint ett_lorawan_join_request;
+static gint ett_lorawan_join_accept;
+static gint ett_lorawan_join_accept_dlsettings;
+static gint ett_lorawan_frame_header;
+static gint ett_lorawan_frame_header_control;
+static gint ett_lorawan_frame_payload_decrypted;
+static gint ett_lorawan_beacon;
+static gint ett_lorawan_beacon_gwspecific;
 
 #define LORAWAN_MAC_FTYPE_MASK						0xE0
 #define LORAWAN_MAC_FTYPE(ftype)					(((ftype) & LORAWAN_MAC_FTYPE_MASK) >> 5)
@@ -290,11 +290,11 @@ static gint ett_lorawan_beacon_gwspecific = -1;
 #define LORAWAN_AES_BLOCK_LENGTH					16
 #define LORAWAN_AES_PADDEDSIZE(length)					(LORAWAN_AES_BLOCK_LENGTH * ((length + LORAWAN_AES_BLOCK_LENGTH - 1) / LORAWAN_AES_BLOCK_LENGTH))
 
-static expert_field ei_lorawan_missing_keys = EI_INIT;
-static expert_field ei_lorawan_decrypting_error = EI_INIT;
-static expert_field ei_lorawan_mic = EI_INIT;
-static expert_field ei_lorawan_length_error = EI_INIT;
-static expert_field ei_lorawan_mhdr_error = EI_INIT;
+static expert_field ei_lorawan_missing_keys;
+static expert_field ei_lorawan_decrypting_error;
+static expert_field ei_lorawan_mic;
+static expert_field ei_lorawan_length_error;
+static expert_field ei_lorawan_mhdr_error;
 
 static const value_string lorawan_ftypenames[] = {
 	{ LORAWAN_MAC_FTYPE_JOINREQUEST,		"Join Request" },
@@ -305,6 +305,8 @@ static const value_string lorawan_ftypenames[] = {
 	{ LORAWAN_MAC_FTYPE_CONFIRMEDDATADOWN,		"Confirmed Data Down" },
 	{ LORAWAN_MAC_FTYPE_RFU,			"RFU" },
 	{ LORAWAN_MAC_FTYPE_PROPRIETARY,		"Proprietary" },
+	// TODO: having this here makes no sense.
+	//  It's value doesn't fit into 3 bits, and is only ever looked up with a hardcoded key...
 	{ LORAWAN_MAC_BEACON, 				"Class-B Beacon" },
 	{ 0, NULL }
 };
@@ -367,10 +369,10 @@ typedef struct _session_keys_t {
 	GByteArray	*appskey;
 } session_key_t;
 
-static root_key_t *root_keys = NULL;
-static session_key_t *session_keys = NULL;
-static guint root_num_keys = 0;
-static guint session_num_keys = 0;
+static root_key_t *root_keys;
+static session_key_t *session_keys;
+static guint root_num_keys;
+static guint session_num_keys;
 
 static void
 byte_array_reverse(GByteArray *arr)
