@@ -24,16 +24,16 @@ void proto_reg_handoff_lsd(void);
 #define LSD_MULTICAST_ADDRESS 0xEFC0988F /* 239.192.152.143 */
 #define LSD_PORT 6771
 
-static int proto_lsd = -1;
-static int hf_lsd_header = -1;
-static int hf_lsd_host = -1;
-static int hf_lsd_port = -1;
-static int hf_lsd_infohash = -1;
-static int hf_lsd_cookie = -1;
+static int proto_lsd;
+static int hf_lsd_header;
+static int hf_lsd_host;
+static int hf_lsd_port;
+static int hf_lsd_infohash;
+static int hf_lsd_cookie;
 
-static gint ett_lsd = -1;
+static gint ett_lsd;
 
-static expert_field ei_lsd_field = EI_INIT;
+static expert_field ei_lsd_field;
 
 static gboolean
 parse_string_field(proto_tree *tree, int hf, packet_info *pinfo, tvbuff_t *tvb, int offset, int* next_offset, int* linelen)
@@ -124,7 +124,7 @@ dissect_lsd(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
   linelen = tvb_find_line_end(tvb, offset, -1, &next_offset, FALSE);
   if (linelen < 0)
       return offset+linelen;
-  /* Cookie is optionnal */
+  /* Cookie is optional */
   if (tvb_strncaseeql(tvb, offset, "cookie", strlen("cookie")) == 0)
   {
     if (!parse_string_field(lsd_tree, hf_lsd_cookie, pinfo, tvb, offset, &next_offset, &linelen))
@@ -134,8 +134,8 @@ dissect_lsd(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
   return tvb_captured_length(tvb);
 }
 
-static gboolean
-dissect_lsd_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool
+dissect_lsd_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
   if (pinfo->dst.type == AT_IPv4 && pntoh32(pinfo->dst.data) == LSD_MULTICAST_ADDRESS && pinfo->destport == LSD_PORT)
       return (dissect_lsd(tvb, pinfo, tree, data) != 0);
@@ -143,7 +143,7 @@ dissect_lsd_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data
   if (pinfo->dst.type == AT_IPv6 && pinfo->destport == LSD_PORT)
       return (dissect_lsd(tvb, pinfo, tree, data) != 0);
 
-  return FALSE;
+  return false;
 }
 
 void
