@@ -84,7 +84,7 @@ void proto_register_lwm(void);
 void proto_reg_handoff_lwm(void);
 
 /* User string with the decryption key. */
-static const gchar *lwmes_key_str = NULL;
+static const gchar *lwmes_key_str;
 static gboolean     lwmes_key_valid;
 static guint8       lwmes_key[16];
 
@@ -96,46 +96,46 @@ static int  dissect_lwm_cmd_frame_route_req   (tvbuff_t *, packet_info *, proto_
 static int  dissect_lwm_cmd_frame_route_reply (tvbuff_t *, packet_info *, proto_tree *);
 
 /*  Initialize protocol and registered fields. */
-static int proto_lwm = -1;
+static int proto_lwm;
 
-static int hf_lwm_fcf = -1;
-static int hf_lwm_fcf_ack_req = -1;
-static int hf_lwm_fcf_security = -1;
-static int hf_lwm_fcf_linklocal = -1;
-static int hf_lwm_fcf_multicast = -1;
-static int hf_lwm_fcf_reserved = -1;
-static int hf_lwm_seq = -1;
-static int hf_lwm_src_addr = -1;
-static int hf_lwm_dst_addr = -1;
-static int hf_lwm_src_endp = -1;
-static int hf_lwm_dst_endp = -1;
-static int hf_lwm_multi_nmrad = -1;
-static int hf_lwm_multi_mnmrad = -1;
-static int hf_lwm_multi_mrad = -1;
-static int hf_lwm_multi_mmrad = -1;
-static int hf_lwm_mic = -1;
-static int hf_lwm_cmd = -1;
-static int hf_lwm_cmd_seq = -1;
-static int hf_lwm_cmd_cm = -1;
-static int hf_lwm_cmd_route_src  = -1;
-static int hf_lwm_cmd_route_dst  = -1;
-static int hf_lwm_cmd_route_multi  = -1;
-static int hf_lwm_cmd_linkquality  = -1;
-static int hf_lwm_cmd_forwlinkquality  = -1;
-static int hf_lwm_cmd_revlinkquality  = -1;
+static int hf_lwm_fcf;
+static int hf_lwm_fcf_ack_req;
+static int hf_lwm_fcf_security;
+static int hf_lwm_fcf_linklocal;
+static int hf_lwm_fcf_multicast;
+static int hf_lwm_fcf_reserved;
+static int hf_lwm_seq;
+static int hf_lwm_src_addr;
+static int hf_lwm_dst_addr;
+static int hf_lwm_src_endp;
+static int hf_lwm_dst_endp;
+static int hf_lwm_multi_nmrad;
+static int hf_lwm_multi_mnmrad;
+static int hf_lwm_multi_mrad;
+static int hf_lwm_multi_mmrad;
+static int hf_lwm_mic;
+static int hf_lwm_cmd;
+static int hf_lwm_cmd_seq;
+static int hf_lwm_cmd_cm;
+static int hf_lwm_cmd_route_src;
+static int hf_lwm_cmd_route_dst;
+static int hf_lwm_cmd_route_multi;
+static int hf_lwm_cmd_linkquality;
+static int hf_lwm_cmd_forwlinkquality;
+static int hf_lwm_cmd_revlinkquality;
 
 /* Initialize protocol subtrees. */
-static gint ett_lwm = -1;
-static gint ett_lwm_fcf = -1;
-static gint ett_lwm_cmd_tree = -1;
-static gint ett_lwm_multi_tree = -1;
+static gint ett_lwm;
+static gint ett_lwm_fcf;
+static gint ett_lwm_cmd_tree;
+static gint ett_lwm_multi_tree;
 
-static expert_field ei_lwm_mal_error = EI_INIT;
-static expert_field ei_lwm_n_src_broad = EI_INIT;
-static expert_field ei_lwm_mismatch_endp = EI_INIT;
-static expert_field ei_lwm_empty_payload = EI_INIT;
-static expert_field ei_lwm_no_decryption_key = EI_INIT;
-static expert_field ei_lwm_decryption_failed = EI_INIT;
+static expert_field ei_lwm_mal_error;
+static expert_field ei_lwm_n_src_broad;
+static expert_field ei_lwm_mismatch_endp;
+static expert_field ei_lwm_empty_payload;
+static expert_field ei_lwm_no_decryption_key;
+static expert_field ei_lwm_decryption_failed;
 
 static dissector_handle_t lwm_handle;
 
@@ -166,30 +166,30 @@ static const value_string lwm_cmd_multi_names[] = {
  *      Boolean value, whether it handles the packet or not.
  *---------------------------------------------------------------
  */
-static gboolean
+static bool
 dissect_lwm_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     guint8 endpt, srcep, dstep;
 
     /* 1) first byte must have bits 0000xxxx */
     if(tvb_get_guint8(tvb, 0) & LWM_FCF_RESERVED)
-        return (FALSE);
+        return false;
 
     /* The header should be at least long enough for the base header. */
     if (tvb_reported_length(tvb) < LWM_HEADER_BASE_LEN)
-        return (FALSE);
+        return false;
 
     /* The endpoints should either both be zero, or both non-zero. */
     endpt = tvb_get_guint8(tvb, 6);
     srcep = (endpt & LWM_SRC_ENDP_MASK) >> LWM_SRC_ENDP_OFFSET;
     dstep = (endpt & LWM_DST_ENDP_MASK) >> LWM_DST_ENDP_OFFSET;
     if ((srcep == 0) && (dstep != 0))
-        return (FALSE);
+        return false;
     if ((srcep != 0) && (dstep == 0))
-        return (FALSE);
+        return false;
 
     dissect_lwm(tvb, pinfo, tree, data);
-    return (TRUE);
+    return true;
 } /* dissect_lwm_heur */
 
 /*FUNCTION:------------------------------------------------------
@@ -522,7 +522,7 @@ static int dissect_lwm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
         lwm_cmd = tvb_get_guint8(new_tvb, 0);
 
         col_clear(pinfo->cinfo, COL_INFO);  /*XXX: why ?*/
-        col_add_fstr(pinfo->cinfo, COL_INFO, "%s",
+        col_add_str(pinfo->cinfo, COL_INFO,
             val_to_str(lwm_cmd, lwm_cmd_names, LWM_CMD_UNKNOWN_VAL_STRING));
 
         lwm_cmd_tree = proto_tree_add_subtree(lwm_tree, new_tvb, 0, -1, ett_lwm_cmd_tree, &ti,
