@@ -22,6 +22,8 @@
 void proto_register_lwres(void);
 void proto_reg_handoff_lwres(void);
 
+static dissector_handle_t lwres_handle;
+
 #define LWRES_LWPACKET_LENGTH           (4 * 5 + 2 * 4)
 #define LWRES_LWPACKETFLAG_RESPONSE     0x0001U /* if set, pkt is a response */
 #define LWRES_LWPACKETVERSION_0         0
@@ -100,79 +102,79 @@ static const value_string result_values[]  = {
     { 0,                        NULL },
 };
 
-static int hf_length = -1;
-static int hf_version = -1;
-static int hf_flags = -1;
-static int hf_serial = -1;
-static int hf_opcode = -1;
-static int hf_result = -1;
-static int hf_recvlen = -1;
-static int hf_authtype = -1;
-static int hf_authlen = -1;
+static int hf_length;
+static int hf_version;
+static int hf_flags;
+static int hf_serial;
+static int hf_opcode;
+static int hf_result;
+static int hf_recvlen;
+static int hf_authtype;
+static int hf_authlen;
 
-static int hf_rflags = -1;
-static int hf_rdclass = -1;
-static int hf_rdtype = -1;
-static int hf_namelen = -1;
-static int hf_req_name = -1;
+static int hf_rflags;
+static int hf_rdclass;
+static int hf_rdtype;
+static int hf_namelen;
+static int hf_req_name;
 
-static int hf_ttl = -1;
-static int hf_nrdatas = -1;
-static int hf_nsigs = -1;
-static int hf_realnamelen = -1;
-static int hf_realname = -1;
+static int hf_ttl;
+static int hf_nrdatas;
+static int hf_nsigs;
+static int hf_realnamelen;
+static int hf_realname;
 
 
-static int hf_a_record = -1;
-static int hf_a_rec_len = -1;
-static int hf_srv_prio = -1;
-static int hf_srv_weight = -1;
-static int hf_srv_port = -1;
-static int hf_srv_dname = -1;
+static int hf_a_record;
+static int hf_a_rec_len;
+static int hf_srv_prio;
+static int hf_srv_weight;
+static int hf_srv_port;
+static int hf_srv_dname;
 
-static int hf_adn_flags = -1;
-static int hf_adn_addrtype = -1;
-static int hf_adn_namelen = -1;
-static int hf_adn_name = -1;
+static int hf_adn_flags;
+static int hf_adn_addrtype;
+static int hf_adn_namelen;
+static int hf_adn_name;
 
-static int hf_adn_realname = -1;
-static int hf_adn_aliasname = -1;
+static int hf_adn_realname;
+static int hf_adn_aliasname;
 
-static int hf_adn_naddrs = -1;
-static int hf_adn_naliases = -1;
-static int hf_adn_family = -1;
-static int hf_adn_addr_len = -1;
-static int hf_adn_addr_addr = -1;
+static int hf_adn_naddrs;
+static int hf_adn_naliases;
+static int hf_adn_family;
+static int hf_adn_addr_len;
+static int hf_adn_addr_addr;
 
-static int hf_ns_dname = -1;
+static int hf_ns_dname;
 
-static int ett_lwres = -1;
-static int ett_rdata_req = -1;
-static int ett_rdata_resp = -1;
-static int ett_a_rec = -1;
-static int ett_a_rec_addr = -1;
-static int ett_srv_rec = -1;
-static int ett_srv_rec_item = -1;
-static int ett_adn_request = -1;
-static int ett_adn_resp = -1;
-static int ett_adn_alias = -1;
-static int ett_adn_addr = -1;
-static int ett_nba_request = -1;
-static int ett_nba_resp = -1;
-static int ett_noop = -1;
+static int ett_lwres;
+static int ett_rdata_req;
+static int ett_rdata_resp;
+static int ett_a_rec;
+static int ett_a_rec_addr;
+static int ett_srv_rec;
+static int ett_srv_rec_item;
+static int ett_adn_request;
+static int ett_adn_resp;
+static int ett_adn_alias;
+static int ett_adn_addr;
+static int ett_nba_request;
+static int ett_nba_resp;
+static int ett_noop;
 
-static int ett_mx_rec = -1;
-static int ett_mx_rec_item = -1;
+static int ett_mx_rec;
+static int ett_mx_rec_item;
 
-static int ett_ns_rec = -1;
-static int ett_ns_rec_item = -1;
+static int ett_ns_rec;
+static int ett_ns_rec_item;
 
 
 
 #define LWRES_UDP_PORT 921 /* Not IANA registered */
 
 /* Define the lwres proto */
-static int proto_lwres = -1;
+static int proto_lwres;
 
 
 /* Define many many headers for mgcp */
@@ -183,7 +185,7 @@ static const value_string message_types_values[] = {
     { 0,        NULL },
 };
 
-static void dissect_getnamebyaddr_request(tvbuff_t* tvb, proto_tree* lwres_tree)
+static void dissect_getnamebyaddr_request(tvbuff_t* tvb, packet_info *pinfo, proto_tree* lwres_tree)
 {
     guint32 flags,family;
     guint   addrlen, slen;
@@ -194,7 +196,7 @@ static void dissect_getnamebyaddr_request(tvbuff_t* tvb, proto_tree* lwres_tree)
     flags = tvb_get_ntohl(tvb, LWRES_LWPACKET_LENGTH);
     family = tvb_get_ntohl(tvb, LWRES_LWPACKET_LENGTH + 4);
     addrlen = tvb_get_ntohs(tvb, LWRES_LWPACKET_LENGTH + 8);
-    addrs = tvb_ip_to_str(wmem_packet_scope(), tvb, LWRES_LWPACKET_LENGTH + 10);
+    addrs = tvb_ip_to_str(pinfo->pool, tvb, LWRES_LWPACKET_LENGTH + 10);
     slen = (int)strlen(addrs);
 
     if (lwres_tree == NULL)
@@ -428,7 +430,7 @@ static void dissect_getaddrsbyname_response(tvbuff_t* tvb, packet_info *pinfo, p
 
 }
 
-static void dissect_a_records(tvbuff_t* tvb, proto_tree* tree,guint32 nrec,int offset)
+static void dissect_a_records(tvbuff_t* tvb, packet_info *pinfo, proto_tree* tree,guint32 nrec,int offset)
 {
     guint32 i, curr;
     const gchar* addrs;
@@ -447,7 +449,7 @@ static void dissect_a_records(tvbuff_t* tvb, proto_tree* tree,guint32 nrec,int o
 
         curr = offset + (int)((sizeof(guint32)+sizeof(guint16)) * i);
 
-        addrs = tvb_ip_to_str(wmem_packet_scope(), tvb, curr+2);
+        addrs = tvb_ip_to_str(pinfo->pool, tvb, curr+2);
 
         addr_tree = proto_tree_add_subtree_format(a_rec_tree, tvb, curr,
                             6, ett_a_rec_addr, NULL, "Address %s", addrs);
@@ -746,7 +748,7 @@ static void dissect_rdata_response(tvbuff_t* tvb, packet_info *pinfo, proto_tree
     switch(rdtype)
     {
         case T_A:
-            dissect_a_records(tvb,rdata_resp_tree,nrdatas,offset);
+            dissect_a_records(tvb,pinfo,rdata_resp_tree,nrdatas,offset);
         break;
 
         case T_SRV:
@@ -795,7 +797,7 @@ static void dissect_getaddrsbyname(tvbuff_t* tvb, packet_info *pinfo, proto_tree
 static void dissect_getnamebyaddr(tvbuff_t* tvb, packet_info *pinfo, proto_tree* lwres_tree, int type)
 {
     if(type == 1)
-        dissect_getnamebyaddr_request(tvb, lwres_tree);
+        dissect_getnamebyaddr_request(tvb, pinfo, lwres_tree);
     else
         dissect_getnamebyaddr_response(tvb, pinfo, lwres_tree);
 }
@@ -1126,15 +1128,14 @@ proto_register_lwres(void)
 
     proto_register_field_array(proto_lwres, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+
+    lwres_handle = register_dissector("lwres", dissect_lwres, proto_lwres);
 }
 
 /* The registration hand-off routine */
 void
 proto_reg_handoff_lwres(void)
 {
-    dissector_handle_t lwres_handle;
-
-    lwres_handle = create_dissector_handle(dissect_lwres, proto_lwres);
     dissector_add_uint_with_preference("udp.port", LWRES_UDP_PORT, lwres_handle);
 }
 
