@@ -1,9 +1,9 @@
 /* packet-m2pa.c
  * Routines for MTP2 Peer Adaptation Layer dissection
  * It is hopefully (needs testing) compliant to
- * http://www.ietf.org/internet-drafts/draft-ietf-sigtran-m2pa-02.txt
- * http://www.ietf.org/internet-drafts/draft-ietf-sigtran-m2pa-08.txt
- * http://tools.ietf.org/rfc/rfc4165.txt
+ * https://tools.ietf.org/html/draft-ietf-sigtran-m2pa-02
+ * https://tools.ietf.org/html/draft-ietf-sigtran-m2pa-08
+ * https://tools.ietf.org/html/rfc4165
  *
  * Copyright 2001, 2002, Jeff Morriss <jeff.morriss.ws [AT] gmail.com>,
  * updated by Michael Tuexen <tuexen [AT] fh-muenster.de>
@@ -31,39 +31,37 @@ void proto_reg_handoff_m2pa(void);
 
 #define SCTP_PORT_M2PA              3565
 
-static guint global_sctp_port       = SCTP_PORT_M2PA;
-
-static int proto_m2pa      = -1;
+static int proto_m2pa;
 static module_t *m2pa_module;
 
-static int hf_version      = -1;
-static int hf_spare        = -1;
-static int hf_v2_type      = -1;
-static int hf_v8_type      = -1;
-static int hf_type         = -1;
-static int hf_class        = -1;
-static int hf_length       = -1;
-static int hf_unused       = -1;
-static int hf_bsn          = -1;
-static int hf_fsn          = -1;
-static int hf_v2_status    = -1;
-static int hf_v8_status    = -1;
-static int hf_status       = -1;
-static int hf_v2_li_spare  = -1;
-static int hf_v8_li_spare  = -1;
-static int hf_v2_li_prio   = -1;
-static int hf_v8_li_prio   = -1;
-static int hf_filler       = -1;
-static int hf_unknown_data = -1;
-static int hf_pri_prio     = -1;
-static int hf_pri_spare    = -1;
-static int hf_undecode_data   = -1;
+static int hf_version;
+static int hf_spare;
+static int hf_v2_type;
+static int hf_v8_type;
+static int hf_type;
+static int hf_class;
+static int hf_length;
+static int hf_unused;
+static int hf_bsn;
+static int hf_fsn;
+static int hf_v2_status;
+static int hf_v8_status;
+static int hf_status;
+static int hf_v2_li_spare;
+static int hf_v8_li_spare;
+static int hf_v2_li_prio;
+static int hf_v8_li_prio;
+static int hf_filler;
+static int hf_unknown_data;
+static int hf_pri_prio;
+static int hf_pri_spare;
+static int hf_undecode_data;
 
-static gint ett_m2pa       = -1;
-static gint ett_m2pa_li    = -1;
+static gint ett_m2pa;
+static gint ett_m2pa_li;
 
-static expert_field ei_undecode_data = EI_INIT;
-static expert_field ei_length = EI_INIT;
+static expert_field ei_undecode_data;
+static expert_field ei_length;
 
 static dissector_handle_t m2pa_handle;
 static dissector_handle_t mtp3_handle;
@@ -567,40 +565,22 @@ proto_register_m2pa(void)
   /* Allow other dissectors to find this one by name. */
   m2pa_handle = register_dissector("m2pa", dissect_m2pa, proto_m2pa);
 
-  m2pa_module = prefs_register_protocol(proto_m2pa, proto_reg_handoff_m2pa);
+  m2pa_module = prefs_register_protocol(proto_m2pa, NULL);
 
   prefs_register_enum_preference(m2pa_module, "version", "M2PA version", "Version used by Wireshark", &m2pa_version, m2pa_version_options, FALSE);
-  prefs_register_uint_preference(m2pa_module, "port", "M2PA SCTP Port", "Set the port for M2PA messages (default: " G_STRINGIFY(SCTP_PORT_M2PA) ")", 10, &global_sctp_port);
 }
 
 void
 proto_reg_handoff_m2pa(void)
 {
-  static gboolean prefs_initialized = FALSE;
-  static guint sctp_port;
+  mtp3_handle   = find_dissector_add_dependency("mtp3", proto_m2pa);
 
-  /* Port preferences code shamelessly copied from packet-beep.c */
-  if (!prefs_initialized) {
-    mtp3_handle   = find_dissector_add_dependency("mtp3", proto_m2pa);
-
-    dissector_add_uint("sctp.ppi", M2PA_PAYLOAD_PROTOCOL_ID, m2pa_handle);
-
-    prefs_initialized = TRUE;
-
-  } else {
-
-    dissector_delete_uint("sctp.port", sctp_port, m2pa_handle);
-
-  }
-
-  /* Set our port number for future use */
-  sctp_port = global_sctp_port;
-
-  dissector_add_uint("sctp.port", sctp_port, m2pa_handle);
+  dissector_add_uint("sctp.ppi", M2PA_PAYLOAD_PROTOCOL_ID, m2pa_handle);
+  dissector_add_uint_with_preference("sctp.port", SCTP_PORT_M2PA, m2pa_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local Variables:
  * c-basic-offset: 2
