@@ -33,52 +33,52 @@
 #define MCPE_UDP_PORT_DEFAULT 19132 /* Not IANA registered */
 static guint mcpe_udp_port_requested = MCPE_UDP_PORT_DEFAULT;
 
-static int proto_mcpe = -1;
-static gint ett_mcpe = -1; /* Should this node be expanded */
-static gint ett_mcpe_batch = -1;
-static gint ett_mcpe_batch_record = -1;
-static gint ett_mcpe_login = -1;
-static gint ett_mcpe_string = -1;
+static int proto_mcpe;
+static gint ett_mcpe; /* Should this node be expanded */
+static gint ett_mcpe_batch;
+static gint ett_mcpe_batch_record;
+static gint ett_mcpe_login;
+static gint ett_mcpe_string;
 
 /*
  * Dissectors
  */
-static dissector_handle_t mcpe_handle = NULL;
-static dissector_table_t mcpe_packet_dissectors = NULL;
+static dissector_handle_t mcpe_handle;
+static dissector_table_t mcpe_packet_dissectors;
 
 /*
  * Expert fields
  */
-static expert_field ei_mcpe_unknown_packet_id = EI_INIT;
-static expert_field ei_mcpe_decompression_failed = EI_INIT;
-static expert_field ei_mcpe_encrypted_packet = EI_INIT;
+static expert_field ei_mcpe_unknown_packet_id;
+static expert_field ei_mcpe_decompression_failed;
+static expert_field ei_mcpe_encrypted_packet;
 
 /*
  * Common Header fields
  */
-static int hf_mcpe_message_id = -1;
-static int hf_mcpe_packet_id = -1;
-static int hf_mcpe_string_length = -1;
-static int hf_mcpe_UTF8_string = -1;
-static int hf_mcpe_byte_string = -1;
+static int hf_mcpe_message_id;
+static int hf_mcpe_packet_id;
+static int hf_mcpe_string_length;
+static int hf_mcpe_UTF8_string;
+static int hf_mcpe_byte_string;
 
 /*
  * Fields specific to a packet ID
  */
-static int hf_mcpe_protocol_version = -1;
-static int hf_mcpe_login_data_length = -1;
-static int hf_mcpe_login_data = -1;
-static int hf_mcpe_login = -1;
-static int hf_mcpe_chain_JSON = -1;
-static int hf_mcpe_client_data_JWT = -1;
-static int hf_mcpe_public_key = -1;
-static int hf_mcpe_server_token = -1;
+static int hf_mcpe_protocol_version;
+static int hf_mcpe_login_data_length;
+static int hf_mcpe_login_data;
+static int hf_mcpe_login;
+static int hf_mcpe_chain_JSON;
+static int hf_mcpe_client_data_JWT;
+static int hf_mcpe_public_key;
+static int hf_mcpe_server_token;
 
-static int hf_mcpe_batch_length = -1;
-static int hf_mcpe_batch_body = -1;
-static int hf_mcpe_batch_records = -1;
-static int hf_mcpe_batch_record_length = -1;
-static int hf_mcpe_batch_record = -1;
+static int hf_mcpe_batch_length;
+static int hf_mcpe_batch_body;
+static int hf_mcpe_batch_records;
+static int hf_mcpe_batch_record_length;
+static int hf_mcpe_batch_record;
 
 /*
  * RakNet Message ID
@@ -150,7 +150,7 @@ mcpe_get_session_state(packet_info *pinfo) {
  * Packet dissectors
  */
 static void
-mcpe_dissect_string(proto_tree *tree, int hf, tvbuff_t *tvb, gint *offset, guint encoding) {
+mcpe_dissect_string(packet_info *pinfo, proto_tree *tree, int hf, tvbuff_t *tvb, gint *offset, guint encoding) {
     proto_item *ti;
     proto_tree *string_tree;
     guint32 length;
@@ -172,7 +172,7 @@ mcpe_dissect_string(proto_tree *tree, int hf, tvbuff_t *tvb, gint *offset, guint
     if (encoding & ENC_UTF_8) {
         guint8 *string;
 
-        string = tvb_get_string_enc(wmem_packet_scope(), tvb, *offset + length_width, length, ENC_UTF_8);
+        string = tvb_get_string_enc(pinfo->pool, tvb, *offset + length_width, length, ENC_UTF_8);
 
         ti = proto_tree_add_string(tree, hf, tvb, *offset, length + length_width, string);
         string_tree = proto_item_add_subtree(ti, ett_mcpe_string);
@@ -182,13 +182,13 @@ mcpe_dissect_string(proto_tree *tree, int hf, tvbuff_t *tvb, gint *offset, guint
         *offset += length_width;
 
         proto_tree_add_item(string_tree, hf_mcpe_UTF8_string, tvb,
-                            *offset, length, ENC_UTF_8|ENC_NA);
+                            *offset, length, ENC_UTF_8);
         *offset += length;
     }
     else {
         guint8 *bytes;
 
-        bytes = (guint8*)tvb_memdup(wmem_packet_scope(), tvb, *offset + length_width, length);
+        bytes = (guint8*)tvb_memdup(pinfo->pool, tvb, *offset + length_width, length);
 
         ti = proto_tree_add_bytes_with_length(tree, hf, tvb, *offset, length + length_width, bytes, length);
         string_tree = proto_item_add_subtree(ti, ett_mcpe_string);
@@ -204,7 +204,7 @@ mcpe_dissect_string(proto_tree *tree, int hf, tvbuff_t *tvb, gint *offset, guint
 }
 
 static int
-mcpe_dissect_login(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, void* data _U_)
+mcpe_dissect_login(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
     if (tree) {
         gint item_size;
@@ -227,7 +227,7 @@ mcpe_dissect_login(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, void
         ti = proto_tree_add_item(tree, hf_mcpe_login_data, tvb,
                                  offset, item_size, ENC_NA);
 
-        login_tvb = tvb_uncompress(tvb, offset, comp_length);
+        login_tvb = tvb_child_uncompress_zlib(tvb, tvb, offset, comp_length);
         if (login_tvb) {
             guint32 decomp_length;
             proto_tree *login_tree;
@@ -243,8 +243,8 @@ mcpe_dissect_login(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, void
             proto_item_append_text(ti, " (%u octets)", decomp_length);
             proto_item_set_generated(ti);
 
-            mcpe_dissect_string(login_tree, hf_mcpe_chain_JSON     , login_tvb, &offset, ENC_LITTLE_ENDIAN | ENC_UTF_8);
-            mcpe_dissect_string(login_tree, hf_mcpe_client_data_JWT, login_tvb, &offset, ENC_LITTLE_ENDIAN | ENC_UTF_8);
+            mcpe_dissect_string(pinfo, login_tree, hf_mcpe_chain_JSON     , login_tvb, &offset, ENC_LITTLE_ENDIAN | ENC_UTF_8);
+            mcpe_dissect_string(pinfo, login_tree, hf_mcpe_client_data_JWT, login_tvb, &offset, ENC_LITTLE_ENDIAN | ENC_UTF_8);
         }
         else {
             expert_add_info(pinfo, ti, &ei_mcpe_decompression_failed);
@@ -260,8 +260,8 @@ mcpe_dissect_server_to_client_handshake(tvbuff_t *tvb, packet_info *pinfo, proto
         gint offset = 1;
         mcpe_session_state_t *state;
 
-        mcpe_dissect_string(tree, hf_mcpe_public_key, tvb, &offset, ENC_BIG_ENDIAN | ENC_UTF_8);
-        mcpe_dissect_string(tree, hf_mcpe_server_token, tvb, &offset, ENC_BIG_ENDIAN);
+        mcpe_dissect_string(pinfo, tree, hf_mcpe_public_key, tvb, &offset, ENC_BIG_ENDIAN | ENC_UTF_8);
+        mcpe_dissect_string(pinfo, tree, hf_mcpe_server_token, tvb, &offset, ENC_BIG_ENDIAN);
 
         /*
          * Everything will be encrypted once the server sends this.
@@ -292,7 +292,7 @@ mcpe_dissect_batch(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* da
         ti = proto_tree_add_item(tree, hf_mcpe_batch_body, tvb,
                                  offset, item_size, ENC_NA);
 
-        batch_tvb = tvb_uncompress(tvb, offset, comp_length);
+        batch_tvb = tvb_child_uncompress_zlib(tvb, tvb, offset, comp_length);
         if (batch_tvb) {
             guint32 decomp_length;
             proto_tree *batch_tree;
@@ -381,7 +381,7 @@ mcpe_init_message_names(void)
 }
 
 static gboolean
-test_mcpe_heur(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree _U_, void* data _U_)
+test_mcpe_heur(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree _U_, void* data)
 {
     /*
      * 0xFE "Wrapper" is the only message ID that MCPE uses. The sole
@@ -410,7 +410,7 @@ test_mcpe_heur(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree _U_, void
     return FALSE;
 }
 
-static gboolean
+static bool
 dissect_mcpe_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     dissector_handle_t handle;
@@ -456,7 +456,7 @@ dissect_mcpe_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
         return call_dissector_only(handle, packet_tvb, pinfo, mcpe_tree, data) > 0;
     }
     else {
-        return FALSE;
+        return false;
     }
 }
 
