@@ -14,169 +14,168 @@
 #include <epan/addr_resolv.h>
 #include <epan/ipproto.h>
 #include <epan/expert.h>
-#include <wsutil/inet_ipv6.h>
 #include <wsutil/utf8_entities.h>
-#include <wiretap/wtap.h>
 
 #include "packet-netmon.h"
 #include "packet-windows-common.h"
+#include "packet-ipv6.h"
 
 void proto_register_message_analyzer(void);
 void proto_reg_handoff_message_analyzer(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_ma_wfp_capture_v4 = -1;
-static int proto_ma_wfp_capture2_v4 = -1;
-static int proto_ma_wfp_capture_v6 = -1;
-static int proto_ma_wfp_capture2_v6 = -1;
-static int proto_ma_wfp_capture_auth_v4 = -1;
-static int proto_ma_wfp_capture_auth_v6 = -1;
-static int proto_etw_wfp_capture = -1;
-static int proto_etw_ndis = -1;
+static int proto_ma_wfp_capture_v4;
+static int proto_ma_wfp_capture2_v4;
+static int proto_ma_wfp_capture_v6;
+static int proto_ma_wfp_capture2_v6;
+static int proto_ma_wfp_capture_auth_v4;
+static int proto_ma_wfp_capture_auth_v6;
+static int proto_etw_wfp_capture;
+static int proto_etw_ndis;
 
-static int hf_ma_wfp_capture_flow_context = -1;
-static int hf_ma_wfp_capture_payload_length = -1;
-static int hf_ma_wfp_capture_auth_src_port = -1;
-static int hf_ma_wfp_capture_auth_dst_port = -1;
-static int hf_ma_wfp_capture_auth_interface_id = -1;
-static int hf_ma_wfp_capture_auth_direction = -1;
-static int hf_ma_wfp_capture_auth_process_id = -1;
-static int hf_ma_wfp_capture_auth_process_path = -1;
+static int hf_ma_wfp_capture_flow_context;
+static int hf_ma_wfp_capture_payload_length;
+static int hf_ma_wfp_capture_auth_src_port;
+static int hf_ma_wfp_capture_auth_dst_port;
+static int hf_ma_wfp_capture_auth_interface_id;
+static int hf_ma_wfp_capture_auth_direction;
+static int hf_ma_wfp_capture_auth_process_id;
+static int hf_ma_wfp_capture_auth_process_path;
 
-static int hf_etw_wfp_capture_event_id = -1;
-static int hf_etw_wfp_capture_driver_name = -1;
-static int hf_etw_wfp_capture_major_version = -1;
-static int hf_etw_wfp_capture_minor_version = -1;
-static int hf_etw_wfp_capture_callout = -1;
-static int hf_etw_wfp_capture_filter_id = -1;
-static int hf_etw_wfp_capture_filter_weight = -1;
-static int hf_etw_wfp_capture_driver_error_message = -1;
-static int hf_etw_wfp_capture_nt_status = -1;
-static int hf_etw_wfp_capture_callout_error_message = -1;
+static int hf_etw_wfp_capture_event_id;
+static int hf_etw_wfp_capture_driver_name;
+static int hf_etw_wfp_capture_major_version;
+static int hf_etw_wfp_capture_minor_version;
+static int hf_etw_wfp_capture_callout;
+static int hf_etw_wfp_capture_filter_id;
+static int hf_etw_wfp_capture_filter_weight;
+static int hf_etw_wfp_capture_driver_error_message;
+static int hf_etw_wfp_capture_nt_status;
+static int hf_etw_wfp_capture_callout_error_message;
 
-static int hf_etw_ndis_event_id = -1;
-static int hf_etw_ndis_miniport_if_index = -1;
-static int hf_etw_ndis_lower_if_index = -1;
-static int hf_etw_ndis_fragment_size = -1;
-static int hf_etw_ndis_fragment = -1;
-static int hf_etw_ndis_metadata_size = -1;
-static int hf_etw_ndis_metadata = -1;
-static int hf_etw_ndis_source_port_id = -1;
-static int hf_etw_ndis_source_port_name = -1;
-static int hf_etw_ndis_source_nic_name = -1;
-static int hf_etw_ndis_source_nic_type = -1;
-static int hf_etw_ndis_destination_count = -1;
-static int hf_etw_ndis_destination_port_id = -1;
-static int hf_etw_ndis_destination_port_name = -1;
-static int hf_etw_ndis_destination_nic_name = -1;
-static int hf_etw_ndis_destination_nic_type = -1;
-static int hf_etw_ndis_oob_data_size = -1;
-static int hf_etw_ndis_oob_data = -1;
-static int hf_etw_ndis_rules_count = -1;
-static int hf_etw_ndis_friendly_name = -1;
-static int hf_etw_ndis_unique_name = -1;
-static int hf_etw_ndis_service_name = -1;
-static int hf_etw_ndis_version = -1;
-static int hf_etw_ndis_media_type = -1;
-static int hf_etw_ndis_reference_context = -1;
-static int hf_etw_ndis_rule_id = -1;
-static int hf_etw_ndis_directive = -1;
-static int hf_etw_ndis_value_length = -1;
-static int hf_etw_ndis_value = -1;
-static int hf_etw_ndis_error_code = -1;
-static int hf_etw_ndis_location = -1;
-static int hf_etw_ndis_context = -1;
-static int hf_etw_ndis_previous_state = -1;
-static int hf_etw_ndis_next_state = -1;
-static int hf_etw_ndis_source_id = -1;
-static int hf_etw_ndis_rundown_id = -1;
-static int hf_etw_ndis_param1 = -1;
-static int hf_etw_ndis_param2 = -1;
-static int hf_etw_ndis_param_str = -1;
-static int hf_etw_ndis_description = -1;
-static int hf_etw_ndis_source_name = -1;
-static int hf_etw_ndis_if_index = -1;
-static int hf_etw_ndis_layer_count = -1;
-static int hf_etw_ndis_layer_id = -1;
-static int hf_etw_ndis_layer_name = -1;
-static int hf_etw_ndis_keyword = -1;
-static int hf_etw_ndis_keyword_ethernet8023 = -1;
-static int hf_etw_ndis_keyword_reserved1 = -1;
-static int hf_etw_ndis_keyword_wireless_wan = -1;
-static int hf_etw_ndis_keyword_reserved2 = -1;
-static int hf_etw_ndis_keyword_tunnel = -1;
-static int hf_etw_ndis_keyword_native80211 = -1;
-static int hf_etw_ndis_keyword_reserved3 = -1;
-static int hf_etw_ndis_keyword_vmswitch = -1;
-static int hf_etw_ndis_keyword_reserved4 = -1;
-static int hf_etw_ndis_keyword_packet_start = -1;
-static int hf_etw_ndis_keyword_packet_end = -1;
-static int hf_etw_ndis_keyword_send_path = -1;
-static int hf_etw_ndis_keyword_receive_path = -1;
-static int hf_etw_ndis_keyword_l3_connect_path = -1;
-static int hf_etw_ndis_keyword_l2_connect_path = -1;
-static int hf_etw_ndis_keyword_close_path = -1;
-static int hf_etw_ndis_keyword_authentication = -1;
-static int hf_etw_ndis_keyword_configuration = -1;
-static int hf_etw_ndis_keyword_global = -1;
-static int hf_etw_ndis_keyword_dropped = -1;
-static int hf_etw_ndis_keyword_pii_present = -1;
-static int hf_etw_ndis_keyword_packet = -1;
-static int hf_etw_ndis_keyword_address = -1;
-static int hf_etw_ndis_keyword_std_template_hint = -1;
-static int hf_etw_ndis_keyword_state_transition = -1;
-static int hf_etw_ndis_keyword_reserved5 = -1;
-static int hf_etw_ndis_packet_metadata_type = -1;
-static int hf_etw_ndis_packet_metadata_revision = -1;
-static int hf_etw_ndis_packet_metadata_size = -1;
-static int hf_etw_ndis_packet_metadata_wifi_flags = -1;
-static int hf_etw_ndis_packet_metadata_wifi_phytype = -1;
-static int hf_etw_ndis_packet_metadata_wifi_channel = -1;
-static int hf_etw_ndis_packet_metadata_wifi_mpdus_received = -1;
-static int hf_etw_ndis_packet_metadata_wifi_mpdu_padding = -1;
-static int hf_etw_ndis_packet_metadata_wifi_rssi = -1;
-static int hf_etw_ndis_packet_metadata_wifi_datarate = -1;
-static int hf_etw_ndis_packet_metadata_data = -1;
-static int hf_etw_ndis_tcp_ip_checksum_net_buffer_list = -1;
-static int hf_etw_ndis_ipsec_offload_v1_net_buffer_list_info = -1;
-static int hf_etw_ndis_tcp_large_send_net_buffer_list_info = -1;
-static int hf_etw_ndis_classification_handle_net_buffer_list_info = -1;
-static int hf_etw_ndis_ieee8021q_net_buffer_list_info = -1;
-static int hf_etw_ndis_net_buffer_cancel_id = -1;
-static int hf_etw_ndis_media_specific_information = -1;
-static int hf_etw_ndis_net_buffer_list_frame_type = -1;
-static int hf_etw_ndis_net_buffer_list_hash_value = -1;
-static int hf_etw_ndis_net_buffer_list_hash_info = -1;
-static int hf_etw_ndis_wpf_net_buffer_list_info = -1;
-static int hf_etw_ndis_max_net_buffer_list_info = -1;
+static int hf_etw_ndis_event_id;
+static int hf_etw_ndis_miniport_if_index;
+static int hf_etw_ndis_lower_if_index;
+static int hf_etw_ndis_fragment_size;
+static int hf_etw_ndis_fragment;
+static int hf_etw_ndis_metadata_size;
+static int hf_etw_ndis_metadata;
+static int hf_etw_ndis_source_port_id;
+static int hf_etw_ndis_source_port_name;
+static int hf_etw_ndis_source_nic_name;
+static int hf_etw_ndis_source_nic_type;
+static int hf_etw_ndis_destination_count;
+static int hf_etw_ndis_destination_port_id;
+static int hf_etw_ndis_destination_port_name;
+static int hf_etw_ndis_destination_nic_name;
+static int hf_etw_ndis_destination_nic_type;
+static int hf_etw_ndis_oob_data_size;
+static int hf_etw_ndis_oob_data;
+static int hf_etw_ndis_rules_count;
+static int hf_etw_ndis_friendly_name;
+static int hf_etw_ndis_unique_name;
+static int hf_etw_ndis_service_name;
+static int hf_etw_ndis_version;
+static int hf_etw_ndis_media_type;
+static int hf_etw_ndis_reference_context;
+static int hf_etw_ndis_rule_id;
+static int hf_etw_ndis_directive;
+static int hf_etw_ndis_value_length;
+static int hf_etw_ndis_value;
+static int hf_etw_ndis_error_code;
+static int hf_etw_ndis_location;
+static int hf_etw_ndis_context;
+static int hf_etw_ndis_previous_state;
+static int hf_etw_ndis_next_state;
+static int hf_etw_ndis_source_id;
+static int hf_etw_ndis_rundown_id;
+static int hf_etw_ndis_param1;
+static int hf_etw_ndis_param2;
+static int hf_etw_ndis_param_str;
+static int hf_etw_ndis_description;
+static int hf_etw_ndis_source_name;
+static int hf_etw_ndis_if_index;
+static int hf_etw_ndis_layer_count;
+static int hf_etw_ndis_layer_id;
+static int hf_etw_ndis_layer_name;
+static int hf_etw_ndis_keyword;
+static int hf_etw_ndis_keyword_ethernet8023;
+static int hf_etw_ndis_keyword_reserved1;
+static int hf_etw_ndis_keyword_wireless_wan;
+static int hf_etw_ndis_keyword_reserved2;
+static int hf_etw_ndis_keyword_tunnel;
+static int hf_etw_ndis_keyword_native80211;
+static int hf_etw_ndis_keyword_reserved3;
+static int hf_etw_ndis_keyword_vmswitch;
+static int hf_etw_ndis_keyword_reserved4;
+static int hf_etw_ndis_keyword_packet_start;
+static int hf_etw_ndis_keyword_packet_end;
+static int hf_etw_ndis_keyword_send_path;
+static int hf_etw_ndis_keyword_receive_path;
+static int hf_etw_ndis_keyword_l3_connect_path;
+static int hf_etw_ndis_keyword_l2_connect_path;
+static int hf_etw_ndis_keyword_close_path;
+static int hf_etw_ndis_keyword_authentication;
+static int hf_etw_ndis_keyword_configuration;
+static int hf_etw_ndis_keyword_global;
+static int hf_etw_ndis_keyword_dropped;
+static int hf_etw_ndis_keyword_pii_present;
+static int hf_etw_ndis_keyword_packet;
+static int hf_etw_ndis_keyword_address;
+static int hf_etw_ndis_keyword_std_template_hint;
+static int hf_etw_ndis_keyword_state_transition;
+static int hf_etw_ndis_keyword_reserved5;
+static int hf_etw_ndis_packet_metadata_type;
+static int hf_etw_ndis_packet_metadata_revision;
+static int hf_etw_ndis_packet_metadata_size;
+static int hf_etw_ndis_packet_metadata_wifi_flags;
+static int hf_etw_ndis_packet_metadata_wifi_phytype;
+static int hf_etw_ndis_packet_metadata_wifi_channel;
+static int hf_etw_ndis_packet_metadata_wifi_mpdus_received;
+static int hf_etw_ndis_packet_metadata_wifi_mpdu_padding;
+static int hf_etw_ndis_packet_metadata_wifi_rssi;
+static int hf_etw_ndis_packet_metadata_wifi_datarate;
+static int hf_etw_ndis_packet_metadata_data;
+static int hf_etw_ndis_tcp_ip_checksum_net_buffer_list;
+static int hf_etw_ndis_ipsec_offload_v1_net_buffer_list_info;
+static int hf_etw_ndis_tcp_large_send_net_buffer_list_info;
+static int hf_etw_ndis_classification_handle_net_buffer_list_info;
+static int hf_etw_ndis_ieee8021q_net_buffer_list_info;
+static int hf_etw_ndis_net_buffer_cancel_id;
+static int hf_etw_ndis_media_specific_information;
+static int hf_etw_ndis_net_buffer_list_frame_type;
+static int hf_etw_ndis_net_buffer_list_hash_value;
+static int hf_etw_ndis_net_buffer_list_hash_info;
+static int hf_etw_ndis_wpf_net_buffer_list_info;
+static int hf_etw_ndis_max_net_buffer_list_info;
 
 /* Fields used from other common dissectors */
-static int hf_ip_src = -1;
-static int hf_ip_addr = -1;
-static int hf_ip_src_host = -1;
-static int hf_ip_host = -1;
-static int hf_ip_dst = -1;
-static int hf_ip_dst_host = -1;
-static int hf_ip_proto = -1;
-static int hf_ipv6_src = -1;
-static int hf_ipv6_addr = -1;
-static int hf_ipv6_src_host = -1;
-static int hf_ipv6_host = -1;
-static int hf_ipv6_dst = -1;
-static int hf_ipv6_dst_host = -1;
+static int hf_ip_src;
+static int hf_ip_addr;
+static int hf_ip_src_host;
+static int hf_ip_host;
+static int hf_ip_dst;
+static int hf_ip_dst_host;
+static int hf_ip_proto;
+static int hf_ipv6_src;
+static int hf_ipv6_addr;
+static int hf_ipv6_src_host;
+static int hf_ipv6_host;
+static int hf_ipv6_dst;
+static int hf_ipv6_dst_host;
 
 
 /* Initialize the subtree pointers */
-static gint ett_ma_wfp_capture_v4 = -1;
-static gint ett_ma_wfp_capture_v6 = -1;
-static gint ett_ma_wfp_capture_auth = -1;
-static gint ett_etw_wfp_capture = -1;
-static gint ett_etw_ndis = -1;
-static gint ett_etw_ndis_dest = -1;
-static gint ett_etw_ndis_layer = -1;
-static gint ett_etw_ndis_keyword = -1;
-static gint ett_etw_ndis_packet_metadata = -1;
-static gint ett_etw_ndis_oob_data = -1;
+static gint ett_ma_wfp_capture_v4;
+static gint ett_ma_wfp_capture_v6;
+static gint ett_ma_wfp_capture_auth;
+static gint ett_etw_wfp_capture;
+static gint ett_etw_ndis;
+static gint ett_etw_ndis_dest;
+static gint ett_etw_ndis_layer;
+static gint ett_etw_ndis_keyword;
+static gint ett_etw_ndis_packet_metadata;
+static gint ett_etw_ndis_oob_data;
 
 static dissector_handle_t ma_wfp_capture_v4_handle;
 static dissector_handle_t ma_wfp_capture2_v4_handle;
@@ -204,7 +203,7 @@ add_ipv4_src_address(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int of
 
 		memcpy(&addr, pinfo->net_src.data, 4);
 		src_host = get_hostname(addr);
-		proto_item_append_text(parent_item, ", Src: %s", address_with_resolution_to_str(wmem_packet_scope(), &pinfo->net_src));
+		proto_item_append_text(parent_item, ", Src: %s", address_with_resolution_to_str(pinfo->pool, &pinfo->net_src));
 
 		proto_tree_add_ipv4(tree, hf_ip_src, tvb, offset, 4, addr);
 		item = proto_tree_add_ipv4(tree, hf_ip_addr, tvb, offset, 4, addr);
@@ -234,7 +233,7 @@ add_ipv4_dst_address(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int of
 
 		memcpy(&addr, pinfo->net_dst.data, 4);
 		dst_host = get_hostname(addr);
-		proto_item_append_text(parent_item, ", Dst: %s", address_with_resolution_to_str(wmem_packet_scope(), &pinfo->net_dst));
+		proto_item_append_text(parent_item, ", Dst: %s", address_with_resolution_to_str(pinfo->pool, &pinfo->net_dst));
 
 		proto_tree_add_ipv4(tree, hf_ip_dst, tvb, offset, 4, addr);
 		item = proto_tree_add_ipv4(tree, hf_ip_addr, tvb, offset, 4, addr);
@@ -261,7 +260,7 @@ add_ipv6_src_address(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int of
 	if (tree) {
 		const char *src_host;
 
-		src_host = address_to_display(wmem_packet_scope(), &pinfo->net_src);
+		src_host = address_to_display(pinfo->pool, &pinfo->net_src);
 
 		proto_tree_add_item(tree, hf_ipv6_src, tvb, offset, IPv6_ADDR_SIZE, ENC_NA);
 		item = proto_tree_add_item(tree, hf_ipv6_addr, tvb, offset, IPv6_ADDR_SIZE, ENC_NA);
@@ -288,7 +287,7 @@ add_ipv6_dst_address(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, int of
 	if (tree) {
 		const char *dst_host;
 
-		dst_host = address_to_display(wmem_packet_scope(), &pinfo->net_dst);
+		dst_host = address_to_display(pinfo->pool, &pinfo->net_dst);
 
 		proto_tree_add_item(tree, hf_ipv6_dst, tvb, offset, IPv6_ADDR_SIZE, ENC_NA);
 		item = proto_tree_add_item(tree, hf_ipv6_addr, tvb, offset, IPv6_ADDR_SIZE, ENC_NA);
@@ -1234,7 +1233,7 @@ void proto_register_message_analyzer(void)
 		},
 		{ &hf_ma_wfp_capture_auth_process_path,
 			{ "Payload Length", "message_analyzer.wfp_capture.auth.process_path",
-			FT_UINT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_UINT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 	};
 
@@ -1245,7 +1244,7 @@ void proto_register_message_analyzer(void)
 		},
 		{ &hf_etw_wfp_capture_driver_name,
 			{ "Driver Name", "etw.wfp_capture.driver_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_wfp_capture_major_version,
 			{ "Major Version", "etw.wfp_capture.major_version",
@@ -1269,11 +1268,11 @@ void proto_register_message_analyzer(void)
 		},
 		{ &hf_etw_wfp_capture_driver_error_message,
 			{ "Driver Name", "etw.wfp_capture.driver_error_message",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_wfp_capture_callout_error_message,
 			{ "Driver Name", "etw.wfp_capture.callout_error_message",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_wfp_capture_nt_status,
 			{ "NT Status", "etw.wfp_capture.nt_status",
@@ -1316,15 +1315,15 @@ void proto_register_message_analyzer(void)
 		},
 		{ &hf_etw_ndis_source_port_name,
 			{ "Source port name", "etw.ndis.source_port_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_source_nic_name,
 			{ "Source NIC name", "etw.ndis.source_nic_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_source_nic_type,
 			{ "Source NIC type", "etw.ndis.source_nic_type",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_destination_count,
 			{ "Destination count", "etw.ndis.destination_count",
@@ -1336,15 +1335,15 @@ void proto_register_message_analyzer(void)
 		},
 		{ &hf_etw_ndis_destination_port_name,
 			{ "Destination port name", "etw.ndis.destination_port_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_destination_nic_name,
 			{ "Destination NIC name", "etw.ndis.destination_nic_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_destination_nic_type,
 			{ "Destination NIC type", "etw.ndis.destination_nic_type",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_oob_data_size,
 			{ "OOB data size", "etw.ndis.oob_data_size",
@@ -1360,19 +1359,19 @@ void proto_register_message_analyzer(void)
 		},
 		{ &hf_etw_ndis_friendly_name,
 			{ "Friendly name", "etw.ndis.friendly_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_unique_name,
 			{ "Unique name", "etw.ndis.unique_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_service_name,
 			{ "Service name", "etw.ndis.service_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_version,
 			{ "Version", "etw.ndis.version",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_media_type,
 			{ "Media types", "etw.ndis.media_type",
@@ -1436,15 +1435,15 @@ void proto_register_message_analyzer(void)
 		},
 		{ &hf_etw_ndis_param_str,
 			{ "Param String", "etw.ndis.param_str",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_description,
 			{ "Description", "etw.ndis.description",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_source_name,
 			{ "Source name", "etw.ndis.source_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_if_index,
 			{ "IfIndex", "etw.ndis.if_index",
@@ -1460,7 +1459,7 @@ void proto_register_message_analyzer(void)
 		},
 		{ &hf_etw_ndis_layer_name,
 			{ "Layer name", "etw.ndis.layer_name",
-			FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+			FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_keyword,
 			{ "Keyword", "etw.ndis.keyword",
@@ -1619,7 +1618,7 @@ void proto_register_message_analyzer(void)
 			FT_UINT64, BASE_DEC, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_ipsec_offload_v1_net_buffer_list_info,
-			{ "IPsecOffloadV2NetBufferListInfo", "etw.ndis.ipsec_offload_v1_net_buffer_list_info",
+			{ "IPsecOffloadV1NetBufferListInfo", "etw.ndis.ipsec_offload_v1_net_buffer_list_info",
 			FT_UINT64, BASE_DEC, NULL, 0x0, NULL, HFILL }
 		},
 		{ &hf_etw_ndis_tcp_large_send_net_buffer_list_info,
