@@ -35,15 +35,15 @@ void proto_register_metamako(void);
 void proto_reg_handoff_metamako(void);
 
 /* FCS Options */
-static gboolean metamako_check_fcs = TRUE;
+static bool metamako_check_fcs = true;
 static gint metamako_fcs_len = -1; /* By default, try to autodetect the FCS. */
 /* Heuristic Options */
 static gint metamako_trailer_present = -1; /* By default, try to autodetect the trailer. */
-static range_t* metamako_trailer_secs_bounds = NULL;
+static range_t* metamako_trailer_secs_bounds;
 static guint metamako_trailer_days_diff_limit = TRAILER_DAYS_DIFF_LIMIT_DFLT;
 
 /* Protocols and Header Fields */
-static int proto_metamako = -1;
+static int proto_metamako;
 
 /*
   Metamako trailer format
@@ -65,34 +65,34 @@ static int proto_metamako = -1;
   +---------------+---------------+---------------+---------------+
 */
 
-static int hf_metamako_origfcs = -1;
-static int hf_metamako_trailerext = -1;
-static int hf_metamako_unknownext = -1;
-static int hf_metamako_seqnum = -1;
-static int hf_metamako_tagstring = -1;
-static int hf_metamako_fracns = -1;
-static int hf_metamako_crchash = -1;
-static int hf_metamako_egress_seqnum = -1;
-static int hf_metamako_time_abs = -1;
-static int hf_metamako_time_rel = -1;
-static int hf_metamako_flags = -1;
-static int hf_metamako_src_port = -1;
-static int hf_metamako_src_device = -1;
-static int hf_metamako_time_diff = -1;
-static int hf_metamako_fcs = -1;
-static int hf_metamako_fcs_status = -1;
+static int hf_metamako_origfcs;
+static int hf_metamako_trailerext;
+static int hf_metamako_unknownext;
+static int hf_metamako_seqnum;
+static int hf_metamako_tagstring;
+static int hf_metamako_fracns;
+static int hf_metamako_crchash;
+static int hf_metamako_egress_seqnum;
+static int hf_metamako_time_abs;
+static int hf_metamako_time_rel;
+static int hf_metamako_flags;
+static int hf_metamako_src_port;
+static int hf_metamako_src_device;
+static int hf_metamako_time_diff;
+static int hf_metamako_fcs;
+static int hf_metamako_fcs_status;
 
-static int hf_metamako_flags_orig_fcs_vld = -1;
-static int hf_metamako_flags_has_ext = -1;
-static int hf_metamako_flags_duplicate = -1;
-static int hf_metamako_flags_ts_degraded = -1;
-static int hf_metamako_flags_control_block_type = -1;
-static int hf_metamako_reserved = -1;
+static int hf_metamako_flags_orig_fcs_vld;
+static int hf_metamako_flags_has_ext;
+static int hf_metamako_flags_duplicate;
+static int hf_metamako_flags_ts_degraded;
+static int hf_metamako_flags_control_block_type;
+static int hf_metamako_reserved;
 
-static gint ett_metamako = -1;
-static gint ett_metamako_timestamp = -1;
-static gint ett_metamako_extensions = -1;
-static gint ett_metamako_flags = -1;
+static gint ett_metamako;
+static gint ett_metamako_timestamp;
+static gint ett_metamako_extensions;
+static gint ett_metamako_flags;
 
 static const enum_val_t metamako_fcs_vals[] = {
   {"heuristic", "According to heuristic", -1},
@@ -130,7 +130,7 @@ static int* const flags[] = {
   NULL
 };
 
-static expert_field ei_metamako_fcs_bad = EI_INIT;
+static expert_field ei_metamako_fcs_bad;
 
 static void
 sub_nanos_base_custom(gchar* result, guint32 value)
@@ -246,7 +246,7 @@ dissect_metamako(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, void* data
   /* Loop through the trailer bytes, trying to find a valid trailer.
    * When:
    *   i == 0, we assume there IS NO trailing FCS
-   *   i == 1, we assume ther IS a trailing FCS
+   *   i == 1, we assume there IS a trailing FCS
    */
   for (i = i_start; i < i_end && !trailer_valid; i++) {
     has_fcs = i == 1;
@@ -470,6 +470,12 @@ dissect_metamako(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, void* data
   return offset;
 }
 
+static bool
+dissect_metamako_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+{
+    return dissect_metamako(tvb, pinfo, tree, data) > 0;
+}
+
 void
 proto_register_metamako(void)
 {
@@ -546,17 +552,17 @@ proto_register_metamako(void)
 
     {&hf_metamako_flags_ts_degraded, {
         "Timestamp degraded", "metamako.flags.ts_degraded",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), 0x10,
+        FT_BOOLEAN, 8, NULL, 0x10,
         NULL, HFILL}},
 
     {&hf_metamako_flags_duplicate, {
         "Duplicate Packet", "metamako.flags.is_duplicate",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), 0x04,
+        FT_BOOLEAN, 8, NULL, 0x04,
         NULL, HFILL}},
 
     {&hf_metamako_flags_has_ext, {
         "Has Trailer Extensions", "metamako.flags.has_extensions",
-        FT_BOOLEAN, 8, TFS(&tfs_true_false), 0x02,
+        FT_BOOLEAN, 8, NULL, 0x02,
         NULL, HFILL}},
 
     {&hf_metamako_flags_orig_fcs_vld, {
@@ -654,7 +660,7 @@ proto_register_metamako(void)
 void
 proto_reg_handoff_metamako(void)
 {
-  heur_dissector_add("eth.trailer", dissect_metamako, "Metamako ethernet trailer", "metamako_eth", proto_metamako, HEURISTIC_DISABLE);
+  heur_dissector_add("eth.trailer", dissect_metamako_heur, "Metamako ethernet trailer", "metamako_eth", proto_metamako, HEURISTIC_DISABLE);
 }
 
 /*
