@@ -51,54 +51,54 @@ void proto_reg_handoff_mint(void);
 
 static dissector_handle_t eth_handle;
 
-static int proto_mint = -1;
+static int proto_mint;
 
-static int hf_mint_control = -1;
-static int hf_mint_control_32zerobytes = -1;
-static int hf_mint_control_unknown1 = -1;
-static int hf_mint_data = -1;
-static int hf_mint_data_seqno = -1;
-static int hf_mint_data_unknown1 = -1;
-static int hf_mint_data_vlan = -1;
-static int hf_mint_ethshim = -1;
-static int hf_mint_ethshim_length = -1;
-static int hf_mint_ethshim_unknown = -1;
-static int hf_mint_header = -1;
-static int hf_mint_header_dstdataport = -1;
-static int hf_mint_header_dstid = -1;
-static int hf_mint_header_srcdataport = -1;
-static int hf_mint_header_srcid = -1;
-static int hf_mint_header_ttl = -1;
-static int hf_mint_header_unknown1 = -1;
-static int hf_mint_header_unknown2 = -1;
-static int hf_mint_mlcp_length = -1;
-static int hf_mint_mlcp_message = -1;
-static int hf_mint_mlcp_type = -1;
-static int hf_mint_mlcp_value = -1;
-static int hf_mint_neighbor_unknown = -1;
-static int hf_mint_router_array = -1;
-static int hf_mint_router_element = -1;
-static int hf_mint_router_header_length = -1;
-static int hf_mint_router_header_sender = -1;
-static int hf_mint_router_header_unknown = -1;
-static int hf_mint_router_length = -1;
-static int hf_mint_router_message_type = -1;
-static int hf_mint_router_type_csnp = -1;
-static int hf_mint_router_type_helo = -1;
-static int hf_mint_router_type_lsp = -1;
-static int hf_mint_router_type_psnp = -1;
-static int hf_mint_router_type_unknown = -1;
-static int hf_mint_router_unknown1 = -1;
-static int hf_mint_router_unknown2 = -1;
-static int hf_mint_router_unknown3 = -1;
-static int hf_mint_router_value = -1;
+static int hf_mint_control;
+static int hf_mint_control_32zerobytes;
+static int hf_mint_control_unknown1;
+static int hf_mint_data;
+static int hf_mint_data_seqno;
+static int hf_mint_data_unknown1;
+static int hf_mint_data_vlan;
+static int hf_mint_ethshim;
+static int hf_mint_ethshim_length;
+static int hf_mint_ethshim_unknown;
+static int hf_mint_header;
+static int hf_mint_header_dstdataport;
+static int hf_mint_header_dstid;
+static int hf_mint_header_srcdataport;
+static int hf_mint_header_srcid;
+static int hf_mint_header_ttl;
+static int hf_mint_header_unknown1;
+static int hf_mint_header_unknown2;
+static int hf_mint_mlcp_length;
+static int hf_mint_mlcp_message;
+static int hf_mint_mlcp_type;
+static int hf_mint_mlcp_value;
+static int hf_mint_neighbor_unknown;
+static int hf_mint_router_array;
+static int hf_mint_router_element;
+static int hf_mint_router_header_length;
+static int hf_mint_router_header_sender;
+static int hf_mint_router_header_unknown;
+static int hf_mint_router_length;
+static int hf_mint_router_message_type;
+static int hf_mint_router_type_csnp;
+static int hf_mint_router_type_helo;
+static int hf_mint_router_type_lsp;
+static int hf_mint_router_type_psnp;
+static int hf_mint_router_type_unknown;
+static int hf_mint_router_unknown1;
+static int hf_mint_router_unknown2;
+static int hf_mint_router_unknown3;
+static int hf_mint_router_value;
 
 /* ett handles */
-static int ett_mint_ethshim = -1;
-static int ett_mint = -1;
-static int ett_mint_header = -1;
-static int ett_mint_ctrl = -1;
-static int ett_mint_data = -1;
+static int ett_mint_ethshim;
+static int ett_mint;
+static int ett_mint_header;
+static int ett_mint_ctrl;
+static int ett_mint_data;
 
 static dissector_handle_t mint_control_handle;
 static dissector_handle_t mint_data_handle;
@@ -291,7 +291,7 @@ dissect_eth_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mint_tree,
 	tvbuff_t *eth_tvb;
 
 #ifdef MINT_DEVELOPMENT
-	col_set_writable(pinfo->cinfo, -1, FALSE);
+	col_set_writable(pinfo->cinfo, -1, false);
 #endif
 
 	eth_tvb = tvb_new_subset_length(tvb, offset, length);
@@ -304,7 +304,7 @@ dissect_eth_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mint_tree,
 	offset += length;
 
 #ifdef MINT_DEVELOPMENT
-	col_set_writable(pinfo->cinfo, -1, TRUE);
+	col_set_writable(pinfo->cinfo, -1, true);
 #endif
 	return offset;
 }
