@@ -26,12 +26,16 @@
 #include <epan/expert.h>
 #include <epan/to_str.h>
 #include <epan/strutil.h>
+#include <epan/iana_charsets.h>
 #include "packet-wap.h"
 #include "packet-wsp.h"
 
 void proto_register_mmse(void);
 void proto_reg_handoff_mmse(void);
 
+static dissector_handle_t mmse_standalone_handle;
+static dissector_handle_t mmse_encapsulated_handle;
+
 #define MM_QUOTE                0x7F    /* Quoted string        */
 
 #define MMS_CONTENT_TYPE        0x3E    /* WINA-value for mms-message   */
@@ -172,7 +176,7 @@ static const value_string vals_mm_header_names[] = {
         { MM_CONTENT_HDR,               "Content" },
         { MM_START_HDR,                 "X-Mms-Start" },
         { MM_ADDITIONAL_HDR,            "Additional-headers" },
-        { MM_DISTRIBUION_IND_HDR,       "X-Mms-Distribution-Indcator" },
+        { MM_DISTRIBUION_IND_HDR,       "X-Mms-Distribution-Indicator" },
         { MM_ELEMENT_DESCR_HDR,         "X-Mms-Element-Descriptor" },
         { MM_LIMIT_HDR,                 "X-Mms-Limit" },
 
@@ -181,63 +185,63 @@ static const value_string vals_mm_header_names[] = {
 /*
  * Initialize the protocol and registered fields
  */
-static int proto_mmse = -1;
+static int proto_mmse;
 
-static int hf_mmse_message_type         = -1;
-static int hf_mmse_transaction_id       = -1;
-static int hf_mmse_mms_version          = -1;
-static int hf_mmse_bcc                  = -1;
-static int hf_mmse_cc                   = -1;
-static int hf_mmse_content_location     = -1;
-static int hf_mmse_date                 = -1;
-static int hf_mmse_delivery_report      = -1;
-static int hf_mmse_delivery_time_abs    = -1;
-static int hf_mmse_delivery_time_rel    = -1;
-static int hf_mmse_expiry_abs           = -1;
-static int hf_mmse_expiry_rel           = -1;
-static int hf_mmse_from                 = -1;
-static int hf_mmse_message_class_id     = -1;
-static int hf_mmse_message_class_str    = -1;
-static int hf_mmse_message_id           = -1;
-static int hf_mmse_message_size         = -1;
-static int hf_mmse_priority             = -1;
-static int hf_mmse_read_reply           = -1;
-static int hf_mmse_report_allowed       = -1;
-static int hf_mmse_response_status      = -1;
-static int hf_mmse_response_text        = -1;
-static int hf_mmse_sender_visibility    = -1;
-static int hf_mmse_status               = -1;
-static int hf_mmse_subject              = -1;
-static int hf_mmse_to                   = -1;
-/* static int hf_mmse_content_type              = -1; */
-static int hf_mmse_ffheader             = -1;
+static int hf_mmse_message_type;
+static int hf_mmse_transaction_id;
+static int hf_mmse_mms_version;
+static int hf_mmse_bcc;
+static int hf_mmse_cc;
+static int hf_mmse_content_location;
+static int hf_mmse_date;
+static int hf_mmse_delivery_report;
+static int hf_mmse_delivery_time_abs;
+static int hf_mmse_delivery_time_rel;
+static int hf_mmse_expiry_abs;
+static int hf_mmse_expiry_rel;
+static int hf_mmse_from;
+static int hf_mmse_message_class_id;
+static int hf_mmse_message_class_str;
+static int hf_mmse_message_id;
+static int hf_mmse_message_size;
+static int hf_mmse_priority;
+static int hf_mmse_read_reply;
+static int hf_mmse_report_allowed;
+static int hf_mmse_response_status;
+static int hf_mmse_response_text;
+static int hf_mmse_sender_visibility;
+static int hf_mmse_status;
+static int hf_mmse_subject;
+static int hf_mmse_to;
+/* static int hf_mmse_content_type; */
+static int hf_mmse_ffheader;
 /* MMSE 1.1 */
-static int hf_mmse_read_report          = -1;
-static int hf_mmse_retrieve_status      = -1;
-static int hf_mmse_retrieve_text        = -1;
-static int hf_mmse_read_status          = -1;
-static int hf_mmse_reply_charging       = -1;
-static int hf_mmse_reply_charging_deadline_abs  = -1;
-static int hf_mmse_reply_charging_deadline_rel  = -1;
-static int hf_mmse_reply_charging_id    = -1;
-static int hf_mmse_reply_charging_size  = -1;
-static int hf_mmse_prev_sent_by = -1;
-static int hf_mmse_prev_sent_by_fwd_count       = -1;
-static int hf_mmse_prev_sent_by_address = -1;
-static int hf_mmse_prev_sent_date       = -1;
-static int hf_mmse_prev_sent_date_fwd_count     = -1;
-static int hf_mmse_prev_sent_date_date  = -1;
-static int hf_mmse_header_uint = -1;
-static int hf_mmse_header_string = -1;
-static int hf_mmse_header_bytes = -1;
+static int hf_mmse_read_report;
+static int hf_mmse_retrieve_status;
+static int hf_mmse_retrieve_text;
+static int hf_mmse_read_status;
+static int hf_mmse_reply_charging;
+static int hf_mmse_reply_charging_deadline_abs;
+static int hf_mmse_reply_charging_deadline_rel;
+static int hf_mmse_reply_charging_id;
+static int hf_mmse_reply_charging_size;
+static int hf_mmse_prev_sent_by;
+static int hf_mmse_prev_sent_by_fwd_count;
+static int hf_mmse_prev_sent_by_address;
+static int hf_mmse_prev_sent_date;
+static int hf_mmse_prev_sent_date_fwd_count;
+static int hf_mmse_prev_sent_date_date;
+static int hf_mmse_header_uint;
+static int hf_mmse_header_string;
+static int hf_mmse_header_bytes;
 
 /*
  * Initialize the subtree pointers
  */
-static gint ett_mmse                    = -1;
-static gint ett_mmse_hdr_details        = -1;
+static gint ett_mmse;
+static gint ett_mmse_hdr_details;
 
-static expert_field ei_mmse_oversized_uintvar = EI_INIT;
+static expert_field ei_mmse_oversized_uintvar;
 
 /*
  * Valuestrings for PDU types
@@ -389,6 +393,9 @@ static const value_string vals_message_status[] = {
 };
 
 static const value_string vals_retrieve_status[] = {
+    /* MMS 1.1 */
+    { 0x80, "Ok" },
+
     /*
      * Transient errors
      */
@@ -435,6 +442,8 @@ static const value_string vals_reply_charging[] = {
  *
  * \param       tvb     The buffer with PDU-data
  * \param       offset  Offset within that buffer
+ * \param       pool    wmem allocation pool from which to allocate
+ *                      memory for strval
  * \param       strval  Pointer to variable into which to put pointer to
  *                      buffer allocated to hold the text; must be freed
  *                      when no longer used
@@ -442,18 +451,23 @@ static const value_string vals_reply_charging[] = {
  * \return              The length in bytes of the entire field
  */
 static guint
-get_text_string(tvbuff_t *tvb, guint offset, const char **strval)
+get_text_string(tvbuff_t *tvb, guint offset, wmem_allocator_t *pool, const char **strval)
 {
     guint        len;
 
     DebugLog(("get_text_string(tvb = %p, offset = %u, **strval) - start\n",
                 tvb, offset));
-    len = tvb_strsize(tvb, offset);
-    DebugLog((" [1] tvb_strsize(tvb, offset) == %u\n", len));
-    if (tvb_get_guint8(tvb, offset) == MM_QUOTE)
-        *strval = (const char *)tvb_memdup(wmem_packet_scope(), tvb, offset+1, len-1);
-    else
-        *strval = (const char *)tvb_memdup(wmem_packet_scope(), tvb, offset, len);
+    /* OMA-TS-MMS-CONF says that Text-string encoding is always US-ASCII.
+     * (In other WSP protocols it might be the document encoding.)
+     * It is allowed to be Base64 or Quoted-Printable encoded, but
+     * we won't bother with that.
+     */
+    if (tvb_get_guint8(tvb, offset) == MM_QUOTE) {
+        *strval = (const char *)tvb_get_stringz_enc(pool, tvb, offset+1, &len, ENC_ASCII);
+        len += 1;
+    } else {
+        *strval = (const char *)tvb_get_stringz_enc(pool, tvb, offset, &len, ENC_ASCII);
+    }
     DebugLog((" [3] Return(len) == %u\n", len));
     return len;
 }
@@ -487,43 +501,15 @@ get_value_length(tvbuff_t *tvb, guint offset, guint *byte_count, packet_info *pi
         field = tvb_get_guintvar(tvb, offset, byte_count, pinfo, &ei_mmse_oversized_uintvar);
         (*byte_count)++;
     }
+
+    /* The packet says there are this many bytes; ensure they're there.
+     * We do this here because several callers do math on the length we
+     * return here and may not catch an overflow.
+     */
+    tvb_ensure_bytes_exist(tvb, offset, field);
     return field;
 }
 
-/*!
- * Decodes an Encoded-string-value from the protocol data
- *      Encoded-string-value = Text-string | Value-length Char-set Text-string
- *
- * \param       tvb     The buffer with PDU-data
- * \param       offset  Offset within that buffer
- * \param       strval  Pointer to variable into which to put pointer to
- *                      buffer allocated to hold the text; must be freed
- *                      when no longer used
- *
- * \return              The length in bytes of the entire field
- */
-static guint
-get_encoded_strval(tvbuff_t *tvb, guint offset, const char **strval, packet_info *pinfo)
-{
-    guint        field;
-    guint        length;
-    guint        count;
-
-    field = tvb_get_guint8(tvb, offset);
-
-    if (field < 32) {
-        length = get_value_length(tvb, offset, &count, pinfo);
-        if (length < 2) {
-            *strval = "";
-        } else {
-            /* \todo    Something with "Char-set", skip for now */
-            *strval = (char *)tvb_get_string_enc(wmem_packet_scope(), tvb, offset + count + 1, length - 1, ENC_ASCII);
-        }
-        return count + length;
-    } else
-        return get_text_string(tvb, offset, strval);
-}
-
 /*!
  * Decodes a Long-integer from the protocol data
  *      Long-integer = Short-length Multi-octet-integer
@@ -620,9 +606,51 @@ get_integer_value(tvbuff_t *tvb, guint offset, guint *byte_count)
     return val;
 }
 
+/*!
+ * Decodes an Encoded-string-value from the protocol data
+ *      Encoded-string-value = Text-string | Value-length Char-set Text-string
+ *
+ * \param       tvb     The buffer with PDU-data
+ * \param       offset  Offset within that buffer
+ * \param       strval  Pointer to variable into which to put pointer to
+ *                      buffer allocated to hold the text; must be freed
+ *                      when no longer used
+ *
+ * \return              The length in bytes of the entire field
+ */
+static guint
+get_encoded_strval(tvbuff_t *tvb, guint offset, const char **strval, packet_info *pinfo)
+{
+    guint        field;
+    guint        length;
+    guint        count, count1;
+    guint        charset;
+
+    field = tvb_get_guint8(tvb, offset);
+
+    if (field < 32) {
+        length = get_value_length(tvb, offset, &count, pinfo);
+        if (length < 2) {
+            *strval = "";
+        } else {
+            /* OMA-TS-MMS-CONF says that char-set is encoded as an integer
+             * value, so don't bother to handle the string case. */
+            field = tvb_get_guint8(tvb, offset + count);
+            if ((field < 32) | (field & 0x80)) {
+                charset = get_integer_value(tvb, offset + count, &count1);
+                *strval = (char *)tvb_get_string_enc(pinfo->pool, tvb, offset + count + count1, length - count1, mibenum_charset_to_encoding(charset));
+            } else {
+                *strval = (char *)tvb_get_string_enc(pinfo->pool, tvb, offset + count, length, ENC_ASCII);
+            }
+        }
+        return count + length;
+    } else
+        return get_text_string(tvb, offset, pinfo->pool, strval);
+}
+
 /* Code to actually dissect the packets */
-static gboolean
-dissect_mmse_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool
+dissect_mmse_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     guint8       pdut;
 
@@ -633,15 +661,15 @@ dissect_mmse_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
      * or MMS-Version header
      */
     if (tvb_get_guint8(tvb, 0) != MM_MTYPE_HDR)
-        return FALSE;
+        return false;
     pdut = tvb_get_guint8(tvb, 1);
     if (try_val_to_str(pdut, vals_message_type) == NULL)
-        return FALSE;
+        return false;
     if ((tvb_get_guint8(tvb, 2) != MM_TID_HDR) &&
         (tvb_get_guint8(tvb, 2) != MM_VERSION_HDR))
-        return FALSE;
+        return false;
     dissect_mmse_standalone(tvb, pinfo, tree, data);
-    return TRUE;
+    return true;
 }
 
 static int
@@ -689,7 +717,7 @@ static void
 dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
         const char *message_type)
 {
-    guint        offset;
+    guint        offset, old_offset;
     guint8       field = 0;
     const char   *strval;
     guint        length;
@@ -711,14 +739,15 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
     proto_tree_add_uint(mmse_tree, hf_mmse_message_type, tvb, 0, 2, pdut);
 
     offset = 2;                 /* Skip Message-Type    */
+    old_offset = 1;
 
     /*
      * Cycle through MMS-headers
      *
-     * NOTE - some PDUs may convey content which can be handed off
+     * NOTE - some PDUs may convey content that can be handed off
      *        to subdissectors.
      */
-    if (tree || pdu_has_content(pdut)) {
+    if (tree == NULL && !pdu_has_content(pdut)) {
         DebugLog(("tree == NULL and PDU has no potential content\n"));
         return;
     }
@@ -733,7 +762,7 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
         switch (field)
         {
             case MM_TID_HDR:                /* Text-string  */
-                length = get_text_string(tvb, offset, &strval);
+                length = get_text_string(tvb, offset, pinfo->pool, &strval);
                 proto_tree_add_string(mmse_tree, hf_mmse_transaction_id,
                         tvb, offset - 1, length + 1,strval);
                 offset += length;
@@ -747,9 +776,9 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
                     major = (version & 0x70) >> 4;
                     minor = version & 0x0F;
                     if (minor == 0x0F)
-                        vers_string = wmem_strdup_printf(wmem_packet_scope(), "%u", major);
+                        vers_string = wmem_strdup_printf(pinfo->pool, "%u", major);
                     else
-                        vers_string = wmem_strdup_printf(wmem_packet_scope(), "%u.%u", major, minor);
+                        vers_string = wmem_strdup_printf(pinfo->pool, "%u.%u", major, minor);
                     proto_tree_add_string(mmse_tree, hf_mmse_mms_version,
                             tvb, offset - 2, 2, vers_string);
                 }
@@ -783,7 +812,7 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
                             tvb, offset - 1, length + 1,
                             "<Undecoded value for m-mbox-delete-conf>");
                 } else {
-                    length = get_text_string(tvb, offset, &strval);
+                    length = get_text_string(tvb, offset, pinfo->pool, &strval);
                     proto_tree_add_string(mmse_tree,
                             hf_mmse_content_location,
                             tvb, offset - 1, length + 1, strval);
@@ -897,7 +926,7 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
                             hf_mmse_message_class_id,
                             tvb, offset - 2, 2, field);
                 } else {
-                    length = get_text_string(tvb, offset, &strval);
+                    length = get_text_string(tvb, offset, pinfo->pool, &strval);
                     proto_tree_add_string(mmse_tree,
                             hf_mmse_message_class_str,
                             tvb, offset - 1, length + 1,
@@ -906,7 +935,7 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
                 }
                 break;
             case MM_MID_HDR:                /* Text-string          */
-                length = get_text_string(tvb, offset, &strval);
+                length = get_text_string(tvb, offset, pinfo->pool, &strval);
                 proto_tree_add_string(mmse_tree, hf_mmse_message_id,
                         tvb, offset - 1, length + 1, strval);
                 offset += length;
@@ -1063,7 +1092,7 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
                 offset += length + count;
                 break;
             case MM_REPLY_CHARGING_ID_HDR:  /* Text-string */
-                length = get_text_string(tvb, offset, &strval);
+                length = get_text_string(tvb, offset, pinfo->pool, &strval);
                 proto_tree_add_string(mmse_tree,
                         hf_mmse_reply_charging_id,
                         tvb, offset - 1, length + 1, strval);
@@ -1096,7 +1125,7 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
                             hf_mmse_prev_sent_by,
                             tvb, offset - 1, 1 + count + length,
                             strval, "%s (Forwarded-count=%u)",
-                            format_text(wmem_packet_scope(), strval, strlen(strval)),
+                            format_text(pinfo->pool, strval, strlen(strval)),
                             fwd_count);
                     subtree = proto_item_add_subtree(tii,
                             ett_mmse_hdr_details);
@@ -1126,14 +1155,14 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
                             &count2);
                     tmptime.secs = tval;
                     tmptime.nsecs = 0;
-                    strval = abs_time_to_str(wmem_packet_scope(), &tmptime, ABSOLUTE_TIME_LOCAL,
+                    strval = abs_time_to_str(pinfo->pool, &tmptime, ABSOLUTE_TIME_LOCAL,
                             TRUE);
                     /* Now render the fields */
                     tii = proto_tree_add_string_format(mmse_tree,
                             hf_mmse_prev_sent_date,
                             tvb, offset - 1, 1 + count + length,
                             strval, "%s (Forwarded-count=%u)",
-                            format_text(wmem_packet_scope(), strval, strlen(strval)),
+                            format_text(pinfo->pool, strval, strlen(strval)),
                             fwd_count);
                     subtree = proto_item_add_subtree(tii,
                             ett_mmse_hdr_details);
@@ -1166,8 +1195,8 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
                                 " (not decoded)",
                                 hdr_name, peek);
                     } else if ((peek == 0) || (peek >= 0x20)) { /* Text */
-                        length = get_text_string(tvb, offset, &strval);
-                        str = format_text(wmem_packet_scope(), strval, strlen(strval));
+                        length = get_text_string(tvb, offset, pinfo->pool, &strval);
+                        str = format_text(pinfo->pool, strval, strlen(strval));
                         proto_tree_add_string_format(mmse_tree, hf_mmse_header_string, tvb, offset - 1,
                                 length + 1, str, "%s: %s (Not decoded)", hdr_name, str);
                     } else { /* General form with length */
@@ -1190,25 +1219,30 @@ dissect_mmse(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint8 pdut,
                     const char       *strval2;
 
                     --offset;
-                    length = get_text_string(tvb, offset, &strval);
+                    length = get_text_string(tvb, offset, pinfo->pool, &strval);
                     DebugLog(("\t\tUndecoded literal header: %s\n",
                                 strval));
-                    length2= get_text_string(tvb, offset+length, &strval2);
+                    length2= get_text_string(tvb, offset+length, pinfo->pool, &strval2);
 
                     proto_tree_add_string_format(mmse_tree,
                             hf_mmse_ffheader, tvb, offset,
                             length + length2,
-                            tvb_get_string_enc(wmem_packet_scope(), tvb, offset,
+                            tvb_get_string_enc(pinfo->pool, tvb, offset,
                                 length + length2, ENC_ASCII),
                             "%s: %s",
-                            format_text(wmem_packet_scope(), strval, strlen(strval)),
-                            format_text(wmem_packet_scope(), strval2, strlen(strval2)));
+                            format_text(pinfo->pool, strval, strlen(strval)),
+                            format_text(pinfo->pool, strval2, strlen(strval2)));
 
                     offset += length + length2;
                 }
                 break;
         }
         DebugLog(("\tEnd(case)\n"));
+
+        if (offset <= old_offset) {
+            REPORT_DISSECTOR_BUG("Offset isn't increasing (offset=%u, old offset=%u)", offset, old_offset);
+        }
+        old_offset = offset;
     }
 
     DebugLog(("\tEnd(switch)\n"));
@@ -1590,6 +1624,10 @@ proto_register_mmse(void)
 
     expert_mmse = expert_register_protocol(proto_mmse);
     expert_register_field_array(expert_mmse, ei, array_length(ei));
+
+    /* Register the dissectors */
+    mmse_standalone_handle = register_dissector("mmse", dissect_mmse_standalone, proto_mmse);
+    mmse_encapsulated_handle = register_dissector("mmse_encapsulated", dissect_mmse_encapsulated, proto_mmse);
 }
 
 /* If this dissector uses sub-dissector registration add registration routine.
@@ -1599,14 +1637,7 @@ proto_register_mmse(void)
 void
 proto_reg_handoff_mmse(void)
 {
-    dissector_handle_t mmse_standalone_handle;
-    dissector_handle_t mmse_encapsulated_handle;
-
     heur_dissector_add("wsp", dissect_mmse_heur, "MMS Message Encapsulation over WSP", "mmse_wsp", proto_mmse, HEURISTIC_ENABLE);
-    mmse_standalone_handle = create_dissector_handle(
-            dissect_mmse_standalone, proto_mmse);
-    mmse_encapsulated_handle = create_dissector_handle(
-            dissect_mmse_encapsulated, proto_mmse);
         /* As the media types for WSP and HTTP are the same, the WSP dissector
          * uses the same string dissector table as the HTTP protocol. */
     dissector_add_string("media_type",
@@ -1616,7 +1647,7 @@ proto_reg_handoff_mmse(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
