@@ -36,78 +36,78 @@ static dissector_handle_t mojito_handle;
 #define MOJITO_STATS_RESPONSE_DEPRECATED  10
 
 /* Initialize the protocol and registered fields */
-static int proto_mojito = -1;
+static int proto_mojito;
 
 /* Start of fields */
-static int hf_mojito_messageid = -1;
-static int hf_mojito_fdhtmessage = -1;
-static int hf_mojito_mjrversion = -1;
-static int hf_mojito_mnrversion = -1;
-static int hf_mojito_length = -1;
-static int hf_mojito_opcode = -1;
-static int hf_mojito_vendor = -1;
-static int hf_mojito_origmjrversion = -1;
-static int hf_mojito_origmnrversion = -1;
-static int hf_mojito_kuid = -1;
-static int hf_mojito_socketaddress_version = -1;
-static int hf_mojito_socketaddress_ipv4 = -1;
-static int hf_mojito_socketaddress_ipv6 = -1;
-static int hf_mojito_socketaddress_port = -1;
-static int hf_mojito_instanceid = -1;
-static int hf_mojito_flags = -1;
-static int hf_mojito_flags_shutdown = -1;
-static int hf_mojito_flags_firewalled = -1;
-static int hf_mojito_extendedlength = -1;
-static int hf_mojito_kuidcount = -1;
-static int hf_mojito_bigintegerlen = -1;
-static int hf_mojito_bigintegerval = -1;
-static int hf_mojito_dhtvaluetype = -1;
-static int hf_mojito_sectokenlen = -1;
-static int hf_mojito_sectoken = -1;
-static int hf_mojito_contactcount = -1;
-static int hf_mojito_contactvendor = -1;
-static int hf_mojito_contactversion = -1;
-static int hf_mojito_contactkuid = -1;
-static int hf_mojito_dhtvaluecount = -1;
-static int hf_mojito_dhtvalue_kuid = -1;
-static int hf_mojito_target_kuid = -1;
-static int hf_mojito_dhtvalue_valuetype = -1;
-static int hf_mojito_dhtvalue_version = -1;
-static int hf_mojito_dhtvalue_length = -1;
-static int hf_mojito_dhtvalue_value = -1;
-static int hf_mojito_bigint_value_one = -1;
-static int hf_mojito_bigint_value_two = -1;
-static int hf_mojito_bigint_value_three = -1;
-static int hf_mojito_bigint_value_four = -1;
-static int hf_mojito_storestatuscode_count = -1;
-static int hf_mojito_storestatuscode_code = -1;
-static int hf_mojito_storestatuscode_kuid = -1;
-static int hf_mojito_storestatuscode_secondary_kuid = -1;
-static int hf_mojito_requestload = -1;
+static int hf_mojito_messageid;
+static int hf_mojito_fdhtmessage;
+static int hf_mojito_mjrversion;
+static int hf_mojito_mnrversion;
+static int hf_mojito_length;
+static int hf_mojito_opcode;
+static int hf_mojito_vendor;
+static int hf_mojito_origmjrversion;
+static int hf_mojito_origmnrversion;
+static int hf_mojito_kuid;
+static int hf_mojito_socketaddress_version;
+static int hf_mojito_socketaddress_ipv4;
+static int hf_mojito_socketaddress_ipv6;
+static int hf_mojito_socketaddress_port;
+static int hf_mojito_instanceid;
+static int hf_mojito_flags;
+static int hf_mojito_flags_shutdown;
+static int hf_mojito_flags_firewalled;
+static int hf_mojito_extendedlength;
+static int hf_mojito_kuidcount;
+static int hf_mojito_bigintegerlen;
+static int hf_mojito_bigintegerval;
+static int hf_mojito_dhtvaluetype;
+static int hf_mojito_sectokenlen;
+static int hf_mojito_sectoken;
+static int hf_mojito_contactcount;
+static int hf_mojito_contactvendor;
+static int hf_mojito_contactversion;
+static int hf_mojito_contactkuid;
+static int hf_mojito_dhtvaluecount;
+static int hf_mojito_dhtvalue_kuid;
+static int hf_mojito_target_kuid;
+static int hf_mojito_dhtvalue_valuetype;
+static int hf_mojito_dhtvalue_version;
+static int hf_mojito_dhtvalue_length;
+static int hf_mojito_dhtvalue_value;
+static int hf_mojito_bigint_value_one;
+static int hf_mojito_bigint_value_two;
+static int hf_mojito_bigint_value_three;
+static int hf_mojito_bigint_value_four;
+static int hf_mojito_storestatuscode_count;
+static int hf_mojito_storestatuscode_code;
+static int hf_mojito_storestatuscode_kuid;
+static int hf_mojito_storestatuscode_secondary_kuid;
+static int hf_mojito_requestload;
 #if 0
-static int hf_mojito_startflag = -1;
-static int hf_mojito_endflag = -1;
-static int hf_mojito_priorityflag = -1;
+static int hf_mojito_startflag;
+static int hf_mojito_endflag;
+static int hf_mojito_priorityflag;
 #endif
-static int hf_mojito_opcode_data = -1;
+static int hf_mojito_opcode_data;
 
 /* Initialize the subtree pointers */
-static gint ett_mojito = -1;
-static gint ett_mojito_header = -1;
-static gint ett_mojito_header_version = -1;
-static gint ett_mojito_contact = -1;
-static gint ett_mojito_contact_version = -1;
-static gint ett_mojito_socket_address = -1;
-static gint ett_mojito_flags = -1;
-static gint ett_mojito_bigint = -1;
-static gint ett_mojito_opcode = -1;
-static gint ett_mojito_dht_version = -1;
-static gint ett_mojito_dht = -1;
-static gint ett_mojito_status_code = -1;
-static gint ett_mojito_kuids = -1;
+static gint ett_mojito;
+static gint ett_mojito_header;
+static gint ett_mojito_header_version;
+static gint ett_mojito_contact;
+static gint ett_mojito_contact_version;
+static gint ett_mojito_socket_address;
+static gint ett_mojito_flags;
+static gint ett_mojito_bigint;
+static gint ett_mojito_opcode;
+static gint ett_mojito_dht_version;
+static gint ett_mojito_dht;
+static gint ett_mojito_status_code;
+static gint ett_mojito_kuids;
 
-static expert_field ei_mojito_socketaddress_unknown = EI_INIT;
-static expert_field ei_mojito_bigint_unsupported = EI_INIT;
+static expert_field ei_mojito_socketaddress_unknown;
+static expert_field ei_mojito_bigint_unsupported;
 
 typedef struct mojito_header_data {
 	guint8 opcode;
@@ -464,7 +464,7 @@ dissect_mojito_store_response(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree
 
 		if (tvb_reported_length_remaining(tvb, offset+3) > 0)
 		{
-			/* Must be a secondard KUID */
+			/* Must be a secondary KUID */
 			proto_tree_add_item(sc_tree, hf_mojito_storestatuscode_secondary_kuid, tvb, offset, 20, ENC_NA);
 			offset += 20;
 		}
@@ -676,7 +676,7 @@ dissect_mojito(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _
 	return tvb_captured_length(tvb);
 }
 
-static gboolean dissect_mojito_heuristic (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool dissect_mojito_heuristic (tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
 	/*
 	  Test the overall length to make sure it's at least 61 bytes (the header)
@@ -688,11 +688,11 @@ static gboolean dissect_mojito_heuristic (tvbuff_t *tvb, packet_info *pinfo, pro
 	    (tvb_get_guint8(tvb, 16) == 68) &&
 	    ((tvb_get_letohl(tvb, 19) + 23) == tvb_reported_length(tvb)))
 	{
-		dissect_mojito(tvb, pinfo, tree, NULL);
-		return TRUE;
+		dissect_mojito(tvb, pinfo, tree, data);
+		return true;
 	}
 
-	return FALSE;
+	return false;
 }
 
 /* Register the mojito dissector */
