@@ -22,69 +22,69 @@
 void proto_register_mount(void);
 void proto_reg_handoff_mount(void);
 
-static int proto_mount = -1;
-static int proto_sgi_mount = -1;
-static int hf_mount_procedure_v1 = -1;
-static int hf_mount_procedure_v2 = -1;
-static int hf_mount_procedure_v3 = -1;
-static int hf_sgi_mount_procedure_v1 = -1;
-static int hf_mount_path = -1;
-static int hf_mount3_status = -1;
-static int hf_mount_mountlist_hostname = -1;
-static int hf_mount_mountlist_directory = -1;
-static int hf_mount_mountlist = -1;
-static int hf_mount_groups_group = -1;
-static int hf_mount_groups = -1;
-static int hf_mount_exportlist_directory = -1;
-static int hf_mount_exportlist = -1;
-static int hf_mount_has_options = -1;
-static int hf_mount_options = -1;
-static int hf_mount_pathconf_link_max = -1;
-static int hf_mount_pathconf_max_canon = -1;
-static int hf_mount_pathconf_max_input = -1;
-static int hf_mount_pathconf_name_max = -1;
-static int hf_mount_pathconf_path_max = -1;
-static int hf_mount_pathconf_pipe_buf = -1;
-static int hf_mount_pathconf_vdisable = -1;
-static int hf_mount_pathconf_mask = -1;
-static int hf_mount_pathconf_error_all = -1;
-static int hf_mount_pathconf_error_link_max = -1;
-static int hf_mount_pathconf_error_max_canon = -1;
-static int hf_mount_pathconf_error_max_input = -1;
-static int hf_mount_pathconf_error_name_max = -1;
-static int hf_mount_pathconf_error_path_max = -1;
-static int hf_mount_pathconf_error_pipe_buf = -1;
-static int hf_mount_pathconf_chown_restricted = -1;
-static int hf_mount_pathconf_no_trunc = -1;
-static int hf_mount_pathconf_error_vdisable = -1;
-static int hf_mount_statvfs_bsize = -1;
-static int hf_mount_statvfs_frsize = -1;
-static int hf_mount_statvfs_blocks = -1;
-static int hf_mount_statvfs_bfree = -1;
-static int hf_mount_statvfs_bavail = -1;
-static int hf_mount_statvfs_files = -1;
-static int hf_mount_statvfs_ffree = -1;
-static int hf_mount_statvfs_favail = -1;
-static int hf_mount_statvfs_fsid = -1;
-static int hf_mount_statvfs_basetype = -1;
-static int hf_mount_statvfs_flag = -1;
-static int hf_mount_statvfs_flag_rdonly = -1;
-static int hf_mount_statvfs_flag_nosuid = -1;
-static int hf_mount_statvfs_flag_notrunc = -1;
-static int hf_mount_statvfs_flag_nodev = -1;
-static int hf_mount_statvfs_flag_grpid = -1;
-static int hf_mount_statvfs_flag_local = -1;
-static int hf_mount_statvfs_namemax = -1;
-static int hf_mount_statvfs_fstr = -1;
-static int hf_mount_flavors = -1;
-static int hf_mount_flavor = -1;
+static int proto_mount;
+static int proto_sgi_mount;
+static int hf_mount_procedure_v1;
+static int hf_mount_procedure_v2;
+static int hf_mount_procedure_v3;
+static int hf_sgi_mount_procedure_v1;
+static int hf_mount_path;
+static int hf_mount3_status;
+static int hf_mount_mountlist_hostname;
+static int hf_mount_mountlist_directory;
+static int hf_mount_mountlist;
+static int hf_mount_groups_group;
+static int hf_mount_groups;
+static int hf_mount_exportlist_directory;
+static int hf_mount_exportlist;
+static int hf_mount_has_options;
+static int hf_mount_options;
+static int hf_mount_pathconf_link_max;
+static int hf_mount_pathconf_max_canon;
+static int hf_mount_pathconf_max_input;
+static int hf_mount_pathconf_name_max;
+static int hf_mount_pathconf_path_max;
+static int hf_mount_pathconf_pipe_buf;
+static int hf_mount_pathconf_vdisable;
+static int hf_mount_pathconf_mask;
+static int hf_mount_pathconf_error_all;
+static int hf_mount_pathconf_error_link_max;
+static int hf_mount_pathconf_error_max_canon;
+static int hf_mount_pathconf_error_max_input;
+static int hf_mount_pathconf_error_name_max;
+static int hf_mount_pathconf_error_path_max;
+static int hf_mount_pathconf_error_pipe_buf;
+static int hf_mount_pathconf_chown_restricted;
+static int hf_mount_pathconf_no_trunc;
+static int hf_mount_pathconf_error_vdisable;
+static int hf_mount_statvfs_bsize;
+static int hf_mount_statvfs_frsize;
+static int hf_mount_statvfs_blocks;
+static int hf_mount_statvfs_bfree;
+static int hf_mount_statvfs_bavail;
+static int hf_mount_statvfs_files;
+static int hf_mount_statvfs_ffree;
+static int hf_mount_statvfs_favail;
+static int hf_mount_statvfs_fsid;
+static int hf_mount_statvfs_basetype;
+static int hf_mount_statvfs_flag;
+static int hf_mount_statvfs_flag_rdonly;
+static int hf_mount_statvfs_flag_nosuid;
+static int hf_mount_statvfs_flag_notrunc;
+static int hf_mount_statvfs_flag_nodev;
+static int hf_mount_statvfs_flag_grpid;
+static int hf_mount_statvfs_flag_local;
+static int hf_mount_statvfs_namemax;
+static int hf_mount_statvfs_fstr;
+static int hf_mount_flavors;
+static int hf_mount_flavor;
 
-static gint ett_mount = -1;
-static gint ett_mount_mountlist = -1;
-static gint ett_mount_groups = -1;
-static gint ett_mount_exportlist = -1;
-static gint ett_mount_pathconf_mask = -1;
-static gint ett_mount_statvfs_flag = -1;
+static gint ett_mount;
+static gint ett_mount_mountlist;
+static gint ett_mount_groups;
+static gint ett_mount_exportlist;
+static gint ett_mount_pathconf_mask;
+static gint ett_mount_statvfs_flag;
 
 /* RFC 1813, Page 107 */
 static const value_string mount3_mountstat3[] =
@@ -109,7 +109,7 @@ static const value_string mount3_mountstat3[] =
  * 3 of the protocol.
  * Though not formally defined in the standard, we use the same
  * value-to-string mappings as version 3 since we believe that this mapping
- * is consistant with most v1 and v2 implementations.
+ * is consistent with most v1 and v2 implementations.
  */
 static int
 dissect_fhstatus(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree, rpc_call_info_value* civ)
@@ -154,12 +154,12 @@ dissect_mount_dirpath_call(tvbuff_t *tvb, packet_info *pinfo,
 				gchar *name, *ptr;
 				int addr_len, name_len;
 
-				name = address_to_str(wmem_packet_scope(), &pinfo->dst);
+				name = address_to_str(pinfo->pool, &pinfo->dst);
 				addr_len = (int)strlen(name);
 				/* IP address, colon, path, terminating 0 */
 				name_len = addr_len + 1 + len_field + 1;
 
-				name = (gchar *)wmem_realloc(wmem_packet_scope(),
+				name = (gchar *)wmem_realloc(pinfo->pool,
 						(void *)name, name_len);
 				ptr = name + addr_len;
 				*ptr++ = ':';
@@ -276,7 +276,7 @@ dissect_exportlist(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tr
 	groups_item = proto_tree_add_item(exportlist_tree, hf_mount_groups, tvb, offset, -1, ENC_NA);
 	groups_tree = proto_item_add_subtree(groups_item, ett_mount_groups);
 
-	group_name_list_strbuf = wmem_strbuf_new(wmem_packet_scope(), "");
+	group_name_list_strbuf = wmem_strbuf_new(pinfo->pool, "");
 	offset = dissect_rpc_list(tvb, pinfo, groups_tree, offset,
 		dissect_group, (void *)group_name_list_strbuf);
 	if (groups_item) {
@@ -295,8 +295,8 @@ dissect_exportlist(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tr
 		/* now we have a nicer string */
 		proto_item_set_text(exportlist_item,
 		    "Export List Entry: %s -> %s",
-		    format_text(wmem_packet_scope(), directory, strlen(directory)),
-		    format_text(wmem_packet_scope(), group_name_list, strlen(group_name_list)));
+		    format_text(pinfo->pool, directory, strlen(directory)),
+		    format_text(pinfo->pool, group_name_list, strlen(group_name_list)));
 		/* now we know, that exportlist is shorter */
 		proto_item_set_len(exportlist_item, offset - old_offset);
 	}
