@@ -42,26 +42,26 @@ static dissector_handle_t mpeg_sect_handle;
 
 static heur_dissector_list_t heur_subdissector_list;
 
-static int proto_mp2t = -1;
-static gint ett_mp2t = -1;
-static gint ett_mp2t_header = -1;
-static gint ett_mp2t_af = -1;
-static gint ett_mp2t_analysis = -1;
-static gint ett_stuff = -1;
+static int proto_mp2t;
+static gint ett_mp2t;
+static gint ett_mp2t_header;
+static gint ett_mp2t_af;
+static gint ett_mp2t_analysis;
+static gint ett_stuff;
 
-static int hf_mp2t_header = -1;
-static int hf_mp2t_sync_byte = -1;
-static int hf_mp2t_tei = -1;
-static int hf_mp2t_pusi = -1;
-static int hf_mp2t_tp = -1;
-static int hf_mp2t_pid = -1;
-static int hf_mp2t_tsc = -1;
-static int hf_mp2t_afc = -1;
-static int hf_mp2t_cc = -1;
+static int hf_mp2t_header;
+static int hf_mp2t_sync_byte;
+static int hf_mp2t_tei;
+static int hf_mp2t_pusi;
+static int hf_mp2t_tp;
+static int hf_mp2t_pid;
+static int hf_mp2t_tsc;
+static int hf_mp2t_afc;
+static int hf_mp2t_cc;
 
-/* static int hf_mp2t_analysis_flags = -1; */
-static int hf_mp2t_analysis_skips = -1;
-static int hf_mp2t_analysis_drops = -1;
+/* static int hf_mp2t_analysis_flags; */
+static int hf_mp2t_analysis_skips;
+static int hf_mp2t_analysis_drops;
 
 #define MP2T_SYNC_BYTE_MASK  0xFF000000
 #define MP2T_TEI_MASK        0x00800000
@@ -81,16 +81,16 @@ static int hf_mp2t_analysis_drops = -1;
 #define MP2T_AFC_SHIFT         4
 #define MP2T_CC_SHIFT          0
 
-static int hf_mp2t_af = -1;
-static int hf_mp2t_af_length = -1;
-static int hf_mp2t_af_di = -1;
-static int hf_mp2t_af_rai = -1;
-static int hf_mp2t_af_espi = -1;
-static int hf_mp2t_af_pcr_flag = -1;
-static int hf_mp2t_af_opcr_flag = -1;
-static int hf_mp2t_af_sp_flag = -1;
-static int hf_mp2t_af_tpd_flag = -1;
-static int hf_mp2t_af_afe_flag = -1;
+static int hf_mp2t_af;
+static int hf_mp2t_af_length;
+static int hf_mp2t_af_di;
+static int hf_mp2t_af_rai;
+static int hf_mp2t_af_espi;
+static int hf_mp2t_af_pcr_flag;
+static int hf_mp2t_af_opcr_flag;
+static int hf_mp2t_af_sp_flag;
+static int hf_mp2t_af_tpd_flag;
+static int hf_mp2t_af_afe_flag;
 
 #define MP2T_AF_DI_MASK     0x80
 #define MP2T_AF_RAI_MASK    0x40
@@ -110,44 +110,44 @@ static int hf_mp2t_af_afe_flag = -1;
 #define MP2T_AF_TPD_SHIFT    1
 #define MP2T_AF_AFE_SHIFT    0
 
-static int hf_mp2t_af_pcr = -1;
-static int hf_mp2t_af_opcr = -1;
+static int hf_mp2t_af_pcr;
+static int hf_mp2t_af_opcr;
 
-static int hf_mp2t_af_sc = -1;
+static int hf_mp2t_af_sc;
 
-static int hf_mp2t_af_tpd_length = -1;
-static int hf_mp2t_af_tpd = -1;
+static int hf_mp2t_af_tpd_length;
+static int hf_mp2t_af_tpd;
 
-static int hf_mp2t_af_e_length = -1;
-static int hf_mp2t_af_e_ltw_flag = -1;
-static int hf_mp2t_af_e_pr_flag = -1;
-static int hf_mp2t_af_e_ss_flag = -1;
-static int hf_mp2t_af_e_reserved = -1;
+static int hf_mp2t_af_e_length;
+static int hf_mp2t_af_e_ltw_flag;
+static int hf_mp2t_af_e_pr_flag;
+static int hf_mp2t_af_e_ss_flag;
+static int hf_mp2t_af_e_reserved;
 
 #define MP2T_AF_E_LTW_FLAG_MASK   0x80
 #define MP2T_AF_E_PR_FLAG_MASK    0x40
 #define MP2T_AF_E_SS_FLAG_MASK    0x20
 
-static int hf_mp2t_af_e_reserved_bytes = -1;
-static int hf_mp2t_af_stuffing_bytes = -1;
+static int hf_mp2t_af_e_reserved_bytes;
+static int hf_mp2t_af_stuffing_bytes;
 
-static int hf_mp2t_af_e_ltwv_flag = -1;
-static int hf_mp2t_af_e_ltwo = -1;
+static int hf_mp2t_af_e_ltwv_flag;
+static int hf_mp2t_af_e_ltwo;
 
-static int hf_mp2t_af_e_pr_reserved = -1;
-static int hf_mp2t_af_e_pr = -1;
+static int hf_mp2t_af_e_pr_reserved;
+static int hf_mp2t_af_e_pr;
 
-static int hf_mp2t_af_e_st = -1;
-static int hf_mp2t_af_e_dnau_32_30 = -1;
-static int hf_mp2t_af_e_m_1 = -1;
-static int hf_mp2t_af_e_dnau_29_15 = -1;
-static int hf_mp2t_af_e_m_2 = -1;
-static int hf_mp2t_af_e_dnau_14_0 = -1;
-static int hf_mp2t_af_e_m_3 = -1;
+static int hf_mp2t_af_e_st;
+static int hf_mp2t_af_e_dnau_32_30;
+static int hf_mp2t_af_e_m_1;
+static int hf_mp2t_af_e_dnau_29_15;
+static int hf_mp2t_af_e_m_2;
+static int hf_mp2t_af_e_dnau_14_0;
+static int hf_mp2t_af_e_m_3;
 
-/* static int hf_mp2t_payload = -1; */
-static int hf_mp2t_stuff_bytes = -1;
-static int hf_mp2t_pointer = -1;
+/* static int hf_mp2t_payload; */
+static int hf_mp2t_stuff_bytes;
+static int hf_mp2t_pointer;
 
 /* proto data keys. Note that the packet_analysis_data structure is stored
  * using the layer number, but since that is at wmem_file_scope() while
@@ -216,24 +216,24 @@ static const value_string mp2t_afc_vals[] = {
     { 0, NULL }
 };
 
-static gint ett_msg_fragment = -1;
-static gint ett_msg_fragments = -1;
-static int hf_msg_fragments = -1;
-static int hf_msg_fragment = -1;
-static int hf_msg_fragment_overlap = -1;
-static int hf_msg_fragment_overlap_conflicts = -1;
-static int hf_msg_fragment_multiple_tails = -1;
-static int hf_msg_fragment_too_long_fragment = -1;
-static int hf_msg_fragment_error = -1;
-static int hf_msg_fragment_count = -1;
-static int hf_msg_reassembled_in = -1;
-static int hf_msg_reassembled_length = -1;
+static gint ett_msg_fragment;
+static gint ett_msg_fragments;
+static int hf_msg_fragments;
+static int hf_msg_fragment;
+static int hf_msg_fragment_overlap;
+static int hf_msg_fragment_overlap_conflicts;
+static int hf_msg_fragment_multiple_tails;
+static int hf_msg_fragment_too_long_fragment;
+static int hf_msg_fragment_error;
+static int hf_msg_fragment_count;
+static int hf_msg_reassembled_in;
+static int hf_msg_reassembled_length;
 
-static int hf_msg_ts_packet_reassembled = -1;
+static int hf_msg_ts_packet_reassembled;
 
-static expert_field ei_mp2t_pointer = EI_INIT;
-static expert_field ei_mp2t_cc_drop = EI_INIT;
-static expert_field ei_mp2t_invalid_afc = EI_INIT;
+static expert_field ei_mp2t_pointer;
+static expert_field ei_mp2t_cc_drop;
+static expert_field ei_mp2t_invalid_afc;
 
 static const fragment_items mp2t_msg_frag_items = {
     /* Fragment subtrees */
@@ -282,7 +282,7 @@ static const fragment_items mp2t_msg_frag_items = {
  *                            +-> ts_analysis_data
  */
 
-static wmem_map_t *mp2t_stream_hashtable = NULL;
+static wmem_map_t *mp2t_stream_hashtable;
 
 typedef struct {
     const conversation_t* conv;
@@ -359,6 +359,7 @@ typedef struct pid_analysis_data {
     guint16                  pid;
     gint8                    cc_prev;      /* Previous CC number */
     enum pid_payload_type    pload_type;
+    wmem_tree_t             *stream_types;
 
     /* Fragments information used for first pass */
     gboolean                 fragmentation;
@@ -451,6 +452,7 @@ get_pid_analysis(mp2t_analysis_data_t *mp2t_data, guint32 pid)
         pid_data          = wmem_new0(wmem_file_scope(), struct pid_analysis_data);
         pid_data->cc_prev = -1;
         pid_data->pid     = pid;
+        pid_data->stream_types = wmem_tree_new(wmem_file_scope());
         pid_data->frag_id = (pid << (32 - 13)) | 0x1;
 
         wmem_tree_insert32(mp2t_data->pid_table, pid, (void *)pid_data);
@@ -535,31 +537,45 @@ mp2t_reassembly_table_functions = {
 
 static reassembly_table mp2t_reassembly_table;
 
+void
+mp2t_add_stream_type(packet_info *pinfo, guint32 pid, guint32 stream_type)
+{
+    mp2t_stream_key *stream;
+
+    stream = (mp2t_stream_key *)p_get_proto_data(pinfo->pool, pinfo, proto_mp2t, MP2T_PROTO_DATA_STREAM);
+    if (!stream) {
+        return;
+    }
+
+    mp2t_analysis_data_t *mp2t_data = get_mp2t_conversation_data(stream);
+    pid_analysis_data_t *pid_data = get_pid_analysis(mp2t_data, pid);
+
+    if (!pid_data->stream_types) {
+        pid_data->stream_types = wmem_tree_new(wmem_file_scope());
+    }
+
+    wmem_tree_insert32(pid_data->stream_types, pinfo->num, GUINT_TO_POINTER(stream_type));
+}
+
 static void
-mp2t_dissect_packet(tvbuff_t *tvb, enum pid_payload_type pload_type,
+mp2t_dissect_packet(tvbuff_t *tvb, const pid_analysis_data_t *pid_analysis,
             packet_info *pinfo, proto_tree *tree)
 {
-    dissector_handle_t handle = NULL;
-
-    switch (pload_type) {
+    switch (pid_analysis->pload_type) {
         case pid_pload_docsis:
-            handle = docsis_handle;
+            call_dissector(docsis_handle, tvb, pinfo, tree);
             break;
         case pid_pload_pes:
-            handle = mpeg_pes_handle;
+            call_dissector_with_data(mpeg_pes_handle, tvb, pinfo, tree, wmem_tree_lookup32_le(pid_analysis->stream_types, pinfo->num));
             break;
         case pid_pload_sect:
-            handle = mpeg_sect_handle;
+            call_dissector(mpeg_sect_handle, tvb, pinfo, tree);
             break;
         default:
             /* Should not happen */
+            call_data_dissector(tvb, pinfo, tree);
             break;
     }
-
-    if (handle)
-        call_dissector(handle, tvb, pinfo, tree);
-    else
-        call_data_dissector(tvb, pinfo, tree);
 }
 
 /* Determine the length of a payload packet. If there aren't enough
@@ -573,16 +589,17 @@ mp2t_get_packet_length(tvbuff_t *tvb, guint offset, packet_info *pinfo,
             guint32 frag_id, enum pid_payload_type pload_type)
 {
     mp2t_stream_key *stream;
-    fragment_head *frag;
+    fragment_head *frag_head;
+    fragment_item *frag = NULL;
     tvbuff_t      *len_tvb = NULL, *frag_tvb = NULL, *data_tvb = NULL;
     gint           pkt_len = 0;
     guint          remaining_len;
 
     stream = (mp2t_stream_key *)p_get_proto_data(pinfo->pool, pinfo, proto_mp2t, MP2T_PROTO_DATA_STREAM);
     if (pinfo->fd->visited) {
-        frag = fragment_get_reassembled_id(&mp2t_reassembly_table, pinfo, frag_id);
-        if (frag) {
-            len_tvb = frag->tvb_data;
+        frag_head = fragment_get_reassembled_id(&mp2t_reassembly_table, pinfo, frag_id);
+        if (frag_head) {
+            len_tvb = frag_head->tvb_data;
             offset = 0;
         } else {
             /* Not reassembled on the first pass. There are two possibilities:
@@ -590,8 +607,8 @@ mp2t_get_packet_length(tvbuff_t *tvb, guint offset, packet_info *pinfo,
              * put in the table.
              * 2) Dangling fragments at the end of the capture.
              */
-            frag = fragment_get(&mp2t_reassembly_table, pinfo, frag_id, stream);
-            if (!frag) {
+            frag_head = fragment_get(&mp2t_reassembly_table, pinfo, frag_id, stream);
+            if (!frag_head) {
                 /* This is the entire packet */
                 len_tvb = tvb;
             } else {
@@ -602,9 +619,10 @@ mp2t_get_packet_length(tvbuff_t *tvb, guint offset, packet_info *pinfo,
             }
         }
     } else {
-        frag = fragment_get(&mp2t_reassembly_table, pinfo, frag_id, stream);
-        if (frag)
-            frag = frag->next;
+        frag_head = fragment_get(&mp2t_reassembly_table, pinfo, frag_id, stream);
+        if (frag_head) {
+            frag = frag_head->next;
+        }
 
         if (!frag) { /* First frame */
             len_tvb = tvb;
@@ -658,7 +676,7 @@ static void
 mp2t_fragment_handle(tvbuff_t *tvb, guint offset, packet_info *pinfo,
         proto_tree *tree, guint32 frag_id,
         guint frag_offset, guint frag_len,
-        gboolean fragment_last, enum pid_payload_type pload_type)
+        gboolean fragment_last, const pid_analysis_data_t *pid_analysis)
 {
     fragment_head   *frag_msg;
     proto_item      *ti;
@@ -718,7 +736,7 @@ mp2t_fragment_handle(tvbuff_t *tvb, guint offset, packet_info *pinfo,
          * back in the calling function.)
          */
         TRY {
-            mp2t_dissect_packet(new_tvb, pload_type, pinfo, tree);
+            mp2t_dissect_packet(new_tvb, pid_analysis, pinfo, tree);
         }
         CATCH_NONFATAL_ERRORS {
             show_exception(tvb, pinfo, tree, EXCEPT_CODE, GET_MESSAGE);
@@ -956,7 +974,7 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
          */
         if (fragmentation) {
             mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, frag_cur_pos,
-                    pointer, TRUE, pid_analysis->pload_type);
+                    pointer, TRUE, pid_analysis);
             frag_id++;
         }
 
@@ -999,7 +1017,7 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
             /* Get the next packet's size if possible */
             frag_tot_len = mp2t_get_packet_length(tvb, offset, pinfo, frag_id, pid_analysis->pload_type);
             if (frag_tot_len == (guint)-1 || !frag_tot_len) {
-                mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, 0, remaining_len, FALSE, pid_analysis->pload_type);
+                mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, 0, remaining_len, FALSE, pid_analysis);
                 fragmentation = TRUE;
                 /*offset += remaining_len;*/
                 frag_cur_pos += remaining_len;
@@ -1007,10 +1025,9 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
             }
 
             /* Check for full packets within this TS frame */
-            if (frag_tot_len &&
-                    frag_tot_len <= remaining_len) {
+            if (frag_tot_len <= remaining_len) {
                 next_tvb = tvb_new_subset_length(tvb, offset, frag_tot_len);
-                mp2t_dissect_packet(next_tvb, pid_analysis->pload_type, pinfo, tree);
+                mp2t_dissect_packet(next_tvb, pid_analysis, pinfo, tree);
                 remaining_len -= frag_tot_len;
                 offset += frag_tot_len;
                 frag_tot_len = 0;
@@ -1035,7 +1052,7 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
         /* The case where PUSI was 0, a continuing SECT ended, and stuff
          * bytes follow. */
         stuff_len = frag_cur_pos + remaining_len - frag_tot_len;
-        mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, frag_cur_pos, remaining_len - stuff_len, TRUE, pid_analysis->pload_type);
+        mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, frag_cur_pos, remaining_len - stuff_len, TRUE, pid_analysis);
         offset += remaining_len - stuff_len;
         frag_id++;
         fragmentation = FALSE;
@@ -1044,13 +1061,13 @@ mp2t_process_fragmented_payload(tvbuff_t *tvb, gint offset, guint remaining_len,
         stuff_tree = proto_tree_add_subtree_format(tree, tvb, offset, stuff_len, ett_stuff, NULL, "Stuffing");
         proto_tree_add_item(stuff_tree, hf_mp2t_stuff_bytes, tvb, offset, stuff_len, ENC_NA);
     } else if ((frag_tot_len && frag_cur_pos + remaining_len == frag_tot_len) || (!frag_tot_len && pusi_flag)) {
-        mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, frag_cur_pos, remaining_len, TRUE, pid_analysis->pload_type);
+        mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, frag_cur_pos, remaining_len, TRUE, pid_analysis);
         frag_id++;
         fragmentation = FALSE;
         frag_cur_pos = 0;
         frag_tot_len = 0;
     } else {
-        mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, frag_cur_pos, remaining_len, FALSE, pid_analysis->pload_type);
+        mp2t_fragment_handle(tvb, offset, pinfo, tree, frag_id, frag_cur_pos, remaining_len, FALSE, pid_analysis);
         fragmentation = TRUE;
         frag_cur_pos += remaining_len;
     }
@@ -1401,10 +1418,8 @@ dissect_tsp(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 
     if (pid_analysis->pload_type == pid_pload_docsis && (afc != 1)) {
         /* DOCSIS packets should not have an adaptation field */
-        if (afc != 1) {
-            expert_add_info_format(pinfo, afci, &ei_mp2t_invalid_afc,
-                    "Adaptation Field Control for DOCSIS packets must be 0x01");
-        }
+        expert_add_info_format(pinfo, afci, &ei_mp2t_invalid_afc,
+                               "Adaptation Field Control for DOCSIS packets must be 0x01");
     }
 
     if (pid_analysis->pload_type == pid_pload_null) {
@@ -1518,7 +1533,7 @@ dissect_mp2t( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U
     return tvb_captured_length(tvb);
 }
 
-static gboolean
+static bool
 heur_dissect_mp2t( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_ )
 {
     gint length;
@@ -1527,23 +1542,23 @@ heur_dissect_mp2t( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *da
     length = tvb_reported_length_remaining(tvb, offset);
     if (length == 0) {
         /* Nothing to check for */
-        return FALSE;
+        return false;
     }
     if ((length % MP2T_PACKET_SIZE) != 0) {
         /* Not a multiple of the MPEG-2 transport packet size */
-        return FALSE;
+        return false;
     } else {
         while (tvb_offset_exists(tvb, offset)) {
             if (tvb_get_guint8(tvb, offset) != MP2T_SYNC_BYTE) {
                 /* No sync byte at the appropriate offset */
-                return FALSE;
+                return false;
             }
             offset += MP2T_PACKET_SIZE;
         }
     }
 
     dissect_mp2t(tvb, pinfo, tree, data);
-    return TRUE;
+    return true;
 }
 
 
@@ -1827,7 +1842,7 @@ proto_register_mp2t(void)
     expert_mp2t = expert_register_protocol(proto_mp2t);
     expert_register_field_array(expert_mp2t, ei, array_length(ei));
 
-    heur_subdissector_list = register_heur_dissector_list("mp2t.pid", proto_mp2t);
+    heur_subdissector_list = register_heur_dissector_list_with_description("mp2t.pid", "Unused", proto_mp2t);
     /* Register init of processing of fragmented DEPI packets */
     reassembly_table_register(&mp2t_reassembly_table,
         &mp2t_reassembly_table_functions);
@@ -1847,7 +1862,7 @@ proto_reg_handoff_mp2t(void)
     dissector_add_for_decode_as_with_preference("udp.port", mp2t_handle);
     heur_dissector_add("usb.bulk", heur_dissect_mp2t, "MP2T USB bulk endpoint", "mp2t_usb_bulk", proto_mp2t, HEURISTIC_ENABLE);
     dissector_add_uint("wtap_encap", WTAP_ENCAP_MPEG_2_TS, mp2t_handle);
-    dissector_add_uint("l2tp.pw_type", L2TPv3_PROTOCOL_DOCSIS_DMPT, mp2t_handle);
+    dissector_add_uint("l2tp.pw_type", L2TPv3_PW_DOCSIS_DMPT, mp2t_handle);
     dissector_add_string("media_type", "video/mp2t", mp2t_handle);
 
     docsis_handle = find_dissector("docsis");
