@@ -35,76 +35,76 @@ void proto_reg_handoff_mpls_pm(void);
 #define MPLS_PM_DFLAGS_RES  0x30
 #define MPLS_PM_DFLAGS_MASK 0xF0
 
-static gint proto_mpls_pm_dlm = -1;
-static gint proto_mpls_pm_ilm = -1;
-static gint proto_mpls_pm_dm = -1;
-static gint proto_mpls_pm_dlm_dm = -1;
-static gint proto_mpls_pm_ilm_dm = -1;
+static gint proto_mpls_pm_dlm;
+static gint proto_mpls_pm_ilm;
+static gint proto_mpls_pm_dm;
+static gint proto_mpls_pm_dlm_dm;
+static gint proto_mpls_pm_ilm_dm;
 
-static gint ett_mpls_pm = -1;
-static gint ett_mpls_pm_flags = -1;
-static gint ett_mpls_pm_dflags = -1;
+static gint ett_mpls_pm;
+static gint ett_mpls_pm_flags;
+static gint ett_mpls_pm_dflags;
 
-static int hf_mpls_pm_version = -1;
-static int hf_mpls_pm_flags = -1;
-static int hf_mpls_pm_flags_r = -1;
-static int hf_mpls_pm_flags_t = -1;
-static int hf_mpls_pm_flags_res = -1;
-static int hf_mpls_pm_query_ctrl_code = -1;
-static int hf_mpls_pm_response_ctrl_code = -1;
-static int hf_mpls_pm_length = -1;
-static int hf_mpls_pm_dflags = -1;
-static int hf_mpls_pm_dflags_x = -1;
-static int hf_mpls_pm_dflags_b = -1;
-static int hf_mpls_pm_dflags_res = -1;
-static int hf_mpls_pm_otf = -1;
-static int hf_mpls_pm_session_id = -1;
-static int hf_mpls_pm_ds = -1;
-static int hf_mpls_pm_origin_timestamp_null = -1;
-static int hf_mpls_pm_origin_timestamp_seq = -1;
-static int hf_mpls_pm_origin_timestamp_ntp = -1;
-static int hf_mpls_pm_origin_timestamp_ptp = -1;
-static int hf_mpls_pm_origin_timestamp_unk = -1;
-static int hf_mpls_pm_counter1 = -1;
-static int hf_mpls_pm_counter2 = -1;
-static int hf_mpls_pm_counter3 = -1;
-static int hf_mpls_pm_counter4 = -1;
-static int hf_mpls_pm_qtf = -1;
-static int hf_mpls_pm_qtf_combined = -1;
-static int hf_mpls_pm_rtf = -1;
-static int hf_mpls_pm_rtf_combined = -1;
-static int hf_mpls_pm_rptf = -1;
-static int hf_mpls_pm_rptf_combined = -1;
-static int hf_mpls_pm_timestamp1_q_null = -1;
-static int hf_mpls_pm_timestamp1_r_null = -1;
-static int hf_mpls_pm_timestamp1_q_seq = -1;
-static int hf_mpls_pm_timestamp1_r_seq = -1;
-static int hf_mpls_pm_timestamp1_q_ntp = -1;
-static int hf_mpls_pm_timestamp1_r_ntp = -1;
-static int hf_mpls_pm_timestamp1_q_ptp = -1;
-static int hf_mpls_pm_timestamp1_r_ptp = -1;
-static int hf_mpls_pm_timestamp1_unk = -1;
-static int hf_mpls_pm_timestamp2_q_null = -1;
-static int hf_mpls_pm_timestamp2_r_null = -1;
-static int hf_mpls_pm_timestamp2_q_seq = -1;
-static int hf_mpls_pm_timestamp2_r_seq = -1;
-static int hf_mpls_pm_timestamp2_q_ntp = -1;
-static int hf_mpls_pm_timestamp2_r_ntp = -1;
-static int hf_mpls_pm_timestamp2_q_ptp = -1;
-static int hf_mpls_pm_timestamp2_r_ptp = -1;
-static int hf_mpls_pm_timestamp2_unk = -1;
-static int hf_mpls_pm_timestamp3_null = -1;
-static int hf_mpls_pm_timestamp3_r_null = -1;
-static int hf_mpls_pm_timestamp3_r_seq = -1;
-static int hf_mpls_pm_timestamp3_r_ntp = -1;
-static int hf_mpls_pm_timestamp3_r_ptp = -1;
-static int hf_mpls_pm_timestamp3_unk = -1;
-static int hf_mpls_pm_timestamp4_null = -1;
-static int hf_mpls_pm_timestamp4_r_null = -1;
-static int hf_mpls_pm_timestamp4_r_seq = -1;
-static int hf_mpls_pm_timestamp4_r_ntp = -1;
-static int hf_mpls_pm_timestamp4_r_ptp = -1;
-static int hf_mpls_pm_timestamp4_unk = -1;
+static int hf_mpls_pm_version;
+static int hf_mpls_pm_flags;
+static int hf_mpls_pm_flags_r;
+static int hf_mpls_pm_flags_t;
+static int hf_mpls_pm_flags_res;
+static int hf_mpls_pm_query_ctrl_code;
+static int hf_mpls_pm_response_ctrl_code;
+static int hf_mpls_pm_length;
+static int hf_mpls_pm_dflags;
+static int hf_mpls_pm_dflags_x;
+static int hf_mpls_pm_dflags_b;
+static int hf_mpls_pm_dflags_res;
+static int hf_mpls_pm_otf;
+static int hf_mpls_pm_session_id;
+static int hf_mpls_pm_ds;
+static int hf_mpls_pm_origin_timestamp_null;
+static int hf_mpls_pm_origin_timestamp_seq;
+static int hf_mpls_pm_origin_timestamp_ntp;
+static int hf_mpls_pm_origin_timestamp_ptp;
+static int hf_mpls_pm_origin_timestamp_unk;
+static int hf_mpls_pm_counter1;
+static int hf_mpls_pm_counter2;
+static int hf_mpls_pm_counter3;
+static int hf_mpls_pm_counter4;
+static int hf_mpls_pm_qtf;
+static int hf_mpls_pm_qtf_combined;
+static int hf_mpls_pm_rtf;
+static int hf_mpls_pm_rtf_combined;
+static int hf_mpls_pm_rptf;
+static int hf_mpls_pm_rptf_combined;
+static int hf_mpls_pm_timestamp1_q_null;
+static int hf_mpls_pm_timestamp1_r_null;
+static int hf_mpls_pm_timestamp1_q_seq;
+static int hf_mpls_pm_timestamp1_r_seq;
+static int hf_mpls_pm_timestamp1_q_ntp;
+static int hf_mpls_pm_timestamp1_r_ntp;
+static int hf_mpls_pm_timestamp1_q_ptp;
+static int hf_mpls_pm_timestamp1_r_ptp;
+static int hf_mpls_pm_timestamp1_unk;
+static int hf_mpls_pm_timestamp2_q_null;
+static int hf_mpls_pm_timestamp2_r_null;
+static int hf_mpls_pm_timestamp2_q_seq;
+static int hf_mpls_pm_timestamp2_r_seq;
+static int hf_mpls_pm_timestamp2_q_ntp;
+static int hf_mpls_pm_timestamp2_r_ntp;
+static int hf_mpls_pm_timestamp2_q_ptp;
+static int hf_mpls_pm_timestamp2_r_ptp;
+static int hf_mpls_pm_timestamp2_unk;
+static int hf_mpls_pm_timestamp3_null;
+static int hf_mpls_pm_timestamp3_r_null;
+static int hf_mpls_pm_timestamp3_r_seq;
+static int hf_mpls_pm_timestamp3_r_ntp;
+static int hf_mpls_pm_timestamp3_r_ptp;
+static int hf_mpls_pm_timestamp3_unk;
+static int hf_mpls_pm_timestamp4_null;
+static int hf_mpls_pm_timestamp4_r_null;
+static int hf_mpls_pm_timestamp4_r_seq;
+static int hf_mpls_pm_timestamp4_r_ntp;
+static int hf_mpls_pm_timestamp4_r_ptp;
+static int hf_mpls_pm_timestamp4_unk;
 
 /*
  * FF: please keep this list in sync with
