@@ -61,15 +61,15 @@
 void proto_register_mpls(void);
 void proto_reg_handoff_mpls(void);
 
-static gint proto_mpls = -1;
-static gint proto_pw_ach = -1;
-static gint proto_pw_ach_mcc = -1;
-static gint proto_pw_mcw = -1;
+static gint proto_mpls;
+static gint proto_pw_ach;
+static gint proto_pw_ach_mcc;
+static gint proto_pw_mcw;
 
-static gint ett_mpls = -1;
-static gint ett_mpls_pw_ach = -1;
-static gint ett_mpls_pw_ach_mcc = -1;
-static gint ett_mpls_pw_mcw = -1;
+static gint ett_mpls;
+static gint ett_mpls_pw_ach;
+static gint ett_mpls_pw_ach_mcc;
+static gint ett_mpls_pw_mcw;
 static char PW_ACH[50] = "PW Associated Channel Header";
 
 const value_string special_labels[] = {
@@ -90,36 +90,39 @@ static dissector_handle_t dissector_ipv6;
 static dissector_handle_t dissector_ip;
 static dissector_handle_t dissector_pw_ach;
 static dissector_handle_t dissector_pw_eth_heuristic;
-static dissector_handle_t dissector_pw_ach_mcc;
-
-/* For RFC6391 - Flow aware transport of pseudowire over a mpls PSN*/
-static gboolean mpls_bos_flowlabel = FALSE;
-
-static int hf_mpls_label = -1;
-static int hf_mpls_label_special = -1;
-static int hf_mpls_exp = -1;
-static int hf_mpls_bos = -1;
-static int hf_mpls_ttl = -1;
-
-static int hf_mpls_pw_ach_ver = -1;
-static int hf_mpls_pw_ach_res = -1;
-static int hf_mpls_pw_ach_channel_type = -1;
-
-static int hf_mpls_pw_ach_mcc_proto = -1;
-
-static int hf_mpls_pw_mcw_flags = -1;
-static int hf_mpls_pw_mcw_length = -1;
-static int hf_mpls_pw_mcw_sequence_number = -1;
-
-static expert_field ei_mpls_pw_ach_error_processing_message = EI_INIT;
-static expert_field ei_mpls_pw_ach_res = EI_INIT;
-static expert_field ei_mpls_pw_mcw_error_processing_message = EI_INIT;
-static expert_field ei_mpls_invalid_label = EI_INIT;
-
 static dissector_handle_t mpls_handle;
 static dissector_handle_t mpls_pwcw_handle;
 static dissector_handle_t mpls_mcc_handle;
 
+/*
+ * RFC 8469 deprecated Ethernet without CW, so default this to false.
+ * https://datatracker.ietf.org/doc/html/rfc8469
+ */
+static bool mpls_try_heuristic_first;
+/* For RFC6391 - Flow aware transport of pseudowire over a mpls PSN*/
+static bool mpls_bos_flowlabel;
+
+static int hf_mpls_label;
+static int hf_mpls_label_special;
+static int hf_mpls_exp;
+static int hf_mpls_bos;
+static int hf_mpls_ttl;
+
+static int hf_mpls_pw_ach_ver;
+static int hf_mpls_pw_ach_res;
+static int hf_mpls_pw_ach_channel_type;
+
+static int hf_mpls_pw_ach_mcc_proto;
+
+static int hf_mpls_pw_mcw_flags;
+static int hf_mpls_pw_mcw_length;
+static int hf_mpls_pw_mcw_sequence_number;
+
+static expert_field ei_mpls_pw_ach_error_processing_message;
+static expert_field ei_mpls_pw_ach_res;
+static expert_field ei_mpls_pw_mcw_error_processing_message;
+static expert_field ei_mpls_invalid_label;
+
 #if 0 /*not used yet*/
 /*
  * MPLS PW types
@@ -201,6 +204,12 @@ static const value_string mpls_pwac_types[] = {
 static value_string_ext mpls_pwac_types_ext = VALUE_STRING_EXT_INIT(mpls_pwac_types);
 
 static dissector_table_t mpls_subdissector_table;
+/*
+ * Post-stack First Nibble
+ * https://datatracker.ietf.org/doc/html/draft-ietf-mpls-1stnibble-06
+ */
+static dissector_table_t mpls_pfn_subdissector_table;
+static heur_dissector_list_t mpls_heur_subdissector_list;
 
 static void mpls_prompt(packet_info *pinfo, gchar* result)
 {
@@ -213,6 +222,17 @@ static gpointer mpls_value(packet_info *pinfo)
     return p_get_proto_data(pinfo->pool, pinfo, proto_mpls, 0);
 }
 
+static void mpls_pfn_prompt(packet_info *pinfo, gchar* result)
+{
+    snprintf(result, MAX_DECODE_AS_PROMPT_LEN, "Data after post-stack first nibble %u as",
+        GPOINTER_TO_UINT(p_get_proto_data(pinfo->pool, pinfo, proto_mpls, 1)));
+}
+
+static gpointer mpls_pfn_value(packet_info *pinfo)
+{
+    return p_get_proto_data(pinfo->pool, pinfo, proto_mpls, 1);
+}
+
 static void pw_ach_prompt(packet_info *pinfo, gchar* result)
 {
     snprintf(result, MAX_DECODE_AS_PROMPT_LEN, "Channel type 0x%x as",
@@ -409,6 +429,8 @@ dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
     int       found;
     guint8    first_nibble;
     struct mplsinfo mplsinfo;
+    heur_dtbl_entry_t *hdtbl_entry;
+    dissector_handle_t payload_handle;
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "MPLS");
     col_set_str(pinfo->cinfo, COL_INFO, "MPLS Label Switched Packet");
@@ -486,6 +508,7 @@ dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
     }
 
     first_nibble = (tvb_get_guint8(tvb, offset) >> 4) & 0x0F;
+    p_add_proto_data(pinfo->pool, pinfo, proto_mpls, 1, GUINT_TO_POINTER(first_nibble));
 
     next_tvb = tvb_new_subset_remaining(tvb, offset);
 
@@ -501,51 +524,41 @@ dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
     }
 
     /*
-     * No, there isn't, so use the 1st nibble logic (see BCP 4928,
-     * RFC 4385 and 5586).
+     * Do we try heuristic dissectors first? This is necessary for, e.g.,
+     * Ethernet without CW where the address begins with a 4 or 6 nibble.
      */
-    switch(first_nibble) {
-    case 4:
-        /*
-         * XXX - this could be from an Ethernet pseudo-wire without a
-         * control word, with the MAC address's first nibble being 4.
-         */
-        call_dissector(dissector_ip, next_tvb, pinfo, tree);
-        /* IP dissector may reduce the length of the tvb.
-           We need to do the same, so that ethernet trailer is detected. */
-        set_actual_length(tvb, offset+tvb_reported_length(next_tvb));
-        break;
-    case 6:
-        /*
-         * XXX - this could be from an Ethernet pseudo-wire without a
-         * control word, with the MAC address's first nibble being 6.
-         */
-        call_dissector(dissector_ipv6, next_tvb, pinfo, tree);
-        /* IPv6 dissector may reduce the length of the tvb.
-           We need to do the same, so that ethernet trailer is detected. */
-        set_actual_length(tvb, offset+tvb_reported_length(next_tvb));
-        break;
-    case 1:
-        /*
-         * XXX - this could be from an Ethernet pseudo-wire without a
-         * control word, with the MAC address's first nibble being 1.
-         */
-        call_dissector(dissector_pw_ach, next_tvb, pinfo, tree);
-        break;
-    case 0:
-        /*
-         * If this is an Ethernet pseudo-wire, this could either be
-         * Ethernet without a control word and with the first nibble
-         * of the destination MAC address being 0 or it could be
-         * Ethernet with a control word.  Let the "pw_eth_heuristic"
-         * dissector try to figure it out.
-         */
-        call_dissector(dissector_pw_eth_heuristic, next_tvb, pinfo, tree);
-        break;
-    default:
-        call_data_dissector(next_tvb, pinfo, tree);
-        break;
+    if (mpls_try_heuristic_first) {
+        if (dissector_try_heuristic(mpls_heur_subdissector_list, next_tvb, pinfo,
+                                    tree, &hdtbl_entry, NULL)) {
+            return tvb_captured_length(tvb);
+        }
     }
+
+    /*
+     * Use the 1st nibble logic (see BCP 128 (RFC 4928), RFC 4385 and 5586).
+     * https://datatracker.ietf.org/doc/html/draft-ietf-mpls-1stnibble-06
+     */
+    if (dissector_try_uint_new(mpls_pfn_subdissector_table, first_nibble,
+        next_tvb, pinfo, tree, FALSE, &mplsinfo)) {
+
+        payload_handle = dissector_get_uint_handle(mpls_pfn_subdissector_table, first_nibble);
+        if (payload_handle == dissector_ip || payload_handle == dissector_ipv6) {
+            /* IPv4 and IPv6 dissectors may reduce the length of the tvb.
+               We need to do the same, so that any Ethernet trailer is detected.
+             */
+            set_actual_length(tvb, offset+tvb_reported_length(next_tvb));
+        }
+        return tvb_captured_length(tvb);
+    }
+
+    if (!mpls_try_heuristic_first) {
+        if (dissector_try_heuristic(mpls_heur_subdissector_list, next_tvb, pinfo,
+                                    tree, &hdtbl_entry, NULL)) {
+            return tvb_captured_length(tvb);
+        }
+    }
+
+    call_data_dissector(next_tvb, pinfo, tree);
     return tvb_captured_length(tvb);
 }
 
@@ -581,7 +594,7 @@ proto_register_mpls(void)
 
         {&hf_mpls_ttl,
          {"MPLS TTL", "mpls.ttl",
-          FT_UINT32, BASE_DEC, NULL, 0x0000000FF,
+          FT_UINT32, BASE_DEC, NULL, 0x000000FF,
           NULL, HFILL }
         },
 
@@ -651,6 +664,11 @@ proto_register_mpls(void)
     static decode_as_t mpls_da = {"mpls", "mpls.label", 1, 0, &mpls_da_values, NULL, NULL,
                                   decode_as_default_populate_list, decode_as_default_reset, decode_as_default_change, NULL};
 
+    static build_valid_func mpls_pfn_da_build_value[1] = {mpls_pfn_value};
+    static decode_as_value_t mpls_pfn_da_values = {mpls_pfn_prompt, 1, mpls_pfn_da_build_value};
+    static decode_as_t mpls_pfn_da = {"mpls", "mpls.pfn", 1, 0, &mpls_pfn_da_values, NULL, NULL,
+                                  decode_as_default_populate_list, decode_as_default_reset, decode_as_default_change, NULL};
+
     static build_valid_func pw_ach_da_build_value[1] = {pw_ach_value};
     static decode_as_value_t pw_ach_da_values = {pw_ach_prompt, 1, pw_ach_da_build_value};
     static decode_as_t pw_ach_da = {"pwach", "pwach.channel_type", 1, 0, &pw_ach_da_values, NULL, NULL,
@@ -659,14 +677,10 @@ proto_register_mpls(void)
     expert_module_t* expert_mpls;
     module_t * module_mpls;
 
-    proto_mpls = proto_register_protocol("MultiProtocol Label Switching Header",
-                                         "MPLS", "mpls");
-    proto_pw_ach = proto_register_protocol(PW_ACH,
-                                           "PW Associated Channel", "pwach");
-    proto_pw_mcw = proto_register_protocol("PW MPLS Control Word (generic/preferred)",
-                                           "Generic PW (with CW)", "pwmcw");
-    proto_pw_ach_mcc = proto_register_protocol("Management Communication Channel (MCC)",
-                                               "PW Associated Management Communication Channel", "mcc");
+    proto_mpls = proto_register_protocol("MultiProtocol Label Switching Header", "MPLS", "mpls");
+    proto_pw_ach = proto_register_protocol(PW_ACH, "PW Associated Channel", "pwach");
+    proto_pw_mcw = proto_register_protocol("PW MPLS Control Word (generic/preferred)", "Generic PW (with CW)", "pwmcw");
+    proto_pw_ach_mcc = proto_register_protocol("Management Communication Channel (MCC)", "PW Associated Management Communication Channel", "mcc");
 
     proto_register_field_array(proto_mpls, mplsf_info, array_length(mplsf_info));
     proto_register_subtree_array(ett, array_length(ett));
@@ -674,14 +688,21 @@ proto_register_mpls(void)
     expert_register_field_array(expert_mpls, ei, array_length(ei));
 
     mpls_handle = register_dissector("mpls", dissect_mpls, proto_mpls);
-    mpls_mcc_handle = register_dissector("mplsmcc", dissect_pw_ach_mcc,proto_pw_ach_mcc);
-    mpls_pwcw_handle = register_dissector("mplspwcw", dissect_pw_mcw, proto_pw_mcw );
+    mpls_mcc_handle = register_dissector("mplsmcc", dissect_pw_ach_mcc, proto_pw_ach_mcc);
+    mpls_pwcw_handle = register_dissector("mplspwcw", dissect_pw_mcw, proto_pw_mcw);
+    dissector_pw_ach = register_dissector("mplspwach", dissect_pw_ach, proto_pw_ach );
 
     /* FF: mpls subdissector table is indexed by label */
     mpls_subdissector_table = register_dissector_table("mpls.label",
-                                                       "MPLS protocol",
+                                                       "MPLS label",
                                                        proto_mpls, FT_UINT32, BASE_DEC);
 
+    mpls_pfn_subdissector_table = register_dissector_table("mpls.pfn",
+                                                           "MPLS post-stack first nibble",
+                                                           proto_mpls, FT_UINT8, BASE_HEX);
+
+    mpls_heur_subdissector_list = register_heur_dissector_list_with_description("mpls", "MPLS payload", proto_mpls);
+
     pw_ach_subdissector_table  = register_dissector_table("pwach.channel_type", "PW Associated Channel Type", proto_pw_ach, FT_UINT16, BASE_HEX);
 
     pw_ach_mcc_subdissector_table  = register_dissector_table("mcc.proto", "PW Associated Management Communication Channel Protocol", proto_pw_ach_mcc, FT_UINT16, BASE_HEX);
@@ -690,6 +711,13 @@ proto_register_mpls(void)
 
     prefs_register_obsolete_preference(module_mpls, "mplspref.payload");
 
+    prefs_register_bool_preference(module_mpls, "try_heuristic_first",
+                                "Try heuristic sub-dissectors first",
+                                "Try to decode a packet heuristically, e.g. as "
+                                "Ethernet without control word, before trying "
+                                "sub-dissectors based upon the first nibble.",
+                                &mpls_try_heuristic_first);
+
     /* RFC6391: Flow aware transport of pseudowire*/
     prefs_register_bool_preference(module_mpls,
                                     "flowlabel_in_mpls_header",
@@ -698,6 +726,7 @@ proto_register_mpls(void)
                                     &mpls_bos_flowlabel);
 
     register_decode_as(&mpls_da);
+    register_decode_as(&mpls_pfn_da);
     register_decode_as(&pw_ach_da);
 }
 
@@ -719,7 +748,7 @@ proto_reg_handoff_mpls(void)
     dissector_add_uint("juniper.proto", JUNIPER_PROTO_CLNP_MPLS, mpls_handle);
     dissector_add_for_decode_as("pwach.channel_type", mpls_handle);
     dissector_add_uint("sflow_245.header_protocol", SFLOW_245_HEADER_MPLS, mpls_handle);
-    dissector_add_uint("l2tp.pw_type", L2TPv3_PROTOCOL_MPLS, mpls_handle);
+    dissector_add_for_decode_as("l2tp.pw_type", mpls_handle);
     dissector_add_uint_with_preference("udp.port", UDP_PORT_MPLS_OVER_UDP, mpls_handle);
     dissector_add_uint("vxlan.next_proto", VXLAN_MPLS, mpls_handle);
     dissector_add_uint("nsh.next_proto", NSH_MPLS, mpls_handle);
@@ -732,8 +761,16 @@ proto_reg_handoff_mpls(void)
     dissector_ip                    = find_dissector_add_dependency("ip", proto_pw_mcw );
     dissector_pw_eth_heuristic      = find_dissector_add_dependency("pw_eth_heuristic", proto_pw_mcw);
 
-    dissector_pw_ach                = create_dissector_handle(dissect_pw_ach, proto_pw_ach );
-    dissector_pw_ach_mcc            = create_dissector_handle(dissect_pw_ach_mcc, proto_pw_ach_mcc );
+    /*
+     * Our previous default behavior has been to try the Eth CW heuristic
+     * on first nibble 0. Continue doing that. For other first nibbles
+     * registered to dissectors, "try heuristic first" can be enabled.
+     */
+    dissector_add_for_decode_as("mpls.pfn", mpls_pwcw_handle);
+    dissector_add_uint("mpls.pfn", 0, dissector_pw_eth_heuristic);
+    dissector_add_uint("mpls.pfn", 1, dissector_pw_ach);
+    dissector_add_uint("mpls.pfn", 4, dissector_ip);
+    dissector_add_uint("mpls.pfn", 6, dissector_ipv6);
 }
 
 /*
