@@ -24,27 +24,30 @@ void proto_register_mplstp_fm(void);
 void proto_reg_handoff_mplstp_lock(void);
 void proto_reg_handoff_mplstp_fm(void);
 
+static dissector_handle_t mplstp_lock_handle;
+static dissector_handle_t mplstp_fm_handle;
+
 /* MPLS-TP FM protocol specific variables */
-static gint proto_mplstp_fm     = -1;
-static gint ett_mplstp_fm       = -1;
-static gint ett_mplstp_fm_flags = -1;
-static gint ett_mplstp_fm_tlv_tree     = -1;
+static gint proto_mplstp_fm;
+static gint ett_mplstp_fm;
+static gint ett_mplstp_fm_flags;
+static gint ett_mplstp_fm_tlv_tree;
 
-static int hf_mplstp_fm_version         = -1;
+static int hf_mplstp_fm_version;
 
-static int hf_mplstp_fm_reserved        = -1;
-static int hf_mplstp_fm_msg_type        = -1;
-static int hf_mplstp_fm_flags           = -1;
-static int hf_mplstp_fm_flags_l         = -1;
-static int hf_mplstp_fm_flags_r         = -1;
-static int hf_mplstp_fm_refresh_timer   = -1;
-static int hf_mplstp_fm_total_tlv_len   = -1;
-static int hf_mplstp_fm_if_tlv_type     = -1;
-static int hf_mplstp_fm_global_tlv_type = -1;
-static int hf_mplstp_fm_tlv_len         = -1;
-static int hf_mplstp_fm_node_id         = -1;
-static int hf_mplstp_fm_if_num          = -1;
-static int hf_mplstp_fm_global_id       = -1;
+static int hf_mplstp_fm_reserved;
+static int hf_mplstp_fm_msg_type;
+static int hf_mplstp_fm_flags;
+static int hf_mplstp_fm_flags_l;
+static int hf_mplstp_fm_flags_r;
+static int hf_mplstp_fm_refresh_timer;
+static int hf_mplstp_fm_total_tlv_len;
+static int hf_mplstp_fm_if_tlv_type;
+static int hf_mplstp_fm_global_tlv_type;
+static int hf_mplstp_fm_tlv_len;
+static int hf_mplstp_fm_node_id;
+static int hf_mplstp_fm_if_num;
+static int hf_mplstp_fm_global_id;
 
 static const value_string fm_msg_type[] = {
   {0, "No Return Code"},
@@ -54,12 +57,12 @@ static const value_string fm_msg_type[] = {
 };
 
 /* MPLS-TP Lock protocol specific variables */
-static gint proto_mplstp_lock = -1;
-static gint ett_mplstp_lock   = -1;
+static gint proto_mplstp_lock;
+static gint ett_mplstp_lock;
 
-static int hf_mplstp_lock_version       = -1;
-static int hf_mplstp_lock_reserved      = -1;
-static int hf_mplstp_lock_refresh_timer = -1;
+static int hf_mplstp_lock_version;
+static int hf_mplstp_lock_reserved;
+static int hf_mplstp_lock_refresh_timer;
 
 static void
 dissect_mplstp_fm_tlv (tvbuff_t *tvb, proto_tree *tree)
@@ -151,7 +154,7 @@ dissect_mplstp_fm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* dat
    proto_item *ti, *ti_flags;
    proto_tree *fm_tree, *fm_flags;
 
-   guint8 offset = 0;
+   gint   offset = 0;
    guint8 tlv_len;
 
    col_set_str(pinfo->cinfo, COL_PROTOCOL, "MPLS-TP FM");
@@ -170,12 +173,12 @@ dissect_mplstp_fm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* dat
                         1, ENC_BIG_ENDIAN);
    proto_tree_add_item (fm_tree, hf_mplstp_fm_reserved, tvb, offset,
                         1, ENC_BIG_ENDIAN);
-   offset = offset + 1;
+   offset++;
 
    /* FM-Message type field */
    proto_tree_add_item (fm_tree, hf_mplstp_fm_msg_type, tvb, offset,
                         1,ENC_BIG_ENDIAN);
-   offset = offset + 1;
+   offset++;
 
    /* Flags field */
    ti_flags = proto_tree_add_item (fm_tree, hf_mplstp_fm_flags, tvb,
@@ -184,26 +187,25 @@ dissect_mplstp_fm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* dat
 
    proto_tree_add_item (fm_flags, hf_mplstp_fm_flags_l, tvb, offset, 1, ENC_BIG_ENDIAN);
    proto_tree_add_item (fm_flags, hf_mplstp_fm_flags_r, tvb, offset, 1, ENC_BIG_ENDIAN);
-   offset = offset + 1;
+   offset++;
 
    /* Refresh-Timer field */
    proto_tree_add_item (fm_tree, hf_mplstp_fm_refresh_timer, tvb, offset,
                         1, ENC_BIG_ENDIAN);
-   offset = offset + 1;
+   offset++;
 
    /* FM-TLV Length field*/
    proto_tree_add_item (fm_tree, hf_mplstp_fm_total_tlv_len, tvb, offset,
                         1, ENC_BIG_ENDIAN);
    offset = offset + 1;
 
-   if (tlv_len != 0)
-     {
-       tvbuff_t *next_tvb;
+   if (tlv_len != 0) {
+      tvbuff_t *next_tvb;
 
-       /* FM TLVs*/
-       next_tvb = tvb_new_subset_remaining (tvb, offset);
-       dissect_mplstp_fm_tlv (next_tvb, tree);
-     }
+      /* FM TLVs*/
+      next_tvb = tvb_new_subset_remaining (tvb, offset);
+      dissect_mplstp_fm_tlv (next_tvb, tree);
+   }
    return tvb_captured_length(tvb);
 }
 
@@ -236,14 +238,13 @@ proto_register_mplstp_lock(void)
 
   proto_register_field_array(proto_mplstp_lock, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+
+  mplstp_lock_handle = register_dissector("mplstp_lock", dissect_mplstp_lock, proto_mplstp_lock);
 }
 
 void
 proto_reg_handoff_mplstp_lock(void)
 {
-  dissector_handle_t mplstp_lock_handle;
-
-  mplstp_lock_handle    = create_dissector_handle( dissect_mplstp_lock, proto_mplstp_lock );
   dissector_add_uint("pwach.channel_type", 0x0026, mplstp_lock_handle); /* KM: MPLSTP LOCK, RFC 6435 */
 }
 
@@ -298,17 +299,17 @@ proto_register_mplstp_fm(void)
 
     { &hf_mplstp_fm_flags,
       { "FM Flags", "mplstp_oam.flags",
-        FT_UINT8, BASE_HEX, NULL, 0x0000, "MPLS-TP FM Flags", HFILL}
+        FT_UINT8, BASE_HEX, NULL, 0x0, "MPLS-TP FM Flags", HFILL}
     },
 
     { &hf_mplstp_fm_flags_l,
       { "Link Down Indication", "mplstp_oam.flag_l",
-        FT_BOOLEAN, 8, NULL, 0x0002, NULL, HFILL}
+        FT_BOOLEAN, 8, NULL, 0x02, NULL, HFILL}
     },
 
     { &hf_mplstp_fm_flags_r,
       { "FM Condition Cleared", "mplstp_oam.flag_r",
-        FT_BOOLEAN, 8, NULL, 0x0001, "Fault Condition Cleared", HFILL}
+        FT_BOOLEAN, 8, NULL, 0x01, "Fault Condition Cleared", HFILL}
     },
   };
 
@@ -325,19 +326,18 @@ proto_register_mplstp_fm(void)
 
   proto_register_field_array(proto_mplstp_fm, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+
+  mplstp_fm_handle = register_dissector("mplstp_fm",  dissect_mplstp_fm, proto_mplstp_fm );
 }
 
 void
 proto_reg_handoff_mplstp_fm(void)
 {
-  dissector_handle_t mplstp_fm_handle;
-
-  mplstp_fm_handle = create_dissector_handle( dissect_mplstp_fm, proto_mplstp_fm );
   dissector_add_uint("pwach.channel_type", PW_ACH_TYPE_MPLSTP_FM, mplstp_fm_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local Variables:
  * c-basic-offset: 2
