@@ -43,48 +43,48 @@ void proto_reg_handoff_mqpcf(void);
 static guint mq_pcf_maxprm = PCF_MAX_PARM;
 static guint mq_pcf_maxlst = PCF_MAX_LIST;
 
-static int proto_mqpcf = -1;
+static int proto_mqpcf;
 
-static int hf_mqpcf_cfh_type = -1;
-static int hf_mqpcf_cfh_length = -1;
-static int hf_mqpcf_cfh_version = -1;
-static int hf_mqpcf_cfh_command = -1;
-static int hf_mqpcf_cfh_MsgSeqNbr = -1;
-static int hf_mqpcf_cfh_control = -1;
-static int hf_mqpcf_cfh_compcode = -1;
-static int hf_mqpcf_cfh_reason = -1;
-static int hf_mqpcf_cfh_ParmCount = -1;
+static int hf_mqpcf_cfh_type;
+static int hf_mqpcf_cfh_length;
+static int hf_mqpcf_cfh_version;
+static int hf_mqpcf_cfh_command;
+static int hf_mqpcf_cfh_MsgSeqNbr;
+static int hf_mqpcf_cfh_control;
+static int hf_mqpcf_cfh_compcode;
+static int hf_mqpcf_cfh_reason;
+static int hf_mqpcf_cfh_ParmCount;
 
-static int hf_mq_pcf_prmtyp = -1;
-static int hf_mq_pcf_prmlen = -1;
-static int hf_mq_pcf_prmid = -1;
-static int hf_mq_pcf_prmidnovals = -1;
-static int hf_mq_pcf_filterop = -1;
-static int hf_mq_pcf_prmccsid = -1;
-static int hf_mq_pcf_prmstrlen = -1;
-static int hf_mq_pcf_prmcount = -1;
-static int hf_mq_pcf_prmunused = -1;
+static int hf_mq_pcf_prmtyp;
+static int hf_mq_pcf_prmlen;
+static int hf_mq_pcf_prmid;
+static int hf_mq_pcf_prmidnovals;
+static int hf_mq_pcf_filterop;
+static int hf_mq_pcf_prmccsid;
+static int hf_mq_pcf_prmstrlen;
+static int hf_mq_pcf_prmcount;
+static int hf_mq_pcf_prmunused;
 
-static int hf_mq_pcf_string = -1;
-static int hf_mq_pcf_stringlist = -1;
-static int hf_mq_pcf_int = -1;
-static int hf_mq_pcf_intlist = -1;
-static int hf_mq_pcf_bytestring = -1;
-static int hf_mq_pcf_int64 = -1;
-static int hf_mq_pcf_int64list = -1;
+static int hf_mq_pcf_string;
+static int hf_mq_pcf_stringlist;
+static int hf_mq_pcf_int;
+static int hf_mq_pcf_intlist;
+static int hf_mq_pcf_bytestring;
+static int hf_mq_pcf_int64;
+static int hf_mq_pcf_int64list;
 
-static expert_field ei_mq_pcf_hdrlne = EI_INIT;
-static expert_field ei_mq_pcf_prmln0 = EI_INIT;
-static expert_field ei_mq_pcf_MaxInt = EI_INIT;
-static expert_field ei_mq_pcf_MaxStr = EI_INIT;
-static expert_field ei_mq_pcf_MaxI64 = EI_INIT;
-static expert_field ei_mq_pcf_MaxPrm = EI_INIT;
-static expert_field ei_mq_pcf_PrmCnt = EI_INIT;
+static expert_field ei_mq_pcf_hdrlne;
+static expert_field ei_mq_pcf_prmln0;
+static expert_field ei_mq_pcf_MaxInt;
+static expert_field ei_mq_pcf_MaxStr;
+static expert_field ei_mq_pcf_MaxI64;
+static expert_field ei_mq_pcf_MaxPrm;
+static expert_field ei_mq_pcf_PrmCnt;
 
-static gint ett_mqpcf_prm = -1;
-static gint ett_mqpcf_grp = -1;
-static gint ett_mqpcf = -1;
-static gint ett_mqpcf_cfh = -1;
+static gint ett_mqpcf_prm;
+static gint ett_mqpcf_grp;
+static gint ett_mqpcf;
+static gint ett_mqpcf_cfh;
 
 #define MQ_TEXT_CFH   "MQ Command Format Header"
 
@@ -149,6 +149,8 @@ static void dissect_mqpcf_parm_int(tvbuff_t *tvb, proto_tree *tree, guint offset
         }
     }
 }
+
+// NOLINTNEXTLINE(misc-no-recursion)
 int dissect_mqpcf_parm_grp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* mq_tree,
     guint offset, guint bLittleEndian, gboolean bParse)
 {
@@ -169,6 +171,7 @@ int dissect_mqpcf_parm_grp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* mq_tre
     return offset;
 }
 
+// NOLINTNEXTLINE(misc-no-recursion)
 guint32 dissect_mqpcf_parm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mq_tree,
     guint offset, guint32 uCount, guint bLittleEndian, gboolean bParse)
 {
@@ -188,11 +191,11 @@ guint32 dissect_mqpcf_parm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mq_tre
     guint32 uDig;
     guint32 _offset = offset;
 
-    const char sMaxLst[] = " Max # of List reached. DECODE interrupted   (actual %u of %u)";
-    const char sPrmLn0[] = " MQPrm[%3u] has a zero length. DECODE Failed (MQPrm Count: %u)";
-    const char sHdrLne[] = " MQPrm[%3u] PCF Header not enough remaining bytes in pdu. DECODE Failed (MQPrm Count: %u)";
-    const char sMaxPrm[] = " Max # of Parm reached. DECODE interrupted   (actual %u of %u)";
-    const char sPrmCnt[] = " Cnt=-1 and Length(%u) < 16. DECODE interrupted for elem %u";
+    static const char *sMaxLst = " Max # of List reached. DECODE interrupted   (actual %u of %u)";
+    static const char *sPrmLn0 = " MQPrm[%3u] has a zero length. DECODE Failed (MQPrm Count: %u)";
+    static const char *sHdrLne = " MQPrm[%3u] PCF Header not enough remaining bytes in pdu. DECODE Failed (MQPrm Count: %u)";
+    static const char *sMaxPrm = " Max # of Parm reached. DECODE interrupted   (actual %u of %u)";
+    static const char *sPrmCnt = " Cnt=-1 and Length(%u) < 16. DECODE interrupted for elem %u";
 
     proto_item *ti = NULL;
     proto_tree *tree = NULL;
@@ -242,16 +245,17 @@ guint32 dissect_mqpcf_parm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mq_tre
         uLenF = 12;
 
         if (bParse)
-            snprintf(strPrm, (gulong)sizeof(strPrm) - 1, " %-s[%*u] {%2d-%-4.4s} 0x%08x (%4d) %-30.30s",
+            snprintf(strPrm, sizeof(strPrm) - 1, " %-s[%*u] {%2d-%-4.4s} 0x%08x (%4d) %-30.30s",
                        "MQPrm", uDig, u + 1,
                        uTyp, val_to_str_ext_const(uTyp, GET_VALS_EXTP(PrmTyp2), "      Unkn") + 6,
                        uPrm, uPrm, val_to_str_ext_const(uPrm, GET_VALS_EXTP(PrmId), "Unknown"));
         else
-            snprintf(strPrm, (gulong)sizeof(strPrm) - 1, " %-s[%*u] {%2d-%-4.4s} 0x%08x (%4d)",
+            snprintf(strPrm, sizeof(strPrm) - 1, " %-s[%*u] {%2d-%-4.4s} 0x%08x (%4d)",
                        "XtraD", uDig, u + 1,
                        uTyp, val_to_str_ext_const(uTyp, GET_VALS_EXTP(PrmTyp2), "      Unkn") + 6,
                        uPrm, uPrm);
 
+        increment_dissection_depth(pinfo);
         switch (uTyp)
         {
             case MQ_MQCFT_NONE:
@@ -571,6 +575,7 @@ guint32 dissect_mqpcf_parm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mq_tre
             }
             break;
         }
+        decrement_dissection_depth(pinfo);
         offset = tOfs + uLen;
     }
     if (u != uCount)
@@ -612,7 +617,7 @@ static void dissect_mqpcf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, m
 
             if (uCC || uRC)
             {
-                snprintf(sTmp, (gulong)sizeof(sTmp) - 1, " %-s [%d-%s] {%d-%s} PrmCnt(%d) CC(%d-%s) RC(%d-%s)",
+                snprintf(sTmp, sizeof(sTmp) - 1, " %-s [%d-%s] {%d-%s} PrmCnt(%d) CC(%d-%s) RC(%d-%s)",
                            MQ_TEXT_CFH,
                            uTyp, val_to_str_const(uTyp, GET_VALSV(mqcft), "Unknown"),
                            uCmd, val_to_str_ext_const(uCmd, GET_VALS_EXTP(MQCMD), "Unknown"),
@@ -622,7 +627,7 @@ static void dissect_mqpcf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, m
             }
             else
             {
-                snprintf(sTmp, (gulong)sizeof(sTmp) - 1, " %-s [%d-%s] {%d-%s} PrmCnt(%d)",
+                snprintf(sTmp, sizeof(sTmp) - 1, " %-s [%d-%s] {%d-%s} PrmCnt(%d)",
                            MQ_TEXT_CFH,
                            uTyp, val_to_str_const(uTyp, GET_VALSV(mqcft), "Unknown"),
                            uCmd, val_to_str_ext_const(uCmd, GET_VALS_EXTP(MQCMD), "Unknown"),
@@ -631,7 +636,7 @@ static void dissect_mqpcf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, m
 
             ti = proto_tree_add_item(tree, proto_mqpcf, tvb, offset, -1, ENC_NA);
 
-            proto_item_append_text(ti, " (%s)", val_to_str_ext_const(iCommand, GET_VALS_EXTP(MQCMD), "Unknown (0x%02x)"));
+            proto_item_append_text(ti, " (%s)", val_to_str_ext(iCommand, GET_VALS_EXTP(MQCMD), "Unknown (0x%02x)"));
             mqroot_tree = proto_item_add_subtree(ti, ett_mqpcf);
 
             mq_tree = proto_tree_add_subtree(mqroot_tree, tvb, offset, iSizeMQCFH, ett_mqpcf_cfh, NULL, sTmp);
@@ -650,7 +655,7 @@ static void dissect_mqpcf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, m
     }
 }
 
-static gboolean dissect_mqpcf_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+static bool dissect_mqpcf_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     if (data && tvb_reported_length(tvb) >= 36)
     {
@@ -661,17 +666,17 @@ static gboolean dissect_mqpcf_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree
         {
             /* Dissect the packet */
             dissect_mqpcf(tvb, pinfo, tree, p_mq_parm);
-            return TRUE;
+            return true;
         }
         if (strncmp((const char *)p_mq_parm->mq_format, "LPOO", 4) == 0)
         {
             gboolean bLittleEndian;
             bLittleEndian = ((p_mq_parm->mq_cur_ccsid.encod & MQ_MQENC_INTEGER_MASK) == MQ_MQENC_INTEGER_REVERSED) ? ENC_LITTLE_ENDIAN : ENC_BIG_ENDIAN;
             dissect_mqpcf_parm(tvb, pinfo, tree, 0, (guint32)-1, bLittleEndian, FALSE);
-            return TRUE;
+            return true;
         }
     }
-    return FALSE;
+    return false;
 }
 
 void proto_register_mqpcf(void)
