@@ -509,109 +509,109 @@ static dissector_handle_t mqtt_handle;
 static heur_dissector_list_t mqtt_topic_subdissector;
 
 /* Initialize the protocol and registered fields */
-static int proto_mqtt = -1;
+static int proto_mqtt;
 
 /* Message */
-static int hf_mqtt_hdrflags = -1;
-static int hf_mqtt_msg_len = -1;
-static int hf_mqtt_msg_type = -1;
-static int hf_mqtt_reserved = -1;
-static int hf_mqtt_dup_flag = -1;
-static int hf_mqtt_qos_level = -1;
-static int hf_mqtt_retain = -1;
-static int hf_mqtt_retain_reserved = -1;
-static int hf_mqtt_conack_reserved = -1;
-static int hf_mqtt_conack_flags = -1;
-static int hf_mqtt_conackflag_reserved = -1;
-static int hf_mqtt_conackflag_sp = -1;
-static int hf_mqtt_conack_code = -1;
-static int hf_mqtt_msgid = -1;
-static int hf_mqtt_sub_qos = -1;
-static int hf_mqtt_suback_qos = -1;
-static int hf_mqtt_topic_len = -1;
-static int hf_mqtt_topic = -1;
-static int hf_mqtt_will_topic_len = -1;
-static int hf_mqtt_will_topic = -1;
-static int hf_mqtt_will_msg_len = -1;
-static int hf_mqtt_will_msg = -1;
-static int hf_mqtt_will_msg_text = -1;
-static int hf_mqtt_username_len = -1;
-static int hf_mqtt_username = -1;
-static int hf_mqtt_passwd_len = -1;
-static int hf_mqtt_passwd = -1;
-static int hf_mqtt_pubmsg = -1;
-static int hf_mqtt_pubmsg_text = -1;
-static int hf_mqtt_pubmsg_decoded = -1;
-static int hf_mqtt_proto_len = -1;
-static int hf_mqtt_proto_name = -1;
-static int hf_mqtt_client_id_len = -1;
-static int hf_mqtt_client_id = -1;
-static int hf_mqtt_proto_ver = -1;
-static int hf_mqtt_conflags = -1;
-static int hf_mqtt_conflag_user = -1;
-static int hf_mqtt_conflag_passwd = -1;
-static int hf_mqtt_conflag_will_retain = -1;
-static int hf_mqtt_conflag_will_qos = -1;
-static int hf_mqtt_conflag_will_flag = -1;
-static int hf_mqtt_conflag_clean_sess = -1;
-static int hf_mqtt_conflag_reserved = -1;
-static int hf_mqtt_keep_alive = -1;
-static int hf_mqtt_subscription_options = -1;
+static int hf_mqtt_hdrflags;
+static int hf_mqtt_msg_len;
+static int hf_mqtt_msg_type;
+static int hf_mqtt_reserved;
+static int hf_mqtt_dup_flag;
+static int hf_mqtt_qos_level;
+static int hf_mqtt_retain;
+static int hf_mqtt_retain_reserved;
+static int hf_mqtt_conack_reserved;
+static int hf_mqtt_conack_flags;
+static int hf_mqtt_conackflag_reserved;
+static int hf_mqtt_conackflag_sp;
+static int hf_mqtt_conack_code;
+static int hf_mqtt_msgid;
+static int hf_mqtt_sub_qos;
+static int hf_mqtt_suback_qos;
+static int hf_mqtt_topic_len;
+static int hf_mqtt_topic;
+static int hf_mqtt_will_topic_len;
+static int hf_mqtt_will_topic;
+static int hf_mqtt_will_msg_len;
+static int hf_mqtt_will_msg;
+static int hf_mqtt_will_msg_text;
+static int hf_mqtt_username_len;
+static int hf_mqtt_username;
+static int hf_mqtt_passwd_len;
+static int hf_mqtt_passwd;
+static int hf_mqtt_pubmsg;
+static int hf_mqtt_pubmsg_text;
+static int hf_mqtt_pubmsg_decoded;
+static int hf_mqtt_proto_len;
+static int hf_mqtt_proto_name;
+static int hf_mqtt_client_id_len;
+static int hf_mqtt_client_id;
+static int hf_mqtt_proto_ver;
+static int hf_mqtt_conflags;
+static int hf_mqtt_conflag_user;
+static int hf_mqtt_conflag_passwd;
+static int hf_mqtt_conflag_will_retain;
+static int hf_mqtt_conflag_will_qos;
+static int hf_mqtt_conflag_will_flag;
+static int hf_mqtt_conflag_clean_sess;
+static int hf_mqtt_conflag_reserved;
+static int hf_mqtt_keep_alive;
+static int hf_mqtt_subscription_options;
 
 /* MQTT v5.0 Reason Codes */
-static int hf_mqtt_reason_code_connack = -1;
-static int hf_mqtt_reason_code_puback = -1;
-static int hf_mqtt_reason_code_pubrec = -1;
-static int hf_mqtt_reason_code_pubrel = -1;
-static int hf_mqtt_reason_code_pubcomp = -1;
-static int hf_mqtt_reason_code_suback = -1;
-static int hf_mqtt_reason_code_unsuback = -1;
-static int hf_mqtt_reason_code_disconnect = -1;
-static int hf_mqtt_reason_code_auth = -1;
+static int hf_mqtt_reason_code_connack;
+static int hf_mqtt_reason_code_puback;
+static int hf_mqtt_reason_code_pubrec;
+static int hf_mqtt_reason_code_pubrel;
+static int hf_mqtt_reason_code_pubcomp;
+static int hf_mqtt_reason_code_suback;
+static int hf_mqtt_reason_code_unsuback;
+static int hf_mqtt_reason_code_disconnect;
+static int hf_mqtt_reason_code_auth;
 
 /* MQTT v5.0 Subscribe Options */
-static int hf_mqtt_subscription_qos = -1;
-static int hf_mqtt_subscription_nl = -1;
-static int hf_mqtt_subscription_rap = -1;
-static int hf_mqtt_subscription_retain = -1;
-static int hf_mqtt_subscription_reserved = -1;
+static int hf_mqtt_subscription_qos;
+static int hf_mqtt_subscription_nl;
+static int hf_mqtt_subscription_rap;
+static int hf_mqtt_subscription_retain;
+static int hf_mqtt_subscription_reserved;
 
 /* MQTT v5.0 Properties */
-static int hf_mqtt_property_len = -1;
-static int hf_mqtt_property = -1;
-static int hf_mqtt_will_property = -1;
-static int hf_mqtt_property_id = -1;
-static int hf_mqtt_prop_num = -1;
-static int hf_mqtt_prop_content_type = -1;
-static int hf_mqtt_prop_max_qos = -1;
-static int hf_mqtt_prop_topic_alias = -1;
-static int hf_mqtt_prop_unknown = -1;
-static int hf_mqtt_prop_string_len = -1;
-static int hf_mqtt_prop_string = -1;
-static int hf_mqtt_prop_key_len = -1;
-static int hf_mqtt_prop_key = -1;
-static int hf_mqtt_prop_value_len = -1;
-static int hf_mqtt_prop_value = -1;
+static int hf_mqtt_property_len;
+static int hf_mqtt_property;
+static int hf_mqtt_will_property;
+static int hf_mqtt_property_id;
+static int hf_mqtt_prop_num;
+static int hf_mqtt_prop_content_type;
+static int hf_mqtt_prop_max_qos;
+static int hf_mqtt_prop_topic_alias;
+static int hf_mqtt_prop_unknown;
+static int hf_mqtt_prop_string_len;
+static int hf_mqtt_prop_string;
+static int hf_mqtt_prop_key_len;
+static int hf_mqtt_prop_key;
+static int hf_mqtt_prop_value_len;
+static int hf_mqtt_prop_value;
 
 /* Initialize the subtree pointers */
-static gint ett_mqtt_hdr = -1;
-static gint ett_mqtt_msg = -1;
-static gint ett_mqtt_hdr_flags = -1;
-static gint ett_mqtt_con_flags = -1;
-static gint ett_mqtt_conack_flags = -1;
-static gint ett_mqtt_property = -1;
-static gint ett_mqtt_subscription_flags = -1;
+static gint ett_mqtt_hdr;
+static gint ett_mqtt_msg;
+static gint ett_mqtt_hdr_flags;
+static gint ett_mqtt_con_flags;
+static gint ett_mqtt_conack_flags;
+static gint ett_mqtt_property;
+static gint ett_mqtt_subscription_flags;
 
 /* Initialize the expert fields */
-static expert_field ei_illegal_length = EI_INIT;
-static expert_field ei_unknown_version = EI_INIT;
-static expert_field ei_unknown_topic_alias = EI_INIT;
+static expert_field ei_illegal_length;
+static expert_field ei_unknown_version;
+static expert_field ei_unknown_topic_alias;
 
 /* Reassemble SMPP TCP segments */
 static gboolean reassemble_mqtt_over_tcp = TRUE;
 
 /* Show Publish Message as text */
-static gboolean show_msg_as_text;
+static bool show_msg_as_text;
 
 static guint get_mqtt_pdu_len(packet_info *pinfo _U_, tvbuff_t *tvb,
                               int offset, void *data _U_)
@@ -739,7 +739,7 @@ static gboolean mqtt_user_decode_message(proto_tree *tree, proto_tree *mqtt_tree
   {
     if (message_decode_entry->msg_decoding == MSG_DECODING_COMPRESSED)
     {
-      msg_tvb = tvb_child_uncompress(msg_tvb, msg_tvb, 0, tvb_reported_length(msg_tvb));
+      msg_tvb = tvb_child_uncompress_zlib(msg_tvb, msg_tvb, 0, tvb_reported_length(msg_tvb));
       if (msg_tvb)
       {
         add_new_data_source(pinfo, msg_tvb, "Uncompressed Message");
@@ -791,7 +791,7 @@ static void dissect_mqtt_reason_code(proto_tree *mqtt_tree, tvbuff_t *tvb, guint
     &hf_mqtt_reason_code_auth
   };
 
-  if (mqtt_msg_type < (sizeof hf_rcode / sizeof hf_rcode[0]))
+  if (mqtt_msg_type < array_length(hf_rcode))
   {
     const int *hfindex = hf_rcode[mqtt_msg_type];
     if (hfindex)
@@ -802,7 +802,7 @@ static void dissect_mqtt_reason_code(proto_tree *mqtt_tree, tvbuff_t *tvb, guint
 }
 
 /* MQTT v5.0: dissect the MQTT properties */
-static guint dissect_mqtt_properties(tvbuff_t *tvb, proto_tree *mqtt_tree, guint offset, int hf_property, mqtt_properties_t *mqtt_properties)
+static guint dissect_mqtt_properties(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mqtt_tree, guint offset, int hf_property, mqtt_properties_t *mqtt_properties)
 {
   proto_tree *mqtt_prop_tree;
   proto_item *ti;
@@ -818,7 +818,7 @@ static guint dissect_mqtt_properties(tvbuff_t *tvb, proto_tree *mqtt_tree, guint
   ti = proto_tree_add_item(mqtt_tree, hf_property, tvb, offset, mqtt_prop_offset + mqtt_prop_len, ENC_NA);
   mqtt_prop_tree = proto_item_add_subtree(ti, ett_mqtt_property);
 
-  proto_tree_add_item(mqtt_prop_tree, hf_mqtt_property_len, tvb, offset, mqtt_prop_offset, ENC_LITTLE_ENDIAN|ENC_VARINT_PROTOBUF);
+  proto_tree_add_item(mqtt_prop_tree, hf_mqtt_property_len, tvb, offset, mqtt_prop_offset, ENC_BIG_ENDIAN);
   offset += mqtt_prop_offset;
 
   const guint bytes_to_read = offset + mqtt_prop_len;
@@ -877,7 +877,7 @@ static guint dissect_mqtt_properties(tvbuff_t *tvb, proto_tree *mqtt_tree, guint
       case PROP_CONTENT_TYPE:
       {
         gint length;
-        proto_tree_add_item_ret_string_and_length(mqtt_prop_tree, hf_mqtt_prop_content_type, tvb, offset, 2, ENC_UTF_8, wmem_packet_scope(), &mqtt_properties->content_type, &length);
+        proto_tree_add_item_ret_string_and_length(mqtt_prop_tree, hf_mqtt_prop_content_type, tvb, offset, 2, ENC_UTF_8, pinfo->pool, &mqtt_properties->content_type, &length);
         offset += length;
         break;
       }
@@ -1058,7 +1058,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 
       if (mqtt->runtime_proto_version == MQTT_PROTO_V50)
       {
-        offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
+        offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
       }
 
       proto_tree_add_item_ret_uint(mqtt_tree, hf_mqtt_client_id_len, tvb, offset, 2, ENC_BIG_ENDIAN, &mqtt_str_len);
@@ -1071,7 +1071,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
       {
         if (mqtt->runtime_proto_version == MQTT_PROTO_V50)
         {
-          offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_will_property, &mqtt_will_properties);
+          offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_will_property, &mqtt_will_properties);
         }
 
         ti = proto_tree_add_item_ret_uint(mqtt_tree, hf_mqtt_will_topic_len, tvb, offset, 2, ENC_BIG_ENDIAN, &mqtt_str_len);
@@ -1146,7 +1146,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 
       if (mqtt->runtime_proto_version == MQTT_PROTO_V50)
       {
-        offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
+        offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
       }
       break;
 
@@ -1159,7 +1159,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
       {
         /* 'topic_regex' requires topic_str to be valid UTF-8. */
         proto_tree_add_item_ret_string(mqtt_tree, hf_mqtt_topic, tvb, offset, mqtt_str_len, ENC_UTF_8|ENC_NA,
-                                       wmem_packet_scope(), &topic_str);
+                                       pinfo->pool, &topic_str);
         offset += mqtt_str_len;
       }
 
@@ -1173,7 +1173,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 
       if (mqtt->runtime_proto_version == MQTT_PROTO_V50)
       {
-        offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
+        offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
 
         if (mqtt_properties.topic_alias != 0)
         {
@@ -1237,7 +1237,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
       if (!msg_handled) {
         heur_dtbl_entry_t *hdtbl_entry;
         tvbuff_t *msg_tvb = tvb_new_subset_length(tvb, offset, mqtt_payload_len);
-        gchar *sub_data = wmem_strdup(wmem_packet_scope(), (const gchar*)topic_str);
+        gchar *sub_data = wmem_strdup(pinfo->pool, (const gchar*)topic_str);
         dissector_try_heuristic(mqtt_topic_subdissector, msg_tvb, pinfo, tree, &hdtbl_entry, sub_data);
       }
       break;
@@ -1253,7 +1253,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 
       if (mqtt->runtime_proto_version == MQTT_PROTO_V50)
       {
-        offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
+        offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
       }
 
       while (offset < tvb_reported_length(tvb))
@@ -1298,7 +1298,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 
       if (mqtt->runtime_proto_version == MQTT_PROTO_V50)
       {
-        offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
+        offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
       }
 
       while (offset < tvb_reported_length(tvb))
@@ -1328,7 +1328,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 
       if (mqtt->runtime_proto_version == MQTT_PROTO_V50)
       {
-        offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
+        offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
       }
 
       while (offset < tvb_reported_length(tvb))
@@ -1368,7 +1368,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
          */
         if (mqtt_msg_len > 3)
         {
-          offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
+          offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
         }
       }
       break;
@@ -1380,7 +1380,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 
       if (mqtt->runtime_proto_version == MQTT_PROTO_V50)
       {
-        offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
+        offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
 
         while (offset < tvb_reported_length(tvb))
         {
@@ -1418,7 +1418,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
          */
         if (mqtt_msg_len >= 2)
         {
-          offset += dissect_mqtt_properties(tvb, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
+          offset += dissect_mqtt_properties(tvb, pinfo, mqtt_tree, offset, hf_mqtt_property, &mqtt_properties);
         }
       }
       break;
@@ -1432,7 +1432,7 @@ static int dissect_mqtt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 Disconnect), and the maximum size is 256MB.  Hence minimum fixed
 length should be 2 bytes for tcp_dissect_pdu.
 
-If the length filed is spread across two TCP segments, then we have a
+If the length field is spread across two TCP segments, then we have a
 problem, because exception will be raised.  So long as MQTT length
 field(although spread over 4 bytes) is present within single TCP
 segment we shouldn't have any issue by calling tcp_dissect_pdu with
@@ -1495,7 +1495,7 @@ void proto_register_mqtt(void)
     /* Conn-Ack */
     { &hf_mqtt_conack_reserved,
       { "Reserved", "mqtt.conack.flags.reserved",
-        FT_BOOLEAN, 8, TFS(&tfs_set_notset), 0,
+        FT_BOOLEAN, BASE_NONE, TFS(&tfs_set_notset), 0,
         NULL, HFILL }},
     { &hf_mqtt_conack_flags,
       { "Acknowledge Flags", "mqtt.conack.flags",
@@ -1821,7 +1821,7 @@ void proto_register_mqtt(void)
   proto_register_field_array(proto_mqtt, hf_mqtt, array_length(hf_mqtt));
   proto_register_subtree_array(ett_mqtt, array_length(ett_mqtt));
 
-  mqtt_topic_subdissector = register_heur_dissector_list("mqtt.topic", proto_mqtt);
+  mqtt_topic_subdissector = register_heur_dissector_list_with_description("mqtt.topic", "MQTT message topic", proto_mqtt);
 
   expert_mqtt = expert_register_protocol(proto_mqtt);
   expert_register_field_array(expert_mqtt, ei, array_length(ei));
