@@ -119,43 +119,44 @@ static const value_string sa_unspec_error_vals[] = {
 #define MSDP_PORT  639
 
 /* Initialize the protocol and registered fields */
-static int proto_msdp = -1;
-static int hf_msdp_type = -1;
-static int hf_msdp_length = -1;
+static int proto_msdp;
+static int hf_msdp_type;
+static int hf_msdp_length;
 
-static int hf_msdp_sa_entry_count = -1;
-static int hf_msdp_sa_rp_addr = -1;
-static int hf_msdp_sa_reserved = -1;
-static int hf_msdp_sa_sprefix_len = -1;
-static int hf_msdp_sa_group_addr = -1;
-static int hf_msdp_sa_src_addr = -1;
+static int hf_msdp_sa_entry_count;
+static int hf_msdp_sa_rp_addr;
+static int hf_msdp_sa_reserved;
+static int hf_msdp_sa_sprefix_len;
+static int hf_msdp_sa_group_addr;
+static int hf_msdp_sa_src_addr;
 
-static int hf_msdp_sa_req_res = -1;
-static int hf_msdp_sa_req_group = -1;
+static int hf_msdp_sa_req_res;
+static int hf_msdp_sa_req_group;
 
-static int hf_msdp_not_o = -1;
-static int hf_msdp_not_error = -1;
-static int hf_msdp_not_error_sub = -1;
+static int hf_msdp_not_o;
+static int hf_msdp_not_error;
+static int hf_msdp_not_error_sub;
 
-static int hf_msdp_not_group_address = -1;
-static int hf_msdp_not_rp_address = -1;
-static int hf_msdp_not_source_address = -1;
-static int hf_msdp_not_res = -1;
-static int hf_msdp_not_entry_count = -1;
-static int hf_msdp_not_sprefix_len = -1;
+static int hf_msdp_not_group_address;
+static int hf_msdp_not_rp_address;
+static int hf_msdp_not_source_address;
+static int hf_msdp_not_res;
+static int hf_msdp_not_entry_count;
+static int hf_msdp_not_sprefix_len;
 
-static int hf_msdp_tlv_contents = -1;
-static int hf_msdp_trailing_junk = -1;
-static int hf_msdp_unknown_data = -1;
+static int hf_msdp_tlv_contents;
+static int hf_msdp_trailing_junk;
+static int hf_msdp_unknown_data;
 
-static gint ett_msdp = -1;
-static gint ett_msdp_sa_entry = -1;
-static gint ett_msdp_sa_enc_data = -1;
-static gint ett_msdp_not_data = -1;
+static gint ett_msdp;
+static gint ett_msdp_sa_entry;
+static gint ett_msdp_sa_enc_data;
+static gint ett_msdp_not_data;
 
-static expert_field ei_msdp_tlv_len_too_short = EI_INIT;
-static expert_field ei_msdp_tlv_len_too_long = EI_INIT;
+static expert_field ei_msdp_tlv_len_too_short;
+static expert_field ei_msdp_tlv_len_too_long;
 
+static dissector_handle_t msdp_handle;
 static dissector_handle_t ip_handle;
 
 
@@ -168,6 +169,7 @@ dissect_msdp_notification(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_msdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 {
         proto_item *ti;
@@ -188,6 +190,7 @@ dissect_msdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
         msdp_tree = proto_item_add_subtree(ti, ett_msdp);
 
         offset = 0;
+        increment_dissection_depth(pinfo);
         while (tvb_reported_length_remaining(tvb, offset) != 0) {
                 proto_tree_add_item_ret_uint(msdp_tree, hf_msdp_type, tvb, offset, 1, ENC_BIG_ENDIAN, &type);
                 length_item = proto_tree_add_item_ret_uint(msdp_tree, hf_msdp_length, tvb, offset + 1, 2, ENC_BIG_ENDIAN, &length);
@@ -268,6 +271,7 @@ dissect_msdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
                         break;
                 }
         }
+        decrement_dissection_depth(pinfo);
 
         return tvb_captured_length(tvb);
 }
@@ -357,8 +361,8 @@ static void dissect_msdp_sa(tvbuff_t *tvb, packet_info *pinfo,
                  * that they reflect the MSDP packet rather than the
                  * encapsulated packet.
                  */
-                col_set_writable(pinfo->cinfo, COL_PROTOCOL, FALSE);
-                col_set_writable(pinfo->cinfo, COL_INFO, FALSE);
+                col_set_writable(pinfo->cinfo, COL_PROTOCOL, false);
+                col_set_writable(pinfo->cinfo, COL_INFO, false);
                 call_dissector(ip_handle, next_tvb, pinfo, enc_tree);
         }
         *offset += length;
@@ -377,6 +381,7 @@ static void add_notification_data_ipv4addr(tvbuff_t *tvb, proto_tree *tree, int
         return;
 }
 
+// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_msdp_notification(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int *offset, guint16 tlv_len, proto_item *length_item)
 {
         guint8              error, error_sub;
@@ -722,6 +727,7 @@ proto_register_msdp(void)
 
         proto_msdp = proto_register_protocol("Multicast Source Discovery Protocol",
             "MSDP", "msdp");
+        msdp_handle = register_dissector("msdp", dissect_msdp, proto_msdp);
 
         proto_register_field_array(proto_msdp, hf, array_length(hf));
         proto_register_subtree_array(ett, array_length(ett));
@@ -732,9 +738,6 @@ proto_register_msdp(void)
 void
 proto_reg_handoff_msdp(void)
 {
-        dissector_handle_t msdp_handle;
-
-        msdp_handle = create_dissector_handle(dissect_msdp, proto_msdp);
         dissector_add_uint_with_preference("tcp.port", MSDP_PORT, msdp_handle);
 
         ip_handle = find_dissector_add_dependency("ip", proto_msdp);
