@@ -25,7 +25,7 @@
 #include <wsutil/str_util.h>
 
 #include "packet-msrp.h"
-#include "packet-http.h"
+#include "packet-media-type.h"
 
 void proto_register_msrp(void);
 void proto_reg_handoff_msrp(void);
@@ -36,35 +36,35 @@ void proto_reg_handoff_msrp(void);
 #define MSRP_HDR_LEN (strlen (MSRP_HDR))
 
 /* Initialize the protocol and registered fields */
-static int proto_msrp       = -1;
+static int proto_msrp;
 
 /* Initialize the subtree pointers */
-static int ett_msrp                 = -1;
-static int ett_raw_text             = -1;
-static int ett_msrp_reqresp         = -1;
-static int ett_msrp_hdr             = -1;
-static int ett_msrp_data            = -1;
-static int ett_msrp_end_line        = -1;
-static int ett_msrp_setup           = -1;
+static int ett_msrp;
+static int ett_raw_text;
+static int ett_msrp_reqresp;
+static int ett_msrp_hdr;
+static int ett_msrp_data;
+static int ett_msrp_end_line;
+static int ett_msrp_setup;
 
-static int hf_msrp_response_line    = -1;
-static int hf_msrp_request_line     = -1;
-static int hf_msrp_transactionID    = -1;
-static int hf_msrp_method           = -1;
-static int hf_msrp_status_code      = -1;
-static int hf_msrp_hdr              = -1;
-static int hf_msrp_msg_hdr          = -1;
-static int hf_msrp_end_line         = -1;
-static int hf_msrp_cnt_flg          = -1;
+static int hf_msrp_response_line;
+static int hf_msrp_request_line;
+static int hf_msrp_transactionID;
+static int hf_msrp_method;
+static int hf_msrp_status_code;
+static int hf_msrp_hdr;
+static int hf_msrp_msg_hdr;
+static int hf_msrp_end_line;
+static int hf_msrp_cnt_flg;
 
-static int hf_msrp_data             = -1;
+static int hf_msrp_data;
 
-static expert_field ei_msrp_status_code_invalid = EI_INIT;
+static expert_field ei_msrp_status_code_invalid;
 
 /* MSRP setup fields */
-static int hf_msrp_setup        = -1;
-static int hf_msrp_setup_frame  = -1;
-static int hf_msrp_setup_method = -1;
+static int hf_msrp_setup;
+static int hf_msrp_setup_frame;
+static int hf_msrp_setup_method;
 
 typedef struct {
         const char *name;
@@ -89,24 +89,7 @@ static const msrp_header_t msrp_headers[] = {
     { "Authentication-Info"},   /*  15 */
 };
 
-static gint hf_header_array[] = {
-    -1, /* 0"Unknown-header" - Pad so that the real headers start at index 1 */
-    -1, /* 1"From-Path                                                       */
-    -1, /* 2"To-Path                                                         */
-    -1, /* 3"Message-ID"                                                     */
-    -1, /* 4"Success-Report"                                                 */
-    -1, /* 5"Failure-Report"                                                 */
-    -1, /* 6"Byte-Range"                                                     */
-    -1, /* 7"Status"                                                         */
-    -1, /* 8"Content-Type"                                                   */
-    -1, /* 9"Content-ID"                                                     */
-    -1, /* 10"Content-Description"                                           */
-    -1, /* 11"Content-Disposition"                                           */
-    -1, /* 12"Use-Path"                                                      */
-    -1, /* 13"WWW-Authenticate"                                              */
-    -1, /* 14"Authorization"                                                 */
-    -1, /* 15"Authentication-Info"                                           */
-};
+static gint hf_header_array[array_length(msrp_headers)];
 
 #define MSRP_FROM_PATH                          1
 #define MSRP_TO_PATH                            2
@@ -125,7 +108,7 @@ static gint hf_header_array[] = {
 #define MSRP_AUTHENTICATION_INFO                15
 
 static dissector_handle_t msrp_handle;
-static gboolean global_msrp_raw_text = TRUE;
+static bool global_msrp_raw_text = true;
 
 /* MSRP content type and internet media type used by other dissectors
  * are the same.  List of media types from IANA at:
@@ -136,7 +119,7 @@ static int dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 
 
 /* Displaying conversation setup info */
-static gboolean global_msrp_show_setup_info = TRUE;
+static bool global_msrp_show_setup_info = true;
 static void show_setup_info(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 
 /* Set up an MSRP conversation using the info given */
@@ -165,14 +148,14 @@ msrp_add_address( packet_info *pinfo,
      * Check if the ip address and port combination is not
      * already registered as a conversation.
      */
-    p_conv = find_conversation( pinfo->num, addr, &null_addr, ENDPOINT_TCP, port, 0,
+    p_conv = find_conversation( pinfo->num, addr, &null_addr, CONVERSATION_TCP, port, 0,
                                 NO_ADDR_B | NO_PORT_B);
 
     /*
      * If not, create a new conversation.
      */
     if (!p_conv) {
-        p_conv = conversation_new( pinfo->num, addr, &null_addr, ENDPOINT_TCP,
+        p_conv = conversation_new( pinfo->num, addr, &null_addr, CONVERSATION_TCP,
                                    (guint32)port, 0,
                                    NO_ADDR2 | NO_PORT2);
     }
@@ -219,7 +202,7 @@ show_setup_info(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     {
         /* First time, get info from conversation */
         p_conv = find_conversation(pinfo->num, &pinfo->net_dst, &pinfo->net_src,
-                                   ENDPOINT_TCP,
+                                   CONVERSATION_TCP,
                                    pinfo->destport, pinfo->srcport, 0);
 
         if (p_conv)
@@ -403,8 +386,8 @@ find_end_line(tvbuff_t *tvb, gint start)
     return -1;
 }
 
-static gboolean
-dissect_msrp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool
+dissect_msrp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     conversation_t* conversation;
 
@@ -418,10 +401,10 @@ dissect_msrp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
             /* Set dissector */
             conversation_set_dissector(conversation, msrp_handle);
         }
-        dissect_msrp(tvb, pinfo, tree, NULL);
-        return TRUE;
+        dissect_msrp(tvb, pinfo, tree, data);
+        return true;
     }
-    return FALSE;
+    return false;
 }
 
 /* Code to actually dissect the packets */
@@ -457,7 +440,7 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     int found_match = 0;
     gint content_type_len, content_type_parameter_str_len;
     gchar *media_type_str_lower_case = NULL;
-    http_message_info_t message_info = { HTTP_OTHERS, NULL, NULL, NULL };
+    media_content_info_t content_info = { MEDIA_CONTAINER_OTHER, NULL, NULL, NULL };
     tvbuff_t *next_tvb;
     gint parameter_offset;
     gint semi_colon_offset;
@@ -650,7 +633,7 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
                                     parameter_offset++;
                                 content_type_len = semi_colon_offset - value_offset;
                                 content_type_parameter_str_len = line_end_offset - parameter_offset;
-                                message_info.media_str = tvb_get_string_enc(pinfo->pool, tvb,
+                                content_info.media_str = tvb_get_string_enc(pinfo->pool, tvb,
                                              parameter_offset, content_type_parameter_str_len, ENC_UTF_8|ENC_NA);
                             }
                             media_type_str_lower_case = ascii_strdown_inplace(
@@ -684,7 +667,7 @@ dissect_msrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
                 found_match = dissector_try_string(media_type_dissector_table,
                                                media_type_str_lower_case,
                                                next_tvb, pinfo,
-                                               msrp_data_tree, &message_info);
+                                               msrp_data_tree, &content_info);
                 /* If no match dump as text */
             }
             if ( found_match == 0 )
