@@ -29,6 +29,9 @@ void proto_register_mtp2(void);
 void proto_reg_handoff_mtp2(void);
 
 static dissector_handle_t mtp2_handle;
+static dissector_handle_t mtp2_with_phdr_handle;
+static dissector_handle_t mtp2_bitstream_handle;
+static dissector_handle_t mtp3_handle;
 
 /* possible packet states */
 enum packet_direction_state_mtp2 {FORWARD, BACKWARD};
@@ -102,40 +105,40 @@ typedef struct mtp2_convo_data {
 } mtp2_convo_data_t;
 
 /* Initialize the protocol and registered fields */
-static int proto_mtp2        = -1;
-static int hf_mtp2_bsn       = -1;
-static int hf_mtp2_ext_bsn   = -1;
-static int hf_mtp2_ext_res   = -1;
-static int hf_mtp2_bib       = -1;
-static int hf_mtp2_ext_bib   = -1;
-static int hf_mtp2_fsn       = -1;
-static int hf_mtp2_ext_fsn   = -1;
-static int hf_mtp2_fib       = -1;
-static int hf_mtp2_ext_fib   = -1;
-static int hf_mtp2_li        = -1;
-static int hf_mtp2_ext_li    = -1;
-static int hf_mtp2_spare     = -1;
-static int hf_mtp2_ext_spare = -1;
-static int hf_mtp2_sf        = -1;
-static int hf_mtp2_sf_extra  = -1;
-static int hf_mtp2_fcs_16    = -1;
-static int hf_mtp2_fcs_16_status = -1;
-static int hf_mtp2_unexpect_end = -1;
-static int hf_mtp2_frame_reset = -1;
+static int proto_mtp2;
+static int hf_mtp2_bsn;
+static int hf_mtp2_ext_bsn;
+static int hf_mtp2_ext_res;
+static int hf_mtp2_bib;
+static int hf_mtp2_ext_bib;
+static int hf_mtp2_fsn;
+static int hf_mtp2_ext_fsn;
+static int hf_mtp2_fib;
+static int hf_mtp2_ext_fib;
+static int hf_mtp2_li;
+static int hf_mtp2_ext_li;
+static int hf_mtp2_spare;
+static int hf_mtp2_ext_spare;
+static int hf_mtp2_sf;
+static int hf_mtp2_sf_extra;
+static int hf_mtp2_fcs_16;
+static int hf_mtp2_fcs_16_status;
+static int hf_mtp2_unexpect_end;
+static int hf_mtp2_frame_reset;
 
 /* reassemble variables */
-static int hf_mtp2_fragments = -1;
-static int hf_mtp2_fragment = -1;
-static int hf_mtp2_fragment_overlap = -1;
-static int hf_mtp2_fragment_overlap_conflicts = -1;
-static int hf_mtp2_fragment_multiple_tails = -1;
-static int hf_mtp2_fragment_too_long_fragment = -1;
-static int hf_mtp2_fragment_error = -1;
-static int hf_mtp2_fragment_count = -1;
-static int hf_mtp2_reassembled_in = -1;
-static int hf_mtp2_reassembled_length = -1;
-static gint ett_mtp2_fragment = -1;
-static gint ett_mtp2_fragments = -1;
+static int hf_mtp2_fragments;
+static int hf_mtp2_fragment;
+static int hf_mtp2_fragment_overlap;
+static int hf_mtp2_fragment_overlap_conflicts;
+static int hf_mtp2_fragment_multiple_tails;
+static int hf_mtp2_fragment_too_long_fragment;
+static int hf_mtp2_fragment_error;
+static int hf_mtp2_fragment_count;
+static int hf_mtp2_reassembled_in;
+static int hf_mtp2_reassembled_length;
+static gint ett_mtp2_fragment;
+static gint ett_mtp2_fragments;
 
 /* local static const needed for reassembly */
 static const fragment_items mtp2_frag_items = {
@@ -159,26 +162,23 @@ static const fragment_items mtp2_frag_items = {
 static reassembly_table mtp2_reassembly_table;
 
 /* variables needed for property registration to wireshark menu */
-static range_t *mtp2_rtp_payload_types;
-static range_t *pref_mtp2_rtp_payload_types = NULL;
-static gboolean reverse_bit_order_mtp2 = FALSE;
+static bool reverse_bit_order_mtp2;
 
-static expert_field ei_mtp2_checksum_error = EI_INIT;
-static expert_field ei_mtp2_li_bad = EI_INIT;
+static expert_field ei_mtp2_checksum_error;
+static expert_field ei_mtp2_li_bad;
 
 /* Initialize the subtree pointers */
-static gint ett_mtp2       = -1;
+static gint ett_mtp2;
 
-static dissector_handle_t mtp3_handle;
-static gboolean use_extended_sequence_numbers_default = FALSE;
-static gboolean capture_contains_fcs_crc_default = FALSE;
+static bool use_extended_sequence_numbers_default;
+static bool capture_contains_fcs_crc_default;
 
 /* sequence number of the actual packet to be reassembled
  * this is needed because the reassemble handler uses a key based on the
  * source and destination IP addresses
  * therefore if there are multiple streams between 2 IP end-points
  * the reassemble sequence numbers can conflict if they are based on conversations */
-static guint32    mtp2_absolute_reass_seq_num = 0;
+static guint32    mtp2_absolute_reass_seq_num;
 
 #define BSN_BIB_LENGTH          1
 #define FSN_FIB_LENGTH          1
@@ -529,16 +529,10 @@ dissect_mtp2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
   return tvb_captured_length(tvb);
 }
 
-static void
-mtp2_init_routine(void)
-{
-        reassembly_table_register(&mtp2_reassembly_table, &addresses_ports_reassembly_table_functions);
-}
-
 /*  get one bit of a guint8 byte
 *   based on the order set in the preferences
-*   reverse_bit_order_mtp2 = FALSE: as the Q.703 states
-*   reverse_bit_order_mtp2 = TRUE: just the opposite
+*   reverse_bit_order_mtp2 = false: as the Q.703 states
+*   reverse_bit_order_mtp2 = true: just the opposite
 */
 static gboolean
 get_bit(guint8 byte, guint8 bit)
@@ -584,8 +578,8 @@ new_byte(char full_byte, guint8 **data, guint8 *data_len)
 /* print debug info to stderr if debug is enabled
  * this function prints the packet bytes as bits separated by new lines
  * and adds extra info to bytes (flag found, frame reset, zeros were skipped, etc. */
-static void
-debug(char *format, ...)
+static void debug(char *format, ...) G_GNUC_PRINTF(1, 2);
+static void debug(char *format, ...)
 {
   guint32 max_buffer_length = 256;
   gchar *buffer = NULL;
@@ -647,7 +641,7 @@ dissect_mtp2_tvb(tvbuff_t* tvb, mtp2_mtp2_flag_search_t back_mtp2_flag_search, g
   guint8        mtp2_flag_search = 0x00,                        /* this helps to detect the flags in the bitstream */
                 data_buff = 0x00,                               /* buffer to store the found bits without the stuffed zeros */
                 data_buff_offset = 0,                           /* index of the data_buff_offset, where to store the next bit */
-                available_bytes_in_rtp_payload = 0,             /* stores the tvb's length which need to be analized */
+                available_bytes_in_rtp_payload = 0,             /* stores the tvb's length which need to be analyzed */
                 *found_data_buff_byte = NULL,                   /* buffer to store the found data_buff bytes till they are assembled to a tvb */
                 offset = 0,                                     /* offset of the tvb, needed to get the appropriate byte */
                 data_len = 0,                                   /* the length of the array where the data_buff's are stored */
@@ -655,7 +649,7 @@ dissect_mtp2_tvb(tvbuff_t* tvb, mtp2_mtp2_flag_search_t back_mtp2_flag_search, g
 #ifdef MTP2_BITSTREAM_DEBUG
   gboolean      zero_skip0 = 0,                                 /* needed for debug output */
                 zero_skip1 = 0,                                 /* needed for debug output */
-                flag = FALSE,                                   /* needed for debug to print flag found message. reseted at every new octet read from tvb */
+                flag = FALSE,                                   /* needed for debug to print flag found message. reset at every new octet read from tvb */
                 frame_reset = FALSE;                            /* needed for debug, informs about a frame reset */
 #endif
   enum mtp2_bitstream_states    state = OUT_OF_SYNC;            /* actual state of the dissection */
@@ -744,7 +738,7 @@ dissect_mtp2_tvb(tvbuff_t* tvb, mtp2_mtp2_flag_search_t back_mtp2_flag_search, g
       {
         /* set the state */
         state = FLAGS;
-        /* if before this flag, we found some real packet related btyes */
+        /* if before this flag, we found some real packet related bytes */
         if (data_len != 0) {
           guint8 unaligned_packet_offset = 0; /* !=0 signals if the packet just found was not a multiple of 8 bits in the bitstream */
           /* here we check if the just found MTP2 packet is unaligned or not
@@ -942,12 +936,12 @@ dissect_mtp2_bitstream(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
 #endif
 
   /* find conversation related to this packet */
-  conversation = find_conversation(pinfo->fd->num,&pinfo->src, &pinfo->dst,conversation_pt_to_endpoint_type(pinfo->ptype), pinfo->srcport, pinfo->destport, 0);
+  conversation = find_conversation(pinfo->fd->num,&pinfo->src, &pinfo->dst,conversation_pt_to_conversation_type(pinfo->ptype), pinfo->srcport, pinfo->destport, 0);
   /* if there is no conversation or it does not contain the per packet data we need */
   if (conversation == NULL) {
     /* there was no conversation => this packet is the first in a new conversation => let's create it */
     /* here we decide about the direction, every following packet with the same direction as this first one will be a forward packet */
-    conversation = conversation_new(pinfo->fd->num,&pinfo->src, &pinfo->dst,conversation_pt_to_endpoint_type(pinfo->ptype), pinfo->srcport, pinfo->destport, 0);
+    conversation = conversation_new(pinfo->fd->num,&pinfo->src, &pinfo->dst,conversation_pt_to_conversation_type(pinfo->ptype), pinfo->srcport, pinfo->destport, 0);
   }
 
   /* there is no proto data in the conversation */
@@ -1270,13 +1264,16 @@ proto_register_mtp2(void)
   proto_mtp2 = proto_register_protocol("Message Transfer Part Level 2", "MTP2", "mtp2");
   mtp2_handle = register_dissector("mtp2", dissect_mtp2, proto_mtp2);
   register_dissector("mtp2_with_crc", dissect_mtp2_with_crc, proto_mtp2);
+  mtp2_with_phdr_handle = register_dissector("mtp2_with_phdr", dissect_mtp2_with_phdr,
+                                                  proto_mtp2);
+  mtp2_bitstream_handle = register_dissector("mtp2_bitstream", dissect_mtp2_bitstream, proto_mtp2);
 
   proto_register_field_array(proto_mtp2, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
   expert_mtp2 = expert_register_protocol(proto_mtp2);
   expert_register_field_array(expert_mtp2, ei, array_length(ei));
 
-  mtp2_module = prefs_register_protocol(proto_mtp2, proto_reg_handoff_mtp2);
+  mtp2_module = prefs_register_protocol(proto_mtp2, NULL);
   prefs_register_bool_preference(mtp2_module,
                                  "use_extended_sequence_numbers",
                                  "Use extended sequence numbers",
@@ -1294,42 +1291,23 @@ proto_register_mtp2(void)
                                  "Reverse bit order inside bytes",
                                  "Reverse the bit order inside bytes specified in Q.703.",
                                  &reverse_bit_order_mtp2);
-  prefs_register_range_preference(mtp2_module, "rtp_payload_type",
-                                 "RTP payload types for embedded packets in RTP stream",
-                                 "RTP payload types for embedded packets in RTP stream"
-                                 "; values must be in the range 1 - 127",
-                                 &pref_mtp2_rtp_payload_types,
-                                 127);
-  register_init_routine(&mtp2_init_routine);
+  prefs_register_obsolete_preference(mtp2_module, "rtp_payload_type");
+
+  reassembly_table_register(&mtp2_reassembly_table, &addresses_ports_reassembly_table_functions);
 }
 
 void
 proto_reg_handoff_mtp2(void)
 {
-  dissector_handle_t mtp2_with_phdr_handle;
-  static dissector_handle_t mtp2_bitstream_handle;
-  static gboolean init = FALSE;
-
   dissector_add_uint("wtap_encap", WTAP_ENCAP_MTP2, mtp2_handle);
-  mtp2_with_phdr_handle = create_dissector_handle(dissect_mtp2_with_phdr,
-                                                  proto_mtp2);
   dissector_add_uint("wtap_encap", WTAP_ENCAP_MTP2_WITH_PHDR,
                                    mtp2_with_phdr_handle);
 
   mtp3_handle   = find_dissector_add_dependency("mtp3", proto_mtp2);
 
-  if (!init) {
-    mtp2_bitstream_handle = create_dissector_handle(dissect_mtp2_bitstream, proto_mtp2);
-    dissector_add_string("rtp_dyn_payload_type", "MTP2", mtp2_bitstream_handle);
-    init = TRUE;
-  } else {
-    dissector_delete_uint_range("rtp.pt", mtp2_rtp_payload_types, mtp2_bitstream_handle);
-    wmem_free(wmem_epan_scope(), mtp2_rtp_payload_types);
-  }
+  dissector_add_string("rtp_dyn_payload_type", "MTP2", mtp2_bitstream_handle);
 
-  mtp2_rtp_payload_types = range_copy(wmem_epan_scope(), pref_mtp2_rtp_payload_types);
-  range_remove_value(wmem_epan_scope(), &mtp2_rtp_payload_types, 0);
-  dissector_add_uint_range("rtp.pt", mtp2_rtp_payload_types, mtp2_bitstream_handle);
+  dissector_add_uint_range_with_preference("rtp.pt", "", mtp2_bitstream_handle);
 }
 
 /*
