@@ -16,7 +16,7 @@
 #include <config.h>
 
 #include <conversation.h>
-#include <packet-tcp.h>
+#include "packet-tcp.h"
 #include <proto_data.h>
 
 #include <epan/packet.h>
@@ -28,62 +28,62 @@ void proto_register_nano(void);
 
 static dissector_handle_t nano_handle, nano_tcp_handle;
 
-static int proto_nano = -1;
+static int proto_nano;
 
-static int hf_nano_magic_number = -1;
-static int hf_nano_version_max = -1;
-static int hf_nano_version_using = -1;
-static int hf_nano_version_min = -1;
-static int hf_nano_packet_type = -1;
-static int hf_nano_extensions = -1;
-static int hf_nano_extensions_block_type = -1;
-static int hf_nano_keepalive_peer_ip = -1;
-static int hf_nano_keepalive_peer_port = -1;
+static int hf_nano_magic_number;
+static int hf_nano_version_max;
+static int hf_nano_version_using;
+static int hf_nano_version_min;
+static int hf_nano_packet_type;
+static int hf_nano_extensions;
+static int hf_nano_extensions_block_type;
+static int hf_nano_keepalive_peer_ip;
+static int hf_nano_keepalive_peer_port;
 
-static int hf_nano_block_hash_previous = -1;
-static int hf_nano_block_hash_source = -1;
-static int hf_nano_block_signature = -1;
-static int hf_nano_block_work = -1;
-static int hf_nano_block_destination_account = -1;
-static int hf_nano_block_balance = -1;
-static int hf_nano_block_account = -1;
-static int hf_nano_block_representative_account = -1;
-static int hf_nano_block_link = -1;
+static int hf_nano_block_hash_previous;
+static int hf_nano_block_hash_source;
+static int hf_nano_block_signature;
+static int hf_nano_block_work;
+static int hf_nano_block_destination_account;
+static int hf_nano_block_balance;
+static int hf_nano_block_account;
+static int hf_nano_block_representative_account;
+static int hf_nano_block_link;
 
-static int hf_nano_vote_account = -1;
-static int hf_nano_vote_signature = -1;
-static int hf_nano_vote_sequence = -1;
+static int hf_nano_vote_account;
+static int hf_nano_vote_signature;
+static int hf_nano_vote_sequence;
 
-static int hf_nano_bulk_pull_account = -1;
-static int hf_nano_bulk_pull_block_hash_end = -1;
+static int hf_nano_bulk_pull_account;
+static int hf_nano_bulk_pull_block_hash_end;
 
-static int hf_nano_frontier_req_account = -1;
-static int hf_nano_frontier_req_age = -1;
-static int hf_nano_frontier_req_count = -1;
+static int hf_nano_frontier_req_account;
+static int hf_nano_frontier_req_age;
+static int hf_nano_frontier_req_count;
 
-static int hf_nano_bulk_pull_blocks_min_hash = -1;
-static int hf_nano_bulk_pull_blocks_max_hash = -1;
-static int hf_nano_bulk_pull_blocks_mode = -1;
-static int hf_nano_bulk_pull_blocks_max_count = -1;
+static int hf_nano_bulk_pull_blocks_min_hash;
+static int hf_nano_bulk_pull_blocks_max_hash;
+static int hf_nano_bulk_pull_blocks_mode;
+static int hf_nano_bulk_pull_blocks_max_count;
 
-static int hf_nano_bulk_push_block_type = -1;
+static int hf_nano_bulk_push_block_type;
 
-static int hf_nano_bulk_pull_block_type = -1;
+static int hf_nano_bulk_pull_block_type;
 
-static int hf_nano_frontier_account = -1;
-static int hf_nano_frontier_head_hash = -1;
+static int hf_nano_frontier_account;
+static int hf_nano_frontier_head_hash;
 
-static gint ett_nano = -1;
-static gint ett_nano_header = -1;
-static gint ett_nano_extensions = -1;
-static gint ett_nano_peers = -1;
-static gint ett_nano_peer_details[8] = {-1, -1, -1, -1, -1, -1, -1, -1};
-static gint ett_nano_block = -1;
-static gint ett_nano_vote = -1;
-static gint ett_nano_bulk_pull = -1;
-static gint ett_nano_frontier_req = -1;
-static gint ett_nano_bulk_pull_blocks = -1;
-static gint ett_nano_frontier = -1;
+static gint ett_nano;
+static gint ett_nano_header;
+static gint ett_nano_extensions;
+static gint ett_nano_peers;
+static gint ett_nano_peer_details[8];
+static gint ett_nano_block;
+static gint ett_nano_vote;
+static gint ett_nano_bulk_pull;
+static gint ett_nano_frontier_req;
+static gint ett_nano_bulk_pull_blocks;
+static gint ett_nano_frontier;
 
 #define NANO_PACKET_TYPE_INVALID 0
 #define NANO_PACKET_TYPE_NOT_A_TYPE 1
@@ -133,7 +133,7 @@ static const string_string nano_magic_numbers[] = {
     { "RA", "Nano Test Network" },
     { "RB", "Nano Beta Network" },
     { "RC", "Nano Production Network" },
-    { 0, NULL }
+    { NULL, NULL }
 };
 
 #define NANO_BULK_PULL_BLOCKS_MODE_LIST_BLOCKS 0
@@ -190,7 +190,7 @@ static int dissect_nano_keepalive(tvbuff_t *tvb, packet_info *pinfo, proto_tree
         if (!memcmp(&ip_addr, "\x0\x0\x0\x0\x0\x0\x0\x0\x0\x0\x0\x0\x0\x0\x0\x0", 16)) {
             proto_item_append_text(ti, ": (none)");
         } else if (!memcmp(&ip_addr, "\x0\x0\x0\x0\x0\x0\x0\x0\x0\x0\xff\xff", 12)) {
-            ip_to_str_buf((gchar *) &ip_addr + 12, buf, sizeof(buf));
+            ip_addr_to_str_buf((ws_in4_addr *)((uint8_t *)&ip_addr + 12), buf, sizeof(buf));
             proto_item_append_text(ti, ": %s:%d", buf, port);
             peers++;
         } else {
@@ -812,13 +812,13 @@ static gboolean test_nano(packet_info *pinfo _U_, tvbuff_t *tvb, int offset _U_,
     return TRUE;
 }
 
-static gboolean dissect_nano_heur_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+static bool dissect_nano_heur_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     conversation_t *conversation;
     struct nano_session_state *session_state;
 
     if (!test_nano(pinfo, tvb, 0, data))
-        return FALSE;
+        return false;
 
     conversation = find_or_create_conversation(pinfo);
     conversation_set_dissector(conversation, nano_tcp_handle);
@@ -835,22 +835,22 @@ static gboolean dissect_nano_heur_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_t
 
     dissect_nano_tcp(tvb, pinfo, tree, data);
 
-    return TRUE;
+    return true;
 }
 
-static gboolean dissect_nano_heur_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+static bool dissect_nano_heur_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     conversation_t *conversation;
 
     if (!test_nano(pinfo, tvb, 0, data))
-        return FALSE;
+        return false;
 
     conversation = find_or_create_conversation(pinfo);
     conversation_set_dissector(conversation, nano_handle);
 
     dissect_nano(tvb, pinfo, tree, data);
 
-    return TRUE;
+    return true;
 }
 
 void proto_register_nano(void)
