@@ -32,6 +32,9 @@
 void proto_register_nat_pmp(void);
 void proto_reg_handoff_nat_pmp(void);
 
+static dissector_handle_t nat_pmp_handle;
+static dissector_handle_t pcp_handle;
+
 #define PCP_PORT_RANGE  "5350-5351"
 
 /* NAT Port opcodes */
@@ -58,87 +61,87 @@ void proto_reg_handoff_nat_pmp(void);
 #define OPT_PREFIX64            129
 #define OPT_PORT_SET            130
 
-static int proto_nat_pmp = -1;
-static int proto_pcp = -1;
+static int proto_nat_pmp;
+static int proto_pcp;
 
-static int hf_version = -1;
-static int hf_opcode = -1;
-static int hf_result_code = -1;
-static int hf_sssoe = -1;
-static int hf_external_ip = -1;
-static int hf_reserved = -1;
-static int hf_internal_port = -1;
-static int hf_external_port_requested = -1;
-static int hf_external_port_mapped = -1;
-static int hf_rpmlis = -1;
-static int hf_pmlis = -1;
+static int hf_version;
+static int hf_opcode;
+static int hf_result_code;
+static int hf_sssoe;
+static int hf_external_ip;
+static int hf_reserved;
+static int hf_internal_port;
+static int hf_external_port_requested;
+static int hf_external_port_mapped;
+static int hf_rpmlis;
+static int hf_pmlis;
 
-static gint ett_nat_pmp = -1;
+static gint ett_nat_pmp;
 
 /* Port Control Protocol */
-static int hf_pcp_version = -1;
-static int hf_request = -1;
-static int hf_response = -1;
-static int hf_pcp_r = -1;
-static int hf_pcp_opcode = -1;
-static int hf_pcp_result_code = -1;
-static int hf_reserved1 = -1;
-static int hf_reserved2 = -1;
-static int hf_reserved12 = -1;
-static int hf_req_lifetime = -1;
-static int hf_rsp_lifetime = -1;
-static int hf_client_ip = -1;
-static int hf_epoch_time = -1;
-static int hf_map_nonce = -1;
-static int hf_map_protocol = -1;
-static int hf_map_reserved1 = -1;
-static int hf_map_internal_port = -1;
-static int hf_map_req_sug_external_port = -1;
-static int hf_map_req_sug_ext_ip = -1;
-static int hf_map_rsp_assigned_external_port = -1;
-static int hf_map_rsp_assigned_ext_ip = -1;
-static int hf_peer_nonce = -1;
-static int hf_peer_protocol = -1;
-static int hf_peer_reserved = -1;
-static int hf_peer_internal_port = -1;
-static int hf_peer_req_sug_external_port = -1;
-static int hf_peer_req_sug_ext_ip = -1;
-static int hf_peer_remote_peer_port = -1;
-static int hf_peer_remote_peer_ip = -1;
-static int hf_peer_rsp_assigned_external_port = -1;
-static int hf_peer_rsp_assigned_ext_ip = -1;
-static int hf_options = -1;
-static int hf_option = -1;
-static int hf_option_code = -1;
-static int hf_option_reserved = -1;
-static int hf_option_length = -1;
-static int hf_option_third_party_internal_ip = -1;
-static int hf_option_filter_reserved = -1;
-static int hf_option_filter_prefix_length = -1;
-static int hf_option_filter_remote_peer_port = -1;
-static int hf_option_filter_remote_peer_ip = -1;
-static int hf_option_description = -1;
-static int hf_option_p64_length = -1;
-static int hf_option_p64_prefix64 = -1;
-static int hf_option_p64_suffix = -1;
-static int hf_option_p64_ipv4_prefix_count = -1;
-static int hf_option_p64_ipv4_prefix_length = -1;
-static int hf_option_p64_ipv4_address = -1;
-static int hf_option_portset_size = -1;
-static int hf_option_portset_first_suggested_port = -1;
-static int hf_option_portset_first_assigned_port = -1;
-static int hf_option_portset_reserved = -1;
-static int hf_option_portset_parity = -1;
-static int hf_option_padding = -1;
+static int hf_pcp_version;
+static int hf_request;
+static int hf_response;
+static int hf_pcp_r;
+static int hf_pcp_opcode;
+static int hf_pcp_result_code;
+static int hf_reserved1;
+static int hf_reserved2;
+static int hf_reserved12;
+static int hf_req_lifetime;
+static int hf_rsp_lifetime;
+static int hf_client_ip;
+static int hf_epoch_time;
+static int hf_map_nonce;
+static int hf_map_protocol;
+static int hf_map_reserved1;
+static int hf_map_internal_port;
+static int hf_map_req_sug_external_port;
+static int hf_map_req_sug_ext_ip;
+static int hf_map_rsp_assigned_external_port;
+static int hf_map_rsp_assigned_ext_ip;
+static int hf_peer_nonce;
+static int hf_peer_protocol;
+static int hf_peer_reserved;
+static int hf_peer_internal_port;
+static int hf_peer_req_sug_external_port;
+static int hf_peer_req_sug_ext_ip;
+static int hf_peer_remote_peer_port;
+static int hf_peer_remote_peer_ip;
+static int hf_peer_rsp_assigned_external_port;
+static int hf_peer_rsp_assigned_ext_ip;
+static int hf_options;
+static int hf_option;
+static int hf_option_code;
+static int hf_option_reserved;
+static int hf_option_length;
+static int hf_option_third_party_internal_ip;
+static int hf_option_filter_reserved;
+static int hf_option_filter_prefix_length;
+static int hf_option_filter_remote_peer_port;
+static int hf_option_filter_remote_peer_ip;
+static int hf_option_description;
+static int hf_option_p64_length;
+static int hf_option_p64_prefix64;
+static int hf_option_p64_suffix;
+static int hf_option_p64_ipv4_prefix_count;
+static int hf_option_p64_ipv4_prefix_length;
+static int hf_option_p64_ipv4_address;
+static int hf_option_portset_size;
+static int hf_option_portset_first_suggested_port;
+static int hf_option_portset_first_assigned_port;
+static int hf_option_portset_reserved;
+static int hf_option_portset_parity;
+static int hf_option_padding;
 
-static gint ett_pcp = -1;
-static gint ett_opcode = -1;
-static gint ett_option = -1;
-static gint ett_suboption = -1;
+static gint ett_pcp;
+static gint ett_opcode;
+static gint ett_option;
+static gint ett_suboption;
 
-static expert_field ei_natpmp_opcode_unknown = EI_INIT;
-static expert_field ei_pcp_opcode_unknown = EI_INIT;
-static expert_field ei_pcp_option_unknown = EI_INIT;
+static expert_field ei_natpmp_opcode_unknown;
+static expert_field ei_pcp_opcode_unknown;
+static expert_field ei_pcp_option_unknown;
 
 static const value_string opcode_vals[] = {
   { EXTERNAL_ADDRESS_REQUEST,  "External Address Request"   },
@@ -508,7 +511,7 @@ dissect_portcontrol_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gui
           break;
 
         case OPT_DESCRIPTION:
-          proto_tree_add_item(option_sub_tree, hf_option_description, tvb, offset, option_length, ENC_UTF_8|ENC_NA);
+          proto_tree_add_item(option_sub_tree, hf_option_description, tvb, offset, option_length, ENC_UTF_8);
           break;
 
         case OPT_PREFIX64:
@@ -831,7 +834,7 @@ void proto_register_nat_pmp(void)
       { "IPv4 Prefix Count", "portcontrol.option.p64.ipv4_prefix_count", FT_UINT16, BASE_DEC,
         NULL, 0x0, NULL, HFILL } },
     { &hf_option_p64_ipv4_prefix_length,
-      { "IPv4 Prefix Length", "portcontrol.option.p64.ipv4_prefix_count", FT_UINT16, BASE_DEC,
+      { "IPv4 Prefix Length", "portcontrol.option.p64.ipv4_prefix_length", FT_UINT16, BASE_DEC,
         NULL, 0x0, NULL, HFILL } },
     { &hf_option_p64_ipv4_address,
       { "IPv4 Address", "portcontrol.option.p64.ipv4_address", FT_IPv4, BASE_NONE,
@@ -886,6 +889,8 @@ void proto_register_nat_pmp(void)
   expert_nat_pmp = expert_register_protocol(proto_nat_pmp);
   expert_register_field_array(expert_nat_pmp, natpmp_ei, array_length(natpmp_ei));
 
+  nat_pmp_handle = register_dissector("nat-pmp", dissect_nat_pmp, proto_nat_pmp);
+
   proto_pcp = proto_register_protocol("Port Control Protocol", "Port Control", "portcontrol");
 
   proto_register_field_array(proto_pcp, pcp_hf, array_length(pcp_hf));
@@ -893,17 +898,13 @@ void proto_register_nat_pmp(void)
   expert_pcp = expert_register_protocol(proto_pcp);
   expert_register_field_array(expert_pcp, pcp_ei, array_length(pcp_ei));
 
+  pcp_handle = register_dissector("portcontrol", dissect_portcontrol, proto_pcp);
 }
 
 void proto_reg_handoff_nat_pmp(void)
 {
-  dissector_handle_t nat_pmp_handle;
-  dissector_handle_t pcp_handle;
-
-  pcp_handle = create_dissector_handle(dissect_portcontrol, proto_pcp);
   dissector_add_uint_range_with_preference("udp.port", PCP_PORT_RANGE, pcp_handle);
 
-  nat_pmp_handle = create_dissector_handle(dissect_nat_pmp, proto_nat_pmp);
   /* Port Control Protocol (packet-portcontrol.c) shares the same UDP ports as
      NAT-PMP, but it backwards compatible.  However, still let NAT-PMP
      use Decode As
