@@ -17,51 +17,50 @@
 #include <epan/exceptions.h>
 #include <epan/show_exception.h>
 
-#include "packet-dcerpc.h"
 #include "packet-gssapi.h"
 
 void proto_register_negoex(void);
 void proto_reg_handoff_negoex(void);
 
-static int proto_negoex = -1;
-static int hf_negoex_sig = -1;
-static int hf_negoex_message_type = -1;
-static int hf_negoex_sequence_num = -1;
-static int hf_negoex_header_len = -1;
-static int hf_negoex_message_len = -1;
-static int hf_negoex_conversation_id = -1;
-static int hf_negoex_random = -1;
-static int hf_negoex_proto_version = -1;
-static int hf_negoex_authscheme = -1;
-static int hf_negoex_authscheme_vector_offset = -1;
-static int hf_negoex_authscheme_vector_count = -1;
-static int hf_negoex_authscheme_vector_pad = -1;
-static int hf_negoex_extension = -1;
-static int hf_negoex_extension_vector_offset = -1;
-static int hf_negoex_extension_vector_count = -1;
-static int hf_negoex_extension_vector_pad = -1;
-static int hf_negoex_exchange_vector_offset = -1;
-static int hf_negoex_exchange_vector_count = -1;
-static int hf_negoex_exchange_vector_pad = -1;
-static int hf_negoex_exchange = -1;
-static int hf_negoex_checksum_scheme = -1;
-static int hf_negoex_checksum_type = -1;
-static int hf_negoex_checksum_vector_offset = -1;
-static int hf_negoex_checksum_vector_count = -1;
-static int hf_negoex_checksum_vector_pad = -1;
-static int hf_negoex_checksum = -1;
-static int hf_negoex_errorcode = -1;
-static int hf_negoex_data = -1;
+static int proto_negoex;
+static int hf_negoex_sig;
+static int hf_negoex_message_type;
+static int hf_negoex_sequence_num;
+static int hf_negoex_header_len;
+static int hf_negoex_message_len;
+static int hf_negoex_conversation_id;
+static int hf_negoex_random;
+static int hf_negoex_proto_version;
+static int hf_negoex_authscheme;
+static int hf_negoex_authscheme_vector_offset;
+static int hf_negoex_authscheme_vector_count;
+static int hf_negoex_authscheme_vector_pad;
+static int hf_negoex_extension;
+static int hf_negoex_extension_vector_offset;
+static int hf_negoex_extension_vector_count;
+static int hf_negoex_extension_vector_pad;
+static int hf_negoex_exchange_vector_offset;
+static int hf_negoex_exchange_vector_count;
+static int hf_negoex_exchange_vector_pad;
+static int hf_negoex_exchange;
+static int hf_negoex_checksum_scheme;
+static int hf_negoex_checksum_type;
+static int hf_negoex_checksum_vector_offset;
+static int hf_negoex_checksum_vector_count;
+static int hf_negoex_checksum_vector_pad;
+static int hf_negoex_checksum;
+static int hf_negoex_errorcode;
+static int hf_negoex_data;
 
-static gint ett_negoex = -1;
-static gint ett_negoex_msg = -1;
-static gint ett_negoex_hdr = -1;
-static gint ett_negoex_authscheme_vector = -1;
-static gint ett_negoex_extension_vector = -1;
-static gint ett_negoex_exchange = -1;
-static gint ett_negoex_checksum = -1;
-static gint ett_negoex_checksum_vector = -1;
-static gint ett_negoex_byte_vector = -1;
+static gint ett_negoex;
+static gint ett_negoex_msg;
+static gint ett_negoex_hdr;
+static gint ett_negoex_authscheme_vector;
+static gint ett_negoex_extension_vector;
+static gint ett_negoex_exchange;
+static gint ett_negoex_checksum;
+static gint ett_negoex_checksum_vector;
+static gint ett_negoex_byte_vector;
 
 static dissector_handle_t negoex_handle;
 
@@ -506,7 +505,7 @@ proto_register_negoex(void)
       { "MessageType", "negoex.message.type", FT_UINT32, BASE_HEX,
          VALS(negoex_message_types), 0x00, NULL, HFILL }},
     { &hf_negoex_sequence_num,
-      { "SequencNum", "negoex.message.seq_num", FT_UINT32, BASE_DEC,
+      { "SequenceNum", "negoex.message.seq_num", FT_UINT32, BASE_DEC,
         NULL, 0x0, NULL, HFILL }},
     { &hf_negoex_header_len,
       { "cbHeaderLength", "negoex.header.len", FT_UINT32, BASE_DEC,
