@@ -99,39 +99,39 @@ static dissector_handle_t netlink_net_dm_handle;
 static dissector_table_t sll_ltype_table;
 static dissector_table_t ethertype_table;
 
-static int proto_netlink_net_dm = -1;
+static int proto_netlink_net_dm;
 
-static int hf_net_dm_alert_mode = -1;
-static int hf_net_dm_attrs = -1;
-static int hf_net_dm_attrs_port = -1;
-static int hf_net_dm_attrs_stats = -1;
-static int hf_net_dm_commands = -1;
-static int hf_net_dm_flow_action_cookie = -1;
-static int hf_net_dm_hw = -1;
-static int hf_net_dm_hw_trap_count = -1;
-static int hf_net_dm_hw_trap_group_name = -1;
-static int hf_net_dm_hw_trap_name = -1;
-static int hf_net_dm_orig_len = -1;
-static int hf_net_dm_origin = -1;
-static int hf_net_dm_pc = -1;
-static int hf_net_dm_port_netdev_index = -1;
-static int hf_net_dm_port_netdev_name = -1;
-static int hf_net_dm_proto = -1;
-static int hf_net_dm_queue_len = -1;
-static int hf_net_dm_stats_dropped = -1;
-static int hf_net_dm_sw = -1;
-static int hf_net_dm_symbol = -1;
-static int hf_net_dm_timestamp = -1;
-static int hf_net_dm_trunc_len = -1;
-static int hf_net_dm_reason = -1;
+static int hf_net_dm_alert_mode;
+static int hf_net_dm_attrs;
+static int hf_net_dm_attrs_port;
+static int hf_net_dm_attrs_stats;
+static int hf_net_dm_commands;
+static int hf_net_dm_flow_action_cookie;
+static int hf_net_dm_hw;
+static int hf_net_dm_hw_trap_count;
+static int hf_net_dm_hw_trap_group_name;
+static int hf_net_dm_hw_trap_name;
+static int hf_net_dm_orig_len;
+static int hf_net_dm_origin;
+static int hf_net_dm_pc;
+static int hf_net_dm_port_netdev_index;
+static int hf_net_dm_port_netdev_name;
+static int hf_net_dm_proto;
+static int hf_net_dm_queue_len;
+static int hf_net_dm_stats_dropped;
+static int hf_net_dm_sw;
+static int hf_net_dm_symbol;
+static int hf_net_dm_timestamp;
+static int hf_net_dm_trunc_len;
+static int hf_net_dm_reason;
 
-static gint ett_net_dm = -1;
-static gint ett_net_dm_attrs = -1;
-static gint ett_net_dm_attrs_in_port = -1;
-static gint ett_net_dm_attrs_stats = -1;
-static gint ett_net_dm_attrs_hw_stats = -1;
-static gint ett_net_dm_attrs_hw_entries = -1;
-static gint ett_net_dm_attrs_hw_entry = -1;
+static gint ett_net_dm;
+static gint ett_net_dm_attrs;
+static gint ett_net_dm_attrs_in_port;
+static gint ett_net_dm_attrs_stats;
+static gint ett_net_dm_attrs_hw_stats;
+static gint ett_net_dm_attrs_hw_entries;
+static gint ett_net_dm_attrs_hw_entry;
 
 static const value_string ws_net_dm_commands_vals[] = {
 	{ WS_NET_DM_CMD_UNSPEC,			"Unspecified command" },
@@ -226,7 +226,7 @@ dissect_net_dm_attrs_port(tvbuff_t *tvb, void *data _U_, struct packet_netlink_d
 static int
 dissect_net_dm_attrs_stats(tvbuff_t *tvb, void *data _U_, struct packet_netlink_data *nl_data, proto_tree *tree, int nla_type, int offset, int len)
 {
-	enum ws_net_dm_attrs_stats type = (enum ws_net_dm_attrs_port) nla_type & NLA_TYPE_MASK;
+	enum ws_net_dm_attrs_port type = (enum ws_net_dm_attrs_port) nla_type & NLA_TYPE_MASK;
 
 	switch (type) {
 	case WS_NET_DM_ATTR_STATS_DROPPED:
