@@ -347,7 +347,7 @@ enum ws_ipset_cadt_attr {
 	WS_IPSET_ATTR_MEMSIZE           = 26,
 };
 
-/* ADT-specific attrivutes */
+/* ADT-specific attributes */
 enum ws_ipset_adt_attr {
 	WS_IPSET_ATTR_ETHER             = 17,
 	WS_IPSET_ATTR_NAME              = 18,
@@ -371,122 +371,161 @@ enum ws_ipset_ip_attr {
 	WS_IPSET_ATTR_IPADDR_IPV6       = 2,
 };
 
+/* Netfilter commands from <include/uapi/linux/netfilter/netfilter.h> */
+enum nf_tables_msg_types {
+	WS_NFT_MSG_NEWTABLE             = 0,
+	WS_NFT_MSG_GETTABLE             = 1,
+	WS_NFT_MSG_DELTABLE             = 2,
+	WS_NFT_MSG_NEWCHAIN             = 3,
+	WS_NFT_MSG_GETCHAIN             = 4,
+	WS_NFT_MSG_DELCHAIN             = 5,
+	WS_NFT_MSG_NEWRULE              = 6,
+	WS_NFT_MSG_GETRULE              = 7,
+	WS_NFT_MSG_DELRULE              = 8,
+	WS_NFT_MSG_NEWSET               = 9,
+	WS_NFT_MSG_GETSET               = 10,
+	WS_NFT_MSG_DELSET               = 11,
+	WS_NFT_MSG_NEWSETELEM           = 12,
+	WS_NFT_MSG_GETSETELEM           = 13,
+	WS_NFT_MSG_DELSETELEM           = 14,
+	WS_NFT_MSG_NEWGEN               = 15,
+	WS_NFT_MSG_GETGEN               = 16,
+	WS_NFT_MSG_TRACE                = 17,
+	WS_NFT_MSG_NEWOBJ               = 18,
+	WS_NFT_MSG_GETOBJ               = 19,
+	WS_NFT_MSG_DELOBJ               = 20,
+	WS_NFT_MSG_GETOBJ_RESET         = 21,
+	WS_NFT_MSG_NEWFLOWTABLE         = 22,
+	WS_NFT_MSG_GETFLOWTABLE         = 23,
+	WS_NFT_MSG_DELFLOWTABLE         = 24,
+	WS_NFT_MSG_GETRULE_RESET        = 25,
+	WS_NFT_MSG_DESTROYTABLE         = 26,
+	WS_NFT_MSG_DESTROYCHAIN         = 27,
+	WS_NFT_MSG_DESTROYRULE          = 28,
+	WS_NFT_MSG_DESTROYSET           = 29,
+	WS_NFT_MSG_DESTROYSETELEM       = 30,
+	WS_NFT_MSG_DESTROYOBJ           = 31,
+	WS_NFT_MSG_DESTROYFLOWTABLE     = 32,
+	WS_NFT_MSG_GETSETELEM_RESET     = 33,
+};
 
 static int proto_netlink_netfilter;
 
-static int hf_ipset_adt_attr = -1;
-static int hf_ipset_adt_attr_comment = -1;
-static int hf_ipset_attr = -1;
-static int hf_ipset_attr_family = -1;
-static int hf_ipset_attr_flags = -1;
-static int hf_ipset_attr_setname = -1;
-static int hf_ipset_attr_typename = -1;
-static int hf_ipset_cadt_attr = -1;
-static int hf_ipset_cadt_attr_cadt_flags = -1;
-static int hf_ipset_cadt_attr_cidr = -1;
-static int hf_ipset_cadt_attr_timeout = -1;
-static int hf_ipset_command = -1;
-static int hf_ipset_ip_attr = -1;
-static int hf_ipset_ip_attr_ipv4 = -1;
-static int hf_ipset_ip_attr_ipv6 = -1;
-static int hf_netlink_netfilter_family = -1;
-static int hf_netlink_netfilter_resid = -1;
-static int hf_netlink_netfilter_subsys = -1;
-static int hf_netlink_netfilter_ulog_type = -1;
-static int hf_netlink_netfilter_version = -1;
-static int hf_nfct_attr = -1;
-static int hf_nfct_attr_id = -1;
-static int hf_nfct_attr_status = -1;
-static int hf_nfct_attr_status_flag_assured = -1;
-static int hf_nfct_attr_status_flag_confirmed = -1;
-static int hf_nfct_attr_status_flag_dst_nat = -1;
-static int hf_nfct_attr_status_flag_dst_nat_done = -1;
-static int hf_nfct_attr_status_flag_dying = -1;
-static int hf_nfct_attr_status_flag_expected = -1;
-static int hf_nfct_attr_status_flag_fixed_timeout = -1;
-static int hf_nfct_attr_status_flag_helper = -1;
-static int hf_nfct_attr_status_flag_hw_offload = -1;
-static int hf_nfct_attr_status_flag_offload = -1;
-static int hf_nfct_attr_status_flag_seen_reply = -1;
-static int hf_nfct_attr_status_flag_seq_adjust = -1;
-static int hf_nfct_attr_status_flag_src_nat = -1;
-static int hf_nfct_attr_status_flag_src_nat_done = -1;
-static int hf_nfct_attr_status_flag_template = -1;
-static int hf_nfct_attr_status_flag_untracked = -1;
-static int hf_nfct_attr_timeout = -1;
-static int hf_nfct_help_attr = -1;
-static int hf_nfct_help_attr_help_name = -1;
-static int hf_nfct_seqadj_attr = -1;
-static int hf_nfct_seqadj_attr_correction_pos = -1;
-static int hf_nfct_seqadj_attr_offset_after = -1;
-static int hf_nfct_seqadj_attr_offset_before = -1;
-static int hf_nfct_tuple_attr = -1;
-static int hf_nfct_tuple_ip_attr = -1;
-static int hf_nfct_tuple_ip_attr_ipv4 = -1;
-static int hf_nfct_tuple_ip_attr_ipv6 = -1;
-static int hf_nfct_tuple_proto_attr = -1;
-static int hf_nfct_tuple_proto_dst_port_attr = -1;
-static int hf_nfct_tuple_proto_num_attr = -1;
-static int hf_nfct_tuple_proto_src_port_attr = -1;
-static int hf_nfct_tuple_zone_attr = -1;
-static int hf_nfexp_attr = -1;
-static int hf_nfexp_attr_class = -1;
-static int hf_nfexp_attr_flag_inactive = -1;
-static int hf_nfexp_attr_flag_permanent = -1;
-static int hf_nfexp_attr_flag_userspace = -1;
-static int hf_nfexp_attr_flags = -1;
-static int hf_nfexp_attr_fn = -1;
-static int hf_nfexp_attr_id = -1;
-static int hf_nfexp_attr_timeout = -1;
-static int hf_nfexp_attr_zone = -1;
-static int hf_nfexp_nat_attr = -1;
-static int hf_nfexp_nat_attr_dir = -1;
-static int hf_nfexp_type = -1;
-static int hf_nfq_attr = -1;
-static int hf_nfq_caplen = -1;
-static int hf_nfq_config_attr = -1;
-static int hf_nfq_config_command_command = -1;
-static int hf_nfq_config_command_pf = -1;
-static int hf_nfq_config_flags = -1;
-static int hf_nfq_config_mask = -1;
-static int hf_nfq_config_params_copymode = -1;
-static int hf_nfq_config_params_copyrange = -1;
-static int hf_nfq_config_queue_maxlen = -1;
-static int hf_nfq_ctinfo = -1;
-static int hf_nfq_gid = -1;
-static int hf_nfq_hwaddr_addr = -1;
-static int hf_nfq_hwaddr_len = -1;
-static int hf_nfq_ifindex_indev = -1;
-static int hf_nfq_ifindex_outdev = -1;
-static int hf_nfq_ifindex_physindev = -1;
-static int hf_nfq_ifindex_physoutdev = -1;
-static int hf_nfq_nfmark = -1;
-static int hf_nfq_packet_hook = -1;
-static int hf_nfq_packet_hwprotocol = -1;
-static int hf_nfq_packet_id = -1;
-static int hf_nfq_timestamp = -1;
-static int hf_nfq_type = -1;
-static int hf_nfq_uid = -1;
-static int hf_nfq_verdict_id = -1;
-static int hf_nfq_verdict_verdict = -1;
+static int hf_ipset_adt_attr;
+static int hf_ipset_adt_attr_comment;
+static int hf_ipset_attr;
+static int hf_ipset_attr_family;
+static int hf_ipset_attr_flags;
+static int hf_ipset_attr_setname;
+static int hf_ipset_attr_typename;
+static int hf_ipset_cadt_attr;
+static int hf_ipset_cadt_attr_cadt_flags;
+static int hf_ipset_cadt_attr_cidr;
+static int hf_ipset_cadt_attr_timeout;
+static int hf_ipset_command;
+static int hf_ipset_ip_attr;
+static int hf_ipset_ip_attr_ipv4;
+static int hf_ipset_ip_attr_ipv6;
+static int hf_netlink_netfilter_family;
+static int hf_netlink_netfilter_resid;
+static int hf_netlink_netfilter_subsys;
+static int hf_netlink_netfilter_ulog_type;
+static int hf_netlink_netfilter_version;
+static int hf_nfct_attr;
+static int hf_nfct_attr_id;
+static int hf_nfct_attr_status;
+static int hf_nfct_attr_status_flag_assured;
+static int hf_nfct_attr_status_flag_confirmed;
+static int hf_nfct_attr_status_flag_dst_nat;
+static int hf_nfct_attr_status_flag_dst_nat_done;
+static int hf_nfct_attr_status_flag_dying;
+static int hf_nfct_attr_status_flag_expected;
+static int hf_nfct_attr_status_flag_fixed_timeout;
+static int hf_nfct_attr_status_flag_helper;
+static int hf_nfct_attr_status_flag_hw_offload;
+static int hf_nfct_attr_status_flag_offload;
+static int hf_nfct_attr_status_flag_seen_reply;
+static int hf_nfct_attr_status_flag_seq_adjust;
+static int hf_nfct_attr_status_flag_src_nat;
+static int hf_nfct_attr_status_flag_src_nat_done;
+static int hf_nfct_attr_status_flag_template;
+static int hf_nfct_attr_status_flag_untracked;
+static int hf_nfct_attr_timeout;
+static int hf_nfct_help_attr;
+static int hf_nfct_help_attr_help_name;
+static int hf_nfct_seqadj_attr;
+static int hf_nfct_seqadj_attr_correction_pos;
+static int hf_nfct_seqadj_attr_offset_after;
+static int hf_nfct_seqadj_attr_offset_before;
+static int hf_nfct_tuple_attr;
+static int hf_nfct_tuple_ip_attr;
+static int hf_nfct_tuple_ip_attr_ipv4;
+static int hf_nfct_tuple_ip_attr_ipv6;
+static int hf_nfct_tuple_proto_attr;
+static int hf_nfct_tuple_proto_dst_port_attr;
+static int hf_nfct_tuple_proto_num_attr;
+static int hf_nfct_tuple_proto_src_port_attr;
+static int hf_nfct_tuple_zone_attr;
+static int hf_nfexp_attr;
+static int hf_nfexp_attr_class;
+static int hf_nfexp_attr_flag_inactive;
+static int hf_nfexp_attr_flag_permanent;
+static int hf_nfexp_attr_flag_userspace;
+static int hf_nfexp_attr_flags;
+static int hf_nfexp_attr_fn;
+static int hf_nfexp_attr_id;
+static int hf_nfexp_attr_timeout;
+static int hf_nfexp_attr_zone;
+static int hf_nfexp_nat_attr;
+static int hf_nfexp_nat_attr_dir;
+static int hf_nfexp_type;
+static int hf_nfq_attr;
+static int hf_nfq_caplen;
+static int hf_nfq_config_attr;
+static int hf_nfq_config_command_command;
+static int hf_nfq_config_command_pf;
+static int hf_nfq_config_flags;
+static int hf_nfq_config_mask;
+static int hf_nfq_config_params_copymode;
+static int hf_nfq_config_params_copyrange;
+static int hf_nfq_config_queue_maxlen;
+static int hf_nfq_ctinfo;
+static int hf_nfq_gid;
+static int hf_nfq_hwaddr_addr;
+static int hf_nfq_hwaddr_len;
+static int hf_nfq_ifindex_indev;
+static int hf_nfq_ifindex_outdev;
+static int hf_nfq_ifindex_physindev;
+static int hf_nfq_ifindex_physoutdev;
+static int hf_nfq_nfmark;
+static int hf_nfq_packet_hook;
+static int hf_nfq_packet_hwprotocol;
+static int hf_nfq_packet_id;
+static int hf_nfq_timestamp;
+static int hf_nfq_type;
+static int hf_nfq_uid;
+static int hf_nfq_verdict_id;
+static int hf_nfq_verdict_verdict;
+static int hf_nftables_command;
+static int hf_padding;
 
-static int ett_netlink_netfilter = -1;
-static int ett_nfct_attr = -1;
-static int ett_nfct_help_attr = -1;
-static int ett_nfct_seqadj_attr = -1;
-static int ett_nfct_status_attr = -1;
-static int ett_nfct_tuple_attr = -1;
-static int ett_nfct_tuple_ip_attr = -1;
-static int ett_nfct_tuple_proto_attr = -1;
-static int ett_nfq_config_attr = -1;
-static int ett_nfq_attr = -1;
-static int ett_nfexp_attr = -1;
-static int ett_nfexp_flags_attr = -1;
-static int ett_nfexp_nat_attr = -1;
-static int ett_ipset_attr = -1;
-static int ett_ipset_cadt_attr = -1;
-static int ett_ipset_adt_attr = -1;
-static int ett_ipset_ip_attr = -1;
+static int ett_netlink_netfilter;
+static int ett_nfct_attr;
+static int ett_nfct_help_attr;
+static int ett_nfct_seqadj_attr;
+static int ett_nfct_status_attr;
+static int ett_nfct_tuple_attr;
+static int ett_nfct_tuple_ip_attr;
+static int ett_nfct_tuple_proto_attr;
+static int ett_nfq_config_attr;
+static int ett_nfq_attr;
+static int ett_nfexp_attr;
+static int ett_nfexp_flags_attr;
+static int ett_nfexp_nat_attr;
+static int ett_ipset_attr;
+static int ett_ipset_cadt_attr;
+static int ett_ipset_adt_attr;
+static int ett_ipset_ip_attr;
 
 static int dissect_netlink_netfilter_header(tvbuff_t *tvb, proto_tree *tree, int offset)
 {
@@ -535,7 +574,7 @@ static const value_string nfct_tuple_l4proto_attr_vals[] = {
 static int
 dissect_nfct_tuple_proto_attrs(tvbuff_t *tvb, void *data _U_, struct packet_netlink_data *nl_data _U_, proto_tree *tree, int nla_type, int offset, int len)
 {
-	enum ws_ctattr_l4proto type = (enum ws_ctattr_ip) nla_type & NLA_TYPE_MASK;
+	enum ws_ctattr_ip type = (enum ws_ctattr_ip) nla_type & NLA_TYPE_MASK;
 
 	switch (type) {
 		case WS_CTA_PROTO_NUM:
@@ -808,7 +847,7 @@ static const value_string nfexp_conntrack_dir_vals[] = {
 static int
 dissect_nfexp_nat_attrs(tvbuff_t *tvb, void *data, struct packet_netlink_data *nl_data, proto_tree *tree, int nla_type, int offset, int len)
 {
-	enum ws_ctattr_expect_nat type = (enum ws_ctattr_expect) nla_type & NLA_TYPE_MASK;
+	enum ws_ctattr_expect type = (enum ws_ctattr_expect) nla_type & NLA_TYPE_MASK;
 	netlink_netfilter_info_t *info = (netlink_netfilter_info_t *) data;
 
 	switch (type) {
@@ -948,7 +987,9 @@ dissect_nfq_config_attrs(tvbuff_t *tvb, void *data _U_, struct packet_netlink_da
 		case WS_NFQA_CFG_CMD:
 			if (len == 4) {
 				proto_tree_add_item(tree, hf_nfq_config_command_command, tvb, offset, 1, ENC_NA);
-				offset += 2; /* skip command and 1 byte padding. */
+				offset += 1;
+				proto_tree_add_item(tree, hf_padding, tvb, offset, 1, ENC_NA);
+				offset += 1;
 
 				proto_tree_add_item(tree, hf_nfq_config_command_pf, tvb, offset, 2, ENC_BIG_ENDIAN);
 				offset += 2;
@@ -1143,7 +1184,10 @@ dissect_nfq_attrs(tvbuff_t *tvb, void *data, struct packet_netlink_data *nl_data
 
 				proto_tree_add_item(tree, hf_nfq_hwaddr_len, tvb, offset, 2, ENC_BIG_ENDIAN);
 				addrlen = tvb_get_ntohs(tvb, offset);
-				offset += 4; /* skip len and padding */
+				offset += 2;
+				proto_tree_add_item(tree, hf_padding, tvb, offset, 2, ENC_NA);
+				offset += 2;
+
 
 				/* XXX expert info if 4 + addrlen > len. */
 				addrlen = MIN(addrlen, len - 4);
@@ -1553,6 +1597,46 @@ dissect_netfilter_ipset(tvbuff_t *tvb, netlink_netfilter_info_t *info, struct pa
 	return dissect_netlink_attributes_to_end(tvb, hf_ipset_attr, ett_ipset_attr, info, nl_data, tree, offset, dissect_ipset_attrs);
 }
 
+/* NFTABLES */
+
+static const value_string nftables_command_vals[] = {
+	{ WS_NFT_MSG_NEWTABLE,         "New table" },
+	{ WS_NFT_MSG_GETTABLE,         "Get table" },
+	{ WS_NFT_MSG_DELTABLE,         "Delete table" },
+	{ WS_NFT_MSG_NEWCHAIN,         "New chain" },
+	{ WS_NFT_MSG_GETCHAIN,         "Get chain" },
+	{ WS_NFT_MSG_DELCHAIN,         "Delete chain" },
+	{ WS_NFT_MSG_NEWRULE,          "New rule" },
+	{ WS_NFT_MSG_GETRULE,          "Get rule" },
+	{ WS_NFT_MSG_DELRULE,          "Delete rule" },
+	{ WS_NFT_MSG_NEWSET,           "New set" },
+	{ WS_NFT_MSG_GETSET,           "Get set" },
+	{ WS_NFT_MSG_DELSET,           "Delete set" },
+	{ WS_NFT_MSG_NEWSETELEM,       "New set element" },
+	{ WS_NFT_MSG_GETSETELEM,       "Get set element" },
+	{ WS_NFT_MSG_DELSETELEM,       "Delete set element" },
+	{ WS_NFT_MSG_NEWGEN,           "New rule-set generation" },
+	{ WS_NFT_MSG_GETGEN,           "Get rule-set generation" },
+	{ WS_NFT_MSG_TRACE,            "Trace" },
+	{ WS_NFT_MSG_NEWOBJ,           "New stateful object" },
+	{ WS_NFT_MSG_GETOBJ,           "Get stateful object" },
+	{ WS_NFT_MSG_DELOBJ,           "Delete stateful object" },
+	{ WS_NFT_MSG_GETOBJ_RESET,     "Get and reset stateful object" },
+	{ WS_NFT_MSG_NEWFLOWTABLE,     "New flow table" },
+	{ WS_NFT_MSG_GETFLOWTABLE,     "Get flow table" },
+	{ WS_NFT_MSG_DELFLOWTABLE,     "Delete flow table" },
+	{ WS_NFT_MSG_GETRULE_RESET,    "Get rules and reset stateful expressions" },
+	{ WS_NFT_MSG_DESTROYTABLE,     "Destroy table" },
+	{ WS_NFT_MSG_DESTROYCHAIN,     "Destroy chain" },
+	{ WS_NFT_MSG_DESTROYRULE,      "Destroy rule" },
+	{ WS_NFT_MSG_DESTROYSET,       "Destroy set" },
+	{ WS_NFT_MSG_DESTROYSETELEM,   "Destroy set element" },
+	{ WS_NFT_MSG_DESTROYOBJ,       "Destroy stateful object" },
+	{ WS_NFT_MSG_DESTROYFLOWTABLE, "Destroy flow table" },
+	{ WS_NFT_MSG_GETSETELEM_RESET, "Get set elements and reset stateful expressions" },
+	{ 0, NULL }
+};
+
 
 static const value_string netlink_netfilter_subsystem_vals[] = {
 	{ WS_NFNL_SUBSYS_NONE,              "None" },
@@ -1608,6 +1692,10 @@ dissect_netlink_netfilter(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, v
 		case WS_NFNL_SUBSYS_IPSET:
 			proto_tree_add_item(nlmsg_tree, hf_ipset_command, tvb, 4, 2, nl_data->encoding);
 			break;
+
+		case WS_NFNL_SUBSYS_NFTABLES:
+			proto_tree_add_item(nlmsg_tree, hf_nftables_command, tvb, 4, 2, nl_data->encoding);
+			break;
 	}
 
 	info.pinfo = pinfo;
@@ -2117,11 +2205,21 @@ proto_register_netlink_netfilter(void)
 			  FT_UINT16, BASE_DEC, VALS(ipset_command_vals), 0x00FF,
 			  NULL, HFILL }
 		},
+		{ &hf_nftables_command,
+			{ "Command", "netlink-netfilter.nftables_command",
+			  FT_UINT16, BASE_DEC, VALS(nftables_command_vals), 0x00FF,
+			  NULL, HFILL }
+		},
 		{ &hf_netlink_netfilter_subsys,
 			{ "Subsystem", "netlink-netfilter.subsys",
 			  FT_UINT16, BASE_DEC, VALS(netlink_netfilter_subsystem_vals), 0xFF00,
 			  NULL, HFILL }
 		},
+		{ &hf_padding,
+			{ "Padding", "netlink-netfilter.padding",
+			  FT_BYTES, BASE_NONE, NULL, 0x0,
+			  NULL, HFILL }
+		}
 	};
 
 	static gint *ett[] = {
