@@ -23,18 +23,20 @@
 void proto_register_npm(void);
 void proto_reg_handoff_npm(void);
 
-static int proto_npm              = -1;
-static int tap_npm                = -1;
-static int ett_npm                = -1;
-static int ett_addflow_flags      = -1;
-static int ett_identifyflow_flags = -1;
-static int ett_start_flags        = -1;
-static int ett_data_flags         = -1;
-static int ett_results_flags      = -1;
-static int ett_onoffarray         = -1;
+static dissector_handle_t npm_handle;
 
-static guint64 npm_total_msgs     = 0;
-static guint64 npm_total_bytes    = 0;
+static int proto_npm;
+static int tap_npm                = -1;
+static int ett_npm;
+static int ett_addflow_flags;
+static int ett_identifyflow_flags;
+static int ett_start_flags;
+static int ett_data_flags;
+static int ett_results_flags;
+static int ett_onoffarray;
+
+static guint64 npm_total_msgs;
+static guint64 npm_total_bytes;
 
 
 #define PPID_NETPERFMETER_CONTROL_LEGACY   0x29097605
@@ -64,83 +66,83 @@ static const value_string message_type_values[] = {
   { 0, NULL }
 };
 
-static int hf_message_type               = -1;
-static int hf_message_flags              = -1;
-static int hf_message_length             = -1;
+static int hf_message_type;
+static int hf_message_flags;
+static int hf_message_length;
 
-static int hf_acknowledge_flowid         = -1;
-static int hf_acknowledge_measurementid  = -1;
-static int hf_acknowledge_streamid       = -1;
-// static int hf_acknowledge_padding     = -1;
-static int hf_acknowledge_status         = -1;
+static int hf_acknowledge_flowid;
+static int hf_acknowledge_measurementid;
+static int hf_acknowledge_streamid;
+// static int hf_acknowledge_padding;
+static int hf_acknowledge_status;
 
-static int hf_addflow_flag_debug         = -1;
-static int hf_addflow_flag_nodelay       = -1;
-static int hf_addflow_flag_repeatonoff   = -1;
-static int hf_addflow_flowid             = -1;
-static int hf_addflow_measurementid      = -1;
-static int hf_addflow_streamid           = -1;
-static int hf_addflow_protocol           = -1;
-static int hf_addflow_flags              = -1;
-static int hf_addflow_description        = -1;
-static int hf_addflow_ordered            = -1;
-static int hf_addflow_reliable           = -1;
-static int hf_addflow_retranstrials      = -1;
-static int hf_addflow_framerate1         = -1;
-static int hf_addflow_framerate2         = -1;
-static int hf_addflow_framerate3         = -1;
-static int hf_addflow_framerate4         = -1;
-static int hf_addflow_framesize1         = -1;
-static int hf_addflow_framesize2         = -1;
-static int hf_addflow_framesize3         = -1;
-static int hf_addflow_framesize4         = -1;
-static int hf_addflow_frameraterng       = -1;
-static int hf_addflow_framesizerng       = -1;
-static int hf_addflow_rcvbuffersize      = -1;
-static int hf_addflow_sndbuffersize      = -1;
-static int hf_addflow_maxmsgsize         = -1;
-static int hf_addflow_cmt                = -1;
-static int hf_addflow_ccid               = -1;
-static int hf_addflow_onoffevents        = -1;
-static int hf_addflow_onoffeventarray    = -1;
+static int hf_addflow_flag_debug;
+static int hf_addflow_flag_nodelay;
+static int hf_addflow_flag_repeatonoff;
+static int hf_addflow_flowid;
+static int hf_addflow_measurementid;
+static int hf_addflow_streamid;
+static int hf_addflow_protocol;
+static int hf_addflow_flags;
+static int hf_addflow_description;
+static int hf_addflow_ordered;
+static int hf_addflow_reliable;
+static int hf_addflow_retranstrials;
+static int hf_addflow_framerate1;
+static int hf_addflow_framerate2;
+static int hf_addflow_framerate3;
+static int hf_addflow_framerate4;
+static int hf_addflow_framesize1;
+static int hf_addflow_framesize2;
+static int hf_addflow_framesize3;
+static int hf_addflow_framesize4;
+static int hf_addflow_frameraterng;
+static int hf_addflow_framesizerng;
+static int hf_addflow_rcvbuffersize;
+static int hf_addflow_sndbuffersize;
+static int hf_addflow_maxmsgsize;
+static int hf_addflow_cmt;
+static int hf_addflow_ccid;
+static int hf_addflow_onoffevents;
+static int hf_addflow_onoffeventarray;
 
-static int hf_removeflow_flowid          = -1;
-static int hf_removeflow_measurementid   = -1;
-static int hf_removeflow_streamid        = -1;
+static int hf_removeflow_flowid;
+static int hf_removeflow_measurementid;
+static int hf_removeflow_streamid;
 
-static int hf_identifyflow_flag_compress_vectors = -1;
-static int hf_identifyflow_flag_no_vectors       = -1;
-static int hf_identifyflow_flowid        = -1;
-static int hf_identifyflow_magicnumber   = -1;
-static int hf_identifyflow_measurementid = -1;
-static int hf_identifyflow_streamid      = -1;
+static int hf_identifyflow_flag_compress_vectors;
+static int hf_identifyflow_flag_no_vectors;
+static int hf_identifyflow_flowid;
+static int hf_identifyflow_magicnumber;
+static int hf_identifyflow_measurementid;
+static int hf_identifyflow_streamid;
 
 #define NETPERFMETER_IDENTIFY_FLOW_MAGIC_NUMBER 0x4bcdf3aa303c6774ULL
 
-static int hf_data_flag_frame_begin       = -1;
-static int hf_data_flag_frame_end         = -1;
-static int hf_data_flowid                 = -1;
-static int hf_data_measurementid          = -1;
-static int hf_data_streamid               = -1;
-static int hf_data_padding                = -1;
-static int hf_data_frameid                = -1;
-static int hf_data_packetseqnumber        = -1;
-static int hf_data_byteseqnumber          = -1;
-static int hf_data_timestamp              = -1;
-static int hf_data_payload                = -1;
+static int hf_data_flag_frame_begin;
+static int hf_data_flag_frame_end;
+static int hf_data_flowid;
+static int hf_data_measurementid;
+static int hf_data_streamid;
+static int hf_data_padding;
+static int hf_data_frameid;
+static int hf_data_packetseqnumber;
+static int hf_data_byteseqnumber;
+static int hf_data_timestamp;
+static int hf_data_payload;
 
-static int hf_start_flag_compress_vectors = -1;
-static int hf_start_flag_compress_scalars = -1;
-static int hf_start_flag_no_vectors       = -1;
-static int hf_start_flag_no_scalars       = -1;
-// static int hf_start_padding            = -1;
-static int hf_start_measurementid         = -1;
+static int hf_start_flag_compress_vectors;
+static int hf_start_flag_compress_scalars;
+static int hf_start_flag_no_vectors;
+static int hf_start_flag_no_scalars;
+// static int hf_start_padding;
+static int hf_start_measurementid;
 
-// static int hf_stop_padding             = -1;
-static int hf_stop_measurementid          = -1;
+// static int hf_stop_padding;
+static int hf_stop_measurementid;
 
-static int hf_results_flag_eof            = -1;
-static int hf_results_data                = -1;
+static int hf_results_flag_eof;
+static int hf_results_data;
 
 
 /* Setup list of Transport Layer protocol types */
@@ -522,12 +524,12 @@ dissect_npm(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *tree, void *d
 }
 
 
-static int
-heur_dissect_npm(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool
+dissect_npm_heur(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
   const guint length = tvb_captured_length(message_tvb);
   if (length < 4)
-    return FALSE;
+    return false;
 
   /* For TCP, UDP or DCCP:
       Type must either be NETPERFMETER_DATA or NETPERFMETER_IDENTIFY_FLOW */
@@ -535,29 +537,29 @@ heur_dissect_npm(tvbuff_t *message_tvb, packet_info *pinfo, proto_tree *tree, vo
   switch(type) {
     case NETPERFMETER_DATA:
       if (length < 48 + 8)
-        return FALSE;
+        return false;
       /* Identify NetPerfMeter flow by payload pattern */
       for(int i = 0; i < 8; i++) {
         guint8 d = tvb_get_guint8(message_tvb, 48 + i);
         if( (d != 30 + i) && (d != 127 - i) )
-          return FALSE;
+          return false;
       }
       break;
     case NETPERFMETER_IDENTIFY_FLOW:
       if (length < 24 + 2)
-        return FALSE;
+        return false;
       if (tvb_get_ntoh64(message_tvb, 8) != NETPERFMETER_IDENTIFY_FLOW_MAGIC_NUMBER) {
         /* Identify NetPerfMeter flow by NETPERFMETER_IDENTIFY_FLOW_MAGIC_NUMBER */
-        return FALSE;
+        return false;
       }
       break;
     default:
       /* Not a NetPerfMeter packet */
-        return FALSE;
+        return false;
       break;
   }
-
-  return dissect_npm(message_tvb, pinfo, tree, data);
+  dissect_npm(message_tvb, pinfo, tree, data);
+  return true;
 }
 
 
@@ -592,10 +594,10 @@ static stat_tap_table_item npm_stat_fields[] = {
 static void npm_stat_init(stat_tap_table_ui* new_stat)
 {
   const char *table_name = "NetPerfMeter Statistics";
-  int num_fields = sizeof(npm_stat_fields)/sizeof(stat_tap_table_item);
+  int num_fields = array_length(npm_stat_fields);
   stat_tap_table *table;
   int i = 0;
-  stat_tap_table_item_type items[sizeof(npm_stat_fields)/sizeof(stat_tap_table_item)];
+  stat_tap_table_item_type items[array_length(npm_stat_fields)];
 
   table = stat_tap_find_table(new_stat, table_name);
   if (table) {
@@ -814,8 +816,8 @@ proto_register_npm(void)
     npm_stat_reset,
     NULL,
     NULL,
-    sizeof(npm_stat_fields)/sizeof(stat_tap_table_item), npm_stat_fields,
-    sizeof(npm_stat_params)/sizeof(tap_param), npm_stat_params,
+    array_length(npm_stat_fields), npm_stat_fields,
+    array_length(npm_stat_params), npm_stat_params,
     NULL,
     0
   };
@@ -829,25 +831,25 @@ proto_register_npm(void)
   tap_npm = register_tap("npm");
 
   register_stat_tap_table_ui(&npm_stat_table);
+
+  /* Register the dissector */
+  npm_handle = register_dissector("netperfmeter", dissect_npm, proto_npm);
 }
 
 
 void
 proto_reg_handoff_npm(void)
 {
-  dissector_handle_t npm_handle;
-
   /* NetPerfMeter protocol over SCTP is detected by PPIDs */
-  npm_handle = create_dissector_handle(dissect_npm, proto_npm);
   dissector_add_uint("sctp.ppi", PPID_NETPERFMETER_CONTROL_LEGACY, npm_handle);
   dissector_add_uint("sctp.ppi", PPID_NETPERFMETER_DATA_LEGACY,    npm_handle);
   dissector_add_uint("sctp.ppi", NPMP_CTRL_PAYLOAD_PROTOCOL_ID,    npm_handle);
   dissector_add_uint("sctp.ppi", NPMP_DATA_PAYLOAD_PROTOCOL_ID,    npm_handle);
 
   /* Heuristic dissector for TCP, UDP and DCCP */
-  heur_dissector_add("tcp",  heur_dissect_npm, "NetPerfMeter over TCP",  "netperfmeter_tcp",  proto_npm, HEURISTIC_ENABLE);
-  heur_dissector_add("udp",  heur_dissect_npm, "NetPerfMeter over UDP",  "netperfmeter_udp",  proto_npm, HEURISTIC_ENABLE);
-  heur_dissector_add("dccp", heur_dissect_npm, "NetPerfMeter over DCCP", "netperfmeter_dccp", proto_npm, HEURISTIC_ENABLE);
+  heur_dissector_add("tcp",  dissect_npm_heur, "NetPerfMeter over TCP",  "netperfmeter_tcp",  proto_npm, HEURISTIC_ENABLE);
+  heur_dissector_add("udp",  dissect_npm_heur, "NetPerfMeter over UDP",  "netperfmeter_udp",  proto_npm, HEURISTIC_ENABLE);
+  heur_dissector_add("dccp", dissect_npm_heur, "NetPerfMeter over DCCP", "netperfmeter_dccp", proto_npm, HEURISTIC_ENABLE);
 }
 
 /*
