@@ -155,7 +155,7 @@
  *
  *  Flags EVENT_PACKET_DATA (0x06)
  *   0000000x = CRC       (0 = Incorrect, 1 = OK)
- *   000000x0 = Direction (0 = Slave -> Master, 1 = Master -> Slave)
+ *   000000x0 = Direction (0 = Peripheral -> Central, 1 = Central -> Peripheral)
  *   00000x00 = Encrypted (0 = No, 1 = Yes)
  *   0000x000 = MIC       (0 = Incorrect, 1 = OK)
  *   0xxx0000 = PHY       (0 = 1M, 1 = 2M, 2 = Coded, rest unused)
@@ -211,58 +211,54 @@
 void proto_reg_handoff_nordic_ble(void);
 void proto_register_nordic_ble(void);
 
+static dissector_handle_t nordic_ble_handle;
+
 /* Initialize the protocol and registered fields */
-static int proto_nordic_ble = -1;
+static int proto_nordic_ble;
 
 /* Initialize the subtree pointers */
-static gint ett_nordic_ble = -1;
-static gint ett_packet_header = -1;
-static gint ett_flags = -1;
+static gint ett_nordic_ble;
+static gint ett_packet_header;
+static gint ett_flags;
 
-static int hf_nordic_ble_board_id = -1;
-static int hf_nordic_ble_legacy_marker = -1;
-static int hf_nordic_ble_header = -1;
-static int hf_nordic_ble_header_length = -1;
-static int hf_nordic_ble_payload_length = -1;
-static int hf_nordic_ble_protover = -1;
-static int hf_nordic_ble_packet_counter = -1;
-static int hf_nordic_ble_packet_id = -1;
-static int hf_nordic_ble_packet_length = -1;
-static int hf_nordic_ble_flags = -1;
-static int hf_nordic_ble_crcok = -1;
-static int hf_nordic_ble_encrypted = -1;
-static int hf_nordic_ble_micok = -1;
-static int hf_nordic_ble_mic_not_relevant = -1;
-static int hf_nordic_ble_aux_type = -1;
-static int hf_nordic_ble_flag_reserved1 = -1;
-static int hf_nordic_ble_flag_reserved2 = -1;
-static int hf_nordic_ble_flag_reserved3 = -1;
-static int hf_nordic_ble_flag_reserved7 = -1;
-static int hf_nordic_ble_le_phy = -1;
-static int hf_nordic_ble_direction = -1;
-static int hf_nordic_ble_channel = -1;
-static int hf_nordic_ble_rssi = -1;
-static int hf_nordic_ble_event_counter = -1;
-static int hf_nordic_ble_time = -1;
-static int hf_nordic_ble_delta_time = -1;
-static int hf_nordic_ble_delta_time_ss = -1;
-static int hf_nordic_ble_packet_time = -1;
+static int hf_nordic_ble_board_id;
+static int hf_nordic_ble_legacy_marker;
+static int hf_nordic_ble_header;
+static int hf_nordic_ble_header_length;
+static int hf_nordic_ble_payload_length;
+static int hf_nordic_ble_protover;
+static int hf_nordic_ble_packet_counter;
+static int hf_nordic_ble_packet_id;
+static int hf_nordic_ble_packet_length;
+static int hf_nordic_ble_flags;
+static int hf_nordic_ble_crcok;
+static int hf_nordic_ble_encrypted;
+static int hf_nordic_ble_micok;
+static int hf_nordic_ble_mic_not_relevant;
+static int hf_nordic_ble_aux_type;
+static int hf_nordic_ble_flag_reserved1;
+static int hf_nordic_ble_flag_reserved2;
+static int hf_nordic_ble_address_resolved;
+static int hf_nordic_ble_flag_reserved7;
+static int hf_nordic_ble_le_phy;
+static int hf_nordic_ble_direction;
+static int hf_nordic_ble_channel;
+static int hf_nordic_ble_rssi;
+static int hf_nordic_ble_event_counter;
+static int hf_nordic_ble_time;
+static int hf_nordic_ble_delta_time;
+static int hf_nordic_ble_delta_time_ss;
+static int hf_nordic_ble_packet_time;
 
-static expert_field ei_nordic_ble_bad_crc = EI_INIT;
-static expert_field ei_nordic_ble_bad_mic = EI_INIT;
-static expert_field ei_nordic_ble_bad_length = EI_INIT;
-static expert_field ei_nordic_ble_unknown_version = EI_INIT;
+static expert_field ei_nordic_ble_bad_crc;
+static expert_field ei_nordic_ble_bad_mic;
+static expert_field ei_nordic_ble_bad_length;
+static expert_field ei_nordic_ble_unknown_version;
 
 static const true_false_string direction_tfs =
 {
-    "Master -> Slave",
-    "Slave -> Master"
-};
-
-static const true_false_string ok_incorrect =
-{
-    "OK",
-    "Incorrect"
+    "Central -> Peripheral",
+    "Peripheral -> Central"
 };
 
 static const value_string le_phys[] =
@@ -298,8 +294,8 @@ typedef struct {
 } nordic_ble_context_t;
 
 /* next dissector */
-static dissector_handle_t btle_dissector_handle = NULL;
-static dissector_handle_t debug_handle = NULL;
+static dissector_handle_t btle_dissector_handle;
+static dissector_handle_t debug_handle;
 
 static gint
 dissect_lengths(tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *tree, nordic_ble_context_t *nordic_ble_context)
@@ -374,14 +370,14 @@ dissect_flags(tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *tree,
 
     if (context->pdu_type == BTLE_PDU_TYPE_DATA) {
         if (dir) {
-            set_address(&pinfo->src, AT_STRINGZ, 7, "Master");
-            set_address(&pinfo->dst, AT_STRINGZ, 6, "Slave");
-            context->direction = BTLE_DIR_MASTER_SLAVE;
+            set_address(&pinfo->src, AT_STRINGZ, 7, "Central");
+            set_address(&pinfo->dst, AT_STRINGZ, 6, "Peripheral");
+            context->direction = BTLE_DIR_CENTRAL_PERIPHERAL;
             pinfo->p2p_dir = P2P_DIR_SENT;
         } else {
-            set_address(&pinfo->src, AT_STRINGZ, 6, "Slave");
-            set_address(&pinfo->dst, AT_STRINGZ, 7, "Master");
-            context->direction = BTLE_DIR_SLAVE_MASTER;
+            set_address(&pinfo->src, AT_STRINGZ, 6, "Peripheral");
+            set_address(&pinfo->dst, AT_STRINGZ, 7, "Central");
+            context->direction = BTLE_DIR_PERIPHERAL_CENTRAL;
             pinfo->p2p_dir = P2P_DIR_RECV;
         }
     }
@@ -417,7 +413,7 @@ dissect_flags(tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *tree,
             proto_tree_add_item(flags_tree, hf_nordic_ble_flag_reserved1, tvb, offset, 1, ENC_NA);
             proto_tree_add_item(flags_tree, hf_nordic_ble_flag_reserved2, tvb, offset, 1, ENC_NA);
         }
-        proto_tree_add_item(flags_tree, hf_nordic_ble_flag_reserved3, tvb, offset, 1, ENC_NA);
+        proto_tree_add_item(flags_tree, hf_nordic_ble_address_resolved, tvb, offset, 1, ENC_NA);
     }
 
     proto_tree_add_item(flags_tree, hf_nordic_ble_le_phy, tvb, offset, 1, ENC_NA);
@@ -770,7 +766,13 @@ dissect_nordic_ble(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *da
     }
 
     if ((context->mic_checked_at_capture) && (!context->mic_valid_at_capture)) {
-        col_add_str(pinfo->cinfo, COL_INFO, "Encrypted packet decrypted incorrectly (bad MIC)");
+        col_set_str(pinfo->cinfo, COL_INFO, "Encrypted packet decrypted incorrectly");
+        if (!context->crc_valid_at_capture) {
+            /* CRC is bad */
+            col_append_str(pinfo->cinfo, COL_INFO, " (bad CRC)");
+        } else {
+            col_append_str(pinfo->cinfo, COL_INFO, " (bad MIC)");
+        }
     }
 
     if (debug_handle) {
@@ -807,7 +809,7 @@ proto_register_nordic_ble(void)
         { &hf_nordic_ble_payload_length,
             { "Length of payload", "nordic_ble.plen",
                 FT_UINT16, BASE_DEC, NULL, 0x0,
-                "Payload length", HFILL }
+                NULL, HFILL }
         },
         { &hf_nordic_ble_protover,
             { "Protocol version", "nordic_ble.protover",
@@ -836,7 +838,7 @@ proto_register_nordic_ble(void)
         },
         { &hf_nordic_ble_crcok,
             { "CRC", "nordic_ble.crcok",
-                FT_BOOLEAN, 8, TFS(&ok_incorrect), 0x01,
+                FT_BOOLEAN, 8, TFS(&tfs_ok_error), 0x01,
                 "Cyclic Redundancy Check state", HFILL }
         },
         { &hf_nordic_ble_direction,
@@ -866,7 +868,7 @@ proto_register_nordic_ble(void)
         },
         { &hf_nordic_ble_micok,
             { "MIC", "nordic_ble.micok",
-                FT_BOOLEAN, 8, TFS(&ok_incorrect), 0x08,
+                FT_BOOLEAN, 8, TFS(&tfs_ok_error), 0x08,
                 "Message Integrity Check state", HFILL }
         },
         { &hf_nordic_ble_mic_not_relevant,
@@ -874,9 +876,9 @@ proto_register_nordic_ble(void)
                 FT_UINT8, BASE_DEC, NULL, 0x08,
                 "Message Integrity Check state is only relevant when encrypted", HFILL }
         },
-        { &hf_nordic_ble_flag_reserved3,
-            { "Reserved", "nordic_ble.flag_reserved3",
-                FT_UINT8, BASE_DEC, NULL, 0x08,
+        { &hf_nordic_ble_address_resolved,
+            { "Address Resolved", "nordic_ble.address_resolved",
+                FT_BOOLEAN, 8, TFS(&tfs_yes_no), 0x08,
                 NULL, HFILL }
         },
         { &hf_nordic_ble_le_phy,
@@ -890,7 +892,7 @@ proto_register_nordic_ble(void)
                 "Reserved for Future Use", HFILL }
         },
         { &hf_nordic_ble_channel,
-            { "Channel", "nordic_ble.channel",
+            { "Channel Index", "nordic_ble.channel",
                 FT_UINT8, BASE_DEC, NULL, 0x0,
                 NULL, HFILL }
         },
@@ -945,7 +947,7 @@ proto_register_nordic_ble(void)
 
     proto_nordic_ble = proto_register_protocol("nRF Sniffer for Bluetooth LE", "NORDIC_BLE", "nordic_ble");
 
-    register_dissector("nordic_ble", dissect_nordic_ble, proto_nordic_ble);
+    nordic_ble_handle = register_dissector("nordic_ble", dissect_nordic_ble, proto_nordic_ble);
 
     expert_nordic_ble = expert_register_protocol(proto_nordic_ble);
     expert_register_field_array(expert_nordic_ble, ei, array_length(ei));
@@ -957,10 +959,6 @@ proto_register_nordic_ble(void)
 void
 proto_reg_handoff_nordic_ble(void)
 {
-    dissector_handle_t nordic_ble_handle;
-
-    nordic_ble_handle = create_dissector_handle(dissect_nordic_ble, proto_nordic_ble);
-
     btle_dissector_handle = find_dissector("btle");
     debug_handle = find_dissector("nordic_debug");
 
