@@ -6,19 +6,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -30,70 +18,72 @@
 void proto_register_ns_mep(void);
 void proto_reg_handoff_ns_mep(void);
 
-static int proto_ns_mep = -1;
+static dissector_handle_t nsmep_handle;
 
-static gint ett_nsmep = -1;
-static gint ett_nsmep_mfu = -1;
-static gint ett_nsmep_nwu = -1;
+static int proto_ns_mep;
 
-static int hf_nsmep_majver = -1;
-static int hf_nsmep_minver = -1;
-static int hf_nsmep_msgtype = -1;
-static int hf_nsmep_msglen = -1;
-static int hf_nsmep_errcode = -1;
-static int hf_nsmep_mfu_state = -1;
+static gint ett_nsmep;
+static gint ett_nsmep_mfu;
+static gint ett_nsmep_nwu;
+
+static int hf_nsmep_majver;
+static int hf_nsmep_minver;
+static int hf_nsmep_msgtype;
+static int hf_nsmep_msglen;
+static int hf_nsmep_errcode;
+static int hf_nsmep_mfu_state;
 
 
-static int hf_ns_metricUpdate = -1;
-static int hf_ns_forceUpdateRequest = -1;
-static int hf_ns_forceUpdateResp = -1;
-static int hf_ns_currentOpenConn = -1;
-static int hf_ns_currentSurgeCount = -1;
-static int hf_ns_currentIOHCount = -1;
-static int hf_ns_currentReusePool  = -1;
-static int hf_ns_currentServerConn = -1;
-static int hf_ns_currentClientConn  = -1;
-static int hf_ns_TotalReq = -1;
-static int hf_ns_TotalReqBytes = -1;
-static int hf_ns_TotalResp = -1;
-static int hf_ns_TotalRespBytes = -1;
-static int hf_ns_networkMetrics = -1;
-static int hf_ns_roundTripTime = -1;
-static int hf_ns_hops = -1;
-static int hf_ns_persistenceInfo = -1;
-static int hf_ns_persistenceGslbServIp = -1;
-static int hf_ns_persistenceGslbServPort = -1;
-static int hf_ns_persistenceId = -1;
-static int hf_ns_sitePersistenceDom  = -1;
-static int hf_ns_gslbDomNamelen  = -1;
-static int hf_ns_gslbServPreflen  = -1;
-static int hf_ns_gslbCookieDomNamelen  = -1;
-static int hf_ns_gslbCookieTimeout = -1;
-static int hf_ns_gslbVidlen = -1;
-static int hf_ns_gslbFlags = -1;
-static int hf_ns_gslbCookieDomName = -1;
-static int hf_ns_gslbVs = -1;
-static int hf_ns_gslbPrefix = -1;
-static int hf_ns_sitePersistenceFlushDom = -1;
-static int hf_ns_gslbDomName = -1;
-static int hf_ns_sitePersistenceFlushServ = -1;
-static int hf_ns_sitePersisGetServReq = -1;
-static int hf_ns_siteDomTTL = -1;
-static int hf_ns_sitePersistenceGetServResp = -1;
+static int hf_ns_metricUpdate;
+static int hf_ns_forceUpdateRequest;
+static int hf_ns_forceUpdateResp;
+static int hf_ns_currentOpenConn;
+static int hf_ns_currentSurgeCount;
+static int hf_ns_currentIOHCount;
+static int hf_ns_currentReusePool;
+static int hf_ns_currentServerConn;
+static int hf_ns_currentClientConn;
+static int hf_ns_TotalReq;
+static int hf_ns_TotalReqBytes;
+static int hf_ns_TotalResp;
+static int hf_ns_TotalRespBytes;
+static int hf_ns_networkMetrics;
+static int hf_ns_roundTripTime;
+static int hf_ns_hops;
+static int hf_ns_persistenceInfo;
+static int hf_ns_persistenceGslbServIp;
+static int hf_ns_persistenceGslbServPort;
+static int hf_ns_persistenceId;
+static int hf_ns_sitePersistenceDom;
+static int hf_ns_gslbDomNamelen;
+static int hf_ns_gslbServPreflen;
+static int hf_ns_gslbCookieDomNamelen;
+static int hf_ns_gslbCookieTimeout;
+static int hf_ns_gslbVidlen;
+static int hf_ns_gslbFlags;
+static int hf_ns_gslbCookieDomName;
+static int hf_ns_gslbVs;
+static int hf_ns_gslbPrefix;
+static int hf_ns_sitePersistenceFlushDom;
+static int hf_ns_gslbDomName;
+static int hf_ns_sitePersistenceFlushServ;
+static int hf_ns_sitePersisGetServReq;
+static int hf_ns_siteDomTTL;
+static int hf_ns_sitePersistenceGetServResp;
 
 
 
-static int hf_nsmep_mfu_ip = -1;
-static int hf_nsmep_mfu_port = -1;
-static int hf_nsmep_mfu_svctype = -1;
-static int hf_nsmep_mfu_eff_state = -1;
-static int hf_nsmep_mfu_mepflag = -1;
-static int hf_nsmep_mfu_reqflag = -1;
+static int hf_nsmep_mfu_ip;
+static int hf_nsmep_mfu_port;
+static int hf_nsmep_mfu_svctype;
+static int hf_nsmep_mfu_eff_state;
+static int hf_nsmep_mfu_mepflag;
+static int hf_nsmep_mfu_reqflag;
 
-static int hf_nsmep_adv_ip = -1;
+static int hf_nsmep_adv_ip;
 
-static int hf_nsmep_ldns_ip = -1;
-static int hf_nsmep_site_persistence = -1;
+static int hf_nsmep_ldns_ip;
+static int hf_nsmep_site_persistence;
 dissector_handle_t nsrpc_handle;
 
 /*GSLB MEP message types */
@@ -259,7 +249,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	offset +=1;
 	proto_tree_add_item_ret_uint(ns_mep_tree, hf_nsmep_msgtype, tvb, offset, 2, ENC_LITTLE_ENDIAN, &mesgtype);
 	offset +=2;
-	version_str = wmem_strdup_printf(wmem_packet_scope(), "v%d.%d %s", maj_ver, min_ver, val_to_str(mesgtype, nslist_gslbmessage, "Unknown Mesg Type:  0x%02X"));
+	version_str = wmem_strdup_printf(pinfo->pool, "v%d.%d %s", maj_ver, min_ver, val_to_str(mesgtype, nslist_gslbmessage, "Unknown Mesg Type:  0x%02X"));
 	proto_item_append_text(ti, ", %s", version_str);
 	proto_tree_add_item_ret_uint(ns_mep_tree, hf_nsmep_msglen, tvb, offset, 2, ENC_LITTLE_ENDIAN, &mesglen);
 	offset +=2;
@@ -291,7 +281,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_item_ret_uint(ns_mep_mfu_tree, hf_nsmep_mfu_svctype, tvb, offset, 2, ENC_LITTLE_ENDIAN, &svctype);
 			offset +=2;
 
-			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(wmem_packet_scope(), tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
+			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(pinfo->pool, tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
 			if ((maj_ver > 2) || ((maj_ver==2) && (min_ver > 2)))
 			{
 				proto_tree_add_item(ns_mep_mfu_tree, hf_nsmep_mfu_eff_state, tvb, offset, 1, ENC_LITTLE_ENDIAN);
@@ -323,7 +313,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_item_ret_uint(ns_mep_mfr_tree, hf_nsmep_mfu_svctype, tvb, offset, 4, ENC_LITTLE_ENDIAN, &svctype);
 			offset +=4;
 
-			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(wmem_packet_scope(), tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
+			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(pinfo->pool, tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
 
 			if ((maj_ver > 2) || ((maj_ver==2) && (min_ver > 2)))
 			{
@@ -365,7 +355,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_item_ret_uint(ns_mep_mfu_tree, hf_nsmep_mfu_svctype, tvb, offset, 2, ENC_LITTLE_ENDIAN, &svctype);
 			offset +=2;
 
-			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(wmem_packet_scope(), tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
+			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(pinfo->pool, tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
 
 			if ((maj_ver > 2) || ((maj_ver==2) && (min_ver > 2)))
 			{
@@ -420,7 +410,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		while (tvb_reported_length_remaining(tvb, offset) >= GSLIB_NET_MET_TABLE_SIZE)
 		{
 			tf = proto_tree_add_item(ns_mep_tree, hf_ns_networkMetrics, tvb, offset, GSLIB_NET_MET_TABLE_SIZE, ENC_NA);
-			proto_item_append_text(tf, " of %s", tvb_address_to_str(wmem_packet_scope(), tvb, AT_IPv4, offset));
+			proto_item_append_text(tf, " of %s", tvb_address_to_str(pinfo->pool, tvb, AT_IPv4, offset));
 			ns_mep_nwu_tree = proto_item_add_subtree(tf, ett_nsmep_nwu);
 
 			proto_tree_add_item(ns_mep_nwu_tree, hf_nsmep_ldns_ip, tvb, offset, 4, ENC_LITTLE_ENDIAN);
@@ -443,7 +433,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		while (tvb_reported_length_remaining(tvb, offset) >= NS_PERSIST_INFO_SIZE)
 		{
 			tf = proto_tree_add_item(ns_mep_tree, hf_ns_persistenceInfo, tvb, offset, NS_PERSIST_INFO_SIZE, ENC_NA);
-			proto_item_append_text(tf, " %s", tvb_address_to_str(wmem_packet_scope(), tvb, AT_IPv4, offset));
+			proto_item_append_text(tf, " %s", tvb_address_to_str(pinfo->pool, tvb, AT_IPv4, offset));
 			ns_mep_pr_tree = proto_item_add_subtree(tf, ett_nsmep_nwu);
 
 			proto_tree_add_item(ns_mep_pr_tree, hf_nsmep_ldns_ip, tvb, offset, 4, ENC_LITTLE_ENDIAN);
@@ -479,7 +469,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_item_ret_uint(ns_mep_di_tree, hf_nsmep_mfu_svctype, tvb, offset, 2, ENC_LITTLE_ENDIAN, &svctype);
 			offset += 2;
 
-			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(wmem_packet_scope(), tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
+			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(pinfo->pool, tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
 
 			proto_tree_add_item_ret_uint(ns_mep_di_tree, hf_ns_gslbDomNamelen, tvb, offset, 1, ENC_LITTLE_ENDIAN, &domainlen);
 			offset += 1;
@@ -542,7 +532,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			proto_tree_add_item_ret_uint(ns_mep_di_tree, hf_nsmep_mfu_svctype, tvb, offset, 2, ENC_LITTLE_ENDIAN, &svctype);
 			offset += 2;
 
-			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(wmem_packet_scope(), tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
+			proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(pinfo->pool, tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
 
 			proto_tree_add_item_ret_uint(ns_mep_di_tree, hf_ns_gslbDomNamelen, tvb, offset, 1, ENC_LITTLE_ENDIAN, &domainlen);
 			offset += 1;
@@ -570,7 +560,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		proto_tree_add_item_ret_uint(ns_mep_di_tree, hf_nsmep_mfu_svctype, tvb, offset, 2, ENC_LITTLE_ENDIAN, &svctype);
 		offset += 2;
 
-		proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(wmem_packet_scope(), tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
+		proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(pinfo->pool, tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
 		break;
 	}
 	case GSLB_MSG_LBNODE_GETSVC:
@@ -589,7 +579,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		proto_tree_add_item_ret_uint(ns_mep_di_tree, hf_nsmep_mfu_svctype, tvb, offset, 2, ENC_LITTLE_ENDIAN, &svctype);
 		offset += 2;
 
-		proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(wmem_packet_scope(), tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
+		proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(pinfo->pool, tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
 
 		proto_tree_add_item_ret_uint(ns_mep_di_tree, hf_ns_gslbDomNamelen, tvb, offset, 1, ENC_LITTLE_ENDIAN, &domainlen);
 		offset += 1;
@@ -616,7 +606,7 @@ dissect_ns_mep_v02xx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		proto_tree_add_item_ret_uint(ns_mep_di_tree, hf_nsmep_mfu_svctype, tvb, offset, 2, ENC_LITTLE_ENDIAN, &svctype);
 		offset += 2;
 
-		proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(wmem_packet_scope(), tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
+		proto_item_append_text(tf, " for %s:%d:%s", tvb_address_to_str(pinfo->pool, tvb, FT_IPv4, offset-8), public_port, val_to_str(svctype, ns_svc_type_vals, "0x%02X"));
 
 		proto_tree_add_item_ret_uint(ns_mep_di_tree, hf_ns_gslbDomNamelen, tvb, offset, 1, ENC_LITTLE_ENDIAN, &domainlen);
 		offset += 1;
@@ -879,20 +869,18 @@ proto_register_ns_mep(void)
 	proto_ns_mep = proto_register_protocol("NetScaler Metric Exchange Protocol", "NetScaler MEP", "nstrace.mep");
 	proto_register_field_array(proto_ns_mep, hf_nsmep, array_length(hf_nsmep));
 	proto_register_subtree_array(ett, array_length(ett));
+
+	nsmep_handle = register_dissector("nstrace.mep", dissect_ns_mep, proto_ns_mep);
 }
 
 void proto_reg_handoff_ns_mep(void)
 {
-	dissector_handle_t nsmep_handle;
-
 	nsrpc_handle = find_dissector_add_dependency("nsrpc", proto_ns_mep);
-
-	nsmep_handle = create_dissector_handle(dissect_ns_mep, proto_ns_mep);
 	dissector_add_for_decode_as("tcp.port", nsmep_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
