@@ -16,14 +16,14 @@
 void proto_register_ns_rpc(void);
 void proto_reg_handoff_ns_rpc(void);
 
-static int proto_ns_rpc = -1;
-static gint ett_nsrpc = -1;
+static int proto_ns_rpc;
+static gint ett_nsrpc;
 
-static int hf_nsrpc_dlen = -1;
-static int hf_nsrpc_cmd = -1;
-static int hf_nsrpc_errcode = -1;
+static int hf_nsrpc_dlen;
+static int hf_nsrpc_cmd;
+static int hf_nsrpc_errcode;
 
-static int hf_ns_remoteIOCTL = -1;
+static int hf_ns_remoteIOCTL;
 
 
 static const value_string ns_rpc_cmd_vals[] = {
@@ -1161,17 +1161,17 @@ dissect_ns_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 	return tvb_captured_length(tvb);
 }
 
-static gboolean
+static bool
 dissect_ns_rpc_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data)
 {
 	static const guint8 ns_rpc_sig[2] = { 0xA5, 0xA5 };
 
 	/* Check the signature */
 	if (tvb_memeql(tvb, 4, ns_rpc_sig, sizeof ns_rpc_sig) != 0)
-		return FALSE;
+		return false;
 
 	dissect_ns_rpc(tvb, pinfo, tree, data);
-	return TRUE;
+	return true;
 }
 
 void
@@ -1210,11 +1210,11 @@ proto_register_ns_rpc(void)
 void proto_reg_handoff_ns_rpc(void)
 {
 	/* Heuristic not strong enough to be enabled by default */
-	heur_dissector_add("tcp", dissect_ns_rpc_heur, "netscaler-nsrpc", "nsrpc", proto_ns_rpc, HEURISTIC_DISABLE);
+	heur_dissector_add("tcp", dissect_ns_rpc_heur, "NSRPC over TCP", "nsrpc", proto_ns_rpc, HEURISTIC_DISABLE);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
