@@ -33,7 +33,10 @@
 void proto_reg_handoff_nsh(void);
 void proto_register_nsh(void);
 
+static dissector_handle_t nsh_handle;
+
 static const value_string nsh_next_protocols[] = {
+	{ NSH_NONE, "None" },
 	{ NSH_IPV4, "IPv4" },
 	{ NSH_IPV6, "IPv6" },
 	{ NSH_ETHERNET, "Ethernet" },
@@ -45,26 +48,26 @@ static const value_string nsh_next_protocols[] = {
 };
 
 
-static int proto_nsh = -1;
-static int hf_nsh_version = -1;
-static int hf_nsh_oam = -1;
-static int hf_nsh_critical_metadata = -1;
-static int hf_nsh_ttl = -1;
-static int hf_nsh_length = -1;
-static int hf_nsh_md_type = -1;
-static int hf_nsh_next_proto = -1;
-static int hf_nsh_service_pathID = -1;
-static int hf_nsh_service_index = -1;
-static int hf_nsh_context_header = -1;
-static int hf_nsh_metadata_class = -1;
-static int hf_nsh_metadata_type = -1;
-static int hf_nsh_metadata_unassignedbit = -1;
-static int hf_nsh_metadata_length = -1;
-static int hf_nsh_metadata = -1;
+static int proto_nsh;
+static int hf_nsh_version;
+static int hf_nsh_oam;
+static int hf_nsh_critical_metadata;
+static int hf_nsh_ttl;
+static int hf_nsh_length;
+static int hf_nsh_md_type;
+static int hf_nsh_next_proto;
+static int hf_nsh_service_pathID;
+static int hf_nsh_service_index;
+static int hf_nsh_context_header;
+static int hf_nsh_metadata_class;
+static int hf_nsh_metadata_type;
+static int hf_nsh_metadata_unassignedbit;
+static int hf_nsh_metadata_length;
+static int hf_nsh_metadata;
 
-static expert_field ei_nsh_length_invalid = EI_INIT;
+static expert_field ei_nsh_length_invalid;
 
-static gint ett_nsh = -1;
+static gint ett_nsh;
 
 static dissector_table_t subdissector_table;
 
@@ -75,13 +78,10 @@ static dissector_table_t subdissector_table;
 static void
 dissect_nsh_md_type_1(tvbuff_t *tvb, proto_tree *nsh_tree, int offset)
 {
-
 	proto_tree_add_item(nsh_tree, hf_nsh_context_header, tvb, offset, 4, ENC_NA);
 	proto_tree_add_item(nsh_tree, hf_nsh_context_header, tvb, offset + 4, 4, ENC_NA);
 	proto_tree_add_item(nsh_tree, hf_nsh_context_header, tvb, offset + 8, 4, ENC_NA);
 	proto_tree_add_item(nsh_tree, hf_nsh_context_header, tvb, offset + 12, 4, ENC_NA);
-
-
 }
 
 /*
@@ -355,14 +355,12 @@ proto_register_nsh(void)
 
 	subdissector_table = register_dissector_table("nsh.next_proto", "NSH Next Protocol", proto_nsh, FT_UINT32, BASE_DEC);
 
+	nsh_handle = register_dissector("nsh", dissect_nsh, proto_nsh);
 }
 
 void
 proto_reg_handoff_nsh(void)
 {
-	static dissector_handle_t nsh_handle;
-
-	nsh_handle = create_dissector_handle(dissect_nsh, proto_nsh);
 	dissector_add_uint("ethertype", ETHERTYPE_NSH, nsh_handle);
 	dissector_add_uint("gre.proto", ETHERTYPE_NSH, nsh_handle);
 	dissector_add_uint("vxlan.next_proto", VXLAN_NSH, nsh_handle);
