@@ -28,11 +28,11 @@ static dissector_table_t null_dissector_table;
 static dissector_table_t ethertype_dissector_table;
 
 /* protocols and header fields */
-static int proto_null = -1;
-static int hf_null_etype = -1;
-static int hf_null_family = -1;
+static int proto_null;
+static int hf_null_etype;
+static int hf_null_family;
 
-static gint ett_null = -1;
+static gint ett_null;
 
 /* Null/loopback structs and definitions */
 
@@ -54,7 +54,7 @@ static capture_dissector_handle_t null_cap_handle;
 static dissector_handle_t ppp_hdlc_handle;
 static capture_dissector_handle_t ppp_hdlc_cap_handle;
 
-static gboolean
+static bool
 capture_null( const guchar *pd, int offset _U_, int len, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header _U_ )
 {
   guint32 null_header;
@@ -342,7 +342,7 @@ dissect_null(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
      * Treat it as a normal DLT_NULL header.  Fetch it in host
      * byte order.
      */
-    null_header = tvb_get_h_guint32(tvb, 0);
+    null_header = tvb_get_h_uint32(tvb, 0);
 
     if ((null_header & 0xFFFF0000) != 0) {
       /*
