@@ -55,7 +55,6 @@ http://www.iana.org/assignments/service-names-port-numbers/service-names-port-nu
 #include "config.h"
 
 #include <stdlib.h>
-#include <errno.h>
 
 #include <epan/packet.h>
 #include <epan/prefs.h>
@@ -108,47 +107,47 @@ struct nvme_rdma_cmd_ctx {
 void proto_reg_handoff_nvme_rdma(void);
 void proto_register_nvme_rdma(void);
 
-static int proto_nvme_rdma = -1;
+static int proto_nvme_rdma;
 static dissector_handle_t ib_handler;
-static int proto_ib = -1;
+static int proto_ib;
 
 /* NVMe Fabrics RDMA CM Private data */
-static int hf_nvmeof_rdma_cm_req_recfmt = -1;
-static int hf_nvmeof_rdma_cm_req_qid = -1;
-static int hf_nvmeof_rdma_cm_req_hrqsize = -1;
-static int hf_nvmeof_rdma_cm_req_hsqsize = -1;
-static int hf_nvmeof_rdma_cm_req_cntlid = -1;
-static int hf_nvmeof_rdma_cm_req_reserved = -1;
+static int hf_nvmeof_rdma_cm_req_recfmt;
+static int hf_nvmeof_rdma_cm_req_qid;
+static int hf_nvmeof_rdma_cm_req_hrqsize;
+static int hf_nvmeof_rdma_cm_req_hsqsize;
+static int hf_nvmeof_rdma_cm_req_cntlid;
+static int hf_nvmeof_rdma_cm_req_reserved;
 
-static int hf_nvmeof_rdma_cm_rsp_recfmt = -1;
-static int hf_nvmeof_rdma_cm_rsp_crqsize = -1;
-static int hf_nvmeof_rdma_cm_rsp_reserved = -1;
+static int hf_nvmeof_rdma_cm_rsp_recfmt;
+static int hf_nvmeof_rdma_cm_rsp_crqsize;
+static int hf_nvmeof_rdma_cm_rsp_reserved;
 
-static int hf_nvmeof_rdma_cm_rej_recfmt = -1;
-static int hf_nvmeof_rdma_cm_rej_status = -1;
+static int hf_nvmeof_rdma_cm_rej_recfmt;
+static int hf_nvmeof_rdma_cm_rej_status;
 
 /* Data Transfers */
-static int hf_nvmeof_from_host_unknown_data = -1;
-static int hf_nvmeof_read_to_host_req = -1;
-static int hf_nvmeof_read_to_host_unmatched = -1;
-static int hf_nvmeof_read_from_host_resp = -1;
-static int hf_nvmeof_read_from_host_prev = -1;
-static int hf_nvmeof_read_from_host_next = -1;
-static int hf_nvmeof_read_from_host_unmatched = -1;
-static int hf_nvmeof_write_to_host_req = -1;
-static int hf_nvmeof_write_to_host_prev = -1;
-static int hf_nvmeof_write_to_host_next = -1;
-static int hf_nvmeof_write_to_host_unmatched = -1;
-static int hf_nvmeof_to_host_unknown_data = -1;
+static int hf_nvmeof_from_host_unknown_data;
+static int hf_nvmeof_read_to_host_req;
+static int hf_nvmeof_read_to_host_unmatched;
+static int hf_nvmeof_read_from_host_resp;
+static int hf_nvmeof_read_from_host_prev;
+static int hf_nvmeof_read_from_host_next;
+static int hf_nvmeof_read_from_host_unmatched;
+static int hf_nvmeof_write_to_host_req;
+static int hf_nvmeof_write_to_host_prev;
+static int hf_nvmeof_write_to_host_next;
+static int hf_nvmeof_write_to_host_unmatched;
+static int hf_nvmeof_to_host_unknown_data;
 
 /* Tracking commands, transfers and CQEs */
-static int hf_nvmeof_data_resp = -1;
-static int hf_nvmeof_cmd_qid = -1;
+static int hf_nvmeof_data_resp;
+static int hf_nvmeof_cmd_qid;
 
 
 /* Initialize the subtree pointers */
-static gint ett_cm = -1;
-static gint ett_data = -1;
+static gint ett_cm;
+static gint ett_data;
 
 static range_t *gPORT_RANGE;
 
@@ -180,7 +179,7 @@ find_ib_conversation(packet_info *pinfo, conversation_infiniband_data **uni_conv
     conversation_infiniband_data *conv_data;
 
     conv = find_conversation(pinfo->num, &pinfo->dst, &pinfo->dst,
-                             ENDPOINT_IBQP, pinfo->destport, pinfo->destport,
+                             CONVERSATION_IBQP, pinfo->destport, pinfo->destport,
                              NO_ADDR_B|NO_PORT_B);
     if (!conv)
         return NULL;   /* nothing to do with no conversation context */
@@ -194,7 +193,7 @@ find_ib_conversation(packet_info *pinfo, conversation_infiniband_data **uni_conv
      * conversation, so that we can relate to nvme q.
      */
     return find_conversation(pinfo->num, &pinfo->src, &pinfo->dst,
-                             ENDPOINT_IBQP, pinfo->srcport, pinfo->destport, 0);
+                             CONVERSATION_IBQP, pinfo->srcport, pinfo->destport, 0);
 }
 
 static guint16 find_nvme_qid(packet_info *pinfo)
@@ -204,7 +203,7 @@ static guint16 find_nvme_qid(packet_info *pinfo)
     guint16 qid;
 
     conv = find_conversation(pinfo->num, &pinfo->dst, &pinfo->dst,
-                             ENDPOINT_IBQP, pinfo->destport, pinfo->destport,
+                             CONVERSATION_IBQP, pinfo->destport, pinfo->destport,
                              NO_ADDR_B|NO_PORT_B);
     if (!conv)
         return 0;   /* nothing to do with no conversation context */
@@ -218,7 +217,7 @@ static guint16 find_nvme_qid(packet_info *pinfo)
         return qid;
     }
     conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->src,
-                             ENDPOINT_IBQP, conv_data->src_qp, conv_data->src_qp,
+                             CONVERSATION_IBQP, conv_data->src_qp, conv_data->src_qp,
                              NO_ADDR_B|NO_PORT_B);
     if (!conv)
         return 0;
@@ -256,7 +255,7 @@ find_ib_cm_conversation(packet_info *pinfo)
     conversation_t *conv;
 
     conv = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst,
-                             ENDPOINT_IBQP, pinfo->srcport, pinfo->destport, 0);
+                             CONVERSATION_IBQP, pinfo->srcport, pinfo->destport, 0);
     if (!conv)
         return NULL;
 
@@ -332,7 +331,7 @@ static void dissect_rdma_cm_rej_packet(tvbuff_t *tvb, proto_tree *tree)
             2, 2, ENC_LITTLE_ENDIAN);
 }
 
-static int dissect_rdma_cm_packet(tvbuff_t *tvb, proto_tree *tree,
+static bool dissect_rdma_cm_packet(tvbuff_t *tvb, proto_tree *tree,
                                   guint16 cm_attribute_id)
 {
     switch (cm_attribute_id) {
@@ -348,10 +347,10 @@ static int dissect_rdma_cm_packet(tvbuff_t *tvb, proto_tree *tree,
     default:
         break;
     }
-    return TRUE;
+    return true;
 }
 
-static int
+static bool
 dissect_nvme_ib_cm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
         void *data)
 {
@@ -364,7 +363,7 @@ dissect_nvme_ib_cm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
     conv_data = find_ib_cm_conversation(pinfo);
     if (!conv_data)
-        return FALSE;
+        return false;
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, NVME_FABRICS_RDMA);
     return dissect_rdma_cm_packet(tvb, tree, info->cm_attribute_id);
@@ -653,7 +652,7 @@ dissect_nvme_to_host(tvbuff_t *nvme_tvb, packet_info *pinfo,
     }
 }
 
-static int
+static bool
 dissect_nvme_ib(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     struct infinibandinfo *info = (struct infinibandinfo *)data;
@@ -666,11 +665,11 @@ dissect_nvme_ib(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 
     conv = find_ib_conversation(pinfo, &conv_data);
     if (!conv)
-        return FALSE;
+        return false;
 
     q_ctx = find_add_q_ctx(pinfo, conv);
     if (!q_ctx)
-        return FALSE;
+        return false;
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, NVME_FABRICS_RDMA);
 
@@ -684,7 +683,7 @@ dissect_nvme_ib(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
     else
         dissect_nvme_to_host(tvb, pinfo, tree, nvme_tree, info, q_ctx, len);
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -808,7 +807,6 @@ proto_register_nvme_rdma(void)
     proto_register_subtree_array(ett, array_length(ett));
 
     /* Register preferences */
-    //nvme_rdma_module = prefs_register_protocol(proto_nvme_rdma, proto_reg_handoff_nvme_rdma);
     nvme_rdma_module = prefs_register_protocol(proto_nvme_rdma, NULL);
 
     range_convert_str(wmem_epan_scope(), &gPORT_RANGE, NVME_RDMA_TCP_PORT_RANGE, MAX_TCP_PORT);
