@@ -24,88 +24,90 @@
 void proto_register_obdii(void);
 void proto_reg_handoff_obdii(void);
 
-static int proto_obdii = -1;
+static dissector_handle_t obdii_handle;
 
-static int ett_obdii = -1;
+static int proto_obdii;
 
-static int hf_obdii_mode = -1;
-static int hf_obdii_raw_value = -1;
+static int ett_obdii;
 
-static int hf_obdii_mode01_pid = -1;
-static int hf_obdii_mode01_supported_pid = -1;
-static int hf_obdii_mode01_unsupported_pid = -1;
-static int hf_obdii_mode01_fuel_system1_status = -1;
-static int hf_obdii_mode01_fuel_system2_status = -1;
-static int hf_obdii_mode01_engine_load = -1;
-static int hf_obdii_mode01_engine_coolant_temp = -1;
-static int hf_obdii_mode01_short_term_fuel_bank1 = -1;
-static int hf_obdii_mode01_long_term_fuel_bank1 = -1;
-static int hf_obdii_mode01_short_term_fuel_bank2 = -1;
-static int hf_obdii_mode01_long_term_fuel_bank2 = -1;
-static int hf_obdii_mode01_fuel_pressure = -1;
-static int hf_obdii_mode01_engine_rpm = -1;
-static int hf_obdii_mode01_vehicle_speed = -1;
-static int hf_obdii_mode01_timing_advance = -1;
-static int hf_obdii_mode01_intake_air_temp = -1;
-static int hf_obdii_mode01_maf_air_flow_rate = -1;
-static int hf_obdii_mode01_throttle_position = -1;
-static int hf_obdii_mode01_secondary_air_status = -1;
-static int hf_obdii_mode01_obd_standards = -1;
-static int hf_obdii_mode01_engine_uptime = -1;
-static int hf_obdii_mode01_fuel_rail_pressure = -1;
-static int hf_obdii_mode01_fuel_rail_gauge_pressure = -1;
-static int hf_obdii_mode01_fuel_rail_absolute_pressure = -1;
-static int hf_obdii_mode01_commanded_egr = -1;
-static int hf_obdii_mode01_egr_error = -1;
-static int hf_obdii_mode01_commanded_evap_purge = -1;
-static int hf_obdii_mode01_fuel_tank_level_input = -1;
-static int hf_obdii_mode01_warm_ups = -1;
-static int hf_obdii_mode01_evap_system_vapor_pressure = -1;
-static int hf_obdii_mode01_absolute_barometric_pressure = -1;
-static int hf_obdii_mode01_intake_manifold_absolute_pressure = -1;
-static int hf_obdii_mode01_oxygen_sensor_id = -1;
-static int hf_obdii_mode01_oxygen_sensor_fuel_air_ratio = -1;
-static int hf_obdii_mode01_oxygen_sensor_voltage = -1;
-static int hf_obdii_mode01_oxygen_sensor_current = -1;
-static int hf_obdii_mode01_distance_traveled_with_mil = -1;
-static int hf_obdii_mode01_distance_traveled_since_code_clear = -1;
-static int hf_obdii_mode01_time_run_with_mil = -1;
-static int hf_obdii_mode01_time_since_trouble_code_clear = -1;
-static int hf_obdii_mode01_catalyst_temp_11 = -1;
-static int hf_obdii_mode01_catalyst_temp_21 = -1;
-static int hf_obdii_mode01_catalyst_temp_12 = -1;
-static int hf_obdii_mode01_catalyst_temp_22 = -1;
-static int hf_obdii_mode01_ambient_air_temp = -1;
-static int hf_obdii_mode01_absolute_throttle_position_B = -1;
-static int hf_obdii_mode01_absolute_throttle_position_C = -1;
-static int hf_obdii_mode01_accelerator_pedal_position_D = -1;
-static int hf_obdii_mode01_accelerator_pedal_position_E = -1;
-static int hf_obdii_mode01_accelerator_pedal_position_F = -1;
-static int hf_obdii_mode01_commanded_throttle_actuator = -1;
-static int hf_obdii_mode01_fuel_type = -1;
-static int hf_obdii_mode01_control_module_voltage = -1;
-static int hf_obdii_mode01_absolute_load_value = -1;
-static int hf_obdii_mode01_fuel_air_commanded_equiv_ratio = -1;
-static int hf_obdii_mode01_relative_throttle_position = -1;
-static int hf_obdii_mode01_ethanol_fuel = -1;
-static int hf_obdii_mode01_absolute_evap_system_vapor_pressure = -1;
-static int hf_obdii_mode01_relative_accelerator_pedal_position = -1;
-static int hf_obdii_mode01_hybrid_battery_remaining_life = -1;
-static int hf_obdii_mode01_engine_oil_temp = -1;
-static int hf_obdii_mode01_fuel_injection_timing = -1;
-static int hf_obdii_mode01_engine_fuel_rate = -1;
-static int hf_obdii_mode01_torque_driver_demand_engine = -1;
-static int hf_obdii_mode01_torque_actual_engine = -1;
-static int hf_obdii_mode01_torque_reference_engine = -1;
+static int hf_obdii_mode;
+static int hf_obdii_raw_value;
 
-static int hf_obdii_mode09_pid = -1;
-static int hf_obdii_mode09_supported_pid = -1;
-static int hf_obdii_mode09_unsupported_pid = -1;
+static int hf_obdii_mode01_pid;
+static int hf_obdii_mode01_supported_pid;
+static int hf_obdii_mode01_unsupported_pid;
+static int hf_obdii_mode01_fuel_system1_status;
+static int hf_obdii_mode01_fuel_system2_status;
+static int hf_obdii_mode01_engine_load;
+static int hf_obdii_mode01_engine_coolant_temp;
+static int hf_obdii_mode01_short_term_fuel_bank1;
+static int hf_obdii_mode01_long_term_fuel_bank1;
+static int hf_obdii_mode01_short_term_fuel_bank2;
+static int hf_obdii_mode01_long_term_fuel_bank2;
+static int hf_obdii_mode01_fuel_pressure;
+static int hf_obdii_mode01_engine_rpm;
+static int hf_obdii_mode01_vehicle_speed;
+static int hf_obdii_mode01_timing_advance;
+static int hf_obdii_mode01_intake_air_temp;
+static int hf_obdii_mode01_maf_air_flow_rate;
+static int hf_obdii_mode01_throttle_position;
+static int hf_obdii_mode01_secondary_air_status;
+static int hf_obdii_mode01_obd_standards;
+static int hf_obdii_mode01_engine_uptime;
+static int hf_obdii_mode01_fuel_rail_pressure;
+static int hf_obdii_mode01_fuel_rail_gauge_pressure;
+static int hf_obdii_mode01_fuel_rail_absolute_pressure;
+static int hf_obdii_mode01_commanded_egr;
+static int hf_obdii_mode01_egr_error;
+static int hf_obdii_mode01_commanded_evap_purge;
+static int hf_obdii_mode01_fuel_tank_level_input;
+static int hf_obdii_mode01_warm_ups;
+static int hf_obdii_mode01_evap_system_vapor_pressure;
+static int hf_obdii_mode01_absolute_barometric_pressure;
+static int hf_obdii_mode01_intake_manifold_absolute_pressure;
+static int hf_obdii_mode01_oxygen_sensor_id;
+static int hf_obdii_mode01_oxygen_sensor_fuel_air_ratio;
+static int hf_obdii_mode01_oxygen_sensor_voltage;
+static int hf_obdii_mode01_oxygen_sensor_current;
+static int hf_obdii_mode01_distance_traveled_with_mil;
+static int hf_obdii_mode01_distance_traveled_since_code_clear;
+static int hf_obdii_mode01_time_run_with_mil;
+static int hf_obdii_mode01_time_since_trouble_code_clear;
+static int hf_obdii_mode01_catalyst_temp_11;
+static int hf_obdii_mode01_catalyst_temp_21;
+static int hf_obdii_mode01_catalyst_temp_12;
+static int hf_obdii_mode01_catalyst_temp_22;
+static int hf_obdii_mode01_ambient_air_temp;
+static int hf_obdii_mode01_absolute_throttle_position_B;
+static int hf_obdii_mode01_absolute_throttle_position_C;
+static int hf_obdii_mode01_accelerator_pedal_position_D;
+static int hf_obdii_mode01_accelerator_pedal_position_E;
+static int hf_obdii_mode01_accelerator_pedal_position_F;
+static int hf_obdii_mode01_commanded_throttle_actuator;
+static int hf_obdii_mode01_fuel_type;
+static int hf_obdii_mode01_control_module_voltage;
+static int hf_obdii_mode01_absolute_load_value;
+static int hf_obdii_mode01_fuel_air_commanded_equiv_ratio;
+static int hf_obdii_mode01_relative_throttle_position;
+static int hf_obdii_mode01_ethanol_fuel;
+static int hf_obdii_mode01_absolute_evap_system_vapor_pressure;
+static int hf_obdii_mode01_relative_accelerator_pedal_position;
+static int hf_obdii_mode01_hybrid_battery_remaining_life;
+static int hf_obdii_mode01_engine_oil_temp;
+static int hf_obdii_mode01_fuel_injection_timing;
+static int hf_obdii_mode01_engine_fuel_rate;
+static int hf_obdii_mode01_torque_driver_demand_engine;
+static int hf_obdii_mode01_torque_actual_engine;
+static int hf_obdii_mode01_torque_reference_engine;
 
-static int hf_obdii_vin = -1;
-static int hf_obdii_ecu_name = -1;
+static int hf_obdii_mode09_pid;
+static int hf_obdii_mode09_supported_pid;
+static int hf_obdii_mode09_unsupported_pid;
 
-static expert_field ei_obdii_padding = EI_INIT;
+static int hf_obdii_vin;
+static int hf_obdii_ecu_name;
+
+static expert_field ei_obdii_padding;
 
 /* OBD-II CAN IDs have three aspects.
    - IDs are either standard 11bit format (SFF) or extended 29bit format (EFF)
@@ -1259,7 +1261,7 @@ dissect_obdii_mode_09(tvbuff_t *tvb, struct obdii_packet_info *oinfo, proto_tree
 		proto_tree_add_item(tree, hf_obdii_raw_value, tvb, OBDII_VAL_OFF, oinfo->value_bytes, ENC_NA);
 		break;
 	case OBDII_MODE09_VIN02:
-		proto_tree_add_item(tree, hf_obdii_vin, tvb, OBDII_VAL_OFF+1, oinfo->value_bytes-1, ENC_ASCII|ENC_NA);
+		proto_tree_add_item(tree, hf_obdii_vin, tvb, OBDII_VAL_OFF+1, oinfo->value_bytes-1, ENC_ASCII);
 		break;
 	case OBDII_MODE09_CALIBRATION_ID04:
 	case OBDII_MODE09_CAL_VER_NUMBERS06:
@@ -1267,7 +1269,7 @@ dissect_obdii_mode_09(tvbuff_t *tvb, struct obdii_packet_info *oinfo, proto_tree
 		proto_tree_add_item(tree, hf_obdii_raw_value, tvb, OBDII_VAL_OFF, oinfo->value_bytes, ENC_NA);
 		break;
 	case OBDII_MODE09_ECU_NAME0A:
-		proto_tree_add_item(tree, hf_obdii_ecu_name, tvb, OBDII_VAL_OFF+1, oinfo->value_bytes-1, ENC_ASCII|ENC_NA);
+		proto_tree_add_item(tree, hf_obdii_ecu_name, tvb, OBDII_VAL_OFF+1, oinfo->value_bytes-1, ENC_ASCII);
 		break;
 	case OBDII_MODE09_PERFORMANCE_COMPRESSION0B:
 	default:
@@ -1288,7 +1290,7 @@ dissect_obdii_query(tvbuff_t *tvb, struct obdii_packet_info *oinfo, proto_tree *
 	pid_len = oinfo->data_bytes - 1;
 	if (pid_len == 0)
 	{
-		if (oinfo->mode != 0x07)
+		if (oinfo->mode != 0x04 && oinfo->mode != 0x07)
 			return 0;
 		pid = 0; /* Should never be required but set to satisfy petri-dish */
 	}
@@ -1309,6 +1311,7 @@ dissect_obdii_query(tvbuff_t *tvb, struct obdii_packet_info *oinfo, proto_tree *
 		col_append_fstr(oinfo->pinfo->cinfo, COL_INFO, " Request[%.3x] %s - %s", oinfo->can_id, mode_str, pid_str);
 		break;
 
+	case 0x04:
 	case 0x07:
 		col_append_fstr(oinfo->pinfo->cinfo, COL_INFO, " Request[%.3x] %s", oinfo->can_id, mode_str);
 		break;
@@ -1333,6 +1336,10 @@ dissect_obdii_response(tvbuff_t *tvb, struct obdii_packet_info *oinfo, proto_tre
 {
 	col_append_fstr(oinfo->pinfo->cinfo, COL_INFO, "Response[%.3x] %s ", oinfo->can_id, val_to_str(oinfo->mode, obdii_mode_vals, "Unknown (%.2x)"));
 
+	if (oinfo->mode == 0x04 && oinfo->data_bytes == 0x01) {
+		return tvb_captured_length(tvb);
+	}
+
 	oinfo->value_bytes = oinfo->data_bytes - OBDII_VAL_OFF;
 
 	if (oinfo->value_bytes >= 1) oinfo->valueA = tvb_get_guint8(tvb, OBDII_VAL_OFF);
@@ -1357,7 +1364,7 @@ dissect_obdii_response(tvbuff_t *tvb, struct obdii_packet_info *oinfo, proto_tre
 }
 
 static int
-dissect_obdii(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+dissect_obdii_iso15765(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
 	iso15765_info_t iso15765_info;
 	guint32         can_id_only;
@@ -1417,7 +1424,7 @@ dissect_obdii(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 
 	if (id_is_response)
 	{
-		if (data_bytes < 2)
+		if (mode != 0x44 && data_bytes < 2)
 			return 0;
 		if (mode < 0x40)
 			return 0;
@@ -1452,9 +1459,52 @@ dissect_obdii(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 }
 
 static int
+dissect_obdii_uds(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+{
+    struct obdii_packet_info  oinfo;
+
+    proto_tree               *obdii_tree;
+    proto_item               *ti;
+
+    guint8                    data_bytes;
+    guint8                    mode;
+    gboolean                  response;
+
+    data_bytes = tvb_reported_length(tvb);
+    mode = tvb_get_guint8(tvb, OBDII_MODE_POS);
+    response = (mode & 0x40) == 0x40;
+    mode = mode & 0xbf;
+
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "OBD-II");
+    col_clear(pinfo->cinfo, COL_INFO);
+
+    ti = proto_tree_add_item(tree, proto_obdii, tvb, 0, -1, ENC_NA);
+    obdii_tree = proto_item_add_subtree(ti, ett_obdii);
+
+    proto_tree_add_uint(obdii_tree, hf_obdii_mode, tvb, OBDII_MODE_POS, 1, mode);
+
+    memset(&oinfo, 0, sizeof(oinfo));
+    oinfo.pinfo = pinfo;
+    oinfo.can_id = 0;
+    oinfo.data_bytes = data_bytes;
+    oinfo.mode = mode;
+
+    if (!response) {
+        return dissect_obdii_query(tvb, &oinfo, obdii_tree);
+    } else {
+        return dissect_obdii_response(tvb, &oinfo, obdii_tree);
+    }
+
+    /* never here */
+    DISSECTOR_ASSERT_NOT_REACHED();
+
+    return tvb_captured_length(tvb);
+}
+
+static bool
 dissect_obdii_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
-    return dissect_obdii(tvb, pinfo, tree, data) != 0;
+    return dissect_obdii_iso15765(tvb, pinfo, tree, data) != 0;
 }
 
 void
@@ -1700,15 +1750,14 @@ proto_register_obdii(void)
 
 	expert_obdii = expert_register_protocol(proto_obdii);
 	expert_register_field_array(expert_obdii, obdii_ei, array_length(obdii_ei));
+
+	obdii_handle = register_dissector("obd-ii", dissect_obdii_iso15765, proto_obdii);
+	register_dissector("obd-ii-uds", dissect_obdii_uds, proto_obdii);
 }
 
 void
 proto_reg_handoff_obdii(void)
 {
-	dissector_handle_t obdii_handle;
-
-	obdii_handle = create_dissector_handle(dissect_obdii, proto_obdii);
-
 	dissector_add_for_decode_as("iso15765.subdissector", obdii_handle);
 
 	/* heuristics default off since these standardized IDs might be reused outside automotive systems */
