@@ -295,66 +295,67 @@ static const char *immediate_str = "Immediate";
 static const char *bundle_str = "#bundle";
 
 /* Initialize the protocol and registered fields */
-static dissector_handle_t osc_udp_handle = NULL;
+static dissector_handle_t osc_udp_handle;
+static dissector_handle_t osc_tcp_handle;
 
-static int proto_osc = -1;
+static int proto_osc;
 
-static int hf_osc_bundle_type = -1;
-static int hf_osc_message_type = -1;
-static int hf_osc_message_header_type = -1;
-static int hf_osc_message_blob_type = -1;
-static int hf_osc_message_midi_type = -1;
-static int hf_osc_message_rgba_type = -1;
+static int hf_osc_bundle_type;
+static int hf_osc_message_type;
+static int hf_osc_message_header_type;
+static int hf_osc_message_blob_type;
+static int hf_osc_message_midi_type;
+static int hf_osc_message_rgba_type;
 
-static int hf_osc_bundle_timetag_type = -1;
-static int hf_osc_bundle_element_size_type = -1;
+static int hf_osc_bundle_timetag_type;
+static int hf_osc_bundle_element_size_type;
 
-static int hf_osc_message_path_type = -1;
-static int hf_osc_message_format_type = -1;
+static int hf_osc_message_path_type;
+static int hf_osc_message_format_type;
 
-static int hf_osc_message_int32_type = -1;
-static int hf_osc_message_float_type = -1;
-static int hf_osc_message_string_type = -1;
-static int hf_osc_message_blob_size_type = -1;
-static int hf_osc_message_blob_data_type = -1;
+static int hf_osc_message_int32_type;
+static int hf_osc_message_float_type;
+static int hf_osc_message_string_type;
+static int hf_osc_message_blob_size_type;
+static int hf_osc_message_blob_data_type;
 
-static int hf_osc_message_true_type = -1;
-static int hf_osc_message_false_type = -1;
-static int hf_osc_message_nil_type = -1;
-static int hf_osc_message_bang_type = -1;
+static int hf_osc_message_true_type;
+static int hf_osc_message_false_type;
+static int hf_osc_message_nil_type;
+static int hf_osc_message_bang_type;
 
-static int hf_osc_message_int64_type = -1;
-static int hf_osc_message_double_type = -1;
-static int hf_osc_message_timetag_type = -1;
+static int hf_osc_message_int64_type;
+static int hf_osc_message_double_type;
+static int hf_osc_message_timetag_type;
 
-static int hf_osc_message_symbol_type = -1;
-static int hf_osc_message_char_type = -1;
+static int hf_osc_message_symbol_type;
+static int hf_osc_message_char_type;
 
-static int hf_osc_message_rgba_red_type = -1;
-static int hf_osc_message_rgba_green_type = -1;
-static int hf_osc_message_rgba_blue_type = -1;
-static int hf_osc_message_rgba_alpha_type = -1;
+static int hf_osc_message_rgba_red_type;
+static int hf_osc_message_rgba_green_type;
+static int hf_osc_message_rgba_blue_type;
+static int hf_osc_message_rgba_alpha_type;
 
-static int hf_osc_message_midi_port_type = -1;
-static int hf_osc_message_midi_system_type = -1;
-static int hf_osc_message_midi_channel_type = -1;
-static int hf_osc_message_midi_status_type = -1;
-static int hf_osc_message_midi_data1_type = -1;
-static int hf_osc_message_midi_data2_type = -1;
-static int hf_osc_message_midi_velocity_type = -1;
-static int hf_osc_message_midi_pressure_type = -1;
-static int hf_osc_message_midi_note_type = -1;
-static int hf_osc_message_midi_controller_type = -1;
-static int hf_osc_message_midi_bender_type = -1;
+static int hf_osc_message_midi_port_type;
+static int hf_osc_message_midi_system_type;
+static int hf_osc_message_midi_channel_type;
+static int hf_osc_message_midi_status_type;
+static int hf_osc_message_midi_data1_type;
+static int hf_osc_message_midi_data2_type;
+static int hf_osc_message_midi_velocity_type;
+static int hf_osc_message_midi_pressure_type;
+static int hf_osc_message_midi_note_type;
+static int hf_osc_message_midi_controller_type;
+static int hf_osc_message_midi_bender_type;
 
 /* Initialize the subtree pointers */
-static int ett_osc_packet = -1;
-static int ett_osc_bundle = -1;
-static int ett_osc_message = -1;
-static int ett_osc_message_header = -1;
-static int ett_osc_blob = -1;
-static int ett_osc_rgba = -1;
-static int ett_osc_midi = -1;
+static int ett_osc_packet;
+static int ett_osc_bundle;
+static int ett_osc_message;
+static int ett_osc_message_header;
+static int ett_osc_blob;
+static int ett_osc_rgba;
+static int ett_osc_midi;
 
 /* check for valid path string */
 static gboolean
@@ -384,7 +385,7 @@ is_valid_format(const char *format)
 
 /* Dissect OSC message */
 static int
-dissect_osc_message(tvbuff_t *tvb, proto_item *ti, proto_tree *osc_tree, gint offset, gint len)
+dissect_osc_message(tvbuff_t *tvb, packet_info *pinfo, proto_item *ti, proto_tree *osc_tree, gint offset, gint len)
 {
     proto_tree  *message_tree;
     proto_tree  *header_tree;
@@ -401,7 +402,7 @@ dissect_osc_message(tvbuff_t *tvb, proto_item *ti, proto_tree *osc_tree, gint of
 
     /* peek/read path */
     path_offset = offset;
-    path = tvb_get_const_stringz(tvb, path_offset, &path_len);
+    path = tvb_get_stringz_enc(pinfo->pool, tvb, path_offset, &path_len, ENC_ASCII);
     if( (rem = path_len%4) ) path_len += 4-rem;
 
     if(!is_valid_path(path))
@@ -409,7 +410,7 @@ dissect_osc_message(tvbuff_t *tvb, proto_item *ti, proto_tree *osc_tree, gint of
 
     /* peek/read fmt */
     format_offset = path_offset + path_len;
-    format = tvb_get_const_stringz(tvb, format_offset, &format_len);
+    format = tvb_get_stringz_enc(pinfo->pool, tvb, format_offset, &format_len, ENC_ASCII);
     if( (rem = format_len%4) ) format_len += 4-rem;
 
     if(!is_valid_format(format))
@@ -724,7 +725,8 @@ dissect_osc_message(tvbuff_t *tvb, proto_item *ti, proto_tree *osc_tree, gint of
 
 /* Dissect OSC bundle */
 static int
-dissect_osc_bundle(tvbuff_t *tvb, proto_item *ti, proto_tree *osc_tree, gint offset, gint len)
+// NOLINTNEXTLINE(misc-no-recursion)
+dissect_osc_bundle(tvbuff_t *tvb, packet_info *pinfo, proto_item *ti, proto_tree *osc_tree, gint offset, gint len)
 {
     proto_tree  *bundle_tree;
     gint         end = offset + len;
@@ -767,21 +769,23 @@ dissect_osc_bundle(tvbuff_t *tvb, proto_item *ti, proto_tree *osc_tree, gint off
             continue;
 
         /* peek first bundle element char */
+        increment_dissection_depth(pinfo);
         switch(tvb_get_guint8(tvb, offset))
         {
             case '#': /* this is a bundle */
-                if(dissect_osc_bundle(tvb, ti, bundle_tree, offset, size))
+                if(dissect_osc_bundle(tvb, pinfo, ti, bundle_tree, offset, size))
                     return -1;
                 else
                     break;
             case '/': /* this is a message */
-                if(dissect_osc_message(tvb, ti, bundle_tree, offset, size))
+                if(dissect_osc_message(tvb, pinfo, ti, bundle_tree, offset, size))
                     return -1;
                 else
                     break;
             default:
                 return -1; /* neither message nor bundle */
         }
+        decrement_dissection_depth(pinfo);
 
         /* check for integer overflow */
         if(size > G_MAXINT - offset)
@@ -816,12 +820,12 @@ dissect_osc_pdu_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
         switch(tvb_get_guint8(tvb, offset))
         {
             case '#': /* this is a bundle */
-                if(dissect_osc_bundle(tvb, ti, osc_tree, offset, len))
+                if(dissect_osc_bundle(tvb, pinfo, ti, osc_tree, offset, len))
                     return;
                 else
                     break;
             case '/': /* this is a message */
-                if(dissect_osc_message(tvb, ti, osc_tree, offset, len))
+                if(dissect_osc_message(tvb, pinfo, ti, osc_tree, offset, len))
                     return;
                 else
                     break;
@@ -1028,13 +1032,13 @@ dissect_osc_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 }
 
 /* UDP Heuristic */
-static gboolean
+static bool
 dissect_osc_heur_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     conversation_t *conversation;
 
     if(tvb_captured_length(tvb) < 8)
-        return FALSE;
+        return false;
 
     /* peek first string */
     if(tvb_strneql(tvb, 0, bundle_str, 8) != 0) /* no OSC bundle */
@@ -1042,35 +1046,34 @@ dissect_osc_heur_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *
         gint               offset = 0;
         gint               slen;
         gint               rem;
-        const gchar       *str;
-        volatile gboolean  valid  = FALSE;
+        volatile bool      valid  = false;
 
         /* Check for valid path */
         /* Don't propagate any exceptions upwards during heuristics check  */
         /* XXX: this check is a bit expensive; Consider: use UDP port pref ? */
         TRY {
-            str = tvb_get_const_stringz(tvb, offset, &slen);
-            if(is_valid_path(str)) {
+            slen = tvb_strsize(tvb, offset);
+            if(is_valid_path(tvb_get_ptr(tvb, offset, slen))) {
 
                 /* skip path */
                 if( (rem = slen%4) ) slen += 4-rem;
                 offset += slen;
 
                 /* peek next string */
-                str = tvb_get_const_stringz(tvb, offset, &slen);
+                slen = tvb_strsize(tvb, offset);
 
                 /* check for valid format */
-                if(is_valid_format(str))
-                    valid = TRUE;
+                if(is_valid_format(tvb_get_ptr(tvb, offset, slen)))
+                    valid = true;
             }
         }
         CATCH_ALL {
-            valid = FALSE;
+            valid = false;
         }
         ENDTRY;
 
         if(! valid)
-            return FALSE;
+            return false;
     }
 
     /* if we get here, then it's an Open Sound Control packet (bundle or message) */
@@ -1082,7 +1085,7 @@ dissect_osc_heur_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *
     /* do the dissection */
     dissect_osc_udp(tvb, pinfo, tree, data);
 
-    return TRUE; /* OSC heuristics was matched */
+    return true; /* OSC heuristics was matched */
 }
 
 /* Register the protocol with Wireshark */
@@ -1272,18 +1275,16 @@ proto_register_osc(void)
 
     proto_register_field_array(proto_osc, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+
+    osc_tcp_handle = register_dissector("osc.tcp", dissect_osc_tcp, proto_osc);
+    osc_udp_handle = register_dissector("osc.udp", dissect_osc_udp, proto_osc);
 }
 
 void
 proto_reg_handoff_osc(void)
 {
-    dissector_handle_t osc_tcp_handle;
-
-    osc_tcp_handle = create_dissector_handle(dissect_osc_tcp, proto_osc);
-
     /* XXX: Add port pref and  "decode as" for UDP ? */
     /*      (The UDP heuristic is a bit expensive    */
-    osc_udp_handle = create_dissector_handle(dissect_osc_udp, proto_osc);
     /* register as heuristic dissector for UDP connections */
     heur_dissector_add("udp", dissect_osc_heur_udp, "Open Sound Control over UDP", "osc_udp", proto_osc, HEURISTIC_DISABLE);
 
