@@ -45,30 +45,30 @@ void proto_reg_handoff_oscore(void);
 void proto_register_oscore(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_oscore                             = -1;
-static int proto_coap                               = -1;
+static int proto_oscore;
+static int proto_coap;
 
-static int hf_oscore_tag                            = -1;
+static int hf_oscore_tag;
 
 static COAP_COMMON_LIST_T(dissect_oscore_hf);
 
-static expert_field ei_oscore_partial_iv_not_found    = EI_INIT;
-static expert_field ei_oscore_context_not_set         = EI_INIT;
-static expert_field ei_oscore_message_too_small       = EI_INIT;
-static expert_field ei_oscore_truncated               = EI_INIT;
-static expert_field ei_oscore_tag_check_failed        = EI_INIT;
-static expert_field ei_oscore_decrypt_error           = EI_INIT;
-static expert_field ei_oscore_cbc_mac_failed          = EI_INIT;
-static expert_field ei_oscore_piv_len_invalid         = EI_INIT;
-static expert_field ei_oscore_info_fetch_failed       = EI_INIT;
+static expert_field ei_oscore_partial_iv_not_found;
+static expert_field ei_oscore_context_not_set;
+static expert_field ei_oscore_message_too_small;
+static expert_field ei_oscore_truncated;
+static expert_field ei_oscore_tag_check_failed;
+static expert_field ei_oscore_decrypt_error;
+static expert_field ei_oscore_cbc_mac_failed;
+static expert_field ei_oscore_piv_len_invalid;
+static expert_field ei_oscore_info_fetch_failed;
 
 /* Initialize the subtree pointers */
-static gint ett_oscore                                = -1;
+static gint ett_oscore;
 
 /* UAT variables */
-static uat_t            *oscore_context_uat = NULL;
-static oscore_context_t *oscore_contexts = NULL;
-static guint            num_oscore_contexts = 0;
+static uat_t            *oscore_context_uat;
+static oscore_context_t *oscore_contexts;
+static guint            num_oscore_contexts;
 
 /* Enumeration for COSE algorithms used by OSCORE */
 static const value_string oscore_context_alg_vals[] = {
