@@ -171,102 +171,102 @@ static const value_string nbraddrtype_vals[] = {
   { 3, "ROUTABLE_ORIG"                  },
   { 0, NULL                             }};
 
-static int proto_packetbb = -1;
+static int proto_packetbb;
 
 #define PACKETBB_PORT 269 /* Not IANA registered */
 
-static int hf_packetbb_header = -1;
-static int hf_packetbb_version = -1;
-static int hf_packetbb_header_flags = -1;
-static int hf_packetbb_header_flags_phasseqnum = -1;
-static int hf_packetbb_header_flags_phastlv = -1;
-static int hf_packetbb_seqnr = -1;
-static int hf_packetbb_msg = -1;
-static int hf_packetbb_msgheader = -1;
-static int hf_packetbb_msgheader_type = -1;
-static int hf_packetbb_msgheader_flags = -1;
-static int hf_packetbb_msgheader_flags_mhasorig = -1;
-static int hf_packetbb_msgheader_flags_mhashoplimit = -1;
-static int hf_packetbb_msgheader_flags_mhashopcount = -1;
-static int hf_packetbb_msgheader_flags_mhasseqnr = -1;
-static int hf_packetbb_msgheader_addresssize = -1;
-static int hf_packetbb_msgheader_size = -1;
-static int hf_packetbb_msgheader_origaddripv4 = -1;
-static int hf_packetbb_msgheader_origaddripv6 = -1;
-static int hf_packetbb_msgheader_origaddrmac = -1;
-static int hf_packetbb_msgheader_origaddrcustom = -1;
-static int hf_packetbb_msgheader_hoplimit = -1;
-static int hf_packetbb_msgheader_hopcount = -1;
-static int hf_packetbb_msgheader_seqnr = -1;
-static int hf_packetbb_addr = -1;
-static int hf_packetbb_addr_num = -1;
-static int hf_packetbb_addr_flags = -1;
-static int hf_packetbb_addr_flags_hashead = -1;
-static int hf_packetbb_addr_flags_hasfulltail = -1;
-static int hf_packetbb_addr_flags_haszerotail = -1;
-static int hf_packetbb_addr_flags_hassingleprelen = -1;
-static int hf_packetbb_addr_flags_hasmultiprelen = -1;
-static int hf_packetbb_addr_head = -1;
-static int hf_packetbb_addr_tail = -1;
-static int hf_packetbb_addr_value[4] = { -1, -1, -1, -1 };
-static int hf_packetbb_addr_value_mid = -1;
-static int hf_packetbb_addr_value_prefix = -1;
-static int hf_packetbb_tlvblock = -1;
-static int hf_packetbb_tlvblock_length = -1;
-static int hf_packetbb_tlv = -1;
-static int hf_packetbb_pkttlv_type = -1;
-static int hf_packetbb_msgtlv_type = -1;
-static int hf_packetbb_addrtlv_type = -1;
-static int hf_packetbb_tlv_flags = -1;
-static int hf_packetbb_tlv_flags_hastypext = -1;
-static int hf_packetbb_tlv_flags_hassingleindex = -1;
-static int hf_packetbb_tlv_flags_hasmultiindex = -1;
-static int hf_packetbb_tlv_flags_hasvalue = -1;
-static int hf_packetbb_tlv_flags_hasextlen = -1;
-static int hf_packetbb_tlv_flags_hasmultivalue = -1;
-static int hf_packetbb_tlv_typeext = -1;
-static int hf_packetbb_tlv_indexstart = -1;
-static int hf_packetbb_tlv_indexend = -1;
-static int hf_packetbb_tlv_length = -1;
-static int hf_packetbb_tlv_value = -1;
-static int hf_packetbb_tlv_multivalue = -1;
-static int hf_packetbb_tlv_intervaltime = -1;
-static int hf_packetbb_tlv_validitytime = -1;
-static int hf_packetbb_tlv_localifs = -1;
-static int hf_packetbb_tlv_linkstatus = -1;
-static int hf_packetbb_tlv_otherneigh = -1;
-static int hf_packetbb_tlv_icv = -1;
-static int hf_packetbb_tlv_timestamp = -1;
-static int hf_packetbb_tlv_linkmetric_flags_linkin = -1;
-static int hf_packetbb_tlv_linkmetric_flags_linkout = -1;
-static int hf_packetbb_tlv_linkmetric_flags_neighin = -1;
-static int hf_packetbb_tlv_linkmetric_flags_neighout = -1;
-static int hf_packetbb_tlv_linkmetric_value = -1;
-static int hf_packetbb_tlv_mpr = -1;
-static int hf_packetbb_tlv_nbraddrtype = -1;
-static int hf_packetbb_tlv_gateway = -1;
-static int hf_packetbb_tlv_mprwillingness = -1;
-static int hf_packetbb_tlv_mprwillingness_flooding = -1;
-static int hf_packetbb_tlv_mprwillingness_routing = -1;
-static int hf_packetbb_tlv_contseqnum = -1;
+static int hf_packetbb_header;
+static int hf_packetbb_version;
+static int hf_packetbb_header_flags;
+static int hf_packetbb_header_flags_phasseqnum;
+static int hf_packetbb_header_flags_phastlv;
+static int hf_packetbb_seqnr;
+static int hf_packetbb_msg;
+static int hf_packetbb_msgheader;
+static int hf_packetbb_msgheader_type;
+static int hf_packetbb_msgheader_flags;
+static int hf_packetbb_msgheader_flags_mhasorig;
+static int hf_packetbb_msgheader_flags_mhashoplimit;
+static int hf_packetbb_msgheader_flags_mhashopcount;
+static int hf_packetbb_msgheader_flags_mhasseqnr;
+static int hf_packetbb_msgheader_addresssize;
+static int hf_packetbb_msgheader_size;
+static int hf_packetbb_msgheader_origaddripv4;
+static int hf_packetbb_msgheader_origaddripv6;
+static int hf_packetbb_msgheader_origaddrmac;
+static int hf_packetbb_msgheader_origaddrcustom;
+static int hf_packetbb_msgheader_hoplimit;
+static int hf_packetbb_msgheader_hopcount;
+static int hf_packetbb_msgheader_seqnr;
+static int hf_packetbb_addr;
+static int hf_packetbb_addr_num;
+static int hf_packetbb_addr_flags;
+static int hf_packetbb_addr_flags_hashead;
+static int hf_packetbb_addr_flags_hasfulltail;
+static int hf_packetbb_addr_flags_haszerotail;
+static int hf_packetbb_addr_flags_hassingleprelen;
+static int hf_packetbb_addr_flags_hasmultiprelen;
+static int hf_packetbb_addr_head;
+static int hf_packetbb_addr_tail;
+static int hf_packetbb_addr_value[4];
+static int hf_packetbb_addr_value_mid;
+static int hf_packetbb_addr_value_prefix;
+static int hf_packetbb_tlvblock;
+static int hf_packetbb_tlvblock_length;
+static int hf_packetbb_tlv;
+static int hf_packetbb_pkttlv_type;
+static int hf_packetbb_msgtlv_type;
+static int hf_packetbb_addrtlv_type;
+static int hf_packetbb_tlv_flags;
+static int hf_packetbb_tlv_flags_hastypext;
+static int hf_packetbb_tlv_flags_hassingleindex;
+static int hf_packetbb_tlv_flags_hasmultiindex;
+static int hf_packetbb_tlv_flags_hasvalue;
+static int hf_packetbb_tlv_flags_hasextlen;
+static int hf_packetbb_tlv_flags_hasmultivalue;
+static int hf_packetbb_tlv_typeext;
+static int hf_packetbb_tlv_indexstart;
+static int hf_packetbb_tlv_indexend;
+static int hf_packetbb_tlv_length;
+static int hf_packetbb_tlv_value;
+static int hf_packetbb_tlv_multivalue;
+static int hf_packetbb_tlv_intervaltime;
+static int hf_packetbb_tlv_validitytime;
+static int hf_packetbb_tlv_localifs;
+static int hf_packetbb_tlv_linkstatus;
+static int hf_packetbb_tlv_otherneigh;
+static int hf_packetbb_tlv_icv;
+static int hf_packetbb_tlv_timestamp;
+static int hf_packetbb_tlv_linkmetric_flags_linkin;
+static int hf_packetbb_tlv_linkmetric_flags_linkout;
+static int hf_packetbb_tlv_linkmetric_flags_neighin;
+static int hf_packetbb_tlv_linkmetric_flags_neighout;
+static int hf_packetbb_tlv_linkmetric_value;
+static int hf_packetbb_tlv_mpr;
+static int hf_packetbb_tlv_nbraddrtype;
+static int hf_packetbb_tlv_gateway;
+static int hf_packetbb_tlv_mprwillingness;
+static int hf_packetbb_tlv_mprwillingness_flooding;
+static int hf_packetbb_tlv_mprwillingness_routing;
+static int hf_packetbb_tlv_contseqnum;
 
-static gint ett_packetbb = -1;
-static gint ett_packetbb_header = -1;
-static gint ett_packetbb_header_flags = -1;
+static gint ett_packetbb;
+static gint ett_packetbb_header;
+static gint ett_packetbb_header_flags;
 static gint ett_packetbb_msg[PACKETBB_MSG_TLV_LENGTH];
-static gint ett_packetbb_msgheader = -1;
-static gint ett_packetbb_msgheader_flags = -1;
-static gint ett_packetbb_addr = -1;
-static gint ett_packetbb_addr_flags = -1;
-static gint ett_packetbb_addr_value = -1;
-static gint ett_packetbb_tlvblock = -1;
+static gint ett_packetbb_msgheader;
+static gint ett_packetbb_msgheader_flags;
+static gint ett_packetbb_addr;
+static gint ett_packetbb_addr_flags;
+static gint ett_packetbb_addr_value;
+static gint ett_packetbb_tlvblock;
 static gint ett_packetbb_tlv[PACKETBB_MSG_TLV_LENGTH];
-static gint ett_packetbb_tlv_flags = -1;
-static gint ett_packetbb_tlv_value = -1;
-static gint ett_packetbb_tlv_mprwillingness = -1;
-static gint ett_packetbb_tlv_linkmetric = -1;
+static gint ett_packetbb_tlv_flags;
+static gint ett_packetbb_tlv_value;
+static gint ett_packetbb_tlv_mprwillingness;
+static gint ett_packetbb_tlv_linkmetric;
 
-static expert_field ei_packetbb_error = EI_INIT;
+static expert_field ei_packetbb_error;
 
 /* Link metric of RFC7181 */
 static guint32 uncompress_metric(guint16 val16) {
@@ -408,11 +408,6 @@ static int dissect_pbb_tlvblock(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
     tlvType = tvb_get_guint8(tvb, offset++);
     tlvFlags = tvb_get_guint8(tvb, offset++);
 
-    if ((tlvFlags & TLV_HAS_TYPEEXT) != 0) {
-      /* skip over ext-type */
-      offset++;
-    }
-
     indexStart = 0;
     indexEnd = addrCount ? (addrCount - 1) : 0;
 
@@ -426,8 +421,7 @@ static int dissect_pbb_tlvblock(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 
     if ((tlvFlags & TLV_HAS_VALUE) != 0) {
       if ((tlvFlags & TLV_HAS_EXTLEN) != 0) {
-        length = tvb_get_ntohs(tvb, offset);
-        offset += 2;
+        length = tvb_get_ntohs(tvb, offset++);
       }
       else {
         length = tvb_get_guint8(tvb, offset++);
@@ -1390,9 +1384,6 @@ void proto_register_packetbb(void) {
   memcpy(ett, ett_base, sizeof(ett_base));
   j = array_length(ett_base);
   for (i=0; i<PACKETBB_MSG_TLV_LENGTH; i++) {
-    ett_packetbb_msg[i] = -1;
-    ett_packetbb_tlv[i] = -1;
-
     ett[j++] = &ett_packetbb_msg[i];
     ett[j++] = &ett_packetbb_tlv[i];
   }
