@@ -21,6 +21,8 @@
 void proto_register_pana(void);
 void proto_reg_handoff_pana(void);
 
+static dissector_handle_t pana_handle;
+
 #if 0
 #define PANA_UDP_PORT 3001
 #endif
@@ -70,37 +72,37 @@ void proto_reg_handoff_pana(void);
 static dissector_handle_t eap_handle;
 
 /* Initialize the protocol and registered fields */
-static int proto_pana = -1;
-static int hf_pana_reserved_type = -1;
-static int hf_pana_length_type = -1;
-static int hf_pana_msg_type = -1;
-static int hf_pana_session_id = -1;
-static int hf_pana_seqnumber = -1;
-static int hf_pana_response_in = -1;
-static int hf_pana_response_to = -1;
-static int hf_pana_response_time = -1;
+static int proto_pana;
+static int hf_pana_reserved_type;
+static int hf_pana_length_type;
+static int hf_pana_msg_type;
+static int hf_pana_session_id;
+static int hf_pana_seqnumber;
+static int hf_pana_response_in;
+static int hf_pana_response_to;
+static int hf_pana_response_time;
 
-static int hf_pana_flags = -1;
-static int hf_pana_flag_r = -1;
-static int hf_pana_flag_s = -1;
-static int hf_pana_flag_c = -1;
-static int hf_pana_flag_a = -1;
-static int hf_pana_flag_p = -1;
-static int hf_pana_flag_i = -1;
-static int hf_pana_avp_code = -1;
-static int hf_pana_avp_data_length = -1;
-static int hf_pana_avp_flags = -1;
-static int hf_pana_avp_flag_v = -1;
-static int hf_pana_avp_reserved = -1;
-static int hf_pana_avp_vendorid = -1;
+static int hf_pana_flags;
+static int hf_pana_flag_r;
+static int hf_pana_flag_s;
+static int hf_pana_flag_c;
+static int hf_pana_flag_a;
+static int hf_pana_flag_p;
+static int hf_pana_flag_i;
+static int hf_pana_avp_code;
+static int hf_pana_avp_data_length;
+static int hf_pana_avp_flags;
+static int hf_pana_avp_flag_v;
+static int hf_pana_avp_reserved;
+static int hf_pana_avp_vendorid;
 
-static int hf_pana_avp_data_uint64 = -1;
-static int hf_pana_avp_data_int64 = -1;
-static int hf_pana_avp_data_uint32 = -1;
-static int hf_pana_avp_data_int32 = -1;
-static int hf_pana_avp_data_bytes = -1;
-static int hf_pana_avp_data_string = -1;
-static int hf_pana_avp_data_enumerated = -1;
+static int hf_pana_avp_data_uint64;
+static int hf_pana_avp_data_int64;
+static int hf_pana_avp_data_uint32;
+static int hf_pana_avp_data_int32;
+static int hf_pana_avp_data_bytes;
+static int hf_pana_avp_data_string;
+static int hf_pana_avp_data_enumerated;
 
 #define MSG_TYPE_MAX 5
 static const value_string msg_type_names[] = {
@@ -182,11 +184,11 @@ static const value_string avp_type_names[]={
 
 
 /* Initialize the subtree pointers */
-static gint ett_pana = -1;
-static gint ett_pana_flags = -1;
-static gint ett_pana_avp = -1;
-static gint ett_pana_avp_info = -1;
-static gint ett_pana_avp_flags = -1;
+static gint ett_pana;
+static gint ett_pana_flags;
+static gint ett_pana_avp;
+static gint ett_pana_avp_info;
+static gint ett_pana_avp_flags;
 
 
 typedef struct _pana_transaction_t {
@@ -372,7 +374,7 @@ dissect_avps(tvbuff_t *tvb, packet_info *pinfo, proto_tree *avp_tree)
                                 }
                                 case PANA_UTF8STRING: {
                                         proto_tree_add_item(single_avp_tree, hf_pana_avp_data_string, tvb,
-                                                                     offset, avp_data_length, ENC_UTF_8|ENC_NA);
+                                                                     offset, avp_data_length, ENC_UTF_8);
                                         break;
                                 }
                                 case PANA_OCTET_STRING: {
@@ -692,6 +694,11 @@ dissect_pana(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
 
 }
 
+static bool
+dissect_pana_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+{
+    return dissect_pana(tvb, pinfo, tree, data) != 0;
+}
 
 /*
  * Register the protocol with Wireshark
@@ -867,18 +874,16 @@ proto_register_pana(void)
         proto_register_field_array(proto_pana, hf, array_length(hf));
         proto_register_subtree_array(ett, array_length(ett));
 
+        /* Register the dissector handle */
+        pana_handle = register_dissector("pana", dissect_pana, proto_pana);
 }
 
 
 void
 proto_reg_handoff_pana(void)
 {
+        heur_dissector_add("udp", dissect_pana_heur, "PANA over UDP", "pana_udp", proto_pana, HEURISTIC_ENABLE);
 
-        dissector_handle_t pana_handle;
-
-        heur_dissector_add("udp", dissect_pana, "PANA over UDP", "pana_udp", proto_pana, HEURISTIC_ENABLE);
-
-        pana_handle = create_dissector_handle(dissect_pana, proto_pana);
         dissector_add_for_decode_as_with_preference("udp.port", pana_handle);
 
         eap_handle = find_dissector_add_dependency("eap", proto_pana);
