@@ -31,40 +31,42 @@
 void proto_reg_handoff_pathport(void);
 void proto_register_pathport(void);
 
+static dissector_handle_t pathport_handle;
+
 /* Initialize the protocol and registered fields */
-static int proto_pathport = -1;
+static int proto_pathport;
 
 /* Initialize the subtree pointers */
-static gint ett_pathport = -1;
-static gint ett_pp_pdu = -1;
-static gint ett_pp_tlv = -1;
-static gint ett_pp_data = -1;
+static gint ett_pathport;
+static gint ett_pp_pdu;
+static gint ett_pp_tlv;
+static gint ett_pp_data;
 
-static int hf_pp_prot = -1;
-static int hf_pp_reserved = -1;
-static int hf_pp_version = -1;
-static int hf_pp_seq = -1;
-static int hf_pp_src = -1;
-static int hf_pp_dst = -1;
-static int hf_pp_data_encoding = -1;
-static int hf_pp_data_len = -1;
-static int hf_pp_data_start_code = -1;
-static int hf_pp_data_dst = -1;
-static int hf_pp_data_levels = -1;
-static int hf_pp_arp_id = -1;
-static int hf_pp_arp_manuf = -1;
-static int hf_pp_arp_class = -1;
-static int hf_pp_arp_type = -1;
-static int hf_pp_arp_numdmx = -1;
-static int hf_pp_arp_ip = -1;
-static int hf_pp_get_type = -1;
-static int hf_pp_pdu_type = -1;
-static int hf_pp_pdu_len = -1;
-static int hf_pp_pdu_payload = -1;
-static int hf_pp_pid_type = -1;
-static int hf_pp_pid_len = -1;
-static int hf_pp_pid_value = -1;
-static int hf_pp_pid_pad_bytes = -1;
+static int hf_pp_prot;
+static int hf_pp_reserved;
+static int hf_pp_version;
+static int hf_pp_seq;
+static int hf_pp_src;
+static int hf_pp_dst;
+static int hf_pp_data_encoding;
+static int hf_pp_data_len;
+static int hf_pp_data_start_code;
+static int hf_pp_data_dst;
+static int hf_pp_data_levels;
+static int hf_pp_arp_id;
+static int hf_pp_arp_manuf;
+static int hf_pp_arp_class;
+static int hf_pp_arp_type;
+static int hf_pp_arp_numdmx;
+static int hf_pp_arp_ip;
+static int hf_pp_get_type;
+static int hf_pp_pdu_type;
+static int hf_pp_pdu_len;
+static int hf_pp_pdu_payload;
+static int hf_pp_pid_type;
+static int hf_pp_pid_len;
+static int hf_pp_pid_value;
+static int hf_pp_pid_pad_bytes;
 
 /* Begin field and constant declarations */
 #define PP_ID_BCAST        0xffffffff
@@ -609,14 +611,14 @@ dissect_pathport(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     return dissect_pathport_common(tvb, pinfo, tree);
 }
 
-static gboolean
+static bool
 dissect_pathport_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
    if(!packet_is_pathport(tvb))
-        return FALSE;
+        return false;
 
     dissect_pathport_common(tvb, pinfo, tree);
-    return (TRUE);
+    return true;
 }
 
 /* Register the protocol with Wireshark.
@@ -658,7 +660,7 @@ proto_register_pathport(void)
         {&hf_pp_arp_class,          {"Device Class", "pathport.arp.class", FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
         {&hf_pp_arp_type,           {"Device Type", "pathport.arp.type", FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
         {&hf_pp_arp_numdmx,         {"Subcomponents", "pathport.arp.numdmx", FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }},
-        {&hf_pp_arp_ip,             {"IP", "pathport.arp.ip", FT_IPv4, 0, NULL, 0x0, NULL, HFILL }}
+        {&hf_pp_arp_ip,             {"IP", "pathport.arp.ip", FT_IPv4, BASE_NONE, NULL, 0x0, NULL, HFILL }}
     };
 
     /* Setup protocol subtree array */
@@ -675,14 +677,14 @@ proto_register_pathport(void)
     /* Required function calls to register the header fields and subtrees */
     proto_register_field_array(proto_pathport, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+
+    /* Register the dissector handle */
+    pathport_handle = register_dissector("pathport", dissect_pathport, proto_pathport);
 }
 
 void
 proto_reg_handoff_pathport(void)
 {
-    static dissector_handle_t pathport_handle;
-
-    pathport_handle = create_dissector_handle(dissect_pathport, proto_pathport);
     heur_dissector_add("udp", dissect_pathport_heur, "Pathport over UDP", "pathport_udp", proto_pathport, HEURISTIC_ENABLE);
     dissector_add_uint_with_preference("udp.port", PATHPORT_UDP_PORT, pathport_handle);
 }
