@@ -23,16 +23,16 @@
 void proto_register_pcap_pktdata(void);
 void proto_reg_handoff_pcap_pktdata(void);
 
-static int proto_pcap_pktdata = -1;
+static int proto_pcap_pktdata;
 
-static int hf_pcap_pktdata_pseudoheader = -1;
-static int hf_pcap_pktdata_pseudoheader_bluetooth_direction = -1;
-static int hf_pcap_pktdata_undecoded_data = -1;
+static int hf_pcap_pktdata_pseudoheader;
+static int hf_pcap_pktdata_pseudoheader_bluetooth_direction;
+static int hf_pcap_pktdata_undecoded_data;
 
-static gint ett_pcap_pktdata_pseudoheader = -1;
+static gint ett_pcap_pktdata_pseudoheader;
 
-static expert_field ei_pcap_pktdata_linktype_unknown = EI_INIT;
-static expert_field ei_pcap_pktdata_cant_generate_phdr = EI_INIT;
+static expert_field ei_pcap_pktdata_linktype_unknown;
+static expert_field ei_pcap_pktdata_cant_generate_phdr;
 
 static dissector_table_t wtap_encap_table;
 
@@ -170,7 +170,7 @@ const value_string link_type_vals[] = {
     { 205,  "C_HDLC_WITH_DIR" },
     { 206,  "FRELAY_WITH_DIR" },
     { 207,  "LAPB_WITH_DIR" },          /* LAPB with direction pseudo-header */
-    { 209,  "IPMB_LINUX" },
+    { 209,  "I2C_LINUX" },
     { 210,  "FLEXRAY" },                /* FlexRay automotive bus */
     { 211,  "MOST" },                   /* Media Oriented Systems Transport */
     { 212,  "LIN" },                    /* Local Interconnect Network */
@@ -245,6 +245,23 @@ const value_string link_type_vals[] = {
     { 281,  "DSA_TAG_BRCM" },
     { 282,  "DSA_TAG_BRCM_PREPEND" },
     { 283,  "IEEE802_15_4_TAP" },
+    { 284,  "DSA_TAG_DSA" },
+    { 285,  "DSA_TAG_EDSA" },
+    { 286,  "ELEE" },
+    { 288,  "USB_2_0" },
+    { 289,  "ATSC_ALP" },
+    { 290,  "ETW" },
+    { 291,  "NETANALYZER_NG" },
+    { 292,  "ZBOSS_NCP" },
+    { 293,  "USB_2_0_LOW_SPEED" },
+    { 294,  "USB_2_0_FULL_SPEED" },
+    { 295,  "USB_2_0_HIGH_SPEED" },
+    { 296,  "AUERSWALD_LOG" },
+    { 297,  "ZWAVE_TAP" },
+    { 298,  "SILABS_DEBUG_CHANNEL" },
+    { 299,  "FIRA_UCI" },
+    { 300,  "MDB" },
+    { 301,  "DECT_NR" },
     { 0, NULL }
 };
 
