@@ -56,10 +56,12 @@
 void proto_register_pgm(void);
 void proto_reg_handoff_pgm(void);
 
+static dissector_handle_t pgm_handle;
+
 /*
  * Flag to control whether to check the PGM checksum.
  */
-static gboolean pgm_check_checksum = TRUE;
+static bool pgm_check_checksum = true;
 
 /* constants for hdr types */
 #define PGM_SPM_PCKT  0x00
@@ -135,132 +137,132 @@ static gboolean pgm_check_checksum = TRUE;
 #define PGM_OPT_REDIRECT_SIZE 12
 #define PGM_OPT_FRAGMENT_SIZE 16
 
-static int proto_pgm = -1;
-static int ett_pgm = -1;
-static int ett_pgm_optbits = -1;
-static int ett_pgm_opts = -1;
-static int ett_pgm_spm = -1;
-static int ett_pgm_data = -1;
-static int ett_pgm_nak = -1;
-static int ett_pgm_poll = -1;
-static int ett_pgm_polr = -1;
-static int ett_pgm_ack = -1;
-static int ett_pgm_opts_join = -1;
-static int ett_pgm_opts_parityprm = -1;
-static int ett_pgm_opts_paritygrp = -1;
-static int ett_pgm_opts_naklist = -1;
-static int ett_pgm_opts_ccdata = -1;
-static int ett_pgm_opts_nak_bo_ivl = -1;
-static int ett_pgm_opts_nak_bo_rng = -1;
-static int ett_pgm_opts_redirect = -1;
-static int ett_pgm_opts_fragment = -1;
+static int proto_pgm;
+static int ett_pgm;
+static int ett_pgm_optbits;
+static int ett_pgm_opts;
+static int ett_pgm_spm;
+static int ett_pgm_data;
+static int ett_pgm_nak;
+static int ett_pgm_poll;
+static int ett_pgm_polr;
+static int ett_pgm_ack;
+static int ett_pgm_opts_join;
+static int ett_pgm_opts_parityprm;
+static int ett_pgm_opts_paritygrp;
+static int ett_pgm_opts_naklist;
+static int ett_pgm_opts_ccdata;
+static int ett_pgm_opts_nak_bo_ivl;
+static int ett_pgm_opts_nak_bo_rng;
+static int ett_pgm_opts_redirect;
+static int ett_pgm_opts_fragment;
 
-static int hf_pgm_main_sport = -1;
-static int hf_pgm_main_dport = -1;
-static int hf_pgm_port = -1;
-static int hf_pgm_main_type = -1;
-static int hf_pgm_main_opts = -1;
-static int hf_pgm_main_opts_opt = -1;
-static int hf_pgm_main_opts_netsig = -1;
-static int hf_pgm_main_opts_varlen = -1;
-static int hf_pgm_main_opts_parity = -1;
-static int hf_pgm_main_cksum = -1;
-static int hf_pgm_main_cksum_status = -1;
-static int hf_pgm_main_gsi = -1;
-static int hf_pgm_main_tsdulen = -1;
-static int hf_pgm_spm_sqn = -1;
-static int hf_pgm_spm_lead = -1;
-static int hf_pgm_spm_trail = -1;
-static int hf_pgm_spm_pathafi = -1;
-static int hf_pgm_spm_res = -1;
-static int hf_pgm_spm_path = -1;
-static int hf_pgm_spm_path6 = -1;
-/* static int hf_pgm_data_sqn = -1; */
-/* static int hf_pgm_data_trail = -1; */
-static int hf_pgm_nak_sqn = -1;
-static int hf_pgm_nak_srcafi = -1;
-static int hf_pgm_nak_srcres = -1;
-static int hf_pgm_nak_src = -1;
-static int hf_pgm_nak_src6 = -1;
-static int hf_pgm_nak_grpafi = -1;
-static int hf_pgm_nak_grpres = -1;
-static int hf_pgm_nak_grp = -1;
-static int hf_pgm_nak_grp6 = -1;
-static int hf_pgm_poll_sqn = -1;
-static int hf_pgm_poll_round = -1;
-static int hf_pgm_poll_subtype = -1;
-static int hf_pgm_poll_pathafi = -1;
-static int hf_pgm_poll_res = -1;
-static int hf_pgm_poll_path = -1;
-static int hf_pgm_poll_path6 = -1;
-static int hf_pgm_poll_backoff_ivl = -1;
-static int hf_pgm_poll_rand_str = -1;
-static int hf_pgm_poll_matching_bmask = -1;
-static int hf_pgm_polr_sqn = -1;
-static int hf_pgm_polr_round = -1;
-static int hf_pgm_polr_res = -1;
-static int hf_pgm_ack_sqn = -1;
-static int hf_pgm_ack_bitmap = -1;
+static int hf_pgm_main_sport;
+static int hf_pgm_main_dport;
+static int hf_pgm_port;
+static int hf_pgm_main_type;
+static int hf_pgm_main_opts;
+static int hf_pgm_main_opts_opt;
+static int hf_pgm_main_opts_netsig;
+static int hf_pgm_main_opts_varlen;
+static int hf_pgm_main_opts_parity;
+static int hf_pgm_main_cksum;
+static int hf_pgm_main_cksum_status;
+static int hf_pgm_main_gsi;
+static int hf_pgm_main_tsdulen;
+static int hf_pgm_spm_sqn;
+static int hf_pgm_spm_lead;
+static int hf_pgm_spm_trail;
+static int hf_pgm_spm_pathafi;
+static int hf_pgm_spm_res;
+static int hf_pgm_spm_path;
+static int hf_pgm_spm_path6;
+/* static int hf_pgm_data_sqn; */
+/* static int hf_pgm_data_trail; */
+static int hf_pgm_nak_sqn;
+static int hf_pgm_nak_srcafi;
+static int hf_pgm_nak_srcres;
+static int hf_pgm_nak_src;
+static int hf_pgm_nak_src6;
+static int hf_pgm_nak_grpafi;
+static int hf_pgm_nak_grpres;
+static int hf_pgm_nak_grp;
+static int hf_pgm_nak_grp6;
+static int hf_pgm_poll_sqn;
+static int hf_pgm_poll_round;
+static int hf_pgm_poll_subtype;
+static int hf_pgm_poll_pathafi;
+static int hf_pgm_poll_res;
+static int hf_pgm_poll_path;
+static int hf_pgm_poll_path6;
+static int hf_pgm_poll_backoff_ivl;
+static int hf_pgm_poll_rand_str;
+static int hf_pgm_poll_matching_bmask;
+static int hf_pgm_polr_sqn;
+static int hf_pgm_polr_round;
+static int hf_pgm_polr_res;
+static int hf_pgm_ack_sqn;
+static int hf_pgm_ack_bitmap;
 
-static int hf_pgm_opt_type = -1;
-static int hf_pgm_opt_len = -1;
-static int hf_pgm_opt_tlen = -1;
+static int hf_pgm_opt_type;
+static int hf_pgm_opt_len;
+static int hf_pgm_opt_tlen;
 
-static int hf_pgm_genopt_end = -1;
-static int hf_pgm_genopt_type = -1;
-static int hf_pgm_genopt_len = -1;
-static int hf_pgm_genopt_opx = -1;
+static int hf_pgm_genopt_end;
+static int hf_pgm_genopt_type;
+static int hf_pgm_genopt_len;
+static int hf_pgm_genopt_opx;
 
-static int hf_pgm_opt_join_res = -1;
-static int hf_pgm_opt_join_minjoin = -1;
+static int hf_pgm_opt_join_res;
+static int hf_pgm_opt_join_minjoin;
 
-static int hf_pgm_opt_parity_prm_po = -1;
-static int hf_pgm_opt_parity_prm_prmtgsz = -1;
+static int hf_pgm_opt_parity_prm_po;
+static int hf_pgm_opt_parity_prm_prmtgsz;
 
-static int hf_pgm_opt_parity_grp_res = -1;
-static int hf_pgm_opt_parity_grp_prmgrp = -1;
+static int hf_pgm_opt_parity_grp_res;
+static int hf_pgm_opt_parity_grp_prmgrp;
 
-static int hf_pgm_opt_nak_res = -1;
-static int hf_pgm_opt_nak_list = -1;
+static int hf_pgm_opt_nak_res;
+static int hf_pgm_opt_nak_list;
 
-static int hf_pgm_opt_ccdata_res = -1;
-static int hf_pgm_opt_ccdata_tsp = -1;
-static int hf_pgm_opt_ccdata_afi = -1;
-static int hf_pgm_opt_ccdata_res2 = -1;
-static int hf_pgm_opt_ccdata_acker = -1;
-static int hf_pgm_opt_ccdata_acker6 = -1;
+static int hf_pgm_opt_ccdata_res;
+static int hf_pgm_opt_ccdata_tsp;
+static int hf_pgm_opt_ccdata_afi;
+static int hf_pgm_opt_ccdata_res2;
+static int hf_pgm_opt_ccdata_acker;
+static int hf_pgm_opt_ccdata_acker6;
 
-static int hf_pgm_opt_ccfeedbk_res = -1;
-static int hf_pgm_opt_ccfeedbk_tsp = -1;
-static int hf_pgm_opt_ccfeedbk_afi = -1;
-static int hf_pgm_opt_ccfeedbk_lossrate = -1;
-static int hf_pgm_opt_ccfeedbk_acker = -1;
-static int hf_pgm_opt_ccfeedbk_acker6 = -1;
+static int hf_pgm_opt_ccfeedbk_res;
+static int hf_pgm_opt_ccfeedbk_tsp;
+static int hf_pgm_opt_ccfeedbk_afi;
+static int hf_pgm_opt_ccfeedbk_lossrate;
+static int hf_pgm_opt_ccfeedbk_acker;
+static int hf_pgm_opt_ccfeedbk_acker6;
 
-static int hf_pgm_opt_nak_bo_ivl_res = -1;
-static int hf_pgm_opt_nak_bo_ivl_bo_ivl = -1;
-static int hf_pgm_opt_nak_bo_ivl_bo_ivl_sqn = -1;
+static int hf_pgm_opt_nak_bo_ivl_res;
+static int hf_pgm_opt_nak_bo_ivl_bo_ivl;
+static int hf_pgm_opt_nak_bo_ivl_bo_ivl_sqn;
 
-static int hf_pgm_opt_nak_bo_rng_res = -1;
-static int hf_pgm_opt_nak_bo_rng_min_bo_ivl = -1;
-static int hf_pgm_opt_nak_bo_rng_max_bo_ivl = -1;
+static int hf_pgm_opt_nak_bo_rng_res;
+static int hf_pgm_opt_nak_bo_rng_min_bo_ivl;
+static int hf_pgm_opt_nak_bo_rng_max_bo_ivl;
 
-static int hf_pgm_opt_redirect_res = -1;
-static int hf_pgm_opt_redirect_afi = -1;
-static int hf_pgm_opt_redirect_res2 = -1;
-static int hf_pgm_opt_redirect_dlr = -1;
-static int hf_pgm_opt_redirect_dlr6 = -1;
+static int hf_pgm_opt_redirect_res;
+static int hf_pgm_opt_redirect_afi;
+static int hf_pgm_opt_redirect_res2;
+static int hf_pgm_opt_redirect_dlr;
+static int hf_pgm_opt_redirect_dlr6;
 
-static int hf_pgm_opt_fragment_res = -1;
-static int hf_pgm_opt_fragment_first_sqn = -1;
-static int hf_pgm_opt_fragment_offset = -1;
-static int hf_pgm_opt_fragment_total_length = -1;
+static int hf_pgm_opt_fragment_res;
+static int hf_pgm_opt_fragment_first_sqn;
+static int hf_pgm_opt_fragment_offset;
+static int hf_pgm_opt_fragment_total_length;
 
-static expert_field ei_pgm_genopt_len = EI_INIT;
-static expert_field ei_pgm_opt_tlen = EI_INIT;
-static expert_field ei_pgm_opt_type = EI_INIT;
-static expert_field ei_address_format_invalid = EI_INIT;
-static expert_field ei_pgm_main_cksum = EI_INIT;
+static expert_field ei_pgm_genopt_len;
+static expert_field ei_pgm_opt_tlen;
+static expert_field ei_pgm_opt_type;
+static expert_field ei_address_format_invalid;
+static expert_field ei_pgm_main_cksum;
 
 static dissector_table_t subdissector_table;
 static heur_dissector_list_t heur_subdissector_list;
@@ -274,7 +276,7 @@ optsstr(wmem_allocator_t *pool, guint8 opts)
 	const int MAX_STR_LEN = 256;
 
 	if (opts == 0)
-		return("");
+		return "";
 
 	msg=(char *)wmem_alloc(pool, MAX_STR_LEN);
 	if (opts & PGM_OPT){
@@ -296,7 +298,7 @@ optsstr(wmem_allocator_t *pool, guint8 opts)
 	if (!idx) {
 		snprintf(&msg[idx], MAX_STR_LEN-idx, "0x%x", opts);
 	}
-	return(msg);
+	return msg;
 }
 static const char *
 paritystr(wmem_allocator_t *pool, guint8 parity)
@@ -306,7 +308,7 @@ paritystr(wmem_allocator_t *pool, guint8 parity)
 	const int MAX_STR_LEN = 256;
 
 	if (parity == 0)
-		return("");
+		return "";
 
 	msg=(char *)wmem_alloc(pool, MAX_STR_LEN);
 	if (parity & PGM_OPT_PARITY_PRM_PRO){
@@ -320,7 +322,7 @@ paritystr(wmem_allocator_t *pool, guint8 parity)
 	if (!idx) {
 		snprintf(&msg[idx], MAX_STR_LEN-idx, "0x%x", parity);
 	}
-	return(msg);
+	return msg;
 }
 
 static const value_string opt_vals[] = {
@@ -340,7 +342,6 @@ static const value_string opt_vals[] = {
 	{ PGM_OPT_PGMCC_FEEDBACK, "CcFeedBack" },
 	{ PGM_OPT_NAK_BO_IVL,	  "NakBackOffIvl" },
 	{ PGM_OPT_NAK_BO_RNG,	  "NakBackOffRng" },
-	{ PGM_OPT_FRAGMENT,	  "Fragment" },
 	{ 0,                   NULL }
 };
 
@@ -1244,7 +1245,7 @@ proto_register_pgm(void)
 		  { "Minimum Sequence Number", "pgm.opts.join.min_join",
 		    FT_UINT32, BASE_HEX, NULL, 0x0, NULL, HFILL }},
 		{ &hf_pgm_opt_parity_grp_res,
-		  { "Reserved", "pgm.opts.parity_prm.op", FT_UINT8, BASE_HEX,
+		  { "Reserved", "pgm.opts.parity_prm.reserved", FT_UINT8, BASE_HEX,
 		    NULL, 0x0, NULL, HFILL }},
 		{ &hf_pgm_opt_parity_grp_prmgrp,
 		  { "Transmission Group Size", "pgm.opts.parity_prm.prm_grp",
@@ -1377,9 +1378,10 @@ proto_register_pgm(void)
 	expert_register_field_array(expert_pgm, ei, array_length(ei));
 
 	/* subdissector code */
+	pgm_handle = register_dissector("pgm", dissect_pgm, proto_pgm);
 	subdissector_table = register_dissector_table("pgm.port",
 						      "PGM port", proto_pgm, FT_UINT16, BASE_DEC);
-	heur_subdissector_list = register_heur_dissector_list("pgm", proto_pgm);
+	heur_subdissector_list = register_heur_dissector_list_with_description("pgm", "PGM data fallback", proto_pgm);
 
 	/*
 	 * Register configuration preferences for UDP encapsulation
@@ -1405,9 +1407,6 @@ proto_register_pgm(void)
 void
 proto_reg_handoff_pgm(void)
 {
-	dissector_handle_t pgm_handle;
-
-	pgm_handle = create_dissector_handle(dissect_pgm, proto_pgm);
 	dissector_add_uint_range_with_preference("udp.port", "", pgm_handle);
 	dissector_add_uint("ip.proto", IP_PROTO_PGM, pgm_handle);
 }
