@@ -26,7 +26,7 @@ void proto_reg_handoff_pim(void);
 #define PIM_TYPE(x)             ((x) & 0x0f)
 #define PIM_VER(x)              (((x) & 0xf0) >> 4)
 #define PIM_BIDIR_SUBTYPE(x)    ((x) & 0x0f)
-#define PIM_BIDIR_RSVD(x)       (((x) & 0xf0) >> 4)
+#define PIM_SUBTYPE(x)          (((x) & 0xf0) >> 4)
 
 /* PIM message type */
 
@@ -43,6 +43,12 @@ void proto_reg_handoff_pim(void);
 #define PIM_TYPE_DF_ELECT 10        /* DF Election [RFC5015] */
 #define PIM_TYPE_ECMP_REDIR 11      /* ECMP Redirect [RFC6754] */
 #define PIM_TYPE_PFM 12             /* PIM PFM [RFC8364] */
+#define PIM_TYPE_PACKED_REGISTER 13 /* PIM PFM [RFC9465] */
+
+/* PIM Message Subtypes */
+
+#define PIM_TYPE_PACKED_NULL_REGISTER 0  /* 13.0 */
+#define PIM_TYPE_PACKED_REGISTER_STOP 1  /* 13.1 */
 
 /* PIM Message hello options */
 
@@ -126,6 +132,16 @@ static const value_string pimtypevals[] = {
     { PIM_TYPE_DF_ELECT, "DF election"},
     { PIM_TYPE_ECMP_REDIR, "ECMP redirect" },
     { PIM_TYPE_PFM, "PFM source discovery"},
+    { PIM_TYPE_PACKED_REGISTER, "Packed Register"},
+    { 0, NULL }
+};
+
+/*
+ * List of subtypes for PIM message Type 13.
+ */
+static const value_string pimtype13subtypevals[] = {
+    { PIM_TYPE_PACKED_NULL_REGISTER, "Packed Null-Register" },
+    { PIM_TYPE_PACKED_REGISTER_STOP, "Packed Register-Stop" },
     { 0, NULL }
 };
 
@@ -198,135 +214,140 @@ enum pimv2_addrtype {
     pimv2_unicast, pimv2_group, pimv2_source
 };
 
-static int proto_pim = -1;
-static int hf_pim_version = -1;
-static int hf_pim_type = -1;
-static int hf_pim_code = -1;
-static int hf_pim_igmp_type = -1;
-static int hf_pim_df_elect_subtype = -1;
-static int hf_pim_df_elect_rsvd = -1;
-static int hf_pim_cksum = -1;
-static int hf_pim_cksum_status = -1;
-static int hf_pim_res_bytes = -1;
+static int proto_pim;
+static int hf_pim_version;
+static int hf_pim_type;
+static int hf_pim_code;
+static int hf_pim_igmp_type;
+static int hf_pim_df_elect_subtype;
+static int hf_pim_df_elect_rsvd;
+static int hf_pim_cksum;
+static int hf_pim_cksum_status;
+static int hf_pim_res_bytes;
+static int hf_pim_reg_stop_p_bit;
+static int hf_pim_type_13_subtype;
+static int hf_pim_type_13_flagbits;
 /* PIM Hello options (RFC 4601, section 4.9.2 and RFC 3973, section 4.7.5) */
-static int hf_pim_option = -1;
-static int hf_pim_optiontype = -1;
-static int hf_pim_optionlength = -1;
-static int hf_pim_optionvalue = -1;
-static int hf_pim_register_flag = -1;
-static int hf_pim_register_flag_border = -1;
-static int hf_pim_register_flag_null_register = -1;
-static int hf_pim_mode = -1;
-static int hf_pim_holdtime = -1;
-static int hf_pim_holdtime_t = -1;
-static int hf_pim_numgroups = -1;
-static int hf_pim_numjoins = -1;
-static int hf_pim_numprunes = -1;
-static int hf_pim_t = -1;
-static int hf_pim_propagation_delay = -1;
-static int hf_pim_override_interval = -1;
-static int hf_pim_dr_priority = -1;
-static int hf_pim_generation_id = -1;
-static int hf_pim_state_refresh_version = -1;
-static int hf_pim_state_refresh_interval = -1;
-static int hf_pim_state_refresh_reserved = -1;
+static int hf_pim_option;
+static int hf_pim_optiontype;
+static int hf_pim_optionlength;
+static int hf_pim_optionvalue;
+static int hf_pim_register_flag;
+static int hf_pim_register_flag_border;
+static int hf_pim_register_flag_null_register;
+static int hf_pim_mode;
+static int hf_pim_holdtime;
+static int hf_pim_holdtime_t;
+static int hf_pim_numgroups;
+static int hf_pim_numjoins;
+static int hf_pim_numprunes;
+static int hf_pim_t;
+static int hf_pim_propagation_delay;
+static int hf_pim_override_interval;
+static int hf_pim_dr_priority;
+static int hf_pim_generation_id;
+static int hf_pim_state_refresh_version;
+static int hf_pim_state_refresh_interval;
+static int hf_pim_state_refresh_reserved;
 /* Assert fields */
-static int hf_pim_rpt = -1;
-static int hf_pim_metric_pref = -1;
-static int hf_pim_df_metric_pref = -1;
-static int hf_pim_metric = -1;
-static int hf_pim_prune_indicator = -1;
-static int hf_pim_prune_now = -1;
-static int hf_pim_assert_override = -1;
-static int hf_pim_ip_version = -1;
-static int hf_pim_dummy_header = -1;
-static int hf_pim_source_ip4 = -1;
-static int hf_pim_source_ip6 = -1;
-static int hf_pim_group_ip4 = -1;
-static int hf_pim_group_ip6 = -1;
-static int hf_pim_group_mask_ip4 = -1;
-static int hf_pim_upstream_neighbor_ip4 = -1;
-static int hf_pim_upstream_neighbor_ip6 = -1;
-static int hf_pim_join_ip4 = -1;
-static int hf_pim_join_ip6 = -1;
-static int hf_pim_prune_ip4 = -1;
-static int hf_pim_prune_ip6 = -1;
-static int hf_pim_address_list_ip4 = -1;
-static int hf_pim_address_list_ip6 = -1;
-static int hf_pim_bsr_ip4 = -1;
-static int hf_pim_bsr_ip6 = -1;
-static int hf_pim_rp_ip4 = -1;
-static int hf_pim_rp_ip6 = -1;
-static int hf_pim_bd_bo_offer_ip4 = -1;
-static int hf_pim_bd_bo_offer_ip6 = -1;
-static int hf_pim_bd_offer_metric_pref = -1;
-static int hf_pim_bd_offer_metric = -1;
-static int hf_pim_bd_offer_interval = -1;
-static int hf_pim_bd_pass_ip4 = -1;
-static int hf_pim_bd_pass_ip6 = -1;
-static int hf_pim_bd_pass_metric_pref = -1;
-static int hf_pim_bd_pass_metric = -1;
-static int hf_pim_originator_ip4 = -1;
-static int hf_pim_originator_ip6 = -1;
-static int hf_pim_group_address_ip4 = -1;
-static int hf_pim_fragment_tag = -1;
-static int hf_pim_hash_mask_len = -1;
-static int hf_pim_bsr_priority = -1;
-static int hf_pim_rp_count = -1;
-static int hf_pim_frp_count = -1;
-static int hf_pim_priority = -1;
-static int hf_pim_prefix_count = -1;
-static int hf_pim_addr_len = -1;
-static int hf_pim_src_flags_a = -1;
-static int hf_pim_src_flags_s = -1;
-static int hf_pim_src_flags_w = -1;
-static int hf_pim_src_flags_r = -1;
-static int hf_pim_src_flags_rsv = -1;
-static int hf_pim_mask_len = -1;
-static int hf_pim_addr_af = -1;
-static int hf_pim_addr_et = -1;
-static int hf_pim_unicast_addr_ipv4 = -1;
-static int hf_pim_unicast_addr_ipv6 = -1;
-static int hf_pim_rloc_addr_ipv4 = -1;
-static int hf_pim_rloc_addr_ipv6 = -1;
-static int hf_pim_attribute_transport_mode = -1;
-static int hf_pim_group = -1;
-static int hf_pim_group_addr_flags = -1;
-static int hf_pim_group_addr_flags_b = -1;
-static int hf_pim_group_addr_flags_reserved = -1;
-static int hf_pim_group_addr_flags_z = -1;
-static int hf_pim_source_addr_flags = -1;
-static int hf_pim_source_addr_flags_reserved = -1;
-static int hf_pim_source_addr_flags_s = -1;
-static int hf_pim_source_addr_flags_w = -1;
-static int hf_pim_source_addr_flags_r = -1;
-static int hf_pim_source_join_attribute = -1;
-static int hf_pim_source_ja_flags = -1;
-static int hf_pim_source_ja_flags_f = -1;
-static int hf_pim_source_ja_flags_e = -1;
-static int hf_pim_source_ja_flags_attr_type = -1;
-static int hf_pim_source_ja_length = -1;
-static int hf_pim_source_ja_value = -1;
-static int hf_pim_ttl = -1;
-static int hf_pim_interval = -1;
-static int hf_pim_srcount = -1;
-static int hf_pim_srcholdt = -1;
-static int hf_pim_transitivetype = -1;
-static int hf_pim_optiontype1 = -1;
-static int hf_pfm_no_forward_bit = -1;
+static int hf_pim_rpt;
+static int hf_pim_metric_pref;
+static int hf_pim_df_metric_pref;
+static int hf_pim_metric;
+static int hf_pim_prune_indicator;
+static int hf_pim_prune_now;
+static int hf_pim_assert_override;
+static int hf_pim_ip_version;
+static int hf_pim_dummy_header;
+static int hf_pim_source_ip4;
+static int hf_pim_source_ip6;
+static int hf_pim_group_ip4;
+static int hf_pim_group_ip6;
+static int hf_pim_group_mask_ip4;
+static int hf_pim_upstream_neighbor_ip4;
+static int hf_pim_upstream_neighbor_ip6;
+static int hf_pim_join_ip4;
+static int hf_pim_join_ip6;
+static int hf_pim_prune_ip4;
+static int hf_pim_prune_ip6;
+static int hf_pim_address_list_ip4;
+static int hf_pim_address_list_ip6;
+static int hf_pim_bsr_ip4;
+static int hf_pim_bsr_ip6;
+static int hf_pim_rp_ip4;
+static int hf_pim_rp_ip6;
+static int hf_pim_bd_bo_offer_ip4;
+static int hf_pim_bd_bo_offer_ip6;
+static int hf_pim_bd_offer_metric_pref;
+static int hf_pim_bd_offer_metric;
+static int hf_pim_bd_offer_interval;
+static int hf_pim_bd_pass_ip4;
+static int hf_pim_bd_pass_ip6;
+static int hf_pim_bd_pass_metric_pref;
+static int hf_pim_bd_pass_metric;
+static int hf_pim_originator_ip4;
+static int hf_pim_originator_ip6;
+static int hf_pim_group_address_ip4;
+static int hf_pim_fragment_tag;
+static int hf_pim_hash_mask_len;
+static int hf_pim_bsr_priority;
+static int hf_pim_rp_count;
+static int hf_pim_frp_count;
+static int hf_pim_priority;
+static int hf_pim_prefix_count;
+static int hf_pim_addr_len;
+static int hf_pim_src_flags_a;
+static int hf_pim_src_flags_s;
+static int hf_pim_src_flags_w;
+static int hf_pim_src_flags_r;
+static int hf_pim_src_flags_rsv;
+static int hf_pim_mask_len;
+static int hf_pim_addr_af;
+static int hf_pim_addr_et;
+static int hf_pim_unicast_addr_ipv4;
+static int hf_pim_unicast_addr_ipv6;
+static int hf_pim_rloc_addr_ipv4;
+static int hf_pim_rloc_addr_ipv6;
+static int hf_pim_attribute_transport_mode;
+static int hf_pim_group;
+static int hf_pim_group_addr_flags;
+static int hf_pim_group_addr_flags_b;
+static int hf_pim_group_addr_flags_reserved;
+static int hf_pim_group_addr_flags_z;
+static int hf_pim_source_addr_flags;
+static int hf_pim_source_addr_flags_reserved;
+static int hf_pim_source_addr_flags_s;
+static int hf_pim_source_addr_flags_w;
+static int hf_pim_source_addr_flags_r;
+static int hf_pim_source_join_attribute;
+static int hf_pim_source_ja_flags;
+static int hf_pim_source_ja_flags_f;
+static int hf_pim_source_ja_flags_e;
+static int hf_pim_source_ja_flags_attr_type;
+static int hf_pim_source_ja_length;
+static int hf_pim_source_ja_value;
+static int hf_pim_ttl;
+static int hf_pim_interval;
+static int hf_pim_srcount;
+static int hf_pim_srcholdt;
+static int hf_pim_transitivetype;
+static int hf_pim_optiontype1;
+static int hf_pfm_no_forward_bit;
 
-static gint ett_pim = -1;
-static gint ett_pim_opts = -1;
-static gint ett_pim_opt = -1;
-static gint ett_pim_addr_flags = -1;
+static gint ett_pim;
+static gint ett_pim_opts;
+static gint ett_pim_opt;
+static gint ett_pim_addr_flags;
 
-static expert_field ei_pim_cksum = EI_INIT;
+static expert_field ei_pim_cksum;
 
+static dissector_handle_t pim_handle;
+static dissector_handle_t pimv1_handle;
 
 static dissector_handle_t ip_handle;
 static dissector_handle_t ipv6_handle;
 
-static gboolean use_main_tree  = TRUE;
+static bool use_main_tree  = true;
 
 /*
  * The Story About Ping^WPIM:
@@ -526,7 +547,7 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U
          * explicitly state that.
          */
         pim_length = 8;
-        col_set_writable(pinfo->cinfo, -1, FALSE);
+		col_set_writable(pinfo->cinfo, -1, false);
     } else {
         /*
          * Other message - checksum the entire packet.
@@ -757,6 +778,7 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U
 }
 
 static gboolean
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_pim_addr(packet_info *pinfo, proto_tree* tree, tvbuff_t *tvb, int offset, enum pimv2_addrtype at,
                  const char* label, proto_item** ret_item, int hf_ip4, int hf_ip6, int *advance) {
     guint8 af, et, flags, mask_len, ja_af;
@@ -1009,6 +1031,7 @@ dissect_pim_addr(packet_info *pinfo, proto_tree* tree, tvbuff_t *tvb, int offset
                     case PIM_JOIN_ATTRIBUTE_TYPE_RPF:
                         if ((ja_length == 6) || (ja_length == 18)) {
                             int advance_attr;
+                            // We recurse here, but we'll run out of packet before we run out of stack.
                             if (!dissect_pim_addr(pinfo, ja_tree, tvb, ja_offset, pimv2_unicast, NULL, NULL,
                                     hf_pim_unicast_addr_ipv4, hf_pim_unicast_addr_ipv6, &advance_attr))
                                 break;
@@ -1065,6 +1088,7 @@ static int
 dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_) {
     int offset = 0;
     guint8 pim_typever;
+    guint8 pim_subtype;
     guint8 pim_bidir_subtype = 0;
     guint length, pim_length;
     vec_t cksum_vec[4];
@@ -1079,10 +1103,20 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     col_clear(pinfo->cinfo, COL_INFO);
 
     pim_typever = tvb_get_guint8(tvb, 0);
+    pim_subtype = PIM_SUBTYPE(tvb_get_guint8(tvb, 1));
 
     switch (PIM_VER(pim_typever)) {
     case 2:
-        typestr = val_to_str(PIM_TYPE(pim_typever), pimtypevals, "Unknown (%u)");
+        if (PIM_TYPE(pim_typever) < 12) {
+            typestr = val_to_str(PIM_TYPE(pim_typever), pimtypevals, "Unknown (%u)");
+        } else if ((PIM_TYPE(pim_typever) == PIM_TYPE_PACKED_REGISTER)) {
+            /*
+             * Need only the first 4 bits for subtype as per the new PIM Common header.
+             */
+            typestr = val_to_str(pim_subtype, pimtype13subtypevals, "Unknown (%u)");
+        } else {
+            typestr = "Unknown";
+        }
         break;
     case 1:     /* PIMv1 - we should never see this */
     default:
@@ -1102,12 +1136,23 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     if (PIM_TYPE(pim_typever) == PIM_TYPE_PFM) {
         proto_tree_add_item(pim_tree, hf_pfm_no_forward_bit, tvb, offset+1, 1, ENC_BIG_ENDIAN);
     }
+    if (PIM_TYPE(pim_typever) == PIM_TYPE_REGISTER_STOP) {
+        /*
+         * [version-4bits][type-4bits][0x01]
+         */
+        proto_tree_add_item(pim_tree, hf_pim_reg_stop_p_bit, tvb, offset+1, 1, ENC_BIG_ENDIAN);
+    }
     if (PIM_TYPE(pim_typever) == PIM_TYPE_DF_ELECT) {
         proto_tree_add_item(pim_tree, hf_pim_df_elect_subtype, tvb, offset + 1, 1, ENC_BIG_ENDIAN);
         proto_tree_add_item(pim_tree, hf_pim_df_elect_rsvd, tvb, offset + 1, 1, ENC_BIG_ENDIAN);
         pim_bidir_subtype = tvb_get_guint8(tvb,offset);
-    }
-    else {
+    } else if ((PIM_TYPE(pim_typever) == PIM_TYPE_PACKED_REGISTER)) {
+        /*
+         * [version-4bits][type-4bits][0x[SubType-4bits][Flagbits-4bits]
+         */
+        proto_tree_add_item(pim_tree, hf_pim_type_13_subtype, tvb, offset+1, 1, ENC_BIG_ENDIAN);
+        proto_tree_add_item(pim_tree, hf_pim_type_13_flagbits, tvb, offset+1, 1, ENC_BIG_ENDIAN);
+    } else {
         proto_tree_add_item(pim_tree, hf_pim_res_bytes, tvb, offset + 1, 1, ENC_NA);
     }
 
@@ -1138,7 +1183,7 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
          * this register will overwrite the PIM info in the columns.
          */
         pim_length = 8;
-        col_set_writable(pinfo->cinfo, -1, FALSE);
+        col_set_writable(pinfo->cinfo, -1, false);
     } else {
         /*
          * Other message - checksum the entire packet.
@@ -1692,6 +1737,46 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     breakbreak12:
         break;
     }
+
+    case PIM_TYPE_PACKED_REGISTER:     /* Packed Register */
+    {
+        int ngroups;
+        int advance, i;
+        proto_tree *grouptree = NULL;
+        proto_item *tigroup;
+
+        switch (pim_subtype) {
+        case PIM_TYPE_PACKED_NULL_REGISTER:
+        case PIM_TYPE_PACKED_REGISTER_STOP:
+            /*
+             * Total length minus PIM header length
+             * divided by 1 encoded record size (14 bytes).
+            */
+            ngroups = (length-4)/14;
+            for (i = 0; i < ngroups; i++) {
+                /*
+                 * RFC9465 states that an (S,G) entry is called a "Record".
+                 */
+                tigroup=proto_tree_add_string_format(pimopt_tree, hf_pim_group, tvb, offset, -1, "", "Record %d", i+1);
+                grouptree = proto_item_add_subtree(tigroup, ett_pim);
+                if (!dissect_pim_addr(pinfo, grouptree, tvb, offset, pimv2_group,
+                                      wmem_strdup_printf(pinfo->pool, "Group"), NULL,
+                                      hf_pim_group_ip4, hf_pim_group_ip6, &advance))
+                    goto breakpackedreg;
+                offset += advance;
+                if (!dissect_pim_addr(pinfo, grouptree, tvb, offset, pimv2_unicast, NULL, NULL,
+                                      hf_pim_source_ip4, hf_pim_source_ip6, &advance))
+                    goto breakpackedreg;
+                offset += advance;
+            }
+            break;
+        default:
+            break;
+        }
+    breakpackedreg:
+        break;
+    }
+
     default:
         break;
     }
@@ -1749,6 +1834,17 @@ proto_register_pim(void)
                 FT_BYTES, BASE_NONE, NULL, 0x0,
                 NULL, HFILL }
             },
+            { &hf_pim_type_13_subtype,
+              { "Subtype", "pim.subtype_type13",
+                FT_UINT8, BASE_DEC, VALS(pimtype13subtypevals), 0xf0,
+                NULL, HFILL }
+            },
+            { &hf_pim_type_13_flagbits,
+              { "Flag Bits", "pim.flag_bits_type13",
+                FT_UINT8, BASE_DEC, NULL, 0x0f,
+                NULL, HFILL }
+            },
+
             { &hf_pim_option,
               { "PIM Options", "pim.option",
                 FT_NONE, BASE_NONE, NULL, 0x0,
@@ -2273,6 +2369,11 @@ proto_register_pim(void)
               { "Pfm no forward bit", "pim.pfmnoforwardbit",
                 FT_BOOLEAN, 8, NULL, 0x80,
                 "When set, this bit means that the PFM message is not to be forwarded.", HFILL }
+            },
+            { &hf_pim_reg_stop_p_bit,
+              { "P-bit", "pim.packedregstoppbit",
+                FT_BOOLEAN, 8, NULL, 0x01,
+                "RP is indicating Register-Packing capability (RFC9465).", HFILL }
             }
         };
 
@@ -2290,13 +2391,15 @@ proto_register_pim(void)
     expert_module_t* expert_pim;
     module_t *pim_module;
 
-    proto_pim = proto_register_protocol("Protocol Independent Multicast",
-                                        "PIM", "pim");
+    proto_pim = proto_register_protocol("Protocol Independent Multicast", "PIM", "pim");
     proto_register_field_array(proto_pim, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
     expert_pim = expert_register_protocol(proto_pim);
     expert_register_field_array(expert_pim, ei, array_length(ei));
 
+    pim_handle = register_dissector("pim", dissect_pim, proto_pim);
+    pimv1_handle = register_dissector("pimv1", dissect_pimv1, proto_pim);
+
     pim_module = prefs_register_protocol(proto_pim, NULL);
     prefs_register_bool_preference(pim_module, "payload_tree",
                                   "PIM payload shown on main tree",
@@ -2308,12 +2411,7 @@ proto_register_pim(void)
 void
 proto_reg_handoff_pim(void)
 {
-    dissector_handle_t pim_handle, pimv1_handle;
-
-    pim_handle = create_dissector_handle(dissect_pim, proto_pim);
     dissector_add_uint("ip.proto", IP_PROTO_PIM, pim_handle);
-
-    pimv1_handle = create_dissector_handle(dissect_pimv1, proto_pim);
     dissector_add_uint("igmp.type", IGMP_V1_PIM_ROUTING_MESSAGE, pimv1_handle);
 
     /*
