@@ -26,20 +26,20 @@ void proto_reg_handoff_pktgen(void);
 #define PKTGEN_MAGIC 0xbe9be955
 
 /* Initialize the protocol and registered fields */
-static int proto_pktgen = -1;
+static int proto_pktgen;
 
 /* pktgen header */
-static int hf_pktgen_magic = -1;
-static int hf_pktgen_seqnum = -1;
-static int hf_pktgen_tvsec = -1;
-static int hf_pktgen_tvusec = -1;
-static int hf_pktgen_timestamp = -1;
+static int hf_pktgen_magic;
+static int hf_pktgen_seqnum;
+static int hf_pktgen_tvsec;
+static int hf_pktgen_tvusec;
+static int hf_pktgen_timestamp;
 
 /* Initialize the subtree pointer */
-static gint ett_pktgen = -1;
+static gint ett_pktgen;
 
 /* entry point */
-static gboolean dissect_pktgen(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool dissect_pktgen(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
     proto_item *ti          = NULL;
     proto_item *tmp         = NULL;
@@ -50,14 +50,14 @@ static gboolean dissect_pktgen(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
 
     /* check for min size */
     if (tvb_reported_length(tvb) < 16) {  /* Not a PKTGEN packet. */
-        return FALSE;
+        return false;
     }
 
     /* check for magic number */
     magic = tvb_get_ntohl(tvb,0);
     if (magic != PKTGEN_MAGIC) {
         /* Not a PKTGEN packet. */
-        return FALSE;
+        return false;
     }
 
 
@@ -100,7 +100,7 @@ static gboolean dissect_pktgen(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
             pktgen_tree);
     }
 
-    return TRUE;
+    return true;
 }
 
 
@@ -177,7 +177,7 @@ void proto_reg_handoff_pktgen(void)
 
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
