@@ -36,38 +36,38 @@
 void proto_register_pop(void);
 void proto_reg_handoff_pop(void);
 
-static int proto_pop = -1;
+static int proto_pop;
 
-static int credentials_tap = -1;
+static int credentials_tap;
 
-static int hf_pop_response = -1;
-static int hf_pop_response_indicator = -1;
-static int hf_pop_response_description = -1;
-static int hf_pop_response_data = -1;
+static int hf_pop_response;
+static int hf_pop_response_indicator;
+static int hf_pop_response_description;
+static int hf_pop_response_data;
 
-static int hf_pop_request = -1;
-static int hf_pop_request_command = -1;
-static int hf_pop_request_parameter = -1;
-static int hf_pop_request_data = -1;
+static int hf_pop_request;
+static int hf_pop_request_command;
+static int hf_pop_request_parameter;
+static int hf_pop_request_data;
 
-static int hf_pop_data_fragments = -1;
-static int hf_pop_data_fragment = -1;
-static int hf_pop_data_fragment_overlap = -1;
-static int hf_pop_data_fragment_overlap_conflicts = -1;
-static int hf_pop_data_fragment_multiple_tails = -1;
-static int hf_pop_data_fragment_too_long_fragment = -1;
-static int hf_pop_data_fragment_error = -1;
-static int hf_pop_data_fragment_count = -1;
-static int hf_pop_data_reassembled_in = -1;
-static int hf_pop_data_reassembled_length = -1;
+static int hf_pop_data_fragments;
+static int hf_pop_data_fragment;
+static int hf_pop_data_fragment_overlap;
+static int hf_pop_data_fragment_overlap_conflicts;
+static int hf_pop_data_fragment_multiple_tails;
+static int hf_pop_data_fragment_too_long_fragment;
+static int hf_pop_data_fragment_error;
+static int hf_pop_data_fragment_count;
+static int hf_pop_data_reassembled_in;
+static int hf_pop_data_reassembled_length;
 
-static expert_field ei_pop_resp_tot_len_invalid = EI_INIT;
+static expert_field ei_pop_resp_tot_len_invalid;
 
-static gint ett_pop = -1;
-static gint ett_pop_reqresp = -1;
+static gint ett_pop;
+static gint ett_pop_reqresp;
 
-static gint ett_pop_data_fragment = -1;
-static gint ett_pop_data_fragments = -1;
+static gint ett_pop_data_fragment;
+static gint ett_pop_data_fragments;
 
 static dissector_handle_t pop_handle;
 static dissector_handle_t imf_handle;
@@ -77,7 +77,7 @@ static dissector_handle_t tls_handle;
 #define TCP_PORT_SSL_POP        995
 
 /* desegmentation of POP command and response lines */
-static gboolean pop_data_desegment = TRUE;
+static bool pop_data_desegment = true;
 
 static reassembly_table pop_data_reassembly_table;
 
@@ -104,17 +104,9 @@ static const fragment_items pop_data_frag_items = {
   "DATA fragments"
 };
 
-typedef enum {
-  pop_arg_type_unknown,
-  pop_arg_type_username,
-  pop_arg_type_password
-} pop_arg_type_t;
-
 struct pop_proto_data {
   guint16 conversation_id;
   gboolean more_frags;
-  gboolean ei_tot_len_invalid;
-  pop_arg_type_t arg_type;
 };
 
 struct pop_data_val {
@@ -126,6 +118,12 @@ struct pop_data_val {
   guint username_num;
 };
 
+typedef enum {
+  pop_arg_type_unknown,
+  pop_arg_type_username,
+  pop_arg_type_password
+} pop_arg_type_t;
+
 static gboolean response_is_continuation(const guchar *data);
 
 static int
@@ -142,15 +140,17 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
   int                    linelen;
   int                    tokenlen;
   const guchar           *next_token;
-  fragment_head          *frag_msg;
-  tvbuff_t               *next_tvb;
-  conversation_t         *conversation;
-  struct pop_data_val    *data_val;
+  fragment_head          *frag_msg = NULL;
+  tvbuff_t               *next_tvb = NULL;
+  conversation_t         *conversation = NULL;
+  struct pop_data_val    *data_val = NULL;
   gint                   length_remaining;
   pop_arg_type_t         pop_arg_type = pop_arg_type_unknown;
 
   col_set_str(pinfo->cinfo, COL_PROTOCOL, "POP");
 
+  frame_data_p = (struct pop_proto_data *)p_get_proto_data(wmem_file_scope(), pinfo, proto_pop, 0);
+
   conversation = find_or_create_conversation(pinfo);
   data_val = (struct pop_data_val *)conversation_get_proto_data(conversation, proto_pop);
   if (!data_val) {
@@ -201,19 +201,16 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
 
     if (pop_data_desegment) {
 
-      if (!PINFO_FD_VISITED(pinfo)) {
+      if (!frame_data_p) {
 
         data_val->msg_read_len += tvb_reported_length(tvb);
 
-        frame_data_p = wmem_new0(wmem_file_scope(), struct pop_proto_data);
+        frame_data_p = wmem_new(wmem_file_scope(), struct pop_proto_data);
 
         frame_data_p->conversation_id = conversation->conv_index;
         frame_data_p->more_frags = data_val->msg_read_len < data_val->msg_tot_len;
 
         p_add_proto_data(wmem_file_scope(), pinfo, proto_pop, 0, frame_data_p);
-      } else {
-          frame_data_p = (struct pop_proto_data *)p_get_proto_data(wmem_file_scope(), pinfo, proto_pop, 0);
-          DISSECTOR_ASSERT(frame_data_p);
       }
 
       frag_msg = fragment_add_seq_next(&pop_data_reassembly_table, tvb, 0,
@@ -233,7 +230,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
         if (imf_handle)
           call_dissector(imf_handle, next_tvb, pinfo, tree);
 
-        if (!PINFO_FD_VISITED(pinfo)) {
+        if (data_val) {
           /* we have read everything - reset */
 
           data_val->msg_read_len = 0;
@@ -280,7 +277,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
                             hf_pop_response_indicator,
                         tvb, offset, tokenlen, ENC_ASCII|ENC_NA);
 
-    if (!PINFO_FD_VISITED(pinfo)) {
+    if (data_val) {
       if (is_request) {
         /* see if this is RETR or TOP command */
         if (g_ascii_strncasecmp(line, "RETR", 4) == 0 ||
@@ -299,13 +296,6 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
         if (g_ascii_strncasecmp(line, "PASS", 4) == 0) {
           pop_arg_type = pop_arg_type_password;
         }
-
-        if (pop_arg_type != pop_arg_type_unknown) {
-          /* store info for subsequent pass */
-          frame_data_p = wmem_new0(wmem_file_scope(), struct pop_proto_data);
-          frame_data_p->arg_type = pop_arg_type;
-          p_add_proto_data(wmem_file_scope(), pinfo, proto_pop, 0, frame_data_p);
-        }
       } else {
         if (data_val->msg_request) {
           /* this is a response to a RETR or TOP command */
@@ -314,13 +304,8 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
             /* the message will be sent - work out how many bytes */
             data_val->msg_read_len = 0;
             data_val->msg_tot_len = 0;
-            if (sscanf(line, "%*s %u %*s", &data_val->msg_tot_len) != 1) {
+            if (sscanf(line, "%*s %u %*s", &data_val->msg_tot_len) != 1)
               expert_add_info(pinfo, ti, &ei_pop_resp_tot_len_invalid);
-              /* store expect info presence to add it to the tree during subsequent pass */
-              frame_data_p = wmem_new0(wmem_file_scope(), struct pop_proto_data);
-              frame_data_p->ei_tot_len_invalid = TRUE;
-              p_add_proto_data(wmem_file_scope(), pinfo, proto_pop, 0, frame_data_p);
-            }
           }
           data_val->msg_request = FALSE;
         }
@@ -333,13 +318,6 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
           data_val->stls_request = FALSE;
         }
       }
-    } else {
-      frame_data_p = (struct pop_proto_data *)p_get_proto_data(wmem_file_scope(), pinfo, proto_pop, 0);
-      if (frame_data_p) {
-        pop_arg_type = frame_data_p->arg_type;
-        if (frame_data_p->ei_tot_len_invalid)
-          expert_add_info(pinfo, ti, &ei_pop_resp_tot_len_invalid);
-      }
     }
 
     offset += (gint) (next_token - line);
@@ -361,7 +339,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     switch (pop_arg_type) {
       case pop_arg_type_username:
         if (!data_val->username && linelen > 0) {
-          data_val->username = tvb_get_string_enc(wmem_file_scope(), tvb, offset, linelen, ENC_NA|ENC_ASCII);;
+          data_val->username = tvb_get_string_enc(wmem_file_scope(), tvb, offset, linelen, ENC_NA|ENC_ASCII);
           data_val->username_num = pinfo->num;
         }
         break;
