@@ -12,11 +12,11 @@
 
 #include "config.h"
 
-
-
+#include <epan/packet.h>
+#include <epan/conversation.h>
+#include <epan/ipproto.h>
 #include "packet-rpc.h"
 #include "packet-portmap.h"
-#include <epan/ipproto.h>
 
 /*
  * See:
@@ -26,31 +26,31 @@
 void proto_register_portmap(void);
 void proto_reg_handoff_portmap(void);
 
-static int proto_portmap = -1;
-static int hf_portmap_procedure_v1 = -1;
-static int hf_portmap_procedure_v2 = -1;
-static int hf_portmap_procedure_v3 = -1;
-static int hf_portmap_procedure_v4 = -1;
-static int hf_portmap_proto = -1;
-static int hf_portmap_prog = -1;
-static int hf_portmap_proc = -1;
-static int hf_portmap_version = -1;
-static int hf_portmap_port = -1;
-static int hf_portmap_answer = -1;
-static int hf_portmap_args = -1;
-static int hf_portmap_result = -1;
-static int hf_portmap_rpcb = -1;
-static int hf_portmap_rpcb_prog = -1;
-static int hf_portmap_rpcb_version = -1;
-static int hf_portmap_rpcb_netid = -1;
-static int hf_portmap_rpcb_addr = -1;
-static int hf_portmap_rpcb_owner = -1;
-static int hf_portmap_uaddr = -1;
+static int proto_portmap;
+static int hf_portmap_procedure_v1;
+static int hf_portmap_procedure_v2;
+static int hf_portmap_procedure_v3;
+static int hf_portmap_procedure_v4;
+static int hf_portmap_proto;
+static int hf_portmap_prog;
+static int hf_portmap_proc;
+static int hf_portmap_version;
+static int hf_portmap_port;
+static int hf_portmap_answer;
+static int hf_portmap_args;
+static int hf_portmap_result;
+static int hf_portmap_rpcb;
+static int hf_portmap_rpcb_prog;
+static int hf_portmap_rpcb_version;
+static int hf_portmap_rpcb_netid;
+static int hf_portmap_rpcb_addr;
+static int hf_portmap_rpcb_owner;
+static int hf_portmap_uaddr;
 
 
-static gint ett_portmap = -1;
-static gint ett_portmap_rpcb = -1;
-static gint ett_portmap_entry = -1;
+static gint ett_portmap;
+static gint ett_portmap_rpcb;
+static gint ett_portmap_entry;
 
 static dissector_handle_t rpc_handle;
 
@@ -66,7 +66,7 @@ dissect_getport_call(tvbuff_t *tvb, packet_info *pinfo _U_,
 	int offset = 0;
 
 	/* make sure we remember protocol type until the reply packet */
-	if(!pinfo->fd->flags.visited){
+	if(!pinfo->fd->visited){
 		rpc_call_info_value *rpc_call=(rpc_call_info_value *)data;
 		if(rpc_call){
 			proto = tvb_get_ntohl(tvb, offset+8);
@@ -120,7 +120,7 @@ dissect_getport_reply(tvbuff_t *tvb, packet_info *pinfo _U_,
 	int offset = 0;
 
 	/* we might have learnt a <ipaddr><protocol><port> mapping for ONC-RPC*/
-	if(!pinfo->fd->flags.visited){
+	if(!pinfo->fd->visited){
 		rpc_call_info_value *rpc_call=(rpc_call_info_value *)data;
 		/* only do this for UDP, TCP does not need anything like this */
 		if(rpc_call && (GPOINTER_TO_UINT(rpc_call->private_data)==PT_UDP) ){
@@ -128,9 +128,9 @@ dissect_getport_reply(tvbuff_t *tvb, packet_info *pinfo _U_,
 			port=tvb_get_ntohl(tvb, offset);
 			if(port){
 				conversation_t *conv;
-				conv=find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_UDP, port, 0, NO_ADDR_B|NO_PORT_B);
+				conv=find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, CONVERSATION_UDP, port, 0, NO_ADDR_B|NO_PORT_B);
 				if(!conv){
-					conv=conversation_new(pinfo->num, &pinfo->src, &pinfo->dst, ENDPOINT_UDP, port, 0, NO_ADDR2|NO_PORT2);
+					conv=conversation_new(pinfo->num, &pinfo->src, &pinfo->dst, CONVERSATION_UDP, port, 0, NO_ADDR2|NO_PORT2);
 				}
 				conversation_set_dissector(conv, rpc_handle);
 			}
@@ -143,7 +143,6 @@ dissect_getport_reply(tvbuff_t *tvb, packet_info *pinfo _U_,
 	proto_item_append_text(tree, " GETPORT Reply Port:%d", portx);
 	if(portx){
 		col_append_fstr(pinfo->cinfo, COL_INFO,  " Port:%d", portx);
-		proto_item_append_text(tree, " Port:%d", portx);
 	} else {
 		col_append_str(pinfo->cinfo, COL_INFO,  " PROGRAM_NOT_AVAILABLE");
 		proto_item_append_text(tree, " PROGRAM_NOT_AVAILABLE");
@@ -284,7 +283,7 @@ dissect_callit_call(tvbuff_t *tvb, packet_info *pinfo,
 	{
 		proto_tree_add_uint_format_value(tree, hf_portmap_proc, tvb,
 			offset+8, 4, proc, "%s (%u)",
-			rpc_proc_name(prog, vers, proc), proc);
+			rpc_proc_name(pinfo->pool, prog, vers, proc), proc);
 	}
 
 	offset += 12;
@@ -292,7 +291,7 @@ dissect_callit_call(tvbuff_t *tvb, packet_info *pinfo,
 	/* Dissect the arguments for this procedure.
 	   Make the columns non-writable, so the dissector won't change
 	   them out from under us. */
-	col_set_writable(pinfo->cinfo, -1, FALSE);
+	col_set_writable(pinfo->cinfo, -1, false);
 	offset = dissect_rpc_indir_call(tvb, pinfo, tree, offset,
 		hf_portmap_args, prog, vers, proc);
 
@@ -313,7 +312,7 @@ dissect_callit_reply(tvbuff_t *tvb, packet_info *pinfo,
 	/* Dissect the result of this procedure.
 	   Make the columns non-writable, so the dissector won't change
 	   them out from under us. */
-	col_set_writable(pinfo->cinfo, -1, FALSE);
+	col_set_writable(pinfo->cinfo, -1, false);
 	offset = dissect_rpc_indir_reply(tvb, pinfo, tree, offset,
 		hf_portmap_result, hf_portmap_prog, hf_portmap_version,
 		hf_portmap_proc);
@@ -448,7 +447,7 @@ dissect_rpcb_rmtcallres(tvbuff_t *tvb, packet_info *pinfo _U_,
 	/* Dissect the result of this procedure.
 	   Make the columns non-writable, so the dissector won't change
 	   them out from under us. */
-	col_set_writable(pinfo->cinfo, -1, FALSE);
+	col_set_writable(pinfo->cinfo, -1, false);
 	offset = dissect_rpc_indir_reply(tvb, pinfo, tree, offset,
 		hf_portmap_result, hf_portmap_prog, hf_portmap_version,
 		hf_portmap_proc);
@@ -633,7 +632,7 @@ proto_reg_handoff_portmap(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
