@@ -164,7 +164,7 @@ typedef enum {
     /* 30000 - 65535: Private types */
     INTEL_CORP_PRIVATE           = 30000,
     MOHAMED_THAGA_PRIVATE        = 30001,
-    PPI_GPS_INFO                 = 30002, /* 30002 - 30005 described in PPI-GEOLOCATION specifcation */
+    PPI_GPS_INFO                 = 30002, /* 30002 - 30005 described in PPI-GEOLOCATION specification */
     PPI_VECTOR_INFO              = 30003, /* currently available in draft from. jellch@harris.com */
     PPI_SENSOR_INFO              = 30004,
     PPI_ANTENNA_INFO             = 30005,
@@ -174,147 +174,147 @@ typedef enum {
 } ppi_field_type;
 
 /* Protocol */
-static int proto_ppi = -1;
+static int proto_ppi;
 
 /* Packet header */
-static int hf_ppi_head_version = -1;
-static int hf_ppi_head_flags = -1;
-static int hf_ppi_head_flag_alignment = -1;
-static int hf_ppi_head_flag_reserved = -1;
-static int hf_ppi_head_len = -1;
-static int hf_ppi_head_dlt = -1;
+static int hf_ppi_head_version;
+static int hf_ppi_head_flags;
+static int hf_ppi_head_flag_alignment;
+static int hf_ppi_head_flag_reserved;
+static int hf_ppi_head_len;
+static int hf_ppi_head_dlt;
 
 /* Field header */
-static int hf_ppi_field_type = -1;
-static int hf_ppi_field_len = -1;
+static int hf_ppi_field_type;
+static int hf_ppi_field_len;
 
 /* 802.11 Common */
-static int hf_80211_common_tsft = -1;
-static int hf_80211_common_flags = -1;
-static int hf_80211_common_flags_fcs = -1;
-static int hf_80211_common_flags_tsft = -1;
-static int hf_80211_common_flags_fcs_valid = -1;
-static int hf_80211_common_flags_phy_err = -1;
-static int hf_80211_common_rate = -1;
-static int hf_80211_common_chan_freq = -1;
-static int hf_80211_common_chan_flags = -1;
+static int hf_80211_common_tsft;
+static int hf_80211_common_flags;
+static int hf_80211_common_flags_fcs;
+static int hf_80211_common_flags_tsft;
+static int hf_80211_common_flags_fcs_valid;
+static int hf_80211_common_flags_phy_err;
+static int hf_80211_common_rate;
+static int hf_80211_common_chan_freq;
+static int hf_80211_common_chan_flags;
 
-static int hf_80211_common_chan_flags_turbo = -1;
-static int hf_80211_common_chan_flags_cck = -1;
-static int hf_80211_common_chan_flags_ofdm = -1;
-static int hf_80211_common_chan_flags_2ghz = -1;
-static int hf_80211_common_chan_flags_5ghz = -1;
-static int hf_80211_common_chan_flags_passive = -1;
-static int hf_80211_common_chan_flags_dynamic = -1;
-static int hf_80211_common_chan_flags_gfsk = -1;
+static int hf_80211_common_chan_flags_turbo;
+static int hf_80211_common_chan_flags_cck;
+static int hf_80211_common_chan_flags_ofdm;
+static int hf_80211_common_chan_flags_2ghz;
+static int hf_80211_common_chan_flags_5ghz;
+static int hf_80211_common_chan_flags_passive;
+static int hf_80211_common_chan_flags_dynamic;
+static int hf_80211_common_chan_flags_gfsk;
 
-static int hf_80211_common_fhss_hopset = -1;
-static int hf_80211_common_fhss_pattern = -1;
-static int hf_80211_common_dbm_antsignal = -1;
-static int hf_80211_common_dbm_antnoise = -1;
+static int hf_80211_common_fhss_hopset;
+static int hf_80211_common_fhss_pattern;
+static int hf_80211_common_dbm_antsignal;
+static int hf_80211_common_dbm_antnoise;
 
 /* 802.11n MAC */
-static int hf_80211n_mac_flags = -1;
-static int hf_80211n_mac_flags_greenfield = -1;
-static int hf_80211n_mac_flags_ht20_40 = -1;
-static int hf_80211n_mac_flags_rx_guard_interval = -1;
-static int hf_80211n_mac_flags_duplicate_rx = -1;
-static int hf_80211n_mac_flags_more_aggregates = -1;
-static int hf_80211n_mac_flags_aggregate = -1;
-static int hf_80211n_mac_flags_delimiter_crc_after = -1;
-static int hf_80211n_mac_ampdu_id = -1;
-static int hf_80211n_mac_num_delimiters = -1;
-static int hf_80211n_mac_reserved = -1;
+static int hf_80211n_mac_flags;
+static int hf_80211n_mac_flags_greenfield;
+static int hf_80211n_mac_flags_ht20_40;
+static int hf_80211n_mac_flags_rx_guard_interval;
+static int hf_80211n_mac_flags_duplicate_rx;
+static int hf_80211n_mac_flags_more_aggregates;
+static int hf_80211n_mac_flags_aggregate;
+static int hf_80211n_mac_flags_delimiter_crc_after;
+static int hf_80211n_mac_ampdu_id;
+static int hf_80211n_mac_num_delimiters;
+static int hf_80211n_mac_reserved;
 
 /* 802.11n MAC+PHY */
-static int hf_80211n_mac_phy_mcs = -1;
-static int hf_80211n_mac_phy_num_streams = -1;
-static int hf_80211n_mac_phy_rssi_combined = -1;
-static int hf_80211n_mac_phy_rssi_ant0_ctl = -1;
-static int hf_80211n_mac_phy_rssi_ant1_ctl = -1;
-static int hf_80211n_mac_phy_rssi_ant2_ctl = -1;
-static int hf_80211n_mac_phy_rssi_ant3_ctl = -1;
-static int hf_80211n_mac_phy_rssi_ant0_ext = -1;
-static int hf_80211n_mac_phy_rssi_ant1_ext = -1;
-static int hf_80211n_mac_phy_rssi_ant2_ext = -1;
-static int hf_80211n_mac_phy_rssi_ant3_ext = -1;
-static int hf_80211n_mac_phy_ext_chan_freq = -1;
-static int hf_80211n_mac_phy_ext_chan_flags = -1;
-static int hf_80211n_mac_phy_ext_chan_flags_turbo = -1;
-static int hf_80211n_mac_phy_ext_chan_flags_cck = -1;
-static int hf_80211n_mac_phy_ext_chan_flags_ofdm = -1;
-static int hf_80211n_mac_phy_ext_chan_flags_2ghz = -1;
-static int hf_80211n_mac_phy_ext_chan_flags_5ghz = -1;
-static int hf_80211n_mac_phy_ext_chan_flags_passive = -1;
-static int hf_80211n_mac_phy_ext_chan_flags_dynamic = -1;
-static int hf_80211n_mac_phy_ext_chan_flags_gfsk = -1;
-static int hf_80211n_mac_phy_dbm_ant0signal = -1;
-static int hf_80211n_mac_phy_dbm_ant0noise = -1;
-static int hf_80211n_mac_phy_dbm_ant1signal = -1;
-static int hf_80211n_mac_phy_dbm_ant1noise = -1;
-static int hf_80211n_mac_phy_dbm_ant2signal = -1;
-static int hf_80211n_mac_phy_dbm_ant2noise = -1;
-static int hf_80211n_mac_phy_dbm_ant3signal = -1;
-static int hf_80211n_mac_phy_dbm_ant3noise = -1;
-static int hf_80211n_mac_phy_evm0 = -1;
-static int hf_80211n_mac_phy_evm1 = -1;
-static int hf_80211n_mac_phy_evm2 = -1;
-static int hf_80211n_mac_phy_evm3 = -1;
+static int hf_80211n_mac_phy_mcs;
+static int hf_80211n_mac_phy_num_streams;
+static int hf_80211n_mac_phy_rssi_combined;
+static int hf_80211n_mac_phy_rssi_ant0_ctl;
+static int hf_80211n_mac_phy_rssi_ant1_ctl;
+static int hf_80211n_mac_phy_rssi_ant2_ctl;
+static int hf_80211n_mac_phy_rssi_ant3_ctl;
+static int hf_80211n_mac_phy_rssi_ant0_ext;
+static int hf_80211n_mac_phy_rssi_ant1_ext;
+static int hf_80211n_mac_phy_rssi_ant2_ext;
+static int hf_80211n_mac_phy_rssi_ant3_ext;
+static int hf_80211n_mac_phy_ext_chan_freq;
+static int hf_80211n_mac_phy_ext_chan_flags;
+static int hf_80211n_mac_phy_ext_chan_flags_turbo;
+static int hf_80211n_mac_phy_ext_chan_flags_cck;
+static int hf_80211n_mac_phy_ext_chan_flags_ofdm;
+static int hf_80211n_mac_phy_ext_chan_flags_2ghz;
+static int hf_80211n_mac_phy_ext_chan_flags_5ghz;
+static int hf_80211n_mac_phy_ext_chan_flags_passive;
+static int hf_80211n_mac_phy_ext_chan_flags_dynamic;
+static int hf_80211n_mac_phy_ext_chan_flags_gfsk;
+static int hf_80211n_mac_phy_dbm_ant0signal;
+static int hf_80211n_mac_phy_dbm_ant0noise;
+static int hf_80211n_mac_phy_dbm_ant1signal;
+static int hf_80211n_mac_phy_dbm_ant1noise;
+static int hf_80211n_mac_phy_dbm_ant2signal;
+static int hf_80211n_mac_phy_dbm_ant2noise;
+static int hf_80211n_mac_phy_dbm_ant3signal;
+static int hf_80211n_mac_phy_dbm_ant3noise;
+static int hf_80211n_mac_phy_evm0;
+static int hf_80211n_mac_phy_evm1;
+static int hf_80211n_mac_phy_evm2;
+static int hf_80211n_mac_phy_evm3;
 
 /* 802.11n-Extensions A-MPDU fragments */
-static int hf_ampdu_reassembled_in = -1;
-/* static int hf_ampdu_segments = -1; */
-static int hf_ampdu_segment = -1;
-static int hf_ampdu_count  = -1;
+static int hf_ampdu_reassembled_in;
+/* static int hf_ampdu_segments; */
+static int hf_ampdu_segment;
+static int hf_ampdu_count;
 
 /* Spectrum-Map */
-static int hf_spectrum_map = -1;
+static int hf_spectrum_map;
 
 /* Process-Info */
-static int hf_process_info = -1;
+static int hf_process_info;
 
 /* Capture-Info */
-static int hf_capture_info = -1;
+static int hf_capture_info;
 
 /* Aggregation Extension */
-static int hf_aggregation_extension_interface_id = -1;
+static int hf_aggregation_extension_interface_id;
 
 /* 802.3 Extension */
-static int hf_8023_extension_flags = -1;
-static int hf_8023_extension_flags_fcs_present = -1;
-static int hf_8023_extension_errors = -1;
-static int hf_8023_extension_errors_fcs = -1;
-static int hf_8023_extension_errors_sequence = -1;
-static int hf_8023_extension_errors_symbol = -1;
-static int hf_8023_extension_errors_data = -1;
+static int hf_8023_extension_flags;
+static int hf_8023_extension_flags_fcs_present;
+static int hf_8023_extension_errors;
+static int hf_8023_extension_errors_fcs;
+static int hf_8023_extension_errors_sequence;
+static int hf_8023_extension_errors_symbol;
+static int hf_8023_extension_errors_data;
 
 /* Generated from convert_proto_tree_add_text.pl */
-static int hf_ppi_antenna = -1;
-static int hf_ppi_harris = -1;
-static int hf_ppi_reserved = -1;
-static int hf_ppi_vector = -1;
-static int hf_ppi_fnet = -1;
-static int hf_ppi_gps = -1;
+static int hf_ppi_antenna;
+static int hf_ppi_harris;
+static int hf_ppi_reserved;
+static int hf_ppi_vector;
+static int hf_ppi_fnet;
+static int hf_ppi_gps;
 
-static gint ett_ppi_pph = -1;
-static gint ett_ppi_flags = -1;
-static gint ett_dot11_common = -1;
-static gint ett_dot11_common_flags = -1;
-static gint ett_dot11_common_channel_flags = -1;
-static gint ett_dot11n_mac = -1;
-static gint ett_dot11n_mac_flags = -1;
-static gint ett_dot11n_mac_phy = -1;
-static gint ett_dot11n_mac_phy_ext_channel_flags = -1;
-static gint ett_ampdu_segments = -1;
-static gint ett_ampdu = -1;
-static gint ett_ampdu_segment  = -1;
-static gint ett_aggregation_extension = -1;
-static gint ett_8023_extension = -1;
-static gint ett_8023_extension_flags = -1;
-static gint ett_8023_extension_errors = -1;
+static gint ett_ppi_pph;
+static gint ett_ppi_flags;
+static gint ett_dot11_common;
+static gint ett_dot11_common_flags;
+static gint ett_dot11_common_channel_flags;
+static gint ett_dot11n_mac;
+static gint ett_dot11n_mac_flags;
+static gint ett_dot11n_mac_phy;
+static gint ett_dot11n_mac_phy_ext_channel_flags;
+static gint ett_ampdu_segments;
+static gint ett_ampdu;
+static gint ett_ampdu_segment;
+static gint ett_aggregation_extension;
+static gint ett_8023_extension;
+static gint ett_8023_extension_flags;
+static gint ett_8023_extension_errors;
 
 /* Generated from convert_proto_tree_add_text.pl */
-static expert_field ei_ppi_invalid_length = EI_INIT;
+static expert_field ei_ppi_invalid_length;
 
 static dissector_handle_t ppi_handle;
 
@@ -353,10 +353,10 @@ static const value_string vs_ppi_field_type[] = {
 static reassembly_table ampdu_reassembly_table;
 
 /* Reassemble A-MPDUs? */
-static gboolean ppi_ampdu_reassemble = TRUE;
+static bool ppi_ampdu_reassemble = true;
 
 
-static gboolean
+static bool
 capture_ppi(const guchar *pd, int offset _U_, int len, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header _U_)
 {
     guint32  dlt;
@@ -403,11 +403,11 @@ ptvcursor_add_invalid_check(ptvcursor_t *csr, int hf, gint len, guint64 invalid_
 }
 
 static void
-add_ppi_field_header(tvbuff_t *tvb, proto_tree *tree, int *offset)
+add_ppi_field_header(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int *offset)
 {
     ptvcursor_t *csr;
 
-    csr = ptvcursor_new(wmem_packet_scope(), tree, tvb, *offset);
+    csr = ptvcursor_new(pinfo->pool, tree, tvb, *offset);
     ptvcursor_add(csr, hf_ppi_field_type, 2, ENC_LITTLE_ENDIAN);
     ptvcursor_add(csr, hf_ppi_field_len, 2, ENC_LITTLE_ENDIAN);
     ptvcursor_free(csr);
@@ -431,7 +431,7 @@ dissect_80211_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int of
     gchar       *chan_str;
 
     ftree = proto_tree_add_subtree(tree, tvb, offset, data_len, ett_dot11_common, NULL, "802.11-Common");
-    add_ppi_field_header(tvb, ftree, &offset);
+    add_ppi_field_header(tvb, pinfo, ftree, &offset);
     data_len -= 4; /* Subtract field header length */
 
     if (data_len != PPI_80211_COMMON_LEN) {
@@ -495,7 +495,7 @@ dissect_80211_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int of
     chan_str = ieee80211_mhz_to_str(common_frequency);
     proto_tree_add_uint_format_value(ptvcursor_tree(csr), hf_80211_common_chan_freq, ptvcursor_tvbuff(csr),
                                ptvcursor_current_offset(csr), 2, common_frequency, "%s", chan_str);
-    col_add_fstr(pinfo->cinfo, COL_FREQ_CHAN, "%s", chan_str);
+    col_add_str(pinfo->cinfo, COL_FREQ_CHAN, chan_str);
     g_free(chan_str);
     ptvcursor_advance(csr, 2);
 
@@ -601,7 +601,7 @@ dissect_80211_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int of
 }
 
 static void
-dissect_80211n_mac(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int offset, int data_len, gboolean add_subtree, guint32 *n_mac_flags, guint32 *ampdu_id, struct ieee_802_11_phdr *phdr)
+dissect_80211n_mac(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, int data_len, gboolean add_subtree, guint32 *n_mac_flags, guint32 *ampdu_id, struct ieee_802_11_phdr *phdr)
 {
     proto_tree  *ftree       = tree;
     ptvcursor_t *csr;
@@ -611,7 +611,7 @@ dissect_80211n_mac(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int
 
     if (add_subtree) {
         ftree = proto_tree_add_subtree(tree, tvb, offset, data_len, ett_dot11n_mac, NULL, "802.11n MAC");
-        add_ppi_field_header(tvb, ftree, &offset);
+        add_ppi_field_header(tvb, pinfo, ftree, &offset);
         data_len -= 4; /* Subtract field header length */
     }
 
@@ -675,7 +675,7 @@ dissect_80211n_mac_phy(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int
     gchar       *chan_str;
 
     ftree = proto_tree_add_subtree(tree, tvb, offset, data_len, ett_dot11n_mac_phy, NULL, "802.11n MAC+PHY");
-    add_ppi_field_header(tvb, ftree, &offset);
+    add_ppi_field_header(tvb, pinfo, ftree, &offset);
     data_len -= 4; /* Subtract field header length */
 
     if (data_len != PPI_80211N_MAC_PHY_LEN) {
@@ -748,13 +748,13 @@ dissect_80211n_mac_phy(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int
 }
 
 static void
-dissect_aggregation_extension(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int offset, int data_len)
+dissect_aggregation_extension(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, int data_len)
 {
     proto_tree *ftree;
     ptvcursor_t *csr;
 
     ftree = proto_tree_add_subtree(tree, tvb, offset, data_len, ett_aggregation_extension, NULL, "Aggregation Extension");
-    add_ppi_field_header(tvb, ftree, &offset);
+    add_ppi_field_header(tvb, pinfo, ftree, &offset);
     data_len -= 4; /* Subtract field header length */
 
     if (data_len != PPI_AGGREGATION_EXTENSION_LEN) {
@@ -769,13 +769,13 @@ dissect_aggregation_extension(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree
 }
 
 static void
-dissect_8023_extension(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, int offset, int data_len)
+dissect_8023_extension(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, int data_len)
 {
     proto_tree  *ftree;
     ptvcursor_t *csr;
 
     ftree = proto_tree_add_subtree(tree, tvb, offset, data_len, ett_8023_extension, NULL, "802.3 Extension");
-    add_ppi_field_header(tvb, ftree, &offset);
+    add_ppi_field_header(tvb, pinfo, ftree, &offset);
     data_len -= 4; /* Subtract field header length */
 
     if (data_len != PPI_8023_EXTENSION_LEN) {
@@ -920,7 +920,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
             }
             else /* we found a suitable dissector */
             {
-                /* skip over the ppi_fieldheader, and pass it off to the dedicated GPS dissetor */
+                /* skip over the ppi_fieldheader, and pass it off to the dedicated GPS dissector */
                 next_tvb = tvb_new_subset_length_caplen(tvb, offset + 4, data_len - 4 , -1);
                 call_dissector(ppi_gps_handle, next_tvb, pinfo, ppi_tree);
             }
@@ -933,7 +933,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
             }
             else /* we found a suitable dissector */
             {
-                /* skip over the ppi_fieldheader, and pass it off to the dedicated VECTOR dissetor */
+                /* skip over the ppi_fieldheader, and pass it off to the dedicated VECTOR dissector */
                 next_tvb = tvb_new_subset_length_caplen(tvb, offset + 4, data_len - 4 , -1);
                 call_dissector(ppi_vector_handle, next_tvb, pinfo, ppi_tree);
             }
@@ -946,7 +946,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
             }
             else /* we found a suitable dissector */
             {
-                /* skip over the ppi_fieldheader, and pass it off to the dedicated SENSOR dissetor */
+                /* skip over the ppi_fieldheader, and pass it off to the dedicated SENSOR dissector */
                 next_tvb = tvb_new_subset_length_caplen(tvb, offset + 4, data_len - 4 , -1);
                 call_dissector(ppi_sensor_handle, next_tvb, pinfo, ppi_tree);
             }
@@ -959,7 +959,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
             }
             else /* we found a suitable dissector */
             {
-                /* skip over the ppi_fieldheader, and pass it off to the dedicated ANTENNA dissetor */
+                /* skip over the ppi_fieldheader, and pass it off to the dedicated ANTENNA dissector */
                 next_tvb = tvb_new_subset_length_caplen(tvb, offset + 4, data_len - 4 , -1);
                 call_dissector(ppi_antenna_handle, next_tvb, pinfo, ppi_tree);
             }
@@ -972,7 +972,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
             }
             else /* we found a suitable dissector */
             {
-                /* skip over the ppi_fieldheader, and pass it off to the dedicated FNET dissetor */
+                /* skip over the ppi_fieldheader, and pass it off to the dedicated FNET dissector */
                 next_tvb = tvb_new_subset_length_caplen(tvb, offset + 4, data_len - 4 , -1);
                 call_dissector(ppi_fnet_handle, next_tvb, pinfo, ppi_tree);
             }
@@ -1212,7 +1212,7 @@ dissect_ppi(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     return tvb_captured_length(tvb);
 }
 
-/* Establish our beachead */
+/* Establish our beachhead */
 
 void
 proto_register_ppi(void)
@@ -1322,25 +1322,25 @@ proto_register_ppi(void)
          FT_UINT32, BASE_HEX, NULL, 0x0, "PPI 802.11n MAC flags", HFILL } },
     { &hf_80211n_mac_flags_greenfield,
        { "Greenfield flag", "ppi.80211n-mac.flags.greenfield",
-         FT_BOOLEAN, 32, TFS(&tfs_true_false), DOT11N_FLAG_GREENFIELD, "PPI 802.11n MAC Greenfield Flag", HFILL } },
+         FT_BOOLEAN, 32, NULL, DOT11N_FLAG_GREENFIELD, "PPI 802.11n MAC Greenfield Flag", HFILL } },
     { &hf_80211n_mac_flags_ht20_40,
        { "HT20/HT40 flag", "ppi.80211n-mac.flags.ht20_40",
          FT_BOOLEAN, 32, TFS(&tfs_ht20_40), DOT11N_FLAG_HT40, "PPI 802.11n MAC HT20/HT40 Flag", HFILL } },
     { &hf_80211n_mac_flags_rx_guard_interval,
        { "RX Short Guard Interval (SGI) flag", "ppi.80211n-mac.flags.rx.short_guard_interval",
-         FT_BOOLEAN, 32, TFS(&tfs_true_false), DOT11N_FLAG_SHORT_GI, "PPI 802.11n MAC RX Short Guard Interval (SGI) Flag", HFILL } },
+         FT_BOOLEAN, 32, NULL, DOT11N_FLAG_SHORT_GI, "PPI 802.11n MAC RX Short Guard Interval (SGI) Flag", HFILL } },
     { &hf_80211n_mac_flags_duplicate_rx,
        { "Duplicate RX flag", "ppi.80211n-mac.flags.rx.duplicate",
-         FT_BOOLEAN, 32, TFS(&tfs_true_false), DOT11N_FLAG_DUPLICATE_RX, "PPI 802.11n MAC Duplicate RX Flag", HFILL } },
+         FT_BOOLEAN, 32, NULL, DOT11N_FLAG_DUPLICATE_RX, "PPI 802.11n MAC Duplicate RX Flag", HFILL } },
     { &hf_80211n_mac_flags_aggregate,
        { "Aggregate flag", "ppi.80211n-mac.flags.agg",
-         FT_BOOLEAN, 32, TFS(&tfs_true_false), DOT11N_FLAG_IS_AGGREGATE, "PPI 802.11 MAC Aggregate Flag", HFILL } },
+         FT_BOOLEAN, 32, NULL, DOT11N_FLAG_IS_AGGREGATE, "PPI 802.11 MAC Aggregate Flag", HFILL } },
     { &hf_80211n_mac_flags_more_aggregates,
        { "More aggregates flag", "ppi.80211n-mac.flags.more_agg",
-         FT_BOOLEAN, 32, TFS(&tfs_true_false), DOT11N_FLAG_MORE_AGGREGATES, "PPI 802.11n MAC More Aggregates Flag", HFILL } },
+         FT_BOOLEAN, 32, NULL, DOT11N_FLAG_MORE_AGGREGATES, "PPI 802.11n MAC More Aggregates Flag", HFILL } },
     { &hf_80211n_mac_flags_delimiter_crc_after,
        { "A-MPDU Delimiter CRC error after this frame flag", "ppi.80211n-mac.flags.delim_crc_error_after",
-         FT_BOOLEAN, 32, TFS(&tfs_true_false), DOT11N_FLAG_AGG_CRC_ERROR, "PPI 802.11n MAC A-MPDU Delimiter CRC Error After This Frame Flag", HFILL } },
+         FT_BOOLEAN, 32, NULL, DOT11N_FLAG_AGG_CRC_ERROR, "PPI 802.11n MAC A-MPDU Delimiter CRC Error After This Frame Flag", HFILL } },
     { &hf_80211n_mac_ampdu_id,
        { "AMPDU-ID", "ppi.80211n-mac.ampdu_id",
          FT_UINT32, BASE_HEX, NULL, 0x0, "PPI 802.11n MAC AMPDU-ID", HFILL } },
@@ -1480,7 +1480,7 @@ proto_register_ppi(void)
        { "Capture information", "ppi.cap-info",
             FT_BYTES, BASE_NONE, NULL, 0x0, "PPI Capture information", HFILL } },
 
-    /* Aggregtion Extension */
+    /* Aggregation Extension */
     { &hf_aggregation_extension_interface_id,
        { "Interface ID", "ppi.aggregation_extension.interface_id",
             FT_UINT32, BASE_DEC, NULL, 0x0, "Zero-based index of the physical interface the packet was captured from", HFILL } },
@@ -1491,25 +1491,25 @@ proto_register_ppi(void)
             FT_UINT32, BASE_HEX, NULL, 0x0, "PPI 802.3 Extension Flags", HFILL } },
     { &hf_8023_extension_flags_fcs_present,
        { "FCS Present Flag", "ppi.8023_extension.flags.fcs_present",
-            FT_BOOLEAN, 32, TFS(&tfs_true_false), 0x00000001, "FCS (4 bytes) is present at the end of the packet", HFILL } },
+            FT_BOOLEAN, 32, NULL, 0x00000001, "FCS (4 bytes) is present at the end of the packet", HFILL } },
     { &hf_8023_extension_errors,
        { "Errors", "ppi.8023_extension.errors",
             FT_UINT32, BASE_HEX, NULL, 0x0, "PPI 802.3 Extension Errors", HFILL } },
     { &hf_8023_extension_errors_fcs,
        { "FCS Error", "ppi.8023_extension.errors.fcs",
-            FT_BOOLEAN, 32, TFS(&tfs_true_false), 0x00000001,
+            FT_BOOLEAN, 32, NULL, 0x00000001,
             "PPI 802.3 Extension FCS Error", HFILL } },
     { &hf_8023_extension_errors_sequence,
        { "Sequence Error", "ppi.8023_extension.errors.sequence",
-            FT_BOOLEAN, 32, TFS(&tfs_true_false), 0x00000002,
+            FT_BOOLEAN, 32, NULL, 0x00000002,
             "PPI 802.3 Extension Sequence Error", HFILL } },
     { &hf_8023_extension_errors_symbol,
        { "Symbol Error", "ppi.8023_extension.errors.symbol",
-            FT_BOOLEAN, 32, TFS(&tfs_true_false), 0x00000004,
+            FT_BOOLEAN, 32, NULL, 0x00000004,
             "PPI 802.3 Extension Symbol Error", HFILL } },
     { &hf_8023_extension_errors_data,
        { "Data Error", "ppi.8023_extension.errors.data",
-            FT_BOOLEAN, 32, TFS(&tfs_true_false), 0x00000008,
+            FT_BOOLEAN, 32, NULL, 0x00000008,
             "PPI 802.3 Extension Data Error", HFILL } },
 
       /* Generated from convert_proto_tree_add_text.pl */
