@@ -20,60 +20,62 @@
 void proto_register_pptp(void);
 void proto_reg_handoff_pptp(void);
 
-static int proto_pptp = -1;
-static int hf_pptp_length = -1;
-static int hf_pptp_message_type = -1;
-static int hf_pptp_magic_cookie = -1;
-static int hf_pptp_control_message_type = -1;
-static int hf_pptp_reserved = -1;
-static int hf_pptp_protocol_version = -1;
-static int hf_pptp_framing_capabilities = -1;
-static int hf_pptp_bearer_capabilities = -1;
-static int hf_pptp_maximum_channels = -1;
-static int hf_pptp_firmware_revision = -1;
-static int hf_pptp_host_name = -1;
-static int hf_pptp_vendor_name = -1;
-static int hf_pptp_control_result = -1;
-static int hf_pptp_error = -1;
-static int hf_pptp_reason = -1;
-static int hf_pptp_stop_result = -1;
-static int hf_pptp_identifier = -1;
-static int hf_pptp_echo_result = -1;
-static int hf_pptp_call_id = -1;
-static int hf_pptp_call_serial_number = -1;
-static int hf_pptp_minimum_bps = -1;
-static int hf_pptp_maximum_bps = -1;
-static int hf_pptp_bearer_type = -1;
-static int hf_pptp_framing_type = -1;
-static int hf_pptp_packet_receive_window_size = -1;
-static int hf_pptp_packet_processing_delay = -1;
-static int hf_pptp_phone_number_length = -1;
-static int hf_pptp_phone_number = -1;
-static int hf_pptp_subaddress = -1;
-static int hf_pptp_peer_call_id = -1;
-static int hf_pptp_out_result = -1;
-static int hf_pptp_cause = -1;
-static int hf_pptp_connect_speed = -1;
-static int hf_pptp_physical_channel_id = -1;
-static int hf_pptp_dialed_number_length = -1;
-static int hf_pptp_dialed_number = -1;
-static int hf_pptp_dialing_number_length = -1;
-static int hf_pptp_dialing_number = -1;
-static int hf_pptp_in_result = -1;
-static int hf_pptp_disc_result = -1;
-static int hf_pptp_call_statistics = -1;
-static int hf_pptp_crc_errors = -1;
-static int hf_pptp_framing_errors = -1;
-static int hf_pptp_hardware_overruns = -1;
-static int hf_pptp_buffer_overruns = -1;
-static int hf_pptp_timeout_errors = -1;
-static int hf_pptp_alignment_errors = -1;
-static int hf_pptp_send_accm = -1;
-static int hf_pptp_receive_accm = -1;
+static dissector_handle_t pptp_handle;
 
-static gint ett_pptp = -1;
+static int proto_pptp;
+static int hf_pptp_length;
+static int hf_pptp_message_type;
+static int hf_pptp_magic_cookie;
+static int hf_pptp_control_message_type;
+static int hf_pptp_reserved;
+static int hf_pptp_protocol_version;
+static int hf_pptp_framing_capabilities;
+static int hf_pptp_bearer_capabilities;
+static int hf_pptp_maximum_channels;
+static int hf_pptp_firmware_revision;
+static int hf_pptp_host_name;
+static int hf_pptp_vendor_name;
+static int hf_pptp_control_result;
+static int hf_pptp_error;
+static int hf_pptp_reason;
+static int hf_pptp_stop_result;
+static int hf_pptp_identifier;
+static int hf_pptp_echo_result;
+static int hf_pptp_call_id;
+static int hf_pptp_call_serial_number;
+static int hf_pptp_minimum_bps;
+static int hf_pptp_maximum_bps;
+static int hf_pptp_bearer_type;
+static int hf_pptp_framing_type;
+static int hf_pptp_packet_receive_window_size;
+static int hf_pptp_packet_processing_delay;
+static int hf_pptp_phone_number_length;
+static int hf_pptp_phone_number;
+static int hf_pptp_subaddress;
+static int hf_pptp_peer_call_id;
+static int hf_pptp_out_result;
+static int hf_pptp_cause;
+static int hf_pptp_connect_speed;
+static int hf_pptp_physical_channel_id;
+static int hf_pptp_dialed_number_length;
+static int hf_pptp_dialed_number;
+static int hf_pptp_dialing_number_length;
+static int hf_pptp_dialing_number;
+static int hf_pptp_in_result;
+static int hf_pptp_disc_result;
+static int hf_pptp_call_statistics;
+static int hf_pptp_crc_errors;
+static int hf_pptp_framing_errors;
+static int hf_pptp_hardware_overruns;
+static int hf_pptp_buffer_overruns;
+static int hf_pptp_timeout_errors;
+static int hf_pptp_alignment_errors;
+static int hf_pptp_send_accm;
+static int hf_pptp_receive_accm;
 
-static expert_field ei_pptp_incorrect_magic_cookie = EI_INIT;
+static gint ett_pptp;
+
+static expert_field ei_pptp_incorrect_magic_cookie;
 
 #define TCP_PORT_PPTP           1723
 
@@ -280,10 +282,10 @@ dissect_stop_req(tvbuff_t *tvb, int offset, packet_info *pinfo _U_, proto_tree *
 
   proto_tree_add_item(tree, hf_pptp_reason,   tvb, offset, 1, ENC_BIG_ENDIAN);
   offset += 1;
-
+  /* Reserved1 */
   proto_tree_add_item(tree, hf_pptp_reserved, tvb, offset, 1, ENC_NA);
   offset += 1;
-
+  /* Reserved2 */
   proto_tree_add_item(tree, hf_pptp_reserved, tvb, offset, 2, ENC_NA);
 }
 
@@ -937,6 +939,7 @@ proto_register_pptp(void)
 
   proto_pptp = proto_register_protocol("Point-to-Point Tunnelling Protocol",
                                        "PPTP", "pptp");
+  pptp_handle = register_dissector("pptp", dissect_pptp, proto_pptp);
   proto_register_field_array(proto_pptp, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
   expert_pptp = expert_register_protocol(proto_pptp);
@@ -946,9 +949,6 @@ proto_register_pptp(void)
 void
 proto_reg_handoff_pptp(void)
 {
-  dissector_handle_t pptp_handle;
-
-  pptp_handle = create_dissector_handle(dissect_pptp, proto_pptp);
   dissector_add_uint_with_preference("tcp.port", TCP_PORT_PPTP, pptp_handle);
 }
 
