@@ -41,69 +41,69 @@ void proto_reg_handoff_pw_atm_ata(void);
 void proto_register_pw_atm(void);
 void proto_reg_handoff_pw_atm(void);
 
-static gint proto_n1_nocw = -1;
-static gint proto_n1_cw = -1;
-static gint proto_11_or_aal5_pdu = -1;
-static gint proto_aal5_sdu = -1;
+static gint proto_n1_nocw;
+static gint proto_n1_cw;
+static gint proto_11_or_aal5_pdu;
+static gint proto_aal5_sdu;
 /* subordinate dissectors: */
-static gint proto_control_word = -1;
-static gint proto_cell_header = -1;
-static gint proto_cell = -1;
+static gint proto_control_word;
+static gint proto_cell_header;
+static gint proto_cell;
 
-static gint ett_encaps = -1;
-static gint ett_cw = -1;
-static gint ett_cell_header = -1;
-static gint ett_cell = -1;
+static gint ett_encaps;
+static gint ett_cw;
+static gint ett_cell_header;
+static gint ett_cell;
 
-static int hf_pw_type_n1_cw = -1;
-static int hf_pw_type_n1_nocw = -1;
-static int hf_pw_type_11_vcc = -1;
-static int hf_pw_type_11_vpc = -1;
-static int hf_pw_type_aal5_sdu = -1;
-static int hf_pw_type_aal5_pdu = -1;
+static int hf_pw_type_n1_cw;
+static int hf_pw_type_n1_nocw;
+static int hf_pw_type_11_vcc;
+static int hf_pw_type_11_vpc;
+static int hf_pw_type_aal5_sdu;
+static int hf_pw_type_aal5_pdu;
 
-static int hf_cell_h_vpi = -1;
-static int hf_cell_h_vci = -1;
-static int hf_cell_h_pti = -1;
-static int hf_cell_h_clp = -1;
-static int hf_cell_h_m = -1;
-static int hf_cell_h_v = -1;
-static int hf_cell_h_rsv = -1;
-static int hf_aal5_pdu_rsv = -1;
-static int hf_aal5_pdu_u = -1;
-static int hf_aal5_pdu_e = -1;
+static int hf_cell_h_vpi;
+static int hf_cell_h_vci;
+static int hf_cell_h_pti;
+static int hf_cell_h_clp;
+static int hf_cell_h_m;
+static int hf_cell_h_v;
+static int hf_cell_h_rsv;
+static int hf_aal5_pdu_rsv;
+static int hf_aal5_pdu_u;
+static int hf_aal5_pdu_e;
 
-static int hf_cw_bits03 = -1;
-static int hf_pref_cw_rsv = -1;
-static int hf_generic_cw_rsv = -1;
-static int hf_pref_cw_flags = -1;
-static int hf_pref_cw_a5s_t = -1;
-static int hf_pref_cw_a5s_e = -1;
-static int hf_pref_cw_a5s_c = -1;
-static int hf_pref_cw_a5s_u = -1;
-static int hf_pref_cw_len = -1;
-static int hf_pref_cw_rsvlen = -1;
-static int hf_cw_seq = -1;
-static int hf_n1_cw_ncells = -1;
-static int hf_n1_nocw_ncells = -1;
-static int hf_11_ncells = -1;
-static int hf_gen_cw_atmbyte = -1;
-static int hf_cell_payload_len = -1;
+static int hf_cw_bits03;
+static int hf_pref_cw_rsv;
+static int hf_generic_cw_rsv;
+static int hf_pref_cw_flags;
+static int hf_pref_cw_a5s_t;
+static int hf_pref_cw_a5s_e;
+static int hf_pref_cw_a5s_c;
+static int hf_pref_cw_a5s_u;
+static int hf_pref_cw_len;
+static int hf_pref_cw_rsvlen;
+static int hf_cw_seq;
+static int hf_n1_cw_ncells;
+static int hf_n1_nocw_ncells;
+static int hf_11_ncells;
+static int hf_gen_cw_atmbyte;
+static int hf_cell_payload_len;
 
-static expert_field ei_cell_h_v_not_one = EI_INIT;
-static expert_field ei_cell_h_pti_undecoded = EI_INIT;
-static expert_field ei_pref_cw_flags = EI_INIT;
-static expert_field ei_cell_h_v_not_zero = EI_INIT;
-static expert_field ei_pw_payload_size_invalid_note = EI_INIT;
-static expert_field ei_pw_payload_size_invalid_error = EI_INIT;
-static expert_field ei_cell_h_pti_malformed = EI_INIT;
-static expert_field ei_cell_h_rsv = EI_INIT;
-static expert_field ei_cell_broken = EI_INIT;
-static expert_field ei_cell_h_m = EI_INIT;
-static expert_field ei_cw_bits03 = EI_INIT;
-static expert_field ei_pw_packet_size_too_small = EI_INIT;
-static expert_field ei_pref_cw_len = EI_INIT;
-static expert_field ei_gen_cw_atmbyte = EI_INIT;
+static expert_field ei_cell_h_v_not_one;
+static expert_field ei_cell_h_pti_undecoded;
+static expert_field ei_pref_cw_flags;
+static expert_field ei_cell_h_v_not_zero;
+static expert_field ei_pw_payload_size_invalid_note;
+static expert_field ei_pw_payload_size_invalid_error;
+static expert_field ei_cell_h_pti_malformed;
+static expert_field ei_cell_h_rsv;
+static expert_field ei_cell_broken;
+static expert_field ei_cell_h_m;
+static expert_field ei_cw_bits03;
+static expert_field ei_pw_packet_size_too_small;
+static expert_field ei_pref_cw_len;
+static expert_field ei_gen_cw_atmbyte;
 
 
 static dissector_handle_t dh_cell;
@@ -247,10 +247,10 @@ static const char shortname_aal5_pdu[]          = "MPLS PW ATM AAL5 PDU";
  * Note that these options will affect PW type auto-guessing, if such heuristic
  * implemented in the future.
  */
-static gboolean pref_n1_cw_allow_cw_length_nonzero       = FALSE;
-static gboolean pref_n1_cw_extend_cw_length_with_rsvd    = FALSE;
-static gboolean pref_aal5_sdu_allow_cw_length_nonzero    = FALSE;
-static gboolean pref_aal5_sdu_extend_cw_length_with_rsvd = FALSE;
+static bool pref_n1_cw_allow_cw_length_nonzero;
+static bool pref_n1_cw_extend_cw_length_with_rsvd;
+static bool pref_aal5_sdu_allow_cw_length_nonzero;
+static bool pref_aal5_sdu_extend_cw_length_with_rsvd;
 
 
 static int
@@ -1779,7 +1779,7 @@ proto_register_pw_atm_ata(void)
 		  { "Number of good N:1 no CW encapsulated cells", "pw.atm.n1_nocw.cells", FT_INT32,
 		    BASE_DEC, NULL, 0, NULL, HFILL }},
 		{ &hf_pw_type_n1_nocw,
-		  { "N:1 noCW", "pw.type.atm.n1nocw", FT_BOOLEAN, 0, NULL, 0x0,
+		  { "N:1 noCW", "pw.type.atm.n1nocw", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 		    NULL, HFILL }}
 	};
 
@@ -1788,7 +1788,7 @@ proto_register_pw_atm_ata(void)
 		  { "Number of good N:1 CW encapsulated cells", "pw.atm.n1_cw.cells", FT_INT32,
 		    BASE_DEC, NULL, 0, NULL, HFILL }},
 		{ &hf_pw_type_n1_cw,
-		  { "N:1 CW", "pw.type.atm.n1cw", FT_BOOLEAN, 0, NULL, 0x0,
+		  { "N:1 CW", "pw.type.atm.n1cw", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 		    NULL, HFILL }}
 	};
 
@@ -1797,19 +1797,19 @@ proto_register_pw_atm_ata(void)
 		  { "Number of good 1:1 encapsulated cells", "pw.atm.11.cells", FT_INT32,
 		    BASE_DEC, NULL, 0, NULL, HFILL }},
 		{ &hf_pw_type_11_vcc,
-		  { "1:1 VCC", "pw.type.atm.11vcc", FT_BOOLEAN, 0, NULL, 0x0,
+		  { "1:1 VCC", "pw.type.atm.11vcc", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 		    NULL, HFILL }},
 		{ &hf_pw_type_11_vpc,
-		  { "1:1 VPC", "pw.type.atm.11vpc", FT_BOOLEAN, 0, NULL, 0x0,
+		  { "1:1 VPC", "pw.type.atm.11vpc", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 		    NULL, HFILL }},
 		{ &hf_pw_type_aal5_pdu,
-		  { "AAL5 PDU", "pw.type.atm.aal5pdu", FT_BOOLEAN, 0, NULL, 0x0,
+		  { "AAL5 PDU", "pw.type.atm.aal5pdu", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 		    NULL, HFILL }}
 	};
 
 	static hf_register_info hfa_aal5_sdu[] = {
 		{ &hf_pw_type_aal5_sdu,
-		  { "AAL5 SDU", "pw.type.atm.aal5sdu", FT_BOOLEAN, 0, NULL, 0x0,
+		  { "AAL5 SDU", "pw.type.atm.aal5sdu", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
 		    NULL, HFILL }}
 	};
 
@@ -2018,12 +2018,16 @@ proto_reg_handoff_pw_atm_ata(void)
 	dissector_handle_t h;
 	h = find_dissector("mpls_pw_atm_n1_cw");
 	dissector_add_for_decode_as( "mpls.label", h );
+	dissector_add_for_decode_as( "mpls.pfn", h);
 	h = find_dissector("mpls_pw_atm_n1_nocw");
 	dissector_add_for_decode_as( "mpls.label", h );
+	dissector_add_for_decode_as( "mpls.pfn", h);
 	h = find_dissector("mpls_pw_atm_11_or_aal5_pdu");
 	dissector_add_for_decode_as( "mpls.label", h );
+	dissector_add_for_decode_as( "mpls.pfn", h);
 	h = find_dissector("mpls_pw_atm_aal5_sdu");
 	dissector_add_for_decode_as( "mpls.label", h );
+	dissector_add_for_decode_as( "mpls.pfn", h);
 
 	dh_atm_truncated   = find_dissector("atm_pw_truncated");
 	dh_atm_untruncated = find_dissector("atm_pw_untruncated");
