@@ -30,25 +30,25 @@ void proto_register_pw_cesopsn(void);
 void proto_reg_handoff_pw_cesopsn(void);
 
 static gint proto = -1;
-static gint ett_pw_cesopsn = -1;
+static gint ett_pw_cesopsn;
 
-static int hf_cw = -1;
-static int hf_cw_bits03 = -1;
-static int hf_cw_lm = -1;
-static int hf_cw_r = -1;
-static int hf_cw_frg = -1;
-static int hf_cw_len = -1;
-static int hf_cw_seq = -1;
-static int hf_payload = -1;
-static int hf_payload_l = -1;
+static int hf_cw;
+static int hf_cw_bits03;
+static int hf_cw_lm;
+static int hf_cw_r;
+static int hf_cw_frg;
+static int hf_cw_len;
+static int hf_cw_seq;
+static int hf_payload;
+static int hf_payload_l;
 
-static expert_field ei_payload_size_invalid_undecoded = EI_INIT;
-static expert_field ei_cw_frg = EI_INIT;
-static expert_field ei_payload_size_invalid_error = EI_INIT;
-static expert_field ei_cw_bits03 = EI_INIT;
-static expert_field ei_pref_cw_len = EI_INIT;
-static expert_field ei_cw_lm = EI_INIT;
-static expert_field ei_packet_size_too_small = EI_INIT;
+static expert_field ei_payload_size_invalid_undecoded;
+static expert_field ei_cw_frg;
+static expert_field ei_payload_size_invalid_error;
+static expert_field ei_cw_bits03;
+static expert_field ei_pref_cw_len;
+static expert_field ei_cw_lm;
+static expert_field ei_packet_size_too_small;
 
 static dissector_handle_t pw_padding_handle;
 static dissector_handle_t pw_cesopsn_udp_handle;
@@ -445,6 +445,7 @@ void proto_reg_handoff_pw_cesopsn(void)
 
 	/* For Decode As */
 	dissector_add_for_decode_as("mpls.label", pw_cesopsn_mpls_handle);
+	dissector_add_for_decode_as("mpls.pfn", pw_cesopsn_mpls_handle);
 
 	dissector_add_for_decode_as_with_preference("udp.port", pw_cesopsn_udp_handle);
 }
