@@ -27,23 +27,23 @@
 void proto_register_pw_fr(void);
 void proto_reg_handoff_pw_fr(void);
 
-static gint proto_encaps = -1;
-static gint ett_encaps = -1;
+static gint proto_encaps;
+static gint ett_encaps;
 
-/* static int hf_pw_fr = -1; */
-static int hf_cw_bits03 = -1;
-static int hf_cw_fecn = -1;
-static int hf_cw_becn = -1;
-static int hf_cw_de = -1;
-static int hf_cw_cr = -1;
-static int hf_cw_frg = -1;
-static int hf_cw_len = -1;
-static int hf_cw_seq = -1;
-static int hf_cw_padding = -1;
+/* static int hf_pw_fr; */
+static int hf_cw_bits03;
+static int hf_cw_fecn;
+static int hf_cw_becn;
+static int hf_cw_de;
+static int hf_cw_cr;
+static int hf_cw_frg;
+static int hf_cw_len;
+static int hf_cw_seq;
+static int hf_cw_padding;
 
-static expert_field ei_payload_size_invalid = EI_INIT;
-static expert_field ei_cw_bits03 = EI_INIT;
-static expert_field ei_cw_packet_size_too_small = EI_INIT;
+static expert_field ei_payload_size_invalid;
+static expert_field ei_cw_bits03;
+static expert_field ei_cw_packet_size_too_small;
 
 static const value_string vals_frg[] = {
 	{ 0x0,	"Unfragmented" },
@@ -174,7 +174,7 @@ dissect_pw_fr( tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void* dat
 		proto_item* item;
 
 		item_headline = proto_tree_add_item(tree, proto_encaps, tvb, 0, 4, ENC_NA);
-		proto_item_append_text(item_headline, ": 0x%.8" G_GINT32_MODIFIER "x", tvb_get_ntohl(tvb, 0));
+		proto_item_append_text(item_headline, ": 0x%.8" PRIx32, tvb_get_ntohl(tvb, 0));
 		subtree = proto_item_add_subtree(item_headline, ett_encaps);
 
 		if (packet_quality & PQ_CW_BAD_BITS03) /*display only if value is wrong*/
@@ -266,7 +266,7 @@ static hf_register_info hf[] = {
 			  ,NULL			,0x3f		,NULL
 			  ,HFILL}},
 
-	{&hf_cw_seq	,{"Sequence number"	,"pwfr.length"	,FT_UINT16	,BASE_DEC
+	{&hf_cw_seq	,{"Sequence number"	,"pwfr.seqno"	,FT_UINT16	,BASE_DEC
 			  ,NULL			,0		,NULL
 			  ,HFILL}},
 
@@ -301,6 +301,7 @@ void
 proto_reg_handoff_pw_fr(void)
 {
 	dissector_add_for_decode_as("mpls.label", pw_fr_mpls_handle);
+	dissector_add_for_decode_as("mpls.pfn", pw_fr_mpls_handle);
 	fr_stripped_address_handle = find_dissector_add_dependency("fr_stripped_address", proto_encaps);
 }
 
