@@ -20,47 +20,47 @@
 
 void proto_register_quake(void);
 
-static int proto_quake = -1;
-static int hf_quake_header_flags = -1;
-static int hf_quake_header_flags_data = -1;
-static int hf_quake_header_flags_ack = -1;
-static int hf_quake_header_flags_no_ack = -1;
-static int hf_quake_header_flags_endmsg = -1;
-static int hf_quake_header_flags_unreliable = -1;
-static int hf_quake_header_flags_control = -1;
-static int hf_quake_header_length = -1;
-static int hf_quake_header_sequence = -1;
-static int hf_quake_control_command = -1;
+static int proto_quake;
+static int hf_quake_header_flags;
+static int hf_quake_header_flags_data;
+static int hf_quake_header_flags_ack;
+static int hf_quake_header_flags_no_ack;
+static int hf_quake_header_flags_endmsg;
+static int hf_quake_header_flags_unreliable;
+static int hf_quake_header_flags_control;
+static int hf_quake_header_length;
+static int hf_quake_header_sequence;
+static int hf_quake_control_command;
 
-static int hf_quake_CCREQ_CONNECT_game = -1;
-static int hf_quake_CCREQ_CONNECT_version = -1;
-static int hf_quake_CCREQ_SERVER_INFO_game = -1;
-static int hf_quake_CCREQ_SERVER_INFO_version = -1;
-static int hf_quake_CCREQ_PLAYER_INFO_player = -1;
-static int hf_quake_CCREQ_RULE_INFO_lastrule = -1;
+static int hf_quake_CCREQ_CONNECT_game;
+static int hf_quake_CCREQ_CONNECT_version;
+static int hf_quake_CCREQ_SERVER_INFO_game;
+static int hf_quake_CCREQ_SERVER_INFO_version;
+static int hf_quake_CCREQ_PLAYER_INFO_player;
+static int hf_quake_CCREQ_RULE_INFO_lastrule;
 
-static int hf_quake_CCREP_ACCEPT_port = -1;
-static int hf_quake_CCREP_REJECT_reason = -1;
-static int hf_quake_CCREP_SERVER_INFO_address = -1;
-static int hf_quake_CCREP_SERVER_INFO_server = -1;
-static int hf_quake_CCREP_SERVER_INFO_map = -1;
-static int hf_quake_CCREP_SERVER_INFO_num_player = -1;
-static int hf_quake_CCREP_SERVER_INFO_max_player = -1;
-static int hf_quake_CCREP_PLAYER_INFO_name = -1;
-static int hf_quake_CCREP_PLAYER_INFO_colors = -1;
-static int hf_quake_CCREP_PLAYER_INFO_colors_shirt = -1;
-static int hf_quake_CCREP_PLAYER_INFO_colors_pants = -1;
-static int hf_quake_CCREP_PLAYER_INFO_frags = -1;
-static int hf_quake_CCREP_PLAYER_INFO_connect_time = -1;
-static int hf_quake_CCREP_PLAYER_INFO_address = -1;
-static int hf_quake_CCREP_RULE_INFO_rule = -1;
-static int hf_quake_CCREP_RULE_INFO_value = -1;
+static int hf_quake_CCREP_ACCEPT_port;
+static int hf_quake_CCREP_REJECT_reason;
+static int hf_quake_CCREP_SERVER_INFO_address;
+static int hf_quake_CCREP_SERVER_INFO_server;
+static int hf_quake_CCREP_SERVER_INFO_map;
+static int hf_quake_CCREP_SERVER_INFO_num_player;
+static int hf_quake_CCREP_SERVER_INFO_max_player;
+static int hf_quake_CCREP_PLAYER_INFO_name;
+static int hf_quake_CCREP_PLAYER_INFO_colors;
+static int hf_quake_CCREP_PLAYER_INFO_colors_shirt;
+static int hf_quake_CCREP_PLAYER_INFO_colors_pants;
+static int hf_quake_CCREP_PLAYER_INFO_frags;
+static int hf_quake_CCREP_PLAYER_INFO_connect_time;
+static int hf_quake_CCREP_PLAYER_INFO_address;
+static int hf_quake_CCREP_RULE_INFO_rule;
+static int hf_quake_CCREP_RULE_INFO_value;
 
 
-static gint ett_quake = -1;
-static gint ett_quake_control = -1;
-static gint ett_quake_control_colors = -1;
-static gint ett_quake_flags = -1;
+static gint ett_quake;
+static gint ett_quake_control;
+static gint ett_quake_control_colors;
+static gint ett_quake_flags;
 
 static dissector_handle_t quake_handle;
 
@@ -386,28 +386,28 @@ dissect_quake(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "QUAKE");
 	col_clear(pinfo->cinfo, COL_INFO);
 
-	flags = tvb_get_ntohs(tvb, 0);
+	flags = tvb_get_ntohs(tvb, 2);
 
 	quake_item = proto_tree_add_item(tree, proto_quake, tvb, 0, -1, ENC_NA);
 	quake_tree = proto_item_add_subtree(quake_item, ett_quake);
 
 	flags_item = proto_tree_add_item(quake_tree, hf_quake_header_flags,
-			tvb, 0, 2, ENC_BIG_ENDIAN);
+			tvb, 2, 2, ENC_BIG_ENDIAN);
 	flags_tree = proto_item_add_subtree(flags_item, ett_quake_flags);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_data,
-			tvb, 0, 2, ENC_BIG_ENDIAN);
+			tvb, 2, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_ack,
-			tvb, 0, 2, ENC_BIG_ENDIAN);
+			tvb, 2, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_no_ack,
-			tvb, 0, 2, ENC_BIG_ENDIAN);
+			tvb, 2, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_endmsg,
-			tvb, 0, 2, ENC_BIG_ENDIAN);
+			tvb, 2, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_unreliable,
-			tvb, 0, 2, ENC_BIG_ENDIAN);
+			tvb, 2, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(flags_tree, hf_quake_header_flags_control,
-			tvb, 0, 2, ENC_BIG_ENDIAN);
+			tvb, 2, 2, ENC_BIG_ENDIAN);
 
-	proto_tree_add_item(quake_tree, hf_quake_header_length, tvb, 2, 2, ENC_BIG_ENDIAN);
+	proto_tree_add_item(quake_tree, hf_quake_header_length, tvb, 0, 2, ENC_BIG_ENDIAN);
 
 	if (flags == NETFLAG_CTL) {
 		next_tvb = tvb_new_subset_remaining(tvb, 4);
