@@ -26,52 +26,52 @@ void proto_reg_handoff_quake2(void);
 
 static dissector_handle_t quake2_handle;
 
-static int proto_quake2 = -1;
+static int proto_quake2;
 
-static int hf_quake2_s2c = -1;
-static int hf_quake2_c2s = -1;
-static int hf_quake2_connectionless = -1;
-static int hf_quake2_game = -1;
-static int hf_quake2_userinfo = -1;
-static int hf_quake2_command = -1;
-static int hf_quake2_connectionless_marker = -1;
-static int hf_quake2_connectionless_text = -1;
-static int hf_quake2_game_seq1 = -1;
-static int hf_quake2_game_rel1 = -1;
-static int hf_quake2_game_seq2 = -1;
-static int hf_quake2_game_rel2 = -1;
-static int hf_quake2_game_qport = -1;
-static int hf_quake2_game_client_command = -1;
-static int hf_quake2_game_server_command = -1;
-static int hf_quake2_game_client_command_move = -1;
-static int hf_quake2_game_client_command_move_chksum = -1;
-static int hf_quake2_game_client_command_move_lframe = -1;
-static int hf_quake2_game_client_command_move_bitfield_angles1 = -1;
-static int hf_quake2_game_client_command_move_bitfield_angles2 = -1;
-static int hf_quake2_game_client_command_move_bitfield_angles3 = -1;
-static int hf_quake2_game_client_command_move_bitfield_movement_fwd = -1;
-static int hf_quake2_game_client_command_move_bitfield_movement_side = -1;
-static int hf_quake2_game_client_command_move_bitfield_movement_up = -1;
-static int hf_quake2_game_client_command_move_bitfield_buttons = -1;
-static int hf_quake2_game_client_command_move_bitfield_impulse = -1;
-static int hf_quake2_game_client_command_move_msec = -1;
-static int hf_quake2_game_client_command_move_lightlevel = -1;
+static int hf_quake2_s2c;
+static int hf_quake2_c2s;
+static int hf_quake2_connectionless;
+static int hf_quake2_game;
+static int hf_quake2_userinfo;
+static int hf_quake2_command;
+static int hf_quake2_connectionless_marker;
+static int hf_quake2_connectionless_text;
+static int hf_quake2_game_seq1;
+static int hf_quake2_game_rel1;
+static int hf_quake2_game_seq2;
+static int hf_quake2_game_rel2;
+static int hf_quake2_game_qport;
+static int hf_quake2_game_client_command;
+static int hf_quake2_game_server_command;
+static int hf_quake2_game_client_command_move;
+static int hf_quake2_game_client_command_move_chksum;
+static int hf_quake2_game_client_command_move_lframe;
+static int hf_quake2_game_client_command_move_bitfield_angles1;
+static int hf_quake2_game_client_command_move_bitfield_angles2;
+static int hf_quake2_game_client_command_move_bitfield_angles3;
+static int hf_quake2_game_client_command_move_bitfield_movement_fwd;
+static int hf_quake2_game_client_command_move_bitfield_movement_side;
+static int hf_quake2_game_client_command_move_bitfield_movement_up;
+static int hf_quake2_game_client_command_move_bitfield_buttons;
+static int hf_quake2_game_client_command_move_bitfield_impulse;
+static int hf_quake2_game_client_command_move_msec;
+static int hf_quake2_game_client_command_move_lightlevel;
 
-static gint ett_quake2 = -1;
-static gint ett_quake2_connectionless = -1;
-static gint ett_quake2_game = -1;
-static gint ett_quake2_game_seq1 = -1;
-static gint ett_quake2_game_seq2 = -1;
-static gint ett_quake2_game_clc = -1;
-static gint ett_quake2_game_svc = -1;
-static gint ett_quake2_game_clc_cmd = -1;
-static gint ett_quake2_game_svc_cmd = -1;
-static gint ett_quake2_game_clc_cmd_move_bitfield = -1;
-static gint ett_quake2_game_clc_cmd_move_moves = -1;
+static gint ett_quake2;
+static gint ett_quake2_connectionless;
+static gint ett_quake2_game;
+static gint ett_quake2_game_seq1;
+static gint ett_quake2_game_seq2;
+static gint ett_quake2_game_clc;
+static gint ett_quake2_game_svc;
+static gint ett_quake2_game_clc_cmd;
+static gint ett_quake2_game_svc_cmd;
+static gint ett_quake2_game_clc_cmd_move_bitfield;
+static gint ett_quake2_game_clc_cmd_move_moves;
 
 
 #define PORT_MASTER 27910 /* Not IANA registered */
-static range_t *gbl_quake2ServerPorts = NULL;
+static range_t *gbl_quake2ServerPorts;
 
 
 static void
