@@ -30,31 +30,32 @@
 #include <epan/addr_resolv.h>
 
 void proto_register_quake3(void);
-static int proto_quake3 = -1;
+static dissector_handle_t quake3_handle;
+static int proto_quake3;
 
-static int hf_quake3_direction = -1;
-static int hf_quake3_connectionless = -1;
-static int hf_quake3_game = -1;
-static int hf_quake3_connectionless_marker = -1;
-static int hf_quake3_connectionless_text = -1;
-static int hf_quake3_connectionless_command = -1;
-static int hf_quake3_server_addr = -1;
-static int hf_quake3_server_port = -1;
-static int hf_quake3_game_seq1 = -1;
-static int hf_quake3_game_rel1 = -1;
-static int hf_quake3_game_seq2 = -1;
-static int hf_quake3_game_rel2 = -1;
-static int hf_quake3_game_qport = -1;
+static int hf_quake3_direction;
+static int hf_quake3_connectionless;
+static int hf_quake3_game;
+static int hf_quake3_connectionless_marker;
+static int hf_quake3_connectionless_text;
+static int hf_quake3_connectionless_command;
+static int hf_quake3_server_addr;
+static int hf_quake3_server_port;
+static int hf_quake3_game_seq1;
+static int hf_quake3_game_rel1;
+static int hf_quake3_game_seq2;
+static int hf_quake3_game_rel2;
+static int hf_quake3_game_qport;
 
-static gint ett_quake3 = -1;
-static gint ett_quake3_connectionless = -1;
-static gint ett_quake3_connectionless_text = -1;
-static gint ett_quake3_server = -1;
-static gint ett_quake3_game = -1;
-static gint ett_quake3_game_seq1 = -1;
-static gint ett_quake3_game_seq2 = -1;
-static gint ett_quake3_game_clc = -1;
-static gint ett_quake3_game_svc = -1;
+static gint ett_quake3;
+static gint ett_quake3_connectionless;
+static gint ett_quake3_connectionless_text;
+static gint ett_quake3_server;
+static gint ett_quake3_game;
+static gint ett_quake3_game_seq1;
+static gint ett_quake3_game_seq2;
+static gint ett_quake3_game_clc;
+static gint ett_quake3_game_svc;
 
 #define QUAKE3_SERVER_PORT 27960
 #define QUAKE3_MASTER_PORT 27950
@@ -156,7 +157,7 @@ dissect_quake3_ConnectionlessPacket(tvbuff_t *tvb, packet_info *pinfo _U_,
 	 * XXX - are non-ASCII characters supported and, if so, what
 	 * encoding is used for them?
 	 */
-	text = tvb_get_stringz_enc(wmem_packet_scope(), tvb, offset, &len, ENC_ASCII|ENC_NA);
+	text = tvb_get_stringz_enc(pinfo->pool, tvb, offset, &len, ENC_ASCII|ENC_NA);
 	if (cl_tree) {
 		text_item = proto_tree_add_string(cl_tree,
 				hf_quake3_connectionless_text,
@@ -549,6 +550,9 @@ proto_register_quake3(void)
 	proto_register_field_array(proto_quake3, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
+	/* Register the dissector handle */
+	quake3_handle = register_dissector("quake3", dissect_quake3, proto_quake3);
+
 	/* Register a configuration option for port */
 	quake3_module = prefs_register_protocol(proto_quake3, proto_reg_handoff_quake3);
 	prefs_register_uint_preference(quake3_module, "udp.arena_port",
@@ -566,14 +570,11 @@ void
 proto_reg_handoff_quake3(void)
 {
 	static gboolean initialized=FALSE;
-	static dissector_handle_t quake3_handle;
 	static guint server_port;
 	static guint master_port;
 	int i;
 
 	if (!initialized) {
-		quake3_handle = create_dissector_handle(dissect_quake3,
-				proto_quake3);
 		initialized=TRUE;
 	} else {
 		for (i=0;i<4;i++)
