@@ -25,44 +25,46 @@
 void proto_register_quakeworld(void);
 void proto_reg_handoff_quakeworld(void);
 
-static int proto_quakeworld = -1;
+static dissector_handle_t quakeworld_handle;
 
-static int hf_quakeworld_s2c = -1;
-static int hf_quakeworld_c2s = -1;
-static int hf_quakeworld_connectionless = -1;
-static int hf_quakeworld_game = -1;
-static int hf_quakeworld_connectionless_marker = -1;
-static int hf_quakeworld_connectionless_text = -1;
-static int hf_quakeworld_connectionless_command = -1;
-static int hf_quakeworld_connectionless_arguments = -1;
-static int hf_quakeworld_connectionless_connect_version = -1;
-static int hf_quakeworld_connectionless_connect_qport = -1;
-static int hf_quakeworld_connectionless_connect_challenge = -1;
-static int hf_quakeworld_connectionless_connect_infostring = -1;
-static int hf_quakeworld_connectionless_connect_infostring_key_value = -1;
-static int hf_quakeworld_connectionless_connect_infostring_key = -1;
-static int hf_quakeworld_connectionless_connect_infostring_value = -1;
-static int hf_quakeworld_connectionless_rcon_password = -1;
-static int hf_quakeworld_connectionless_rcon_command = -1;
-static int hf_quakeworld_game_seq1 = -1;
-static int hf_quakeworld_game_rel1 = -1;
-static int hf_quakeworld_game_seq2 = -1;
-static int hf_quakeworld_game_rel2 = -1;
-static int hf_quakeworld_game_qport = -1;
+static int proto_quakeworld;
 
-static gint ett_quakeworld = -1;
-static gint ett_quakeworld_connectionless = -1;
-static gint ett_quakeworld_connectionless_text = -1;
-static gint ett_quakeworld_connectionless_arguments = -1;
-static gint ett_quakeworld_connectionless_connect_infostring = -1;
-static gint ett_quakeworld_connectionless_connect_infostring_key_value = -1;
-static gint ett_quakeworld_game = -1;
-static gint ett_quakeworld_game_seq1 = -1;
-static gint ett_quakeworld_game_seq2 = -1;
-static gint ett_quakeworld_game_clc = -1;
-static gint ett_quakeworld_game_svc = -1;
+static int hf_quakeworld_s2c;
+static int hf_quakeworld_c2s;
+static int hf_quakeworld_connectionless;
+static int hf_quakeworld_game;
+static int hf_quakeworld_connectionless_marker;
+static int hf_quakeworld_connectionless_text;
+static int hf_quakeworld_connectionless_command;
+static int hf_quakeworld_connectionless_arguments;
+static int hf_quakeworld_connectionless_connect_version;
+static int hf_quakeworld_connectionless_connect_qport;
+static int hf_quakeworld_connectionless_connect_challenge;
+static int hf_quakeworld_connectionless_connect_infostring;
+static int hf_quakeworld_connectionless_connect_infostring_key_value;
+static int hf_quakeworld_connectionless_connect_infostring_key;
+static int hf_quakeworld_connectionless_connect_infostring_value;
+static int hf_quakeworld_connectionless_rcon_password;
+static int hf_quakeworld_connectionless_rcon_command;
+static int hf_quakeworld_game_seq1;
+static int hf_quakeworld_game_rel1;
+static int hf_quakeworld_game_seq2;
+static int hf_quakeworld_game_rel2;
+static int hf_quakeworld_game_qport;
 
-static expert_field ei_quakeworld_connectionless_command_invalid = EI_INIT;
+static gint ett_quakeworld;
+static gint ett_quakeworld_connectionless;
+static gint ett_quakeworld_connectionless_text;
+static gint ett_quakeworld_connectionless_arguments;
+static gint ett_quakeworld_connectionless_connect_infostring;
+static gint ett_quakeworld_connectionless_connect_infostring_key_value;
+static gint ett_quakeworld_game;
+static gint ett_quakeworld_game_seq1;
+static gint ett_quakeworld_game_seq2;
+static gint ett_quakeworld_game_clc;
+static gint ett_quakeworld_game_svc;
+
+static expert_field ei_quakeworld_connectionless_command_invalid;
 
 /*
 	helper functions, they may ave to go somewhere else
@@ -141,7 +143,7 @@ skipwhite:
 
 
 #define			MAX_ARGS 80
-static	int		cmd_argc = 0;
+static	int		cmd_argc;
 static	const char	*cmd_argv[MAX_ARGS];
 static	const char	*cmd_null_string = "";
 static	int		cmd_argv_start[MAX_ARGS];
@@ -310,8 +312,7 @@ static const value_string names_direction[] = {
 
 /* I took this name and value directly out of the QW source. */
 #define PORT_MASTER 27500 /* Not IANA registered */
-static guint gbl_quakeworldServerPort=PORT_MASTER;
-
+static range_t *gbl_quakeworldServerPorts;
 
 /* out of band message id bytes (taken out of quakeworldsource/client/protocol.h */
 
@@ -344,7 +345,7 @@ dissect_quakeworld_ConnectionlessPacket(tvbuff_t *tvb, packet_info *pinfo,
 	int		offset;
 	guint32		marker;
 	int		command_len;
-	const char	*command = "";
+	const char	*command;
 	gboolean	command_finished = FALSE;
 
 	marker = tvb_get_ntohl(tvb, 0);
@@ -356,7 +357,7 @@ dissect_quakeworld_ConnectionlessPacket(tvbuff_t *tvb, packet_info *pinfo,
 	/* all the rest of the packet is just text */
 	offset = 4;
 
-	text = tvb_get_stringz_enc(wmem_packet_scope(), tvb, offset, &len, ENC_ASCII|ENC_NA);
+	text = tvb_get_stringz_enc(pinfo->pool, tvb, offset, &len, ENC_ASCII|ENC_NA);
 	/* actually, we should look for a eol char and stop already there */
 
 	if (cl_tree) {
@@ -440,7 +441,7 @@ dissect_quakeworld_ConnectionlessPacket(tvbuff_t *tvb, packet_info *pinfo,
 				info_tree = proto_item_add_subtree(
 					info_item, ett_quakeworld_connectionless_connect_infostring);
 				dissect_id_infostring(tvb, info_tree, offset + Cmd_Argv_start(4),
-					wmem_strdup(wmem_packet_scope(), infostring),
+					wmem_strdup(pinfo->pool, infostring),
 					ett_quakeworld_connectionless_connect_infostring_key_value,
 					hf_quakeworld_connectionless_connect_infostring_key_value,
 					hf_quakeworld_connectionless_connect_infostring_key,
@@ -478,8 +479,8 @@ dissect_quakeworld_ConnectionlessPacket(tvbuff_t *tvb, packet_info *pinfo,
 			}
 			remaining[0] = '\0';
 			for (i=2; i<Cmd_Argc() ; i++) {
-				g_strlcat (remaining, Cmd_Argv(i), MAX_TEXT_SIZE+1);
-				g_strlcat (remaining, " ", MAX_TEXT_SIZE+1);
+				(void) g_strlcat (remaining, Cmd_Argv(i), MAX_TEXT_SIZE+1);
+				(void) g_strlcat (remaining, " ", MAX_TEXT_SIZE+1);
 			}
 			if (text_tree) {
 				proto_tree_add_string(argument_tree,
@@ -579,7 +580,7 @@ dissect_quakeworld_GamePacket(tvbuff_t *tvb, packet_info *pinfo,
 	int		offset;
 	guint		rest_length;
 
-	direction = (pinfo->destport == gbl_quakeworldServerPort) ?
+	direction = value_is_in_range(gbl_quakeworldServerPorts, pinfo->destport) ?
 			DIR_C2S : DIR_S2C;
 
 	game_tree = proto_tree_add_subtree(tree, tvb, 0, -1, ett_quakeworld_game, NULL, "Game");
@@ -648,7 +649,7 @@ dissect_quakeworld(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* da
 	proto_tree	*quakeworld_tree = NULL;
 	int		direction;
 
-	direction = (pinfo->destport == gbl_quakeworldServerPort) ?
+	direction = value_is_in_range(gbl_quakeworldServerPorts, pinfo->destport) ?
 			DIR_C2S : DIR_S2C;
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "QUAKEWORLD");
@@ -693,7 +694,7 @@ static void
 apply_quakeworld_prefs(void)
 {
     /* Port preference used to determine client/server */
-    gbl_quakeworldServerPort = prefs_get_uint_value("quakeworld", "udp.port");
+    gbl_quakeworldServerPorts = prefs_get_range_value("quakeworld", "udp.port");
 }
 
 void
@@ -814,6 +815,9 @@ proto_register_quakeworld(void)
 	proto_register_field_array(proto_quakeworld, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
+	/* Register the dissector handle */
+	quakeworld_handle = register_dissector("quakeworld", dissect_quakeworld, proto_quakeworld);
+
 	/* Register a configuration option for port */
 	prefs_register_protocol(proto_quakeworld, apply_quakeworld_prefs);
 
@@ -825,9 +829,6 @@ proto_register_quakeworld(void)
 void
 proto_reg_handoff_quakeworld(void)
 {
-	dissector_handle_t quakeworld_handle;
-
-	quakeworld_handle = create_dissector_handle(dissect_quakeworld, proto_quakeworld);
 	dissector_add_uint_with_preference("udp.port", PORT_MASTER, quakeworld_handle);
         apply_quakeworld_prefs();
 }
