@@ -19,7 +19,9 @@
 #include <epan/prefs.h>
 #include <epan/conversation.h>
 #include <epan/expert.h>
+#include <epan/proto_data.h>
 #include <epan/tvbuff_rdp.h>
+#include <epan/crc32-tvb.h>
 
 #include "packet-rdp.h"
 #include "packet-rdpudp.h"
@@ -27,53 +29,61 @@
 void proto_register_rdp_egfx(void);
 void proto_reg_handoff_rdp_egfx(void);
 
-static int proto_rdp_egfx = -1;
+static int proto_rdp_egfx;
 
-static int hf_egfx_cmdId = -1;
-static int hf_egfx_flags = -1;
-static int hf_egfx_pduLength = -1;
+static int hf_egfx_cmdId;
+static int hf_egfx_flags;
+static int hf_egfx_pduLength;
 
-static int hf_egfx_caps_capsSetCount = -1;
-static int hf_egfx_cap_version = -1;
-static int hf_egfx_cap_length = -1;
+static int hf_egfx_caps_capsSetCount;
+static int hf_egfx_cap_version;
+static int hf_egfx_cap_length;
 
-static int hf_egfx_reset_width = -1;
-static int hf_egfx_reset_height = -1;
-static int hf_egfx_reset_monitorCount = -1;
-static int hf_egfx_reset_monitorDefLeft = -1;
-static int hf_egfx_reset_monitorDefTop = -1;
-static int hf_egfx_reset_monitorDefRight = -1;
-static int hf_egfx_reset_monitorDefBottom = -1;
-static int hf_egfx_reset_monitorDefFlags = -1;
+static int hf_egfx_reset_width;
+static int hf_egfx_reset_height;
+static int hf_egfx_reset_monitorCount;
+static int hf_egfx_reset_monitorDefLeft;
+static int hf_egfx_reset_monitorDefTop;
+static int hf_egfx_reset_monitorDefRight;
+static int hf_egfx_reset_monitorDefBottom;
+static int hf_egfx_reset_monitorDefFlags;
 
 
-static int hf_egfx_ack_queue_depth = -1;
-static int hf_egfx_ack_frame_id = -1;
-static int hf_egfx_ack_total_decoded = -1;
+static int hf_egfx_ack_queue_depth;
+static int hf_egfx_ack_frame_id;
+static int hf_egfx_ack_total_decoded;
+static int hf_egfx_ack_frame_start;
+static int hf_egfx_ack_frame_end;
 
-static int hf_egfx_ackqoe_frame_id = -1;
-static int hf_egfx_ackqoe_timestamp = -1;
-static int hf_egfx_ackqoe_timediffse = -1;
-static int hf_egfx_ackqoe_timediffedr = -1;
+static int hf_egfx_ackqoe_frame_id;
+static int hf_egfx_ackqoe_timestamp;
+static int hf_egfx_ackqoe_timediffse;
+static int hf_egfx_ackqoe_timediffedr;
+static int hf_egfx_ackqoe_frame_start;
+static int hf_egfx_ackqoe_frame_end;
 
-static int hf_egfx_start_timestamp = -1;
-static int hf_egfx_start_frameid = -1;
-static int hf_egfx_end_frameid = -1;
+static int hf_egfx_start_timestamp;
+static int hf_egfx_start_frameid;
+static int hf_egfx_start_acked_in;
+
+static int hf_egfx_end_frameid;
+static int hf_egfx_end_acked_in;
 
 
-static int ett_rdp_egfx = -1;
-static int ett_egfx_caps = -1;
-static int ett_egfx_capsconfirm = -1;
-static int ett_egfx_cap = -1;
-static int ett_egfx_ack = -1;
-static int ett_egfx_ackqoe = -1;
-static int ett_egfx_reset = -1;
-static int ett_egfx_monitors = -1;
-static int ett_egfx_monitordef = -1;
+static int ett_rdp_egfx;
+static int ett_egfx_caps;
+static int ett_egfx_capsconfirm;
+static int ett_egfx_cap;
+static int ett_egfx_cap_version;
+static int ett_egfx_ack;
+static int ett_egfx_ackqoe;
+static int ett_egfx_reset;
+static int ett_egfx_monitors;
+static int ett_egfx_monitordef;
 
 
-static expert_field ei_egfx_pdulen_invalid = EI_INIT;
-static expert_field ei_egfx_invalid_compression = EI_INIT;
+static expert_field ei_egfx_pdulen_invalid;
+static expert_field ei_egfx_invalid_compression;
 
 
 #define PNAME  "RDP Graphic pipeline channel Protocol"
@@ -109,12 +119,15 @@ enum {
 enum {
 	RDPGFX_CAPVERSION_8 = 0x00080004,
 	RDPGFX_CAPVERSION_81 = 0x00080105,
+	RDPGFX_CAPVERSION_10 = 0x000A0002,
 	RDPGFX_CAPVERSION_101 = 0x000A0100,
 	RDPGFX_CAPVERSION_102 = 0x000A0200,
 	RDPGFX_CAPVERSION_103 = 0x000A0301,
 	RDPGFX_CAPVERSION_104 = 0x000A0400,
 	RDPGFX_CAPVERSION_105 = 0x000A0502,
-	RDPGFX_CAPVERSION_106 = 0x000A0600
+	RDPGFX_CAPVERSION_106_ERROR = 0x000A0600,
+	RDPGFX_CAPVERSION_106 = 0x000A0601,
+	RDPGFX_CAPVERSION_107 = 0x000A0701
 };
 
 static const value_string rdp_egfx_cmd_vals[] = {
@@ -130,7 +143,7 @@ static const value_string rdp_egfx_cmd_vals[] = {
 	{ RDPGFX_CMDID_DELETESURFACE, "Delete surface" },
 	{ RDPGFX_CMDID_STARTFRAME, "Start frame" },
 	{ RDPGFX_CMDID_ENDFRAME, "End frame" },
-	{ RDPGFX_CMDID_FRAMEACKNOWLEDGE, "Frame acknowlegde" },
+	{ RDPGFX_CMDID_FRAMEACKNOWLEDGE, "Frame acknowledge" },
 	{ RDPGFX_CMDID_RESETGRAPHICS, "Reset graphics" },
 	{ RDPGFX_CMDID_MAPSURFACETOOUTPUT, "Map Surface to output" },
 	{ RDPGFX_CMDID_CACHEIMPORTOFFER, "Cache import offer" },
@@ -138,21 +151,24 @@ static const value_string rdp_egfx_cmd_vals[] = {
 	{ RDPGFX_CMDID_CAPSADVERTISE, "Caps advertise" },
 	{ RDPGFX_CMDID_CAPSCONFIRM, "Caps confirm" },
 	{ RDPGFX_CMDID_MAPSURFACETOWINDOW, "Map surface to window" },
-	{ RDPGFX_CMDID_QOEFRAMEACKNOWLEDGE, "Qoe frame acknowlegde" },
+	{ RDPGFX_CMDID_QOEFRAMEACKNOWLEDGE, "Qoe frame acknowledge" },
 	{ RDPGFX_CMDID_MAPSURFACETOSCALEDOUTPUT, "Map surface to scaled output" },
 	{ RDPGFX_CMDID_MAPSURFACETOSCALEDWINDOW, "Map surface to scaled window" },
 	{ 0x0, NULL },
 };
 
 static const value_string rdp_egfx_caps_version_vals[] = {
-	{ RDPGFX_CAPVERSION_8, "8" },
+	{ RDPGFX_CAPVERSION_8, "8.0" },
 	{ RDPGFX_CAPVERSION_81, "8.1" } ,
+	{ RDPGFX_CAPVERSION_10, "10.0" } ,
 	{ RDPGFX_CAPVERSION_101, "10.1" },
 	{ RDPGFX_CAPVERSION_102, "10.2" },
 	{ RDPGFX_CAPVERSION_103, "10.3" },
 	{ RDPGFX_CAPVERSION_104, "10.4" },
 	{ RDPGFX_CAPVERSION_105, "10.5" },
+	{ RDPGFX_CAPVERSION_106_ERROR, "10.6 bogus" },
 	{ RDPGFX_CAPVERSION_106, "10.6" },
+	{ RDPGFX_CAPVERSION_107, "10.7" },
 	{ 0x0, NULL },
 };
 
@@ -165,8 +181,32 @@ static const value_string rdp_egfx_monitor_flags_vals[] = {
 
 typedef struct {
 	zgfx_context_t *zgfx;
+	wmem_map_t *frames;
 } egfx_conv_info_t;
 
+enum {
+	EGFX_PDU_KEY = 1
+};
+
+typedef struct {
+	wmem_tree_t* pdus;
+} egfx_pdu_info_t;
+
+typedef struct {
+	int startNum;
+	int endNum;
+	int ackNum;
+} egfx_frame_t;
+
+static const char *
+find_egfx_version(guint32 v) {
+	const value_string *vs = rdp_egfx_caps_version_vals;
+	for ( ; vs->strptr; vs++)
+		if (vs->value == v)
+			return vs->strptr;
+
+	return "<unknown>";
+}
 
 static egfx_conv_info_t *
 egfx_get_conversation_data(packet_info *pinfo)
@@ -186,6 +226,7 @@ egfx_get_conversation_data(packet_info *pinfo)
 	if (info == NULL) {
 		info = wmem_new0(wmem_file_scope(), egfx_conv_info_t);
 		info->zgfx = zgfx_context_new(wmem_file_scope());
+		info->frames = wmem_map_new(wmem_file_scope(), g_direct_hash, g_direct_equal);
 		conversation_add_proto_data(conversation, proto_rdp_egfx, info);
 	}
 
@@ -194,17 +235,17 @@ egfx_get_conversation_data(packet_info *pinfo)
 
 
 static int
-dissect_rdp_egfx_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void *data _U_)
+dissect_rdp_egfx_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, egfx_conv_info_t *conv, void *data _U_)
 {
 	proto_item *item;
+	proto_item *pi;
 	proto_tree *tree;
 	proto_tree *subtree;
 	gint offset = 0;
-	guint16 cmdId = 0;
+	guint32 cmdId = 0;
 	guint32 pduLength;
 	guint32 i;
 
-
 	parent_tree = proto_tree_get_root(parent_tree);
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "EGFX");
 	col_clear(pinfo->cinfo, COL_INFO);
@@ -215,8 +256,7 @@ dissect_rdp_egfx_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_t
 		item = proto_tree_add_item(parent_tree, proto_rdp_egfx, tvb, offset, pduLength, ENC_NA);
 		tree = proto_item_add_subtree(item, ett_rdp_egfx);
 
-		cmdId = tvb_get_guint16(tvb, offset, ENC_LITTLE_ENDIAN);
-		proto_tree_add_item(tree, hf_egfx_cmdId, tvb, offset, 2, ENC_LITTLE_ENDIAN);
+		proto_tree_add_item_ret_uint(tree, hf_egfx_cmdId, tvb, offset, 2, ENC_LITTLE_ENDIAN, &cmdId);
 		offset += 2;
 
 		proto_tree_add_item(tree, hf_egfx_flags, tvb, offset, 2, ENC_LITTLE_ENDIAN);
@@ -230,6 +270,7 @@ dissect_rdp_egfx_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_t
 			return offset;
 		}
 
+		gint nextOffset = offset + (pduLength - 8);
 		switch (cmdId) {
 		case RDPGFX_CMDID_CAPSADVERTISE: {
 			guint16 capsSetCount = tvb_get_guint16(tvb, offset, ENC_LITTLE_ENDIAN);
@@ -241,13 +282,14 @@ dissect_rdp_egfx_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_t
 			offset += 2;
 
 			for (i = 0; i < capsSetCount; i++) {
-				guint32 capsDataLength;
+				guint32 version = tvb_get_guint32(tvb, offset, ENC_LITTLE_ENDIAN);
+				guint32 capsDataLength = tvb_get_guint32(tvb, offset + 4, ENC_LITTLE_ENDIAN);
+				proto_tree* vtree = proto_tree_add_subtree(subtree, tvb, offset, 8 + capsDataLength, ett_egfx_cap_version, NULL, find_egfx_version(version));
 
-				proto_tree_add_item(subtree, hf_egfx_cap_version, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+				proto_tree_add_item(vtree, hf_egfx_cap_version, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 				offset += 4;
 
-				proto_tree_add_item(subtree, hf_egfx_cap_length, tvb, offset, 4, ENC_LITTLE_ENDIAN);
-				capsDataLength = tvb_get_guint32(tvb, offset, ENC_LITTLE_ENDIAN);
+				proto_tree_add_item(vtree, hf_egfx_cap_length, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 				offset += 4;
 
 				offset += capsDataLength;
@@ -265,7 +307,6 @@ dissect_rdp_egfx_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_t
 			offset += 4;
 
 			proto_tree_add_item_ret_uint(subtree, hf_egfx_cap_length, tvb, offset, 4, ENC_LITTLE_ENDIAN, &capsDataLength);
-			offset += 4 + capsDataLength;
 			break;
 		}
 
@@ -274,7 +315,7 @@ dissect_rdp_egfx_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_t
 			proto_tree *monitors_tree;
 			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Reset graphics");
 
-			subtree = proto_tree_add_subtree(tree, tvb, offset, pduLength-4, ett_egfx_reset, NULL, "Reset graphics");
+			subtree = proto_tree_add_subtree(tree, tvb, offset, pduLength-8, ett_egfx_reset, NULL, "Reset graphics");
 			proto_tree_add_item(subtree, hf_egfx_reset_width, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 			offset += 4;
 
@@ -311,45 +352,103 @@ dissect_rdp_egfx_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_t
 				proto_tree_add_item(monitor_tree, hf_egfx_reset_monitorDefFlags, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 				offset += 4;
 			}
-
-			offset += (pduLength - 8);
 			break;
 		}
 
 		case RDPGFX_CMDID_STARTFRAME: {
+			guint32 frameId;
+			egfx_frame_t *frame;
 			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Start frame");
 			proto_tree_add_item(tree, hf_egfx_start_timestamp, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 			// TODO: dissect timestamp
 			offset += 4;
 
-			proto_tree_add_item(tree, hf_egfx_start_frameid, tvb, offset, 4, ENC_LITTLE_ENDIAN);
-			offset += 4;
+			proto_tree_add_item_ret_uint(tree, hf_egfx_start_frameid, tvb, offset, 4, ENC_LITTLE_ENDIAN, &frameId);
+			frame = wmem_map_lookup(conv->frames, GUINT_TO_POINTER(frameId));
+			if (!frame) {
+				frame = wmem_alloc0(wmem_file_scope(), sizeof(*frame));
+				frame->startNum = pinfo->num;
+				frame->endNum = -1;
+				frame->ackNum = -1;
+				wmem_map_insert(conv->frames, GUINT_TO_POINTER(frameId), frame);
+			}
+
+			if (PINFO_FD_VISITED(pinfo) && frame->ackNum != -1) {
+				pi = proto_tree_add_uint(tree, hf_egfx_start_acked_in, tvb, 0, 0, frame->ackNum);
+				proto_item_set_generated(pi);
+			}
 			break;
 		}
 
-		case RDPGFX_CMDID_ENDFRAME:
+		case RDPGFX_CMDID_ENDFRAME: {
+			guint32 frameId;
+			egfx_frame_t *frame;
+
 			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "End frame");
-			proto_tree_add_item(tree, hf_egfx_end_frameid, tvb, offset, 4, ENC_LITTLE_ENDIAN);
-			offset += 4;
+			proto_tree_add_item_ret_uint(tree, hf_egfx_end_frameid, tvb, offset, 4, ENC_LITTLE_ENDIAN, &frameId);
+
+			frame = wmem_map_lookup(conv->frames, GUINT_TO_POINTER(frameId));
+			if (!frame) {
+				frame = wmem_alloc0(wmem_file_scope(), sizeof(*frame));
+				frame->startNum = -1;
+				frame->ackNum = -1;
+				wmem_map_insert(conv->frames, GUINT_TO_POINTER(frameId), frame);
+			}
+
+			frame->endNum = pinfo->num;
+
+			if (PINFO_FD_VISITED(pinfo) && frame->ackNum != -1) {
+				pi = proto_tree_add_uint(tree, hf_egfx_end_acked_in, tvb, 0, 0, frame->ackNum);
+				proto_item_set_generated(pi);
+			}
+
 			break;
+		}
+
+		case RDPGFX_CMDID_FRAMEACKNOWLEDGE: {
+			guint32 frameId;
+			egfx_frame_t *frame;
 
-		case RDPGFX_CMDID_FRAMEACKNOWLEDGE:
 			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Frame acknowledge");
 			subtree = proto_tree_add_subtree(tree, tvb, offset, -1, ett_egfx_ack, NULL, "Frame acknowledge");
 			proto_tree_add_item(subtree, hf_egfx_ack_queue_depth, tvb, offset, 4, ENC_LITTLE_ENDIAN);
 			offset += 4;
 
-			proto_tree_add_item(subtree, hf_egfx_ack_frame_id, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+			proto_tree_add_item_ret_uint(subtree, hf_egfx_ack_frame_id, tvb, offset, 4, ENC_LITTLE_ENDIAN, &frameId);
 			offset += 4;
 
 			proto_tree_add_item(subtree, hf_egfx_ack_total_decoded, tvb, offset, 4, ENC_LITTLE_ENDIAN);
-			offset += 4;
-			break;
 
-		case RDPGFX_CMDID_QOEFRAMEACKNOWLEDGE:
+			frame = wmem_map_lookup(conv->frames, GUINT_TO_POINTER(frameId));
+			if (!frame) {
+				frame = wmem_alloc0(wmem_file_scope(), sizeof(*frame));
+				frame->startNum = -1;
+				frame->endNum = -1;
+				frame->ackNum = frameId;
+				wmem_map_insert(conv->frames, GUINT_TO_POINTER(frameId), frame);
+			}
+
+			frame->ackNum = pinfo->num;
+
+			if (PINFO_FD_VISITED(pinfo) && frame->startNum != -1) {
+				pi = proto_tree_add_uint(tree, hf_egfx_ack_frame_start, tvb, 0, 0, frame->startNum);
+				proto_item_set_generated(pi);
+			}
+
+			if (PINFO_FD_VISITED(pinfo) && frame->endNum != -1) {
+				pi = proto_tree_add_uint(tree, hf_egfx_ack_frame_end, tvb, 0, 0, frame->endNum);
+				proto_item_set_generated(pi);
+			}
+			break;
+		}
+
+		case RDPGFX_CMDID_QOEFRAMEACKNOWLEDGE: {
+			guint32 frameId;
+			egfx_frame_t *frame;
+
 			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Frame acknowledge QoE");
 			subtree = proto_tree_add_subtree(tree, tvb, offset, -1, ett_egfx_ackqoe, NULL, "Frame acknowledge QoE");
-			proto_tree_add_item(subtree, hf_egfx_ackqoe_frame_id, tvb, offset, 4, ENC_LITTLE_ENDIAN);
+			proto_tree_add_item_ret_uint(subtree, hf_egfx_ackqoe_frame_id, tvb, offset, 4, ENC_LITTLE_ENDIAN, &frameId);
 			offset += 4;
 
 			proto_tree_add_item(subtree, hf_egfx_ackqoe_timestamp, tvb, offset, 4, ENC_LITTLE_ENDIAN);
@@ -359,13 +458,99 @@ dissect_rdp_egfx_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_t
 			offset += 2;
 
 			proto_tree_add_item(subtree, hf_egfx_ackqoe_timediffedr, tvb, offset, 2, ENC_LITTLE_ENDIAN);
-			offset += 2;
+			frame = wmem_map_lookup(conv->frames, GUINT_TO_POINTER(frameId));
+			if (!frame) {
+				frame = wmem_alloc0(wmem_file_scope(), sizeof(*frame));
+				frame->startNum = -1;
+				frame->endNum = -1;
+				frame->ackNum = frameId;
+				wmem_map_insert(conv->frames, GUINT_TO_POINTER(frameId), frame);
+			}
+
+			frame->ackNum = pinfo->num;
+
+			if (PINFO_FD_VISITED(pinfo) && frame->startNum != -1) {
+				pi = proto_tree_add_uint(tree, hf_egfx_ackqoe_frame_start, tvb, 0, 0, frame->startNum);
+				proto_item_set_generated(pi);
+			}
+
+			if (PINFO_FD_VISITED(pinfo) && frame->endNum != -1) {
+				pi = proto_tree_add_uint(tree, hf_egfx_ackqoe_frame_end, tvb, 0, 0, frame->endNum);
+				proto_item_set_generated(pi);
+			}
+
+			break;
+		}
+
+		case RDPGFX_CMDID_CREATESURFACE:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Create Surface");
+			break;
+
+		case RDPGFX_CMDID_MAPSURFACETOOUTPUT:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Map Surface To Output");
+			break;
+
+		case RDPGFX_CMDID_WIRETOSURFACE_1:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Wire To Surface 1");
+			break;
+
+		case RDPGFX_CMDID_WIRETOSURFACE_2:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Wire To Surface 2");
+			break;
+
+		case RDPGFX_CMDID_DELETEENCODINGCONTEXT:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Delete Encoding Context");
+			break;
+
+		case RDPGFX_CMDID_SOLIDFILL:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Solid Fill");
+			break;
+
+		case RDPGFX_CMDID_SURFACETOSURFACE:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Surface To Surface");
+			break;
+
+		case RDPGFX_CMDID_SURFACETOCACHE:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Surface To Cache");
+			break;
+
+		case RDPGFX_CMDID_CACHETOSURFACE:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Cache To Surface");
+			break;
+
+		case RDPGFX_CMDID_EVICTCACHEENTRY:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Evict Cache Entry");
+			break;
+
+		case RDPGFX_CMDID_DELETESURFACE:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Delete Surface");
+			break;
+
+		case RDPGFX_CMDID_CACHEIMPORTOFFER:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Cache Import Offer");
+			break;
+
+		case RDPGFX_CMDID_CACHEIMPORTREPLY:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Cache Import Reply");
+			break;
+
+		case RDPGFX_CMDID_MAPSURFACETOWINDOW:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Map Surface To Window");
+			break;
+
+		case RDPGFX_CMDID_MAPSURFACETOSCALEDOUTPUT:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Map Surface To Scaled Output");
+			break;
+
+		case RDPGFX_CMDID_MAPSURFACETOSCALEDWINDOW:
+			col_append_sep_str(pinfo->cinfo, COL_INFO, ",", "Map Surface To Scaled Window");
 			break;
 
 		default:
-			offset += (pduLength - 8);
 			break;
 		}
+
+		offset = nextOffset;
 	}
 	return offset;
 }
@@ -374,6 +559,7 @@ static int
 dissect_rdp_egfx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, void *data)
 {
 	tvbuff_t *work_tvb = tvb;
+	egfx_conv_info_t *infos = egfx_get_conversation_data(pinfo);
 
 	col_set_str(pinfo->cinfo, COL_PROTOCOL, "EGFX");
 	col_clear(pinfo->cinfo, COL_INFO);
@@ -381,16 +567,36 @@ dissect_rdp_egfx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree, voi
 	parent_tree = proto_tree_get_root(parent_tree);
 
 	if (!rdp_isServerAddressTarget(pinfo)) {
-		egfx_conv_info_t *infos = egfx_get_conversation_data(pinfo);
-		work_tvb = rdp8_decompress(infos->zgfx, wmem_packet_scope(), tvb, 0);
-		if (!work_tvb && parent_tree) {
-			expert_add_info_format(pinfo, parent_tree->last_child, &ei_egfx_invalid_compression, "invalid compression");
-			return 0;
+		guint32 hash = crc32_ccitt_tvb(tvb, tvb_captured_length_remaining(tvb, 0));
+		egfx_pdu_info_t *pdu_infos = p_get_proto_data(wmem_file_scope(), pinfo, proto_rdp_egfx, EGFX_PDU_KEY);
+		if (!pdu_infos) {
+			pdu_infos = wmem_alloc(wmem_file_scope(), sizeof(*pdu_infos));
+			pdu_infos->pdus = wmem_tree_new(wmem_file_scope());
+			p_set_proto_data(wmem_file_scope(), pinfo, proto_rdp_egfx, EGFX_PDU_KEY, pdu_infos);
 		}
-		add_new_data_source(pinfo, work_tvb, "Uncompressed GFX");
+
+		if (!PINFO_FD_VISITED(pinfo)) {
+			work_tvb = rdp8_decompress(infos->zgfx, wmem_file_scope(), tvb, 0);
+			if (work_tvb) {
+				//printf("%d: zgfx sz=%d\n", pinfo->num, tvb_captured_length(work_tvb));
+				wmem_tree_insert32(pdu_infos->pdus, hash, work_tvb);
+			}
+		} else {
+			pdu_infos = p_get_proto_data(wmem_file_scope(), pinfo, proto_rdp_egfx, EGFX_PDU_KEY);
+			work_tvb = wmem_tree_lookup32(pdu_infos->pdus, hash);
+		}
+
+		if (work_tvb)
+			add_new_data_source(pinfo, work_tvb, "Uncompressed GFX");
+	}
+
+	if (work_tvb)
+		dissect_rdp_egfx_payload(work_tvb, pinfo, parent_tree, infos, data);
+	else {
+		if (parent_tree)
+			expert_add_info_format(pinfo, parent_tree->last_child, &ei_egfx_invalid_compression, "invalid compression");
 	}
 
-	dissect_rdp_egfx_payload(work_tvb, pinfo, parent_tree, data);
 	return tvb_reported_length(tvb);
 }
 
@@ -442,6 +648,16 @@ void proto_register_rdp_egfx(void) {
 			FT_UINT32, BASE_DEC, NULL, 0x0,
 			NULL, HFILL }
 		},
+		{ &hf_egfx_ack_frame_start,
+		  { "Frame starts in", "rdp_egfx.ack.framestart",
+			FT_FRAMENUM, BASE_NONE, FRAMENUM_TYPE(FT_FRAMENUM_REQUEST), 0x0,
+			NULL, HFILL }
+		},
+		{ &hf_egfx_ack_frame_end,
+		  { "Frame ends in", "rdp_egfx.ack.frameend",
+			FT_FRAMENUM, BASE_NONE, FRAMENUM_TYPE(FT_FRAMENUM_REQUEST), 0x0,
+			NULL, HFILL }
+		},
 		{ &hf_egfx_ackqoe_frame_id,
 		  { "frameId", "rdp_egfx.ackqoe.frameid",
 			FT_UINT32, BASE_HEX, NULL, 0x0,
@@ -462,6 +678,16 @@ void proto_register_rdp_egfx(void) {
 			FT_UINT16, BASE_DEC, NULL, 0x0,
 			NULL, HFILL }
 		},
+		{ &hf_egfx_ackqoe_frame_start,
+		  { "Frame starts in", "rdp_egfx.ackqoe.framestart",
+			FT_FRAMENUM, BASE_NONE, FRAMENUM_TYPE(FT_FRAMENUM_REQUEST), 0x0,
+			NULL, HFILL }
+		},
+		{ &hf_egfx_ackqoe_frame_end,
+		  { "Frame ends in", "rdp_egfx.ackqoe.frameend",
+			FT_FRAMENUM, BASE_NONE, FRAMENUM_TYPE(FT_FRAMENUM_REQUEST), 0x0,
+			NULL, HFILL }
+		},
 		{ &hf_egfx_reset_width,
 		  { "Width", "rdp_egfx.reset.width",
 			FT_UINT32, BASE_DEC, NULL, 0x0,
@@ -512,17 +738,29 @@ void proto_register_rdp_egfx(void) {
 			FT_UINT32, BASE_HEX, NULL, 0x0,
 			NULL, HFILL }
 		},
+		{ &hf_egfx_start_acked_in,
+		  { "Frame acked in", "rdp_egfx.startframe.ackedin",
+			FT_FRAMENUM, BASE_NONE, FRAMENUM_TYPE(FT_FRAMENUM_RESPONSE), 0x0,
+			NULL, HFILL }
+		},
+
 		{ &hf_egfx_end_frameid,
 		  { "Frame id", "rdp_egfx.endframe.frameid",
 			FT_UINT32, BASE_HEX, NULL, 0x0,
 			NULL, HFILL }
 		},
+		{ &hf_egfx_end_acked_in,
+		  { "Frame acked in", "rdp_egfx.endframe.ackedin",
+			FT_FRAMENUM, BASE_NONE, FRAMENUM_TYPE(FT_FRAMENUM_RESPONSE), 0x0,
+			NULL, HFILL }
+		},
 	};
 
 	static gint *ett[] = {
 		&ett_rdp_egfx,
 		&ett_egfx_caps,
 		&ett_egfx_cap,
+		&ett_egfx_cap_version,
 		&ett_egfx_ack,
 		&ett_egfx_ackqoe,
 		&ett_egfx_reset,
