@@ -18,20 +18,20 @@
 void proto_register_redbackli(void);
 void proto_reg_handoff_redbackli(void);
 
-static int proto_redbackli = -1;
+static int proto_redbackli;
 
-static int hf_redbackli_avptype = -1;
-static int hf_redbackli_avplen = -1;
-static int hf_redbackli_seqno = -1;		/* Sequence No */
-static int hf_redbackli_liid = -1;		/* LI Id */
-static int hf_redbackli_sessid = -1;		/* Session Id */
-static int hf_redbackli_label = -1;		/* Label */
-static int hf_redbackli_acctid = -1;		/* Accounting Session Id */
-static int hf_redbackli_dir = -1;		/* Direction */
-static int hf_redbackli_eohpad = -1;		/* End Of Header Padding */
-static int hf_redbackli_unknownavp = -1;	/* Unknown AVP */
+static int hf_redbackli_avptype;
+static int hf_redbackli_avplen;
+static int hf_redbackli_seqno;		/* Sequence No */
+static int hf_redbackli_liid;		/* LI Id */
+static int hf_redbackli_sessid;		/* Session Id */
+static int hf_redbackli_label;		/* Label */
+static int hf_redbackli_acctid;		/* Accounting Session Id */
+static int hf_redbackli_dir;		/* Direction */
+static int hf_redbackli_eohpad;		/* End Of Header Padding */
+static int hf_redbackli_unknownavp;	/* Unknown AVP */
 
-static int ett_redbackli = -1;
+static int ett_redbackli;
 
 static dissector_handle_t ip_handle;
 static dissector_handle_t redbackli_handle;
@@ -93,7 +93,7 @@ redbackli_dissect_avp(guint8 avptype, guint8 avplen, tvbuff_t *tvb, gint offset,
 			break;
 		case(RB_AVP_LABEL):
 			proto_tree_add_item(st, hf_redbackli_label, tvb,
-					    offset+2, avplen, ENC_ASCII|ENC_NA);
+					    offset+2, avplen, ENC_ASCII);
 			break;
 		case(RB_AVP_EOH):
 			proto_tree_add_item(st, hf_redbackli_eohpad, tvb,
@@ -163,8 +163,8 @@ redbackli_dissect(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* dat
 #define REDBACKLI_EOHSIZE	2
 #define MIN_REDBACKLI_SIZE	(3*REDBACKLI_INTSIZE+REDBACKLI_EOHSIZE)
 
-static gboolean
-redbackli_dissect_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool
+redbackli_dissect_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
 	gint		len, offset = 0;
 	gboolean	eoh = FALSE;
@@ -173,7 +173,7 @@ redbackli_dissect_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
 
 	len = tvb_captured_length(tvb);
 	if (len < MIN_REDBACKLI_SIZE)
-		return FALSE;
+		return false;
 
 	/*
 	 * We scan the possible AVPs and look out for mismatches.
@@ -190,12 +190,12 @@ redbackli_dissect_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
 			case(RB_AVP_LIID):
 			case(RB_AVP_SESSID):
 				if (avplen != 4)
-					return FALSE;
+					return false;
 				avpfound |= 1<<avptype;
 				break;
 			case(RB_AVP_EOH):
 				if (avplen > 1 || offset == 0)
-					return FALSE;
+					return false;
 				eoh = TRUE;
 				break;
 			case(RB_AVP_LABEL):
@@ -203,22 +203,22 @@ redbackli_dissect_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
 			case(RB_AVP_ACCTID):
 				break;
 			default:
-				return FALSE;
+				return false;
 		}
 		offset += 2 + avplen;
 		len    -= 2 + avplen;
 	}
 
 	if (!(avpfound & (1<<RB_AVP_SEQNO)))
-		return FALSE;
+		return false;
 	if (!(avpfound & (1<<RB_AVP_SESSID)))
-		return FALSE;
+		return false;
 	if (!(avpfound & (1<<RB_AVP_LIID)))
-		return FALSE;
+		return false;
 
 	redbackli_dissect(tvb, pinfo, tree, data);
 
-	return TRUE;
+	return true;
 }
 void proto_register_redbackli(void) {
 	static hf_register_info hf[] = {
@@ -237,17 +237,13 @@ void proto_register_redbackli(void) {
 		{ &hf_redbackli_sessid,
 			{ "Session Id", "redbackli.sessid", FT_UINT32, BASE_DEC, NULL, 0x0,
 			"Session Identifier", HFILL }},
-#if 0 /* XXX: If one goes by the heuristic then this field can be variable length ??
-	 In the absence of any documentation We'll assume that's the case
-	 (even though 'direction' sounds like a fixed length field */
-		{ &hf_redbackli_dir,
-			{ "Direction", "redbackli.dir", FT_UINT8, BASE_DEC, NULL, 0x0,
-			NULL, HFILL }},
-#else
+		/* XXX: If one goes by the heuristic then this field can be variable length ??
+		 * In the absence of any documentation We'll assume that's the case
+		 * (even though 'direction' sounds like a fixed length field
+		 */
 		{ &hf_redbackli_dir,
 			{ "Direction", "redbackli.dir", FT_BYTES, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
-#endif
 		{ &hf_redbackli_label,
 			{ "Label", "redbackli.label", FT_STRING, BASE_NONE, NULL, 0x0,
 			NULL, HFILL }},
