@@ -27,20 +27,20 @@ void proto_register_reload_framing(void);
 void proto_reg_handoff_reload_framing(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_reload_framing = -1;
+static int proto_reload_framing;
 
-static int hf_reload_framing_type = -1;
-static int hf_reload_framing_sequence = -1;
-static int hf_reload_framing_ack_sequence = -1;
-static int hf_reload_framing_message = -1;
-static int hf_reload_framing_message_length = -1;
-static int hf_reload_framing_message_data = -1;
-static int hf_reload_framing_received = -1;
-static int hf_reload_framing_parsed_received = -1;
-static int hf_reload_framing_duplicate = -1;
-static int hf_reload_framing_response_in = -1;
-static int hf_reload_framing_response_to = -1;
-static int hf_reload_framing_time = -1;
+static int hf_reload_framing_type;
+static int hf_reload_framing_sequence;
+static int hf_reload_framing_ack_sequence;
+static int hf_reload_framing_message;
+static int hf_reload_framing_message_length;
+static int hf_reload_framing_message_data;
+static int hf_reload_framing_received;
+static int hf_reload_framing_parsed_received;
+static int hf_reload_framing_duplicate;
+static int hf_reload_framing_response_in;
+static int hf_reload_framing_response_to;
+static int hf_reload_framing_time;
 
 static dissector_handle_t reload_handle;
 static dissector_handle_t reload_framing_tcp_handle;
@@ -67,11 +67,11 @@ typedef struct _reload_frame_conv_info_t {
 
 
 /* Initialize the subtree pointers */
-static gint ett_reload_framing = -1;
-static gint ett_reload_framing_message = -1;
-static gint ett_reload_framing_received = -1;
+static gint ett_reload_framing;
+static gint ett_reload_framing_message;
+static gint ett_reload_framing_received;
 
-static expert_field ei_reload_no_dissector = EI_INIT;
+static expert_field ei_reload_no_dissector;
 
 #define UDP_PORT_RELOAD                 6084
 #define TCP_PORT_RELOAD                 6084
@@ -124,14 +124,8 @@ dissect_reload_framing_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
   effective_length = tvb_captured_length(tvb);
 
   /* First, make sure we have enough data to do the check. */
-  if (effective_length < MIN_HDR_LENGTH) {
+  if (effective_length < MIN_HDR_LENGTH)
     return 0;
-  }
-
-  /* Next, make sure we can create transaction ID keys. */
-  if (!(pinfo->src.data && pinfo->dst.data)) {
-    return 0;
-  }
 
   conversation = find_conversation_pinfo(pinfo, 0);
   if (conversation)
@@ -192,24 +186,22 @@ dissect_reload_framing_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
   transaction_id_key[0].key = &sequence; /* sequence number */
 
   /* When the wmem_tree_* functions iterate through the keys, they
-   * perform pointer arithmetic with guint32s (which requires copying
-   * the address, at least on some platforms, as there's no guarantee
-   * that the address structure data field is 4-byte aligned), so we
-   * have to divide our length fields by that to make things work, but
-   * we still want to wmem_alloc and memcpy the entire amounts, since
-   * those both operate in raw bytes. */
+   * perform pointer arithmetic with guint32s, so we have to divide
+   * our length fields by that to make things work, but we still want
+   * to g_malloc and memcpy the entire amounts, since those both operate
+   * in raw bytes. */
   if (type==DATA) {
     transaction_id_key[1].length = 1;
     transaction_id_key[1].key    = &pinfo->srcport;
     transaction_id_key[2].length = (pinfo->src.len) / (guint)sizeof(guint32);
-    transaction_id_key[2].key    = (guint32 *)wmem_alloc(wmem_file_scope(), pinfo->src.len);
+    transaction_id_key[2].key    = (guint32 *)g_malloc(pinfo->src.len);
     memcpy(transaction_id_key[2].key, pinfo->src.data, pinfo->src.len);
   }
   else {
     transaction_id_key[1].length = 1;
     transaction_id_key[1].key    = &pinfo->destport;
     transaction_id_key[2].length = (pinfo->dst.len) / (guint)sizeof(guint32);
-    transaction_id_key[2].key    = (guint32 *)wmem_alloc(wmem_file_scope(), pinfo->dst.len);
+    transaction_id_key[2].key    = (guint32 *)g_malloc(pinfo->dst.len);
     memcpy(transaction_id_key[2].key, pinfo->dst.data, pinfo->dst.len);
   }
   transaction_id_key[3].length=0;
@@ -270,7 +262,7 @@ dissect_reload_framing_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tr
     transaction_id_key[2].key    = key_save;
     transaction_id_key[2].length = len_save;
   }
-  wmem_free(wmem_file_scope(), transaction_id_key[2].key);
+  g_free(transaction_id_key[2].key);
 
   if (!reload_frame) {
     /* create a "fake" pana_trans structure */
@@ -460,7 +452,7 @@ dissect_reload_framing_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
  *        done for a TCP connection identified as reload-framing because of
  *        the TCP port used).
  */
-static gboolean
+static bool
 dissect_reload_framing_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
   if (dissect_reload_framing_message(tvb, pinfo, tree, FALSE) == 0) {
@@ -468,12 +460,12 @@ dissect_reload_framing_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
      * It wasn't a valid RELOAD message, and wasn't
      * dissected as such.
      */
-    return FALSE;
+    return false;
   }
-  return TRUE;
+  return true;
 }
 
-static gboolean
+static bool
 dissect_reload_framing_heur_dtls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
   if (dissect_reload_framing_message(tvb, pinfo, tree, TRUE) == 0) {
@@ -481,9 +473,9 @@ dissect_reload_framing_heur_dtls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
      * It wasn't a valid RELOAD message, and wasn't
      * dissected as such.
      */
-    return FALSE;
+    return false;
   }
-  return TRUE;
+  return true;
 }
 
 void
