@@ -28,38 +28,38 @@
 #define DESEGMENT_ENABLED(pinfo) ((pinfo)->can_desegment && resp_desegment)
 
 static dissector_handle_t resp_handle;
-static gboolean resp_desegment = TRUE;
+static bool resp_desegment = true;
 
-static int proto_resp = -1;
+static int proto_resp;
 
-static gint ett_resp = -1;
-static gint ett_resp_bulk_string = -1;
-static gint ett_resp_array = -1;
+static gint ett_resp;
+static gint ett_resp_bulk_string;
+static gint ett_resp_array;
 
-static expert_field ei_resp_partial = EI_INIT;
-static expert_field ei_resp_malformed_length = EI_INIT;
-static expert_field ei_resp_array_recursion_too_deep = EI_INIT;
-static expert_field ei_resp_reassembled_in_next_frame = EI_INIT;
+static expert_field ei_resp_partial;
+static expert_field ei_resp_malformed_length;
+static expert_field ei_resp_array_recursion_too_deep;
+static expert_field ei_resp_reassembled_in_next_frame;
 
-static int hf_resp_string = -1;
-static int hf_resp_error = -1;
-static int hf_resp_bulk_string = -1;
-static int hf_resp_bulk_string_length = -1;
-static int hf_resp_bulk_string_value = -1;
-static int hf_resp_integer = -1;
-static int hf_resp_array = -1;
-static int hf_resp_array_length = -1;
-static int hf_resp_fragment = -1;
+static int hf_resp_string;
+static int hf_resp_error;
+static int hf_resp_bulk_string;
+static int hf_resp_bulk_string_length;
+static int hf_resp_bulk_string_value;
+static int hf_resp_integer;
+static int hf_resp_array;
+static int hf_resp_array_length;
+static int hf_resp_fragment;
 
 static int dissect_resp_loop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint offset, gint array_depth, gint64 expected_elements);
 static void resp_bulk_string_enhance_colinfo_ascii(packet_info *pinfo, gint array_depth, gint bulk_string_length, const guint8 *bulk_string_as_str);
 void proto_reg_handoff_resp(void);
 void proto_register_resp(void);
 
-static int dissect_resp_string(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, gint offset, gint string_lenth, gint array_depth) {
+static int dissect_resp_string(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint offset, gint string_lenth, gint array_depth) {
     guint8 *string_value;
 
-    string_value = tvb_get_string_enc(wmem_packet_scope(), tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
+    string_value = tvb_get_string_enc(pinfo->pool, tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
                                       string_lenth - RESP_TOKEN_PREFIX_LENGTH, ENC_ASCII);
     proto_tree_add_string(tree, hf_resp_string, tvb, offset, string_lenth + CRLF_LENGTH, string_value);
 
@@ -74,7 +74,7 @@ static int dissect_resp_string(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree
 static int dissect_resp_error(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint offset, gint string_lenth) {
     guint8 *error_value;
 
-    error_value = tvb_get_string_enc(wmem_packet_scope(), tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
+    error_value = tvb_get_string_enc(pinfo->pool, tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
                                      string_lenth - RESP_TOKEN_PREFIX_LENGTH, ENC_ASCII);
     proto_tree_add_string(tree, hf_resp_error, tvb, offset, string_lenth + CRLF_LENGTH, error_value);
     col_append_fstr(pinfo->cinfo, COL_INFO, " Error: %s", error_value);
@@ -89,7 +89,7 @@ static int dissect_resp_bulk_string(tvbuff_t *tvb, packet_info *pinfo, proto_tre
     proto_item *resp_string_item;
     proto_tree *resp_string_tree;
 
-    bulk_string_length_as_str = tvb_get_string_enc(wmem_packet_scope(), tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
+    bulk_string_length_as_str = tvb_get_string_enc(pinfo->pool, tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
                                                    bulk_string_string_length - RESP_TOKEN_PREFIX_LENGTH, ENC_ASCII);
     bulk_string_length = (gint)g_ascii_strtoll(bulk_string_length_as_str, NULL, 10);
     /* Negative string lengths */
@@ -141,7 +141,7 @@ static int dissect_resp_bulk_string(tvbuff_t *tvb, packet_info *pinfo, proto_tre
     }
 
     /* Enhance display */
-    guint8 *bulk_string_as_str = tvb_get_string_enc(wmem_packet_scope(), tvb, offset, bulk_string_captured_length, ENC_NA);
+    guint8 *bulk_string_as_str = tvb_get_string_enc(pinfo->pool, tvb, offset, bulk_string_captured_length, ENC_NA);
     if (g_str_is_ascii(bulk_string_as_str)) {
         proto_item_append_text(resp_string_item, ": %s", bulk_string_as_str);
         resp_bulk_string_enhance_colinfo_ascii(pinfo, array_depth, bulk_string_length, bulk_string_as_str);
@@ -177,7 +177,7 @@ static void resp_bulk_string_enhance_colinfo_ascii(packet_info *pinfo, gint arra
 static int dissect_resp_integer(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint offset, gint bulk_string_string_length, gint array_depth) {
     guint8 *integer_as_string;
     gint64 integer;
-    integer_as_string = tvb_get_string_enc(wmem_packet_scope(), tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
+    integer_as_string = tvb_get_string_enc(pinfo->pool, tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
                                                    bulk_string_string_length - RESP_TOKEN_PREFIX_LENGTH, ENC_ASCII);
     integer = g_ascii_strtoll(integer_as_string, NULL, 10);
     proto_tree_add_int64(tree, hf_resp_integer, tvb, offset, bulk_string_string_length + CRLF_LENGTH, integer);
@@ -188,8 +188,9 @@ static int dissect_resp_integer(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
     return bulk_string_string_length + CRLF_LENGTH;
 }
 
+// NOLINTNEXTLINE(misc-no-recursion)
 static int dissect_resp_array(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint offset, gint string_length, gint array_depth) {
-    guint8 *array_length_as_string = tvb_get_string_enc(wmem_packet_scope(), tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
+    guint8 *array_length_as_string = tvb_get_string_enc(pinfo->pool, tvb, offset + RESP_TOKEN_PREFIX_LENGTH,
                                                         string_length - RESP_TOKEN_PREFIX_LENGTH, ENC_ASCII);
     gint64 array_length = g_ascii_strtoll(array_length_as_string, NULL, 10);
 
@@ -254,6 +255,7 @@ static int dissect_resp_array(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
     return dissected_offset - offset;
 }
 
+// NOLINTNEXTLINE(misc-no-recursion)
 static int dissect_resp_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint offset, gint string_length, gint array_depth) {
     switch (tvb_get_guint8(tvb, offset)) {
         case '+':
@@ -282,6 +284,7 @@ static int dissect_resp_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
     }
 }
 
+// NOLINTNEXTLINE(misc-no-recursion)
 static int dissect_resp_loop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, gint offset, gint array_depth, gint64 expected_elements) {
     gint error_or_offset;
     gint crlf_string_line_length;
@@ -300,7 +303,9 @@ static int dissect_resp_loop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
             pinfo->desegment_len = DESEGMENT_ONE_MORE_SEGMENT;
             return -1;
         }
+        increment_dissection_depth(pinfo);
         error_or_offset = dissect_resp_message(tvb, pinfo, tree, offset, crlf_string_line_length, array_depth);
+        decrement_dissection_depth(pinfo);
         if (error_or_offset == -1) {
             return -1;
         }
