@@ -7,26 +7,14 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 /* Riemann (http://riemann.io) aggregates events from servers and
  * applications with a powerful stream processing language.
  *
  * Protobuf structures layout:
- * https://github.com/aphyr/riemann-java-client/blob/master/src/main/proto/riemann/proto.proto
+ * https://github.com/riemann/riemann-java-client/blob/master/riemann-java-client/src/main/proto/riemann/proto.proto
  *
  *   message State {
  *     optional int64 time = 1;
@@ -49,6 +37,7 @@
  *     optional float ttl = 8;
  *     repeated Attribute attributes = 9;
  *
+ *     optional int64 time_micros = 10;
  *     optional sint64 metric_sint64 = 13;
  *     optional double metric_d = 14;
  *     optional float metric_f = 15;
@@ -81,40 +70,43 @@
 void proto_reg_handoff_riemann(void);
 void proto_register_riemann(void);
 
-static int proto_riemann = -1;
-static int hf_riemann_msg_ok = -1;
-static int hf_riemann_msg_error = -1;
-static int hf_riemann_attribute = -1;
-static int hf_riemann_attribute_key = -1;
-static int hf_riemann_attribute_value = -1;
-static int hf_riemann_query = -1;
-static int hf_riemann_query_string = -1;
-static int hf_riemann_event = -1;
-static int hf_riemann_event_state = -1;
-static int hf_riemann_event_service = -1;
-static int hf_riemann_event_host = -1;
-static int hf_riemann_event_description = -1;
-static int hf_riemann_event_tag = -1;
-static int hf_riemann_event_ttl = -1;
-static int hf_riemann_event_time = -1;
-static int hf_riemann_event_metric_d = -1;
-static int hf_riemann_event_metric_f = -1;
-static int hf_riemann_event_metric_sint64 = -1;
-static int hf_riemann_state = -1;
-static int hf_riemann_state_service = -1;
-static int hf_riemann_state_host = -1;
-static int hf_riemann_state_description = -1;
-static int hf_riemann_state_tag = -1;
-static int hf_riemann_state_ttl = -1;
-static int hf_riemann_state_time = -1;
-static int hf_riemann_state_state = -1;
-static int hf_riemann_state_once = -1;
+static dissector_handle_t riemann_udp_handle, riemann_tcp_handle;
 
-static gint ett_riemann = -1;
-static gint ett_query = -1;
-static gint ett_event = -1;
-static gint ett_attribute = -1;
-static gint ett_state = -1;
+static int proto_riemann;
+static int hf_riemann_msg_ok;
+static int hf_riemann_msg_error;
+static int hf_riemann_attribute;
+static int hf_riemann_attribute_key;
+static int hf_riemann_attribute_value;
+static int hf_riemann_query;
+static int hf_riemann_query_string;
+static int hf_riemann_event;
+static int hf_riemann_event_state;
+static int hf_riemann_event_service;
+static int hf_riemann_event_host;
+static int hf_riemann_event_description;
+static int hf_riemann_event_tag;
+static int hf_riemann_event_ttl;
+static int hf_riemann_event_time;
+static int hf_riemann_event_metric_d;
+static int hf_riemann_event_metric_f;
+static int hf_riemann_event_time_micros;
+static int hf_riemann_event_metric_sint64;
+static int hf_riemann_state;
+static int hf_riemann_state_service;
+static int hf_riemann_state_host;
+static int hf_riemann_state_description;
+static int hf_riemann_state_tag;
+static int hf_riemann_state_ttl;
+static int hf_riemann_state_time;
+static int hf_riemann_state_state;
+static int hf_riemann_state_once;
+
+static gint ett_riemann;
+static gint ett_query;
+static gint ett_event;
+static gint ett_attribute;
+static gint ett_state;
 
 #define RIEMANN_MIN_LENGTH 16
 #define RIEMANN_MIN_NEEDED_FOR_HEURISTICS 10
@@ -134,6 +126,7 @@ static gint ett_state = -1;
 #define RIEMANN_FN_EVENT_TAGS 7
 #define RIEMANN_FN_EVENT_TTL 8
 #define RIEMANN_FN_EVENT_ATTRIBUTES 9
+#define RIEMANN_FN_EVENT_TIME_MICROS 10
 #define RIEMANN_FN_EVENT_METRIC_SINT64 13
 #define RIEMANN_FN_EVENT_METRIC_D 14
 #define RIEMANN_FN_EVENT_METRIC_F 15
@@ -158,9 +151,9 @@ static gint ett_state = -1;
 #define RIEMANN_WIRE_BYTES 2
 #define RIEMANN_WIRE_FLOAT 5
 
-static expert_field ei_error_unknown_wire_tag = EI_INIT;
-static expert_field ei_error_unknown_field_number = EI_INIT;
-static expert_field ei_error_insufficient_data = EI_INIT;
+static expert_field ei_error_unknown_wire_tag;
+static expert_field ei_error_unknown_field_number;
+static expert_field ei_error_insufficient_data;
 
 static void
 riemann_verify_wire_format(guint64 field_number, const char *field_name, int expected, int actual,
@@ -230,14 +223,14 @@ riemann_get_guint64(tvbuff_t *tvb, guint offset, guint *len)
 }
 
 static guint8 *
-riemann_get_string(tvbuff_t *tvb, gint offset)
+riemann_get_string(wmem_allocator_t *scope, tvbuff_t *tvb, gint offset)
 {
     guint64 size;
     guint   len = 0;
 
     size = riemann_get_guint64(tvb, offset, &len);
     offset += len;
-    return tvb_get_string_enc(wmem_packet_scope(), tvb, offset, (gint)size, ENC_ASCII);
+    return tvb_get_string_enc(scope, tvb, offset, (gint)size, ENC_ASCII);
 }
 
 static guint
@@ -353,7 +346,7 @@ riemann_dissect_query(packet_info *pinfo, proto_tree *riemann_tree,
         switch (fn) {
         case RIEMANN_FN_QUERY_STRING:
             VERIFY_WIRE_FORMAT("Query.string", RIEMANN_WIRE_BYTES);
-            col_append_str(pinfo->cinfo, COL_INFO, riemann_get_string(tvb, offset));
+            col_append_str(pinfo->cinfo, COL_INFO, riemann_get_string(pinfo->pool, tvb, offset));
             len = riemann_dissect_string(query_tree, tvb, offset, hf_riemann_query_string);
             break;
         default:
@@ -403,13 +396,13 @@ riemann_dissect_event(packet_info *pinfo, proto_tree *riemann_tree,
             break;
         case RIEMANN_FN_EVENT_SERVICE:
             VERIFY_WIRE_FORMAT("Event.service", RIEMANN_WIRE_BYTES);
-            col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", comma, riemann_get_string(tvb, offset));
+            col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", comma, riemann_get_string(pinfo->pool, tvb, offset));
             len = riemann_dissect_string(event_tree, tvb, offset, hf_riemann_event_service);
             need_comma = TRUE;
             break;
         case RIEMANN_FN_EVENT_HOST:
             VERIFY_WIRE_FORMAT("Event.host", RIEMANN_WIRE_BYTES);
-            col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", comma, riemann_get_string(tvb, offset));
+            col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", comma, riemann_get_string(pinfo->pool, tvb, offset));
             len = riemann_dissect_string(event_tree, tvb, offset, hf_riemann_event_host);
             need_comma = TRUE;
             break;
@@ -430,6 +423,10 @@ riemann_dissect_event(packet_info *pinfo, proto_tree *riemann_tree,
             VERIFY_WIRE_FORMAT("Event.attributes", RIEMANN_WIRE_BYTES);
             len = riemann_dissect_attribute(pinfo, event_tree, tvb, offset);
             break;
+        case RIEMANN_FN_EVENT_TIME_MICROS:
+            VERIFY_WIRE_FORMAT("Event.time_micros", RIEMANN_WIRE_INTEGER);
+            len = riemann_dissect_int64(event_tree, tvb, offset, hf_riemann_event_time_micros);
+            break;
         case RIEMANN_FN_EVENT_METRIC_SINT64:
             VERIFY_WIRE_FORMAT("Event.metric_sint64", RIEMANN_WIRE_INTEGER);
             len = riemann_dissect_sint64(event_tree, tvb, offset, hf_riemann_event_metric_sint64);
@@ -488,13 +485,13 @@ riemann_dissect_state(packet_info *pinfo, proto_tree *riemann_tree,
             break;
         case RIEMANN_FN_STATE_SERVICE:
             VERIFY_WIRE_FORMAT("State.service", RIEMANN_WIRE_BYTES);
-            col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", comma, riemann_get_string(tvb, offset));
+            col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", comma, riemann_get_string(pinfo->pool, tvb, offset));
             len = riemann_dissect_string(state_tree, tvb, offset, hf_riemann_state_service);
             need_comma = TRUE;
             break;
         case RIEMANN_FN_STATE_HOST:
             VERIFY_WIRE_FORMAT("State.host", RIEMANN_WIRE_BYTES);
-            col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", comma, riemann_get_string(tvb, offset));
+            col_append_fstr(pinfo->cinfo, COL_INFO, "%s%s", comma, riemann_get_string(pinfo->pool, tvb, offset));
             len = riemann_dissect_string(state_tree, tvb, offset, hf_riemann_state_host);
             need_comma = TRUE;
             break;
@@ -740,6 +737,10 @@ proto_register_riemann(void)
           { "metric_f", "riemann.event.metric_f",
             FT_FLOAT, BASE_NONE, NULL, 0, NULL, HFILL }
         },
+        { &hf_riemann_event_time_micros,
+          { "time_micros", "riemann.event.time_micros",
+            FT_INT64, BASE_DEC, NULL, 0, NULL, HFILL }
+        },
         { &hf_riemann_event_metric_sint64,
           { "metric_sint64", "riemann.event.metric_sint64",
             FT_INT64, BASE_DEC, NULL, 0, NULL, HFILL }
@@ -808,15 +809,14 @@ proto_register_riemann(void)
 
     proto_register_field_array(proto_riemann, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
+
+    riemann_udp_handle = register_dissector("riemann.udp", dissect_riemann_udp, proto_riemann);
+    riemann_tcp_handle = register_dissector("riemann.tcp", dissect_riemann_tcp, proto_riemann);
 }
 
 void
 proto_reg_handoff_riemann(void)
 {
-    dissector_handle_t riemann_udp_handle, riemann_tcp_handle;
-
-    riemann_udp_handle = create_dissector_handle(dissect_riemann_udp, proto_riemann);
-    riemann_tcp_handle = create_dissector_handle(dissect_riemann_tcp, proto_riemann);
     dissector_add_for_decode_as_with_preference("tcp.port", riemann_tcp_handle);
     dissector_add_for_decode_as_with_preference("udp.port", riemann_udp_handle);
 }
