@@ -43,19 +43,19 @@ static dissector_handle_t alc_handle;
 void proto_register_alc(void);
 void proto_reg_handoff_alc(void);
 
-static int proto_rmt_alc = -1;
+static int proto_rmt_alc;
 
-static int hf_version = -1;
-static int hf_atsc3 = -1;
-static int hf_object_start_offset = -1;
-static int hf_payload = -1;
-static int hf_uncomp_payload = -1;
+static int hf_version;
+static int hf_atsc3;
+static int hf_object_start_offset;
+static int hf_payload;
+static int hf_uncomp_payload;
 
-static int ett_main = -1;
-static int ett_uncomp_payload = -1;
-static int ett_uncomp_decode = -1;
+static int ett_main;
+static int ett_uncomp_payload;
+static int ett_uncomp_decode;
 
-static expert_field ei_version1_only = EI_INIT;
+static expert_field ei_version1_only;
 
 static dissector_handle_t xml_handle;
 static dissector_handle_t rmt_lct_handle;
@@ -63,7 +63,7 @@ static dissector_handle_t rmt_fec_handle;
 
 static dissector_table_t media_type_dissector_table;
 
-static gboolean g_codepoint_as_fec_encoding = TRUE;
+static bool g_codepoint_as_fec_encoding = true;
 static gint     g_ext_192                   = LCT_PREFS_EXT_192_FLUTE;
 static gint     g_ext_193                   = LCT_PREFS_EXT_193_FLUTE;
 static gint     g_atsc3_mode                = LCT_ATSC3_MODE_AUTO;
@@ -99,7 +99,7 @@ try_decode_payload(tvbuff_t *tvb, packet_info *pinfo, proto_item *tree)
 static void
 try_uncompress(tvbuff_t *tvb, packet_info *pinfo, gint offset, /*gint len,*/ proto_item *ti)
 {
-    tvbuff_t *uncompress_tvb = tvb_uncompress(tvb, offset, tvb_captured_length(tvb) - offset);
+    tvbuff_t *uncompress_tvb = tvb_uncompress_zlib(tvb, offset, tvb_captured_length(tvb) - offset);
     if (uncompress_tvb) {
         add_new_data_source(pinfo, uncompress_tvb, "Uncompressed Payload");
 
@@ -246,12 +246,12 @@ dissect_alc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 }
 
 
-static gboolean
+static bool
 dissect_alc_heur_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     /* Lookup over ATSC3 SLT Table*/
     if (!test_alc_over_slt(pinfo, tvb, 0, data))
-        return FALSE;
+        return false;
 
     conversation_t *conversation = find_or_create_conversation(pinfo);
     conversation_set_dissector(conversation, alc_handle);
@@ -268,7 +268,7 @@ void proto_register_alc(void)
           { "Version", "alc.version", FT_UINT8, BASE_DEC, NULL, 0x0, NULL, HFILL }},
 
         { &hf_atsc3,
-          { "Decode as ATSC3", "alc.atsc3", FT_BOOLEAN, 0, NULL, 0x0, NULL, HFILL }},
+          { "Decode as ATSC3", "alc.atsc3", FT_BOOLEAN, BASE_NONE, NULL, 0x0, NULL, HFILL }},
 
         { &hf_object_start_offset,
           { "Object Start Offset", "alc.object_start_offset", FT_UINT32, BASE_DEC, NULL, 0x0, NULL, HFILL }},
