@@ -38,6 +38,8 @@
 void proto_register_norm(void);
 void proto_reg_handoff_norm(void);
 
+static dissector_handle_t norm_handle;
+
 /* String tables */
 
 #define NORM_INFO       1
@@ -130,70 +132,70 @@ typedef struct norm_packet_data
 /* ============================================= */
 static dissector_handle_t rmt_fec_handle;
 
-static int proto_rmt_norm = -1;
+static int proto_rmt_norm;
 
-static int hf_version = -1;
-static int hf_type = -1;
-static int hf_hlen = -1;
-static int hf_sequence = -1;
-static int hf_source_id = -1;
-static int hf_instance_id = -1;
-static int hf_grtt = -1;
-static int hf_backoff = -1;
-static int hf_gsize = -1;
-static int hf_flags = -1;
-static int hf_flag_repair = -1;
-static int hf_flag_norm_explicit = -1;
-static int hf_flag_info = -1;
-static int hf_flag_unreliable = -1;
-static int hf_flag_file = -1;
-static int hf_flag_stream = -1;
-static int hf_flag_msgstart = -1;
-static int hf_object_transport_id = -1;
-static int hf_extension = -1;
-static int hf_reserved = -1;
-static int hf_payload_len = -1;
-static int hf_payload_offset = -1;
-static int hf_cmd_flavor = -1;
-static int hf_cc_sequence = -1;
-static int hf_cc_sts = -1;
-static int hf_cc_stus = -1;
-static int hf_cc_node_id = -1;
-static int hf_cc_flags = -1;
-static int hf_cc_flags_clr = -1;
-static int hf_cc_flags_plr = -1;
-static int hf_cc_flags_rtt = -1;
-static int hf_cc_flags_start = -1;
-static int hf_cc_flags_leave = -1;
-static int hf_cc_rtt = -1;
-static int hf_cc_rate = -1;
-static int hf_cc_transport_id = -1;
-static int hf_ack_source = -1;
-static int hf_ack_type = -1;
-static int hf_ack_id = -1;
-static int hf_ack_grtt_sec = -1;
-static int hf_ack_grtt_usec = -1;
-static int hf_nack_server = -1;
-static int hf_nack_grtt_sec = -1;
-static int hf_nack_grtt_usec = -1;
-static int hf_nack_form = -1;
-static int hf_nack_flags = -1;
-static int hf_nack_flags_segment = -1;
-static int hf_nack_flags_block = -1;
-static int hf_nack_flags_info = -1;
-static int hf_nack_flags_object = -1;
-static int hf_nack_length = -1;
-static int hf_payload = -1;
-static int hf_fec_encoding_id = -1;
+static int hf_version;
+static int hf_type;
+static int hf_hlen;
+static int hf_sequence;
+static int hf_source_id;
+static int hf_instance_id;
+static int hf_grtt;
+static int hf_backoff;
+static int hf_gsize;
+static int hf_flags;
+static int hf_flag_repair;
+static int hf_flag_norm_explicit;
+static int hf_flag_info;
+static int hf_flag_unreliable;
+static int hf_flag_file;
+static int hf_flag_stream;
+static int hf_flag_msgstart;
+static int hf_object_transport_id;
+static int hf_extension;
+static int hf_reserved;
+static int hf_payload_len;
+static int hf_payload_offset;
+static int hf_cmd_flavor;
+static int hf_cc_sequence;
+static int hf_cc_sts;
+static int hf_cc_stus;
+static int hf_cc_node_id;
+static int hf_cc_flags;
+static int hf_cc_flags_clr;
+static int hf_cc_flags_plr;
+static int hf_cc_flags_rtt;
+static int hf_cc_flags_start;
+static int hf_cc_flags_leave;
+static int hf_cc_rtt;
+static int hf_cc_rate;
+static int hf_cc_transport_id;
+static int hf_ack_source;
+static int hf_ack_type;
+static int hf_ack_id;
+static int hf_ack_grtt_sec;
+static int hf_ack_grtt_usec;
+static int hf_nack_server;
+static int hf_nack_grtt_sec;
+static int hf_nack_grtt_usec;
+static int hf_nack_form;
+static int hf_nack_flags;
+static int hf_nack_flags_segment;
+static int hf_nack_flags_block;
+static int hf_nack_flags_info;
+static int hf_nack_flags_object;
+static int hf_nack_length;
+static int hf_payload;
+static int hf_fec_encoding_id;
 
-static int ett_main = -1;
-static int ett_hdrext = -1;
-static int ett_flags = -1;
-static int ett_streampayload = -1;
-static int ett_congestioncontrol = -1;
-static int ett_nackdata = -1;
+static int ett_main;
+static int ett_hdrext;
+static int ett_flags;
+static int ett_streampayload;
+static int ett_congestioncontrol;
+static int ett_nackdata;
 
-static expert_field ei_version1_only = EI_INIT;
+static expert_field ei_version1_only;
 
 static const double RTT_MIN = 1.0e-06;
 static const double RTT_MAX = 1000;
@@ -636,21 +638,21 @@ dissect_norm(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     return tvb_reported_length(tvb);
 }
 
-static gboolean
+static bool
 dissect_norm_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     guint8 byte1;
 
     if (tvb_reported_length(tvb) < 12)
-        return FALSE;  /* not enough to check */
+        return false;  /* not enough to check */
     byte1 = tvb_get_guint8(tvb, 0);
 
-    if (hi_nibble(byte1) != 1) return FALSE;
-    if (lo_nibble(byte1) < 1 || lo_nibble(byte1) > 6) return FALSE;
-    if (tvb_get_guint8(tvb, 1) > 20) return FALSE;
+    if (hi_nibble(byte1) != 1) return false;
+    if (lo_nibble(byte1) < 1 || lo_nibble(byte1) > 6) return false;
+    if (tvb_get_guint8(tvb, 1) > 20) return false;
 
     dissect_norm(tvb, pinfo, tree, data);
-    return TRUE; /* appears to be a NORM packet */
+    return true; /* appears to be a NORM packet */
 }
 
 void proto_register_norm(void)
@@ -954,6 +956,8 @@ void proto_register_norm(void)
     expert_rmt_norm = expert_register_protocol(proto_rmt_norm);
     expert_register_field_array(expert_rmt_norm, ei, array_length(ei));
 
+    /* Register the subdissector handle */
+    norm_handle = register_dissector("norm", dissect_norm, proto_rmt_norm);
 
     /* Register preferences */
     module = prefs_register_protocol(proto_rmt_norm, NULL);
@@ -962,10 +966,7 @@ void proto_register_norm(void)
 
 void proto_reg_handoff_norm(void)
 {
-    static dissector_handle_t handle;
-
-    handle = create_dissector_handle(dissect_norm, proto_rmt_norm);
-    dissector_add_for_decode_as_with_preference("udp.port", handle);
+    dissector_add_for_decode_as_with_preference("udp.port", norm_handle);
     heur_dissector_add("udp", dissect_norm_heur, "NORM over UDP", "rmt_norm_udp", proto_rmt_norm, HEURISTIC_DISABLE);
 
     rmt_fec_handle = find_dissector_add_dependency("rmt-fec", proto_rmt_norm);
