@@ -61,32 +61,33 @@ static const value_string roofnet_pt_vals[] = {
 void proto_register_roofnet(void);
 void proto_reg_handoff_roofnet(void);
 
+static dissector_handle_t roofnet_handle;
 static dissector_handle_t ip_handle;
 static dissector_handle_t eth_withoutfcs_handle;
-static int proto_roofnet = -1;
+static int proto_roofnet;
 
 /* hf fields for the header of roofnet */
-static int hf_roofnet_version = -1;
-static int hf_roofnet_type = -1;
-static int hf_roofnet_nlinks = -1;
-static int hf_roofnet_next = -1;
-static int hf_roofnet_ttl = -1;
-static int hf_roofnet_cksum = -1;
-static int hf_roofnet_flags = -1;
-static int hf_roofnet_flags_error = -1;
-static int hf_roofnet_flags_update = -1;
-static int hf_roofnet_flags_layer2 = -1;
-static int hf_roofnet_flags_reserved = -1;
-static int hf_roofnet_data_length = -1;
-static int hf_roofnet_query_dst = -1;
-static int hf_roofnet_seq = -1;
-/* static int hf_roofnet_links = -1; */
-static int hf_roofnet_link_src = -1;
-static int hf_roofnet_link_forward = -1;
-static int hf_roofnet_link_rev = -1;
-static int hf_roofnet_link_seq = -1;
-static int hf_roofnet_link_age = -1;
-static int hf_roofnet_link_dst = -1;
+static int hf_roofnet_version;
+static int hf_roofnet_type;
+static int hf_roofnet_nlinks;
+static int hf_roofnet_next;
+static int hf_roofnet_ttl;
+static int hf_roofnet_cksum;
+static int hf_roofnet_flags;
+static int hf_roofnet_flags_error;
+static int hf_roofnet_flags_update;
+static int hf_roofnet_flags_layer2;
+static int hf_roofnet_flags_reserved;
+static int hf_roofnet_data_length;
+static int hf_roofnet_query_dst;
+static int hf_roofnet_seq;
+/* static int hf_roofnet_links; */
+static int hf_roofnet_link_src;
+static int hf_roofnet_link_forward;
+static int hf_roofnet_link_rev;
+static int hf_roofnet_link_seq;
+static int hf_roofnet_link_age;
+static int hf_roofnet_link_dst;
 
 static int * const flag_list[] = {
     &hf_roofnet_flags_error,
@@ -97,20 +98,20 @@ static int * const flag_list[] = {
 };
 
 
-static gint ett_roofnet = -1;
-static gint ett_roofnet_flags = -1;
-static gint ett_roofnet_link = -1;
+static gint ett_roofnet;
+static gint ett_roofnet_flags;
+static gint ett_roofnet_link;
 
-static expert_field ei_roofnet_too_many_links = EI_INIT;
-static expert_field ei_roofnet_too_much_data = EI_INIT;
+static expert_field ei_roofnet_too_many_links;
+static expert_field ei_roofnet_too_much_data;
 
 /*
  * dissect the header of roofnet
  */
-static guint16 dissect_roofnet_header(proto_tree *tree, tvbuff_t *tvb, guint *offset)
+static guint16 dissect_roofnet_header(proto_tree *tree, packet_info *pinfo, tvbuff_t *tvb, guint *offset)
 {
   guint16 flags;
-  ptvcursor_t *cursor = ptvcursor_new(tree, tvb, *offset);
+  ptvcursor_t *cursor = ptvcursor_new(pinfo->pool, tree, tvb, *offset);
 
   ptvcursor_add(cursor, hf_roofnet_version, 1, ENC_BIG_ENDIAN);
   ptvcursor_add(cursor, hf_roofnet_type, 1, ENC_BIG_ENDIAN);
@@ -137,7 +138,7 @@ static guint16 dissect_roofnet_header(proto_tree *tree, tvbuff_t *tvb, guint *of
 /*
  * dissect the description of link in roofnet
  */
-static void dissect_roofnet_link(proto_tree *tree, tvbuff_t *tvb, guint *offset, guint link)
+static void dissect_roofnet_link(proto_tree *tree, packet_info *pinfo, tvbuff_t *tvb, guint *offset, guint link)
 {
   proto_tree *subtree = NULL;
 
@@ -158,7 +159,7 @@ static void dissect_roofnet_link(proto_tree *tree, tvbuff_t *tvb, guint *offset,
   proto_tree_add_ipv4(subtree, hf_roofnet_link_src, tvb, *offset, 4, addr_src);
   *offset += 4;
 
-  cursor = ptvcursor_new(subtree, tvb, *offset);
+  cursor = ptvcursor_new(pinfo->pool, subtree, tvb, *offset);
 
   ptvcursor_add(cursor, hf_roofnet_link_forward, 4, ENC_BIG_ENDIAN);
   ptvcursor_add(cursor, hf_roofnet_link_rev, 4, ENC_BIG_ENDIAN);
@@ -227,7 +228,7 @@ static int dissect_roofnet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   it = proto_tree_add_item(tree, proto_roofnet, tvb, offset, -1, ENC_NA);
   roofnet_tree = proto_item_add_subtree(it, ett_roofnet);
 
-  flags = dissect_roofnet_header(roofnet_tree, tvb, &offset);
+  flags = dissect_roofnet_header(roofnet_tree, pinfo, tvb, &offset);
 
   roofnet_nlinks = tvb_get_guint8(tvb, ROOFNET_OFFSET_NLINKS);
   /* Check that we do not have a malformed roofnet packet */
@@ -240,7 +241,7 @@ static int dissect_roofnet(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     /* Do we have enough buffer to decode the next link ? */
     if (tvb_reported_length_remaining(tvb, offset) < ROOFNET_LINK_DESCRIPTION_LENGTH)
       return offset;
-    dissect_roofnet_link(roofnet_tree, tvb, &offset, nlink++);
+    dissect_roofnet_link(roofnet_tree, pinfo, tvb, &offset, nlink++);
   }
 
   dissect_roofnet_data(tree, tvb, pinfo, offset+4, flags);
@@ -379,18 +380,17 @@ void proto_register_roofnet(void)
   proto_register_subtree_array(ett, array_length(ett));
   expert_roofnet = expert_register_protocol(proto_roofnet);
   expert_register_field_array(expert_roofnet, ei, array_length(ei));
+
+  roofnet_handle = register_dissector("roofnet", dissect_roofnet, proto_roofnet);
 }
 
 
 void proto_reg_handoff_roofnet(void)
 {
-  dissector_handle_t roofnet_handle;
-
   /* Until now there is no other option than having an IPv4 payload (maybe
    * extended one day to IPv6 or other?) */
   ip_handle = find_dissector_add_dependency("ip", proto_roofnet);
   eth_withoutfcs_handle = find_dissector_add_dependency("eth_withoutfcs", proto_roofnet);
-  roofnet_handle = create_dissector_handle(dissect_roofnet, proto_roofnet);
   /* I did not put the type numbers in the ethertypes.h as they only are
    * experimental and not official */
   dissector_add_uint("ethertype", 0x0641, roofnet_handle);
