@@ -45,60 +45,61 @@
 void proto_reg_handoff_rpcordma(void);
 void proto_register_rpcordma(void);
 
-static int proto_rpcordma = -1;
+static int proto_rpcordma;
+static dissector_handle_t rpcordma_handle;
 static dissector_handle_t rpc_handler;
 
 /* RPCoRDMA Header */
-static int hf_rpcordma_xid = -1;
-static int hf_rpcordma_vers = -1;
-static int hf_rpcordma_flow_control = -1;
-static int hf_rpcordma_message_type = -1;
+static int hf_rpcordma_xid;
+static int hf_rpcordma_vers;
+static int hf_rpcordma_flow_control;
+static int hf_rpcordma_message_type;
 
 /* chunks */
-static int hf_rpcordma_reads_count = -1;
-static int hf_rpcordma_writes_count = -1;
-static int hf_rpcordma_reply_count = -1;
+static int hf_rpcordma_reads_count;
+static int hf_rpcordma_writes_count;
+static int hf_rpcordma_reply_count;
 
-static int hf_rpcordma_position = -1;
-static int hf_rpcordma_segment_count = -1;
+static int hf_rpcordma_position;
+static int hf_rpcordma_segment_count;
 
 /* rdma_segment */
-static int hf_rpcordma_rdma_handle = -1;
-static int hf_rpcordma_rdma_length = -1;
-static int hf_rpcordma_rdma_offset = -1;
+static int hf_rpcordma_rdma_handle;
+static int hf_rpcordma_rdma_length;
+static int hf_rpcordma_rdma_offset;
 
-static int hf_rpcordma_rdma_align = -1;
-static int hf_rpcordma_rdma_thresh = -1;
+static int hf_rpcordma_rdma_align;
+static int hf_rpcordma_rdma_thresh;
 
-static int hf_rpcordma_errcode = -1;
-static int hf_rpcordma_vers_high = -1;
-static int hf_rpcordma_vers_low = -1;
+static int hf_rpcordma_errcode;
+static int hf_rpcordma_vers_high;
+static int hf_rpcordma_vers_low;
 
 /* Initialize the subtree pointers */
-static gint ett_rpcordma = -1;
-static gint ett_rpcordma_chunk = -1;
-static gint ett_rpcordma_read_list = -1;
-static gint ett_rpcordma_read_chunk = -1;
-static gint ett_rpcordma_write_list = -1;
-static gint ett_rpcordma_write_chunk = -1;
-static gint ett_rpcordma_reply_chunk = -1;
-static gint ett_rpcordma_segment = -1;
+static gint ett_rpcordma;
+static gint ett_rpcordma_chunk;
+static gint ett_rpcordma_read_list;
+static gint ett_rpcordma_read_chunk;
+static gint ett_rpcordma_write_list;
+static gint ett_rpcordma_write_chunk;
+static gint ett_rpcordma_reply_chunk;
+static gint ett_rpcordma_segment;
 
 /* Fragmentation */
-static int hf_rpcordma_fragments = -1;
-static int hf_rpcordma_fragment = -1;
-static int hf_rpcordma_fragment_overlap = -1;
-static int hf_rpcordma_fragment_overlap_conflicts = -1;
-static int hf_rpcordma_fragment_multiple_tails = -1;
-static int hf_rpcordma_fragment_too_long_fragment = -1;
-static int hf_rpcordma_fragment_error = -1;
-static int hf_rpcordma_fragment_count = -1;
-static int hf_rpcordma_reassembled_in = -1;
-static int hf_rpcordma_reassembled_length = -1;
-static int hf_rpcordma_reassembled_data = -1;
+static int hf_rpcordma_fragments;
+static int hf_rpcordma_fragment;
+static int hf_rpcordma_fragment_overlap;
+static int hf_rpcordma_fragment_overlap_conflicts;
+static int hf_rpcordma_fragment_multiple_tails;
+static int hf_rpcordma_fragment_too_long_fragment;
+static int hf_rpcordma_fragment_error;
+static int hf_rpcordma_fragment_count;
+static int hf_rpcordma_reassembled_in;
+static int hf_rpcordma_reassembled_length;
+static int hf_rpcordma_reassembled_data;
 
-static gint ett_rpcordma_fragment = -1;
-static gint ett_rpcordma_fragments = -1;
+static gint ett_rpcordma_fragment;
+static gint ett_rpcordma_fragments;
 
 static const fragment_items rpcordma_frag_items = {
     /* Fragment subtrees */
@@ -241,19 +242,19 @@ enum {
  * an extra argument to differentiate between InfiniBand and iWarp.
  * Reassembly is only supported for InfiniBand packets.
  */
-static struct infinibandinfo *gp_infiniband_info = NULL;
+static struct infinibandinfo *gp_infiniband_info;
 
 /* Global variable set for every iWarp packet */
-static rdmap_info_t *gp_rdmap_info = NULL;
+static rdmap_info_t *gp_rdmap_info;
 
 /* Call process_reassembled_data just once per frame */
-static gboolean g_needs_reassembly = FALSE;
+static gboolean g_needs_reassembly;
 
 /* Array of offsets for reduced data in write chunks */
-static wmem_array_t *gp_rdma_write_offsets = NULL;
+static wmem_array_t *gp_rdma_write_offsets;
 
 /* Signal upper layer(s) the current frame's data has been reduced by DDP */
-static gboolean g_rpcrdma_reduced = FALSE;
+static gboolean g_rpcrdma_reduced;
 
 /*
  * Signal upper layer(s) the current frame's data has been reduced by DDP
@@ -1743,7 +1744,7 @@ dissect_rpcrdma(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data
     return offset;
 }
 
-static gboolean
+static bool
 dissect_rpcrdma_ib_heur(tvbuff_t *tvb, packet_info *pinfo,
         proto_tree *tree, void *data)
 {
@@ -1758,7 +1759,7 @@ dissect_rpcrdma_ib_heur(tvbuff_t *tvb, packet_info *pinfo,
     gp_infiniband_info = (struct infinibandinfo *)data;
 
     if (!gp_infiniband_info)
-        return FALSE;
+        return false;
 
     /* Get conversation state */
     p_rdma_conv_info = get_rdma_conv_info(pinfo);
@@ -1770,7 +1771,7 @@ dissect_rpcrdma_ib_heur(tvbuff_t *tvb, packet_info *pinfo,
     case RC_SEND_FIRST:
     case RC_SEND_MIDDLE:
         add_send_fragment(p_rdma_conv_info, tvb, pinfo, tree);
-        return FALSE;
+        return false;
     case RC_SEND_LAST:
     case RC_SEND_LAST_INVAL:
         tvb = add_send_fragment(p_rdma_conv_info, tvb, pinfo, tree);
@@ -1779,7 +1780,7 @@ dissect_rpcrdma_ib_heur(tvbuff_t *tvb, packet_info *pinfo,
     case RC_RDMA_WRITE_ONLY_IMM:
         set_max_iosize(p_rdma_conv_info, tvb_reported_length(tvb));
         add_ib_fragment(tvb, p_rdma_conv_info, TRUE, pinfo, tree);
-        return FALSE;
+        return false;
     case RC_RDMA_WRITE_FIRST:
         set_max_iosize(p_rdma_conv_info, tvb_reported_length(tvb));
         add_request_info(p_rdma_conv_info, pinfo);
@@ -1790,10 +1791,10 @@ dissect_rpcrdma_ib_heur(tvbuff_t *tvb, packet_info *pinfo,
         /* Add fragment to the reassembly table */
         add_ib_fragment(tvb, p_rdma_conv_info, FALSE, pinfo, tree);
         /* Do not dissect here, dissection is done on RDMA_MSG or RDMA_NOMSG */
-        return FALSE;
+        return false;
     case RC_RDMA_READ_REQUEST:
         add_request_info(p_rdma_conv_info, pinfo);
-        return FALSE;
+        return false;
     case RC_RDMA_READ_RESPONSE_FIRST:
         set_max_iosize(p_rdma_conv_info, tvb_reported_length(tvb));
         /* fall through */
@@ -1818,18 +1819,18 @@ dissect_rpcrdma_ib_heur(tvbuff_t *tvb, packet_info *pinfo,
             /* This is the last fragment, data has been reassembled and ready to dissect */
             return call_dissector(rpc_handler, new_tvb, pinfo, tree);
         }
-        return FALSE;
+        return false;
     default:
-        return FALSE;
+        return false;
     }
 
     if (!packet_is_rpcordma(tvb))
-        return FALSE;
+        return false;
     dissect_rpcrdma(tvb, pinfo, tree, NULL);
-    return TRUE;
+    return true;
 }
 
-static gboolean
+static bool
 dissect_rpcrdma_iwarp_heur(tvbuff_t *tvb, packet_info *pinfo,
         proto_tree *tree, void *data)
 {
@@ -1844,7 +1845,7 @@ dissect_rpcrdma_iwarp_heur(tvbuff_t *tvb, packet_info *pinfo,
     gp_rdmap_info = (rdmap_info_t *)data;
 
     if (!gp_rdmap_info)
-        return FALSE;
+        return false;
 
     /* Get conversation state */
     p_rdma_conv_info = get_rdma_conv_info(pinfo);
@@ -1855,36 +1856,36 @@ dissect_rpcrdma_iwarp_heur(tvbuff_t *tvb, packet_info *pinfo,
         tvb = add_send_fragment(p_rdma_conv_info, tvb, pinfo, tree);
         if (!gp_rdmap_info->last_flag) {
             /* This is a SEND fragment, do not dissect yet */
-            return FALSE;
+            return false;
         }
         break;
     case RDMA_WRITE:
         add_iwarp_fragment(tvb, p_rdma_conv_info, pinfo, tree);
         /* Do not dissect here, dissection is done on RDMA_MSG or RDMA_NOMSG */
-        return FALSE;
+        return false;
     case RDMA_READ_REQUEST:
         if (!pinfo->fd->visited && gp_rdmap_info->read_request) {
             p_read_request = wmem_new(wmem_file_scope(), rdmap_request_t);
             memcpy(p_read_request, gp_rdmap_info->read_request, sizeof(rdmap_request_t));
             wmem_tree_insert32(p_rdma_conv_info->request_list, gp_rdmap_info->read_request->sink_stag, p_read_request);
         }
-        return FALSE;
+        return false;
     case RDMA_READ_RESPONSE:
         new_tvb = add_iwarp_fragment(tvb, p_rdma_conv_info, pinfo, tree);
         if (new_tvb) {
             /* This is the last fragment, data has been reassembled and ready to dissect */
             return call_dissector(rpc_handler, new_tvb, pinfo, tree);
         }
-        return FALSE;
+        return false;
     default:
-        return FALSE;
+        return false;
     }
 
     if (!packet_is_rpcordma(tvb))
-        return FALSE;
+        return false;
 
     dissect_rpcrdma(tvb, pinfo, tree, NULL);
-    return TRUE;
+    return true;
 }
 
 void
@@ -1988,19 +1989,19 @@ proto_register_rpcordma(void)
         },
         { &hf_rpcordma_fragment_overlap,
           { "Fragment overlap", "rpcordma.fragment.overlap",
-            FT_BOOLEAN, 0, NULL, 0x00, NULL, HFILL}
+            FT_BOOLEAN, BASE_NONE, NULL, 0x00, NULL, HFILL}
         },
         { &hf_rpcordma_fragment_overlap_conflicts,
           { "Fragment overlapping with conflicting data", "rpcordma.fragment.overlap.conflicts",
-            FT_BOOLEAN, 0, NULL, 0x00, NULL, HFILL}
+            FT_BOOLEAN, BASE_NONE, NULL, 0x00, NULL, HFILL}
         },
         { &hf_rpcordma_fragment_multiple_tails,
           { "Multiple tail fragments found", "rpcordma.fragment.multiple_tails",
-            FT_BOOLEAN, 0, NULL, 0x00, NULL, HFILL}
+            FT_BOOLEAN, BASE_NONE, NULL, 0x00, NULL, HFILL}
         },
         { &hf_rpcordma_fragment_too_long_fragment,
           { "Fragment too long", "rpcordma.fragment.too_long_fragment",
-            FT_BOOLEAN, 0, NULL, 0x00, NULL, HFILL}
+            FT_BOOLEAN, BASE_NONE, NULL, 0x00, NULL, HFILL}
         },
         { &hf_rpcordma_fragment_error,
           { "Defragmentation error", "rpcordma.fragment.error",
@@ -2047,6 +2048,9 @@ proto_register_rpcordma(void)
     proto_register_subtree_array(ett, array_length(ett));
     reassembly_table_register(&rpcordma_reassembly_table, &addresses_ports_reassembly_table_functions);
 
+    /* Register dissector handle */
+    rpcordma_handle = register_dissector("rpcordma", dissect_rpcrdma, proto_rpcordma);
+
     /* Register preferences */
     rpcordma_module = prefs_register_protocol_obsolete(proto_rpcordma);
 
@@ -2067,7 +2071,7 @@ proto_reg_handoff_rpcordma(void)
 {
     heur_dissector_add("infiniband.payload", dissect_rpcrdma_ib_heur, "RPC-over-RDMA on Infiniband",
                         "rpcrdma_infiniband", proto_rpcordma, HEURISTIC_ENABLE);
-    dissector_add_for_decode_as("infiniband", create_dissector_handle( dissect_rpcrdma, proto_rpcordma ) );
+    dissector_add_for_decode_as("infiniband", rpcordma_handle);
 
     heur_dissector_add("iwarp_ddp_rdmap", dissect_rpcrdma_iwarp_heur, "RPC-over-RDMA on iWARP",
                         "rpcrdma_iwarp", proto_rpcordma, HEURISTIC_ENABLE);
