@@ -48,7 +48,7 @@ enum rsync_who {
     SERVER
 };
 
-static gboolean rsync_desegment = TRUE;
+static bool rsync_desegment = true;
 
 /* this is a guide to the current conversation state */
 struct rsync_conversation_data {
@@ -60,25 +60,25 @@ struct rsync_frame_data {
     rsync_state_t state;
 };
 
-static int proto_rsync = -1;
+static int proto_rsync;
 
-static int hf_rsync_command_string = -1;
-static int hf_rsync_data = -1;
-static int hf_rsync_hdr_magic = -1;
-static int hf_rsync_hdr_version = -1;
-static int hf_rsync_module_list_string = -1;
-static int hf_rsync_motd_string = -1;
-static int hf_rsync_query_string = -1;
-static int hf_rsync_rsyncdok_string = -1;
+static int hf_rsync_command_string;
+static int hf_rsync_data;
+static int hf_rsync_hdr_magic;
+static int hf_rsync_hdr_version;
+static int hf_rsync_module_list_string;
+static int hf_rsync_motd_string;
+static int hf_rsync_query_string;
+static int hf_rsync_rsyncdok_string;
 
-static gint ett_rsync = -1;
+static gint ett_rsync;
 
 static dissector_handle_t rsync_handle;
 
 
 #define TCP_PORT_RSYNC  873
 
-static range_t *glb_rsync_tcp_range = NULL;
+static range_t *glb_rsync_tcp_range;
 
 #define VERSION_LEN     4           /* 2 digits for main version; '.'; 1 digit for sub version */
 
