@@ -124,32 +124,32 @@ void proto_reg_handoff_rtitcp(void);
 void proto_register_rtitcp(void);
 
 /* Initialize the protocol and registered fields */
-static gint proto_rtitcp                                         = -1;
-static gint hf_rtitcp_header_control_byte                        = -1;
-static gint hf_rtitcp_header_magic_number                        = -1;
-static gint hf_rtitcp_header_message_length                      = -1;
-static gint hf_rtitcp_control_transaction_id                     = -1;
-static gint hf_rtitcp_control_kind                               = -1;
-static gint hf_rtitcp_control_attribute_type                     = -1;
-static gint hf_rtitcp_control_attribute_length                   = -1;
-static gint hf_rtitcp_control_attribute_port                     = -1;
-static gint hf_rtitcp_attributes_list_length                     = -1;
-static gint hf_rtitcp_control_magic_cookie                       = -1;
-static gint hf_rtitcp_control_attribute_connection_cookie        = -1;
-static gint hf_rtitcp_control_attribute_connection_type          = -1;
-static gint hf_rtitcp_control_attribute_session_id               = -1;
-static gint hf_rtitcp_control_attribute_error_code_value         = -1;
-static gint hf_rtitcp_control_attribute_error_code_description   = -1;
-static gint hf_rtitcp_locator_ipv4                               = -1;
-static gint hf_rtitcp_locator_port                               = -1;
-static gint hf_rtitcp_locator_ipv6                               = -1;
-static gint hf_rtitcp_locator_kind                               = -1;
-static gint hf_rtitcp_crc_magic_cookie                           = -1;
-static gint hf_rtitcp_control_crc_value                          = -1;
+static gint proto_rtitcp;
+static gint hf_rtitcp_header_control_byte;
+static gint hf_rtitcp_header_magic_number;
+static gint hf_rtitcp_header_message_length;
+static gint hf_rtitcp_control_transaction_id;
+static gint hf_rtitcp_control_kind;
+static gint hf_rtitcp_control_attribute_type;
+static gint hf_rtitcp_control_attribute_length;
+static gint hf_rtitcp_control_attribute_port;
+static gint hf_rtitcp_attributes_list_length;
+static gint hf_rtitcp_control_magic_cookie;
+static gint hf_rtitcp_control_attribute_connection_cookie;
+static gint hf_rtitcp_control_attribute_connection_type;
+static gint hf_rtitcp_control_attribute_session_id;
+static gint hf_rtitcp_control_attribute_error_code_value;
+static gint hf_rtitcp_control_attribute_error_code_description;
+static gint hf_rtitcp_locator_ipv4;
+static gint hf_rtitcp_locator_port;
+static gint hf_rtitcp_locator_ipv6;
+static gint hf_rtitcp_locator_kind;
+static gint hf_rtitcp_crc_magic_cookie;
+static gint hf_rtitcp_control_crc_value;
 
-static gint hf_rtitcp_response_in                                = -1;
-static gint hf_rtitcp_response_to                                = -1;
-static gint hf_rtitcp_response_time                              = -1;
+static gint hf_rtitcp_response_in;
+static gint hf_rtitcp_response_to;
+static gint hf_rtitcp_response_time;
 
 #define RTITCP_FLAG_NOT_REQUEST 0x0100
 
@@ -164,13 +164,13 @@ typedef struct _rtitcp_conv_info_t {
 } rtitcp_conv_info_t;
 
 /* Subtree pointers */
-static gint ett_rtitcp                              = -1;
-static gint ett_rtitcp_signalling_protocol          = -1;
-static gint ett_rtitcp_message                      = -1;
-static gint ett_rtitcp_attributes_list              = -1;
-static gint ett_rtitcp_attribute                    = -1;
+static gint ett_rtitcp;
+static gint ett_rtitcp_signalling_protocol;
+static gint ett_rtitcp_message;
+static gint ett_rtitcp_attributes_list;
+static gint ett_rtitcp_attribute;
 
-static header_field_info *hfi_rtitcp                = NULL;
+static header_field_info *hfi_rtitcp;
 static heur_dissector_list_t heur_subdissector_list;
 
 static const value_string ctrl_message_types_vals[] = {
@@ -764,6 +764,11 @@ static gint dissect_rtitcp(tvbuff_t *tvb, packet_info *pinfo,
 
 }
 
+static bool
+dissect_rtitcp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+{
+    return dissect_rtitcp(tvb, pinfo, tree, data) > 0;
+}
 
 /* Register the protocol with Wireshark.
  *
@@ -781,25 +786,25 @@ proto_register_rtitcp(void)
         { &hf_rtitcp_header_control_byte, {
             "Control Byte", "rtitcp.header.control_byte",
             FT_UINT16, BASE_HEX, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_header_message_length, {
             "Message Length", "rtitcp.header.message_length",
             FT_UINT16, BASE_DEC, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_header_magic_number, {
             "Magic Cookie", "rtitcp.header.magic_cookie",
             FT_UINT32, BASE_HEX, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_crc_magic_cookie, {
             "CRC Magic Cookie", "rtitcp.header.crc_magic_cookie",
             FT_UINT32, BASE_HEX, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_control_kind,
@@ -811,19 +816,19 @@ proto_register_rtitcp(void)
         { &hf_rtitcp_control_magic_cookie, {
             "Control Magic Cookie", "rtitcp.control.magic_cookie",
             FT_UINT32, BASE_HEX, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_control_transaction_id, {
             "Transaction ID", "rtitcp.control.transaction_id",
             FT_BYTES, BASE_NONE, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_control_attribute_session_id, {
             "Session ID", "rtitcp.control.attribute.session_id",
             FT_BYTES, BASE_NONE, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_control_attribute_type,
@@ -841,38 +846,37 @@ proto_register_rtitcp(void)
         { &hf_rtitcp_control_attribute_error_code_description, {
             "Description", "rtitcp.control.attribute.error_code.description",
             FT_STRING, BASE_NONE, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_control_attribute_connection_cookie, {
             "Connection Cookie", "rtitcp.control.attribute.connection_cookie",
             FT_BYTES, BASE_NONE, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_control_attribute_connection_type, {
             "Class ID", "rtitcp.control_attribute.connection_type",
             FT_UINT8, BASE_HEX, VALS(rtitcp_attribute_connection_type_vals), 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_attributes_list_length, {
             "Attributes list length", "rtitcp.attributes_list_length",
             FT_UINT16, BASE_DEC, NULL, 0,
-            0,
-            HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_control_attribute_length, {
             "Attribute Length", "rtitcp.control.attribute.length",
             FT_UINT16, BASE_DEC, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_control_attribute_port, {
             "Port", "rtitcp.control.attribute_port",
             FT_UINT32, BASE_DEC, NULL, 0,
-            0, HFILL }
+            NULL, HFILL }
         },
 
         { &hf_rtitcp_locator_kind,
@@ -899,30 +903,29 @@ proto_register_rtitcp(void)
             NULL, HFILL }
         },
 
-        { &hf_rtitcp_control_crc_value, {
-         "CRC", "rtitcp.control.crc",
-         FT_UINT32, BASE_HEX, NULL, 0,
-         0, HFILL }
+        { &hf_rtitcp_control_crc_value,
+          { "CRC", "rtitcp.control.crc",
+            FT_UINT32, BASE_HEX, NULL, 0,
+            NULL, HFILL }
         },
 
-        { &hf_rtitcp_response_in, {
-         "Response In", "rtitcp.response_in",
-         FT_FRAMENUM, BASE_NONE, NULL, 0x0,
-         "The response to this RTITCP request is in this frame", HFILL }
+        { &hf_rtitcp_response_in,
+          { "Response In", "rtitcp.response_in",
+            FT_FRAMENUM, BASE_NONE, NULL, 0x0,
+            "The response to this RTITCP request is in this frame", HFILL }
         },
 
-        { &hf_rtitcp_response_to, {
-         "Request In", "rtitcp.response_to",
-         FT_FRAMENUM, BASE_NONE, NULL, 0x0,
-         "This is a response to the RTITCP request in this frame", HFILL }
-        },
-
-        { &hf_rtitcp_response_time, {
-         "Response Time", "rtitcp.response_time",
-         FT_RELATIVE_TIME, BASE_NONE, NULL, 0x0,
-         "The time between the Request and the Reply", HFILL }
+        { &hf_rtitcp_response_to,
+          { "Request In", "rtitcp.response_to",
+            FT_FRAMENUM, BASE_NONE, NULL, 0x0,
+            "This is a response to the RTITCP request in this frame", HFILL }
         },
 
+        { &hf_rtitcp_response_time,
+          { "Response Time", "rtitcp.response_time",
+            FT_RELATIVE_TIME, BASE_NONE, NULL, 0x0,
+            "The time between the Request and the Reply", HFILL }
+        }
     };
 
     static gint *ett[] = {
@@ -950,7 +953,7 @@ proto_register_rtitcp(void)
      expert_register_field_array(expert_rtitcp, ei, array_length(ei)); */
 
     register_dissector("rtitcp", dissect_rtitcp, proto_rtitcp);
-    heur_subdissector_list = register_heur_dissector_list("rtitcp", proto_rtitcp);
+    heur_subdissector_list = register_heur_dissector_list_with_description("rtitcp", "RTI TCP signalling message", proto_rtitcp);
 
 }
 
@@ -959,7 +962,7 @@ proto_register_rtitcp(void)
 void
 proto_reg_handoff_rtitcp(void)
 {
-    heur_dissector_add("tcp", dissect_rtitcp, "RTI TCP Layer" , "rtitcp", proto_rtitcp, HEURISTIC_ENABLE);
+    heur_dissector_add("tcp", dissect_rtitcp_heur, "RTI TCP Layer" , "rtitcp", proto_rtitcp, HEURISTIC_ENABLE);
 }
 
 /*
