@@ -39,14 +39,14 @@ void proto_reg_handoff_rtp_events(void);
 
 /* RTP Event Fields */
 
-static int proto_rtp_events = -1;
-static int rtp_event_tap = -1;
+static int proto_rtp_events;
+static int rtp_event_tap;
 
-static int hf_rtp_events_event = -1;	/* one byte */
-static int hf_rtp_events_end = -1;	/* one bit */
-static int hf_rtp_events_reserved = -1; /* one bit */
-static int hf_rtp_events_volume = -1;	/* six bits */
-static int hf_rtp_events_duration = -1; /* sixteen bits */
+static int hf_rtp_events_event;	/* one byte */
+static int hf_rtp_events_end;	/* one bit */
+static int hf_rtp_events_reserved; /* one bit */
+static int hf_rtp_events_volume;	/* six bits */
+static int hf_rtp_events_duration; /* sixteen bits */
 
 
 #define RTP_DTMF_0	0
@@ -352,7 +352,7 @@ static const value_string rtp_event_type_values[] =
     { 189,                           "MFC forward signal 14" }, // [RFC5244]
     { 190,                           "MFC forward signal 15" }, // [RFC5244]
     { 191,                           "MFC backward signal 1" }, // [RFC5244]
-    { 192,                           "MFC backward signal 2" }, // [RFC5244]
+    //{ 192,                           "MFC backward signal 2" }, // [RFC5244]
 
         //193	MFC backward signal 3[RFC5244]
         //194	MFC backward signal 4[RFC5244]
@@ -387,7 +387,7 @@ value_string_ext rtp_event_type_values_ext = VALUE_STRING_EXT_INIT(rtp_event_typ
 
 /* RTP Events fields defining a subtree */
 
-static gint ett_rtp_events           = -1;
+static gint ett_rtp_events;
 
 static dissector_handle_t rtp_events_handle;
 
@@ -422,7 +422,7 @@ dissect_rtp_events( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* d
 	/* get tap info */
 	rtp_event_info.info_rtp_evt = rtp_evt;
 
-	p_packet_data = (struct _rtp_packet_info *)p_get_proto_data(wmem_file_scope(), pinfo, proto_get_id_by_filter_name("rtp"), 0);
+	p_packet_data = (struct _rtp_packet_info *)p_get_proto_data(wmem_file_scope(), pinfo, proto_get_id_by_filter_name("rtp"), RTP_CONVERSATION_PROTO_DATA);
 	if (p_packet_data)
 		rtp_event_info.info_setup_frame_num = p_packet_data->frame_number;
 	else
