@@ -60,9 +60,8 @@
 #include <epan/addr_resolv.h>
 #include <epan/wmem_scopes.h>
 #include <epan/conversation.h>
-#include <epan/column.h>
-#include <epan/dissectors/packet-tcp.h>
-#include <epan/dissectors/packet-rtps.h>
+#include "packet-tcp.h"
+#include "packet-rtps.h"
 
 
 #define PARAM_ID_ADVANCED_FRAME0               0x000C1
@@ -82,18 +81,18 @@ static void get_new_colinfo_w_submessages(
 
 /* Subtree pointers */
 static gint rtpsproc_tree = -1;
-static gint rtpsproc_ett = -1;
-static gint rtpsproc_ett_security = -1;
-static gint rtpsproc_ett_advanced_frame0 = -1;
-static gint rtpsproc_ett_advanced_frame1 = -1;
+static gint ett_rtpsproc;
+static gint ett_rtpsproc_security;
+static gint ett_rtpsproc_advanced_frame0;
+static gint ett_rtpsproc_advanced_frame1;
 
 /* Initialize the protocol and registered fields */
-static header_field_info *rtpsproc_hf = NULL;
-static gint rtpsproc_hf_param_id = -1;
-static gint rtpsproc_hf_param_length = -1;
+static header_field_info *rtpsproc_hf;
+static int hf_rtpsproc_param_id;
+static int hf_rtpsproc_param_length;
 
 /* Used for caching a handle to the RTPS dissector */
-static dissector_handle_t rtps_handle = NULL;
+static dissector_handle_t rtps_handle;
 
 /* ========================================================================== */
 /*                                 Dissector                                  */
@@ -167,7 +166,7 @@ static gint dissect_rtps_processed(
             offset,
             -1,
             ENC_BIG_ENDIAN);
-    rtpsproc_tree_general = proto_item_add_subtree(rtpsproc_ti, rtpsproc_ett);
+    rtpsproc_tree_general = proto_item_add_subtree(rtpsproc_ti, ett_rtpsproc);
 
     /* ***************************  ADVANCED 0  *******************************/
     param_id = tvb_get_guint16(tvb, offset, ENC_BIG_ENDIAN);
@@ -180,7 +179,7 @@ static gint dissect_rtps_processed(
                 tvb,
                 offset,
                 0,
-                rtpsproc_ett_security,
+                ett_rtpsproc_security,
                 NULL,
                 "%s",
                 title_security);
@@ -190,14 +189,14 @@ static gint dissect_rtps_processed(
                 tvb,
                 offset,
                 0,
-                rtpsproc_ett_advanced_frame0,
+                ett_rtpsproc_advanced_frame0,
                 NULL,
                 "%s",
                 "RTPS level");
 
         proto_tree_add_uint(
                 rtpsproc_tree_frame0,
-                rtpsproc_hf_param_id,
+                hf_rtpsproc_param_id,
                 tvb,
                 offset,
                 2, /* length */
@@ -206,7 +205,7 @@ static gint dissect_rtps_processed(
 
         proto_tree_add_uint(
                 rtpsproc_tree_frame0,
-                rtpsproc_hf_param_length,
+                hf_rtpsproc_param_length,
                 tvb,
                 offset,
                 2, /* length */
@@ -245,7 +244,7 @@ static gint dissect_rtps_processed(
                     tvb,
                     offset,
                     0,
-                    rtpsproc_ett_security,
+                    ett_rtpsproc_security,
                     NULL,
                     "%s",
                     title_security);
@@ -256,14 +255,14 @@ static gint dissect_rtps_processed(
                 tvb,
                 offset,
                 0,
-                rtpsproc_ett_advanced_frame1,
+                ett_rtpsproc_advanced_frame1,
                 NULL,
                 "%s",
                 title);
 
         proto_tree_add_uint(
                 rtpsproc_tree_frame1,
-                rtpsproc_hf_param_id,
+                hf_rtpsproc_param_id,
                 tvb,
                 offset,
                 2, /* length */
@@ -272,7 +271,7 @@ static gint dissect_rtps_processed(
 
         proto_tree_add_uint(
                 rtpsproc_tree_frame1,
-                rtpsproc_hf_param_length,
+                hf_rtpsproc_param_length,
                 tvb,
                 offset,
                 2, /* length */
@@ -314,7 +313,8 @@ static gint dissect_rtps_processed(
                     rtpsproc_tree_frame1,
                     rtps_version,
                     rtps_vendor_id,
-                    &guid);
+                    &guid,
+                    false /* dissect_rtps_submessages. */);
 
             /*
              * Get the decrypted submessages and update the column information.
@@ -392,39 +392,36 @@ static void get_new_colinfo_w_submessages(
 }
 
 /* ========================================================================== */
-/*                            Protocol egistration                            */
+/*                            Protocol registration                           */
 /* ========================================================================== */
 void
 proto_register_rtps_processed(void)
 {
     static hf_register_info hf[] = {
         {
-            &rtpsproc_hf_param_id,
+            &hf_rtpsproc_param_id,
             {
                 "Parameter Identifier", "rtpsproc.param.id",
-                FT_UINT16, BASE_DEC, NULL, 0, 0, HFILL
+                FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL
             },
         },
         {
-            &rtpsproc_hf_param_length,
+            &hf_rtpsproc_param_length,
             {
                 "Parameter Length", "rtpsproc.param.length",
-                FT_UINT16, BASE_DEC, NULL, 0, 0, HFILL
+                FT_UINT16, BASE_DEC, NULL, 0, NULL, HFILL
             }
         },
     };
     static gint *ett[] = {
-        &rtpsproc_ett,
-        &rtpsproc_ett_security,
-        &rtpsproc_ett_advanced_frame0,
-        &rtpsproc_ett_advanced_frame1
+        &ett_rtpsproc,
+        &ett_rtpsproc_security,
+        &ett_rtpsproc_advanced_frame0,
+        &ett_rtpsproc_advanced_frame1
     };
 
   /* Register the protocol name and description */
-    rtpsproc_tree = proto_register_protocol(
-            "Real-Time Publish-Subscribe Wire Protocol (processed)",
-            "RTPS-PROC",
-            "rtpsproc");
+    rtpsproc_tree = proto_register_protocol("Real-Time Publish-Subscribe Wire Protocol (processed)", "RTPS-PROC", "rtpsproc");
 
     /* Required function calls to register the header fields and subtrees */
     rtpsproc_hf = proto_registrar_get_nth(rtpsproc_tree);
