@@ -39,7 +39,7 @@
 
 void proto_register_rtsp(void);
 
-static int rtsp_tap = -1;
+static int rtsp_tap;
 static rtsp_info_value_t *rtsp_stat_info;
 
 /* http://www.iana.org/assignments/rtsp-parameters/rtsp-parameters.xml */
@@ -101,38 +101,38 @@ const value_string rtsp_status_code_vals[] = {
     { 0,    NULL}
 };
 
-static int proto_rtsp       = -1;
+static int proto_rtsp;
 
-static gint ett_rtsp        = -1;
-static gint ett_rtspframe   = -1;
-static gint ett_rtsp_method     = -1;
+static gint ett_rtsp;
+static gint ett_rtspframe;
+static gint ett_rtsp_method;
 
-static int hf_rtsp_request  = -1;
-static int hf_rtsp_response = -1;
-static int hf_rtsp_content_type = -1;
-static int hf_rtsp_content_length   = -1;
-static int hf_rtsp_method   = -1;
-static int hf_rtsp_url      = -1;
-static int hf_rtsp_status   = -1;
-static int hf_rtsp_session  = -1;
-static int hf_rtsp_transport    = -1;
-static int hf_rtsp_rdtfeaturelevel  = -1;
-static int hf_rtsp_X_Vig_Msisdn = -1;
-static int hf_rtsp_magic = -1;
-static int hf_rtsp_channel = -1;
-static int hf_rtsp_length = -1;
-static int hf_rtsp_data = -1;
+static int hf_rtsp_request;
+static int hf_rtsp_response;
+static int hf_rtsp_content_type;
+static int hf_rtsp_content_length;
+static int hf_rtsp_method;
+static int hf_rtsp_url;
+static int hf_rtsp_status;
+static int hf_rtsp_session;
+static int hf_rtsp_transport;
+static int hf_rtsp_rdtfeaturelevel;
+static int hf_rtsp_X_Vig_Msisdn;
+static int hf_rtsp_magic;
+static int hf_rtsp_channel;
+static int hf_rtsp_length;
+static int hf_rtsp_data;
 
-static int voip_tap = -1;
+static int voip_tap;
 
-static expert_field ei_rtsp_unknown_transport_type = EI_INIT;
-static expert_field ei_rtsp_bad_server_port = EI_INIT;
-static expert_field ei_rtsp_bad_client_port = EI_INIT;
-static expert_field ei_rtsp_bad_interleaved_channel = EI_INIT;
-static expert_field ei_rtsp_content_length_invalid = EI_INIT;
-static expert_field ei_rtsp_rdtfeaturelevel_invalid = EI_INIT;
-static expert_field ei_rtsp_bad_server_ip_address = EI_INIT;
-static expert_field ei_rtsp_bad_client_ip_address = EI_INIT;
+static expert_field ei_rtsp_unknown_transport_type;
+static expert_field ei_rtsp_bad_server_port;
+static expert_field ei_rtsp_bad_client_port;
+static expert_field ei_rtsp_bad_interleaved_channel;
+static expert_field ei_rtsp_content_length_invalid;
+static expert_field ei_rtsp_rdtfeaturelevel_invalid;
+static expert_field ei_rtsp_bad_server_ip_address;
+static expert_field ei_rtsp_bad_client_ip_address;
 
 static dissector_handle_t rtsp_handle;
 static dissector_handle_t rtp_handle;
@@ -167,16 +167,16 @@ static int st_node_other = -1;
 static void
 rtsp_stats_tree_init(stats_tree* st)
 {
-    st_node_packets     = stats_tree_create_node(st, st_str_packets, 0, STAT_DT_INT, TRUE);
+    st_node_packets     = stats_tree_create_node(st, st_str_packets, 0, STAT_DT_INT, true);
     st_node_requests    = stats_tree_create_pivot(st, st_str_requests, st_node_packets);
-    st_node_responses   = stats_tree_create_node(st, st_str_responses, st_node_packets, STAT_DT_INT, TRUE);
-    st_node_resp_broken = stats_tree_create_node(st, st_str_resp_broken, st_node_responses, STAT_DT_INT, TRUE);
-    st_node_resp_100    = stats_tree_create_node(st, st_str_resp_100,    st_node_responses, STAT_DT_INT, TRUE);
-    st_node_resp_200    = stats_tree_create_node(st, st_str_resp_200,    st_node_responses, STAT_DT_INT, TRUE);
-    st_node_resp_300    = stats_tree_create_node(st, st_str_resp_300,    st_node_responses, STAT_DT_INT, TRUE);
-    st_node_resp_400    = stats_tree_create_node(st, st_str_resp_400,    st_node_responses, STAT_DT_INT, TRUE);
-    st_node_resp_500    = stats_tree_create_node(st, st_str_resp_500,    st_node_responses, STAT_DT_INT, TRUE);
-    st_node_other       = stats_tree_create_node(st, st_str_other, st_node_packets, STAT_DT_INT, FALSE);
+    st_node_responses   = stats_tree_create_node(st, st_str_responses, st_node_packets, STAT_DT_INT, true);
+    st_node_resp_broken = stats_tree_create_node(st, st_str_resp_broken, st_node_responses, STAT_DT_INT, true);
+    st_node_resp_100    = stats_tree_create_node(st, st_str_resp_100,    st_node_responses, STAT_DT_INT, true);
+    st_node_resp_200    = stats_tree_create_node(st, st_str_resp_200,    st_node_responses, STAT_DT_INT, true);
+    st_node_resp_300    = stats_tree_create_node(st, st_str_resp_300,    st_node_responses, STAT_DT_INT, true);
+    st_node_resp_400    = stats_tree_create_node(st, st_str_resp_400,    st_node_responses, STAT_DT_INT, true);
+    st_node_resp_500    = stats_tree_create_node(st, st_str_resp_500,    st_node_responses, STAT_DT_INT, true);
+    st_node_other       = stats_tree_create_node(st, st_str_other, st_node_packets, STAT_DT_INT, false);
 }
 
 /* RTSP/Packet Counter stats packet function */
@@ -189,10 +189,10 @@ rtsp_stats_tree_packet(stats_tree* st, packet_info* pinfo _U_, epan_dissect_t* e
     const gchar  *resp_str;
     static gchar  str[64];
 
-    tick_stat_node(st, st_str_packets, 0, FALSE);
+    tick_stat_node(st, st_str_packets, 0, false);
 
     if (i) {
-        tick_stat_node(st, st_str_responses, st_node_packets, FALSE);
+        tick_stat_node(st, st_str_responses, st_node_packets, false);
 
         if ( (i<100)||(i>=600) ) {
             resp_grp = st_node_resp_broken;
@@ -214,14 +214,14 @@ rtsp_stats_tree_packet(stats_tree* st, packet_info* pinfo _U_, epan_dissect_t* e
             resp_str = st_str_resp_500;
         }
 
-        tick_stat_node(st, resp_str, st_node_responses, FALSE);
+        tick_stat_node(st, resp_str, st_node_responses, false);
 
         snprintf(str, sizeof(str),"%u %s",i,val_to_str(i,rtsp_status_code_vals, "Unknown (%d)"));
-        tick_stat_node(st, str, resp_grp, FALSE);
+        tick_stat_node(st, str, resp_grp, false);
     } else if (v->request_method) {
         stats_tree_tick_pivot(st,st_node_requests,v->request_method);
     } else {
-        tick_stat_node(st, st_str_other, st_node_packets, FALSE);
+        tick_stat_node(st, st_str_other, st_node_packets, false);
     }
 
     return TAP_PACKET_REDRAW;
@@ -232,14 +232,14 @@ void proto_reg_handoff_rtsp(void);
  * desegmentation of RTSP headers
  * (when we are over TCP or another protocol providing the desegmentation API)
  */
-static gboolean rtsp_desegment_headers = TRUE;
+static bool rtsp_desegment_headers = true;
 
 /*
  * desegmentation of RTSP bodies
  * (when we are over TCP or another protocol providing the desegmentation API)
  * TODO let the user filter on content-type the bodies he wants desegmented
  */
-static gboolean rtsp_desegment_body = TRUE;
+static bool rtsp_desegment_body = true;
 
 /* http://www.iana.org/assignments/port-numbers lists two rtsp ports.
  * In Addition RTSP uses display port over Wi-Fi Display: 7236.
@@ -387,7 +387,7 @@ dissect_rtspinterleaved(tvbuff_t *tvb, int offset, packet_info *pinfo,
         (dissector = data->interleaved[rf_chan].dissector)) {
         call_dissector(dissector, next_tvb, pinfo, tree);
     } else {
-        gboolean dissected = FALSE;
+        bool dissected = false;
         heur_dtbl_entry_t *hdtbl_entry = NULL;
 
         dissected = dissector_try_heuristic(heur_subdissector_list,
@@ -848,7 +848,8 @@ dissect_rtspmessage(tvbuff_t *tvb, int offset, packet_info *pinfo,
          * assumes zero if missing.
          */
         if (!req_resp_hdrs_do_reassembly(tvb, offset, pinfo,
-            rtsp_desegment_headers, rtsp_desegment_body, FALSE)) {
+            rtsp_desegment_headers, rtsp_desegment_body, FALSE, NULL,
+            NULL, NULL)) {
             /*
              * More data needed for desegmentation.
              */
@@ -1430,7 +1431,7 @@ process_rtsp_request(tvbuff_t *tvb, int offset, const guchar *data,
     while (url < lineend && !g_ascii_isspace(*url))
         url++;
     /* Create a URL-sized buffer and copy contents */
-    tmp_url = wmem_strndup(wmem_packet_scope(), url_start, url - url_start);
+    tmp_url = format_text(wmem_packet_scope(), url_start, url - url_start);
 
     /* Add URL to tree */
     proto_tree_add_string(sub_tree, hf_rtsp_url, tvb,
@@ -1621,7 +1622,7 @@ proto_register_rtsp(void)
      * this table using the standard heur_dissector_add()
      * function.
      */
-    heur_subdissector_list = register_heur_dissector_list("rtsp", proto_rtsp);
+    heur_subdissector_list = register_heur_dissector_list_with_description("rtsp", "RTSP data", proto_rtsp);
 
     /*
      * Register for tapping
@@ -1643,7 +1644,7 @@ proto_reg_handoff_rtsp(void)
     dissector_add_uint_range_with_preference("tcp.port", RTSP_TCP_PORT_RANGE, rtsp_handle);
 
     /* XXX: Do the following only once ?? */
-    stats_tree_register("rtsp","rtsp","RTSP/Packet Counter", 0, rtsp_stats_tree_packet, rtsp_stats_tree_init, NULL );
+    stats_tree_register("rtsp","rtsp","RTSP" STATS_TREE_MENU_SEPARATOR "Packet Counter", 0, rtsp_stats_tree_packet, rtsp_stats_tree_init, NULL );
 
 }
 
