@@ -21,61 +21,61 @@
 void proto_register_sametime(void);
 void proto_reg_handoff_sametime(void);
 
-static int proto_sametime = -1;
+static int proto_sametime;
 static dissector_handle_t sametime_handle;
 
 /*preferences*/
-static gboolean global_sametime_show_length = FALSE;
-static gboolean global_sametime_reassemble_packets = TRUE;
+static bool global_sametime_show_length;
+static bool global_sametime_reassemble_packets = true;
 
 /*heart beat*/
-static int hf_sametime_heartbeat = -1;
+static int hf_sametime_heartbeat;
 
 /*sametime message header*/
-static int hf_sametime_message_length = -1;
-static int hf_sametime_message_type = -1;
-static int hf_sametime_message_options = -1;
-static int hf_sametime_message_options_attribute = -1;
-static int hf_sametime_message_options_encrypted = -1;
-static int hf_sametime_message_channel = -1;
+static int hf_sametime_message_length;
+static int hf_sametime_message_type;
+static int hf_sametime_message_options;
+static int hf_sametime_message_options_attribute;
+static int hf_sametime_message_options_encrypted;
+static int hf_sametime_message_channel;
 
 /*common types*/
-static int hf_sametime_field_length = -1;
-static int hf_sametime_field_text = -1;
-static int hf_sametime_code = -1;
-static int hf_sametime_login_type = -1;
-static int hf_sametime_time = -1;
+static int hf_sametime_field_length;
+static int hf_sametime_field_text;
+static int hf_sametime_code;
+static int hf_sametime_login_type;
+static int hf_sametime_time;
 
 /*handshake*/
-static int hf_sametime_handshake_major = -1;
-static int hf_sametime_handshake_minor = -1;
-static int hf_sametime_handshake_srvrcalc_addr = -1;
-static int hf_sametime_handshake_loclcalc_addr = -1;
+static int hf_sametime_handshake_major;
+static int hf_sametime_handshake_minor;
+static int hf_sametime_handshake_srvrcalc_addr;
+static int hf_sametime_handshake_loclcalc_addr;
 
 /*channel*/
-static int hf_sametime_channel_service = -1;
-static int hf_sametime_channel_id = -1;
-static int hf_sametime_channel_send_type = -1;
-static int hf_sametime_channel_awareness = -1;
+static int hf_sametime_channel_service;
+static int hf_sametime_channel_id;
+static int hf_sametime_channel_send_type;
+static int hf_sametime_channel_awareness;
 
 /*user status*/
-static int hf_sametime_user_status = -1;
+static int hf_sametime_user_status;
 
 /*location*/
-static int hf_sametime_location_country = -1;
-static int hf_sametime_location_postalcode = -1;
-static int hf_sametime_location_province = -1;
-static int hf_sametime_location_city = -1;
-static int hf_sametime_location_phone = -1;
-static int hf_sametime_location_name = -1;
-static int hf_sametime_location_timezone = -1;
+static int hf_sametime_location_country;
+static int hf_sametime_location_postalcode;
+static int hf_sametime_location_province;
+static int hf_sametime_location_city;
+static int hf_sametime_location_phone;
+static int hf_sametime_location_name;
+static int hf_sametime_location_timezone;
 
 /*packet detail tree*/
-static gint ett_sametime = -1;
-static gint ett_sametime_options = -1;
+static gint ett_sametime;
+static gint ett_sametime_options;
 
 /*statistics*/
-static int sametime_tap = -1;
+static int sametime_tap;
 static const guint8* st_str_packet = "Sametime Message Count";
 static const guint8* st_str_message_type = "Message Type";
 static const guint8* st_str_send_type = "Send Type";
@@ -616,11 +616,11 @@ dissect_sametime_content(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, vo
         tick statistics
 */
 static tap_packet_status
-sametime_stats_tree_packet(stats_tree* st, packet_info* pinfo _U_, epan_dissect_t* edt _U_, const void* p)
+sametime_stats_tree_packet(stats_tree* st, packet_info* pinfo _U_, epan_dissect_t* edt _U_, const void* p, tap_flags_t flags _U_)
 {
    const struct SametimeTap *pi = (const struct SametimeTap *)p;
 
-   tick_stat_node(st, st_str_packet, 0, FALSE);
+   tick_stat_node(st, st_str_packet, 0, false);
    if (pi->message_type != -1)
       stats_tree_tick_pivot(st, st_node_message_type, val_to_str(pi->message_type, messagetypenames, "Unknown (0x%04x)"));
 
@@ -640,7 +640,7 @@ sametime_stats_tree_packet(stats_tree* st, packet_info* pinfo _U_, epan_dissect_
 static void
 sametime_stats_tree_init(stats_tree* st)
 {
-   st_node_packet = stats_tree_create_node(st, st_str_packet, 0, STAT_DT_INT, TRUE);
+   st_node_packet = stats_tree_create_node(st, st_str_packet, 0, STAT_DT_INT, true);
    st_node_message_type = stats_tree_create_pivot(st, st_str_message_type, st_node_packet);
    st_node_send_type = stats_tree_create_pivot(st, st_str_send_type, st_node_packet);
    st_node_user_status = stats_tree_create_pivot(st, st_str_user_status, st_node_packet);
@@ -877,6 +877,8 @@ proto_register_sametime(void)
    proto_register_field_array(proto_sametime, hf, array_length(hf));
    proto_register_subtree_array(ett, array_length(ett));
 
+   sametime_handle = register_dissector("sametime", dissect_sametime, proto_sametime);
+
    sametime_tap = register_tap("sametime");
 
    /* Preference setting */
@@ -897,10 +899,9 @@ proto_register_sametime(void)
 void
 proto_reg_handoff_sametime(void)
 {
-   sametime_handle = create_dissector_handle(dissect_sametime, proto_sametime);
    dissector_add_uint_with_preference("tcp.port", DEFAULT_SAMETIME_PORT, sametime_handle);
 
-   stats_tree_register("sametime", "sametime", "Sametime/Messages", 0,
+   stats_tree_register("sametime", "sametime", "Sametime" STATS_TREE_MENU_SEPARATOR "Messages", 0,
         sametime_stats_tree_packet,
         sametime_stats_tree_init, NULL );
 
