@@ -61,133 +61,133 @@ static const unsigned char SCTE35_TABLE_ID = 0xFCU;
 static const int SCTE35_SI_MIN_LEN = 20;
 
 /* Protocol handle */
-static int proto_scte35 = -1;
+static int proto_scte35;
 
 /* Dissector table for scte35.splice_command_type */
-static dissector_table_t scte35_cmd_dissector_table = NULL;
+static dissector_table_t scte35_cmd_dissector_table;
 
 
 /* splice_info_section table */
-static gint ett_scte35_splice_info_section = -1;
+static gint ett_scte35_splice_info_section;
 
 /* splice_info_section fields */
-static gint hf_table_id = -1;
-static gint hf_section_syntax_indicator = -1;
-static gint hf_private_indicator = -1;
-static gint hf_reserved = -1;
-static gint hf_section_length = -1;
-static gint hf_protocol_version = -1;
-static gint hf_encrypted_packet = -1;
-static gint hf_encryption_algorithm = -1;
-static gint hf_pts_adjustment = -1;
-static gint hf_cw_index = -1;
-static gint hf_tier = -1;
-static gint hf_splice_command_length = -1;
-static gint hf_splice_command_type = -1;
-static gint hf_descriptor_loop_length = -1;
-static gint hf_splice_descriptor_tag = -1;
-static gint hf_splice_descriptor_length = -1;
-static gint hf_splice_descriptor_identifier = -1;
-static gint hf_descriptor_provider_avail_id = -1;
-static gint hf_descriptor_preroll = -1;
-static gint hf_descriptor_dtmf_count = -1;
-static gint hf_descriptor_dtmf_reserved = -1;
-static gint hf_descriptor_dtmf = -1;
-static gint hf_descriptor_event_id = -1;
-static gint hf_descriptor_cancel_indicator = -1;
-static gint hf_descriptor_reserved0 = -1;
-static gint hf_descriptor_psf = -1;
-static gint hf_descriptor_segmentation_duration_flag = -1;
-static gint hf_descriptor_delivery_not_restricted_flag = -1;
-static gint hf_descriptor_web_delivery_allowed_flag = -1;
-static gint hf_descriptor_no_regional_blackout_flag = -1;
-static gint hf_descriptor_archive_allow_flag = -1;
-static gint hf_descriptor_device_restrictions = -1;
-static gint hf_descriptor_reserved1 = -1;
-static gint hf_descriptor_component_count = -1;
-static gint hf_descriptor_component_tag = -1;
-static gint hf_descriptor_component_reserved = -1;
-static gint hf_descriptor_component_pts_offset = -1;
-static gint hf_descriptor_segmentation_duration = -1;
-static gint hf_descriptor_segmentation_upid_type = -1;
-static gint hf_descriptor_segmentation_upid_length = -1;
-static gint hf_descriptor_segmentation_upid = -1;
-static gint hf_descriptor_segmentation_type_id = -1;
-static gint hf_descriptor_segment_num = -1;
-static gint hf_descriptor_segments_expected = -1;
-static gint hf_e_crc32 = -1;
-static gint hf_crc32 = -1;
+static gint hf_table_id;
+static gint hf_section_syntax_indicator;
+static gint hf_private_indicator;
+static gint hf_reserved;
+static gint hf_section_length;
+static gint hf_protocol_version;
+static gint hf_encrypted_packet;
+static gint hf_encryption_algorithm;
+static gint hf_pts_adjustment;
+static gint hf_cw_index;
+static gint hf_tier;
+static gint hf_splice_command_length;
+static gint hf_splice_command_type;
+static gint hf_descriptor_loop_length;
+static gint hf_splice_descriptor_tag;
+static gint hf_splice_descriptor_length;
+static gint hf_splice_descriptor_identifier;
+static gint hf_descriptor_provider_avail_id;
+static gint hf_descriptor_preroll;
+static gint hf_descriptor_dtmf_count;
+static gint hf_descriptor_dtmf_reserved;
+static gint hf_descriptor_dtmf;
+static gint hf_descriptor_event_id;
+static gint hf_descriptor_cancel_indicator;
+static gint hf_descriptor_reserved0;
+static gint hf_descriptor_psf;
+static gint hf_descriptor_segmentation_duration_flag;
+static gint hf_descriptor_delivery_not_restricted_flag;
+static gint hf_descriptor_web_delivery_allowed_flag;
+static gint hf_descriptor_no_regional_blackout_flag;
+static gint hf_descriptor_archive_allow_flag;
+static gint hf_descriptor_device_restrictions;
+static gint hf_descriptor_reserved1;
+static gint hf_descriptor_component_count;
+static gint hf_descriptor_component_tag;
+static gint hf_descriptor_component_reserved;
+static gint hf_descriptor_component_pts_offset;
+static gint hf_descriptor_segmentation_duration;
+static gint hf_descriptor_segmentation_upid_type;
+static gint hf_descriptor_segmentation_upid_length;
+static gint hf_descriptor_segmentation_upid;
+static gint hf_descriptor_segmentation_type_id;
+static gint hf_descriptor_segment_num;
+static gint hf_descriptor_segments_expected;
+static gint hf_e_crc32;
+static gint hf_crc32;
 
 /* time_signal protocol and fields */
-static int proto_scte35_time = -1;
-static gint ett_scte35_time_signal = -1;
-static gint ett_scte35_time_signal_splice_time = -1;
-static gint hf_time_specified = -1;
-static gint hf_time_reserved = -1;
-static gint hf_time_pts = -1;
+static int proto_scte35_time;
+static gint ett_scte35_time_signal;
+static gint ett_scte35_time_signal_splice_time;
+static gint hf_time_specified;
+static gint hf_time_reserved;
+static gint hf_time_pts;
 
 /* private_command protocol and fields */
-static int proto_private_command = -1;
-static gint ett_private_command = -1;
-static gint hf_identifier = -1;
-static gint hf_private_byte = -1;
+static int proto_private_command;
+static gint ett_private_command;
+static gint hf_identifier;
+static gint hf_private_byte;
 
 /* Dissector table for scte35_private_command.identifier */
-static dissector_table_t private_identifier_table = NULL;
+static dissector_table_t private_identifier_table;
 
-static dissector_handle_t scte35_handle = NULL;
+static dissector_handle_t scte35_handle;
 static dissector_handle_t scte35_time_handle;
 static dissector_handle_t scte35_private_command_handle;
 static dissector_handle_t scte35_si_handle;
 static dissector_handle_t scte35_ss_handle;
 
 /* splice_insert protocol and fields */
-static int proto_scte35_si = -1;
-static gint ett_scte35_splice_insert = -1;
-static gint hf_splice_insert_event_id = -1;
-static gint hf_splice_cancel_indicator = -1;
-static gint hf_reserved0 = -1;
-static gint hf_out_of_network_indicator = -1;
-static gint hf_program_splice_flag = -1;
-static gint hf_duration_flag = -1;
-static gint hf_splice_immediate_flag = -1;
-static gint hf_reserved1 = -1;
-static gint hf_splice_time_specified_flag = -1;
-static gint hf_splice_time_reserved = -1;
-static gint hf_splice_time_pts_time = -1;
-static gint hf_component_count = -1;
-static gint hf_component_tag = -1;
-static gint hf_component_splice_time_tsf = -1;
-static gint hf_component_splice_time_reserved = -1;
-static gint hf_component_splice_time_pts_time = -1;
-static gint hf_break_duration_auto_return = -1;
-static gint hf_break_duration_reserved = -1;
-static gint hf_break_duration_duration = -1;
-static gint hf_unique_program_id = -1;
-static gint hf_avail_num = -1;
-static gint hf_avails_expected = -1;
+static int proto_scte35_si;
+static gint ett_scte35_splice_insert;
+static gint hf_splice_insert_event_id;
+static gint hf_splice_cancel_indicator;
+static gint hf_reserved0;
+static gint hf_out_of_network_indicator;
+static gint hf_program_splice_flag;
+static gint hf_duration_flag;
+static gint hf_splice_immediate_flag;
+static gint hf_reserved1;
+static gint hf_splice_time_specified_flag;
+static gint hf_splice_time_reserved;
+static gint hf_splice_time_pts_time;
+static gint hf_component_count;
+static gint hf_component_tag;
+static gint hf_component_splice_time_tsf;
+static gint hf_component_splice_time_reserved;
+static gint hf_component_splice_time_pts_time;
+static gint hf_break_duration_auto_return;
+static gint hf_break_duration_reserved;
+static gint hf_break_duration_duration;
+static gint hf_unique_program_id;
+static gint hf_avail_num;
+static gint hf_avails_expected;
 
 /* splice_schedule protocol and fields */
-static int proto_scte35_splice_schedule = -1;
-static gint ett_scte35_splice_schedule = -1;
-static gint hf_splice_count = -1;
-static gint hf_splice_event_id = -1;
-static gint hf_splice_event_cancel_indicator = -1;
-static gint hf_splice_reserved0 = -1;
-static gint hf_splice_out_of_network = -1;
-static gint hf_splice_program_splice_flag = -1;
-static gint hf_splice_duration_flag = -1;
-static gint hf_splice_reserved1 = -1;
-static gint hf_splice_utc_splice_time = -1;
-static gint hf_splice_component_count = -1;
-static gint hf_splice_component_tag = -1;
-static gint hf_splice_component_utc_splice_time = -1;
-static gint hf_splice_break_duration_auto_return = -1;
-static gint hf_splice_break_duration_reserved = -1;
-static gint hf_splice_break_duration_duration = -1;
-static gint hf_splice_unique_program_id = -1;
-static gint hf_splice_avail_num = -1;
-static gint hf_splice_avails_expected = -1;
+static int proto_scte35_splice_schedule;
+static gint ett_scte35_splice_schedule;
+static gint hf_splice_count;
+static gint hf_splice_event_id;
+static gint hf_splice_event_cancel_indicator;
+static gint hf_splice_reserved0;
+static gint hf_splice_out_of_network;
+static gint hf_splice_program_splice_flag;
+static gint hf_splice_duration_flag;
+static gint hf_splice_reserved1;
+static gint hf_splice_utc_splice_time;
+static gint hf_splice_component_count;
+static gint hf_splice_component_tag;
+static gint hf_splice_component_utc_splice_time;
+static gint hf_splice_break_duration_auto_return;
+static gint hf_splice_break_duration_reserved;
+static gint hf_splice_break_duration_duration;
+static gint hf_splice_unique_program_id;
+static gint hf_splice_avail_num;
+static gint hf_splice_avails_expected;
 
 static const true_false_string tfs_section_syntax_indicator = {
     "Reserved", "MPEG short sections in use"};
@@ -324,7 +324,7 @@ dissect_scte35_time_signal(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     col_add_fstr(pinfo->cinfo, COL_INFO, "Time Signal (%s)",
                  time_specified_flag ? "Future" : "Immediate");
 
-    /* Create a subtee for the time_signal */
+    /* Create a subtree for the time_signal */
     ti = proto_tree_add_item(tree, proto_scte35_time, tvb, 0, -1, ENC_NA);
     time_tree = proto_item_add_subtree(ti, ett_scte35_time_signal);
 
@@ -1082,7 +1082,7 @@ dissect_scte35_segmentation_descriptor(tvbuff_t *tvb, packet_info *pinfo, proto_
             }
         }
 
-        /* Parse segementation duration if present. */
+        /* Parse segmentation duration if present. */
         if (sdf) {
             proto_tree_add_item(tree, hf_descriptor_segmentation_duration, tvb,
                                 offset, 5, ENC_BIG_ENDIAN);
@@ -1391,7 +1391,7 @@ proto_register_scte35(void)
              FT_UINT8, BASE_HEX, NULL, 0x1F, NULL, HFILL}},
         {&hf_descriptor_dtmf,
          {"DTMF", "scte35.splice_descriptor.dtmf",
-             FT_STRING, 0, NULL, 0, NULL, HFILL}},
+             FT_STRING, BASE_NONE, NULL, 0, NULL, HFILL}},
 
         /* segmentation_descriptor */
         {&hf_descriptor_event_id,
@@ -1452,7 +1452,7 @@ proto_register_scte35(void)
              FT_UINT8, BASE_DEC, NULL, 0, NULL, HFILL}},
         {&hf_descriptor_segmentation_upid,
          {"UPID", "scte35.splice_descriptor.upid",
-             FT_STRING, 0, NULL, 0, NULL, HFILL}},
+             FT_STRING, BASE_NONE, NULL, 0, NULL, HFILL}},
         {&hf_descriptor_segmentation_type_id,
          {"Segmentation Type", "scte35.splice_descriptor.segmentation_type_id",
              FT_UINT8, BASE_HEX | BASE_RANGE_STRING,
