@@ -30,6 +30,8 @@
 void proto_reg_handoff_scylla(void);
 void proto_register_scylla(void);
 
+static dissector_handle_t scylla_handle;
+
 #define SCYLLA_PORT 0 /* Not IANA registered, 7000 is the expected value */
 
 #define SCYLLA_HEADER_SIZE 28
@@ -44,47 +46,47 @@ void proto_register_scylla(void);
 #define SCYLLA_NEGOTIATION_SIZE 12
 #define SCYLLA_NEGOTIATION_LEN_OFFSET 8
 
-static int proto_scylla = -1;
+static int proto_scylla;
 
-static int hf_scylla_request = -1;
-static int hf_scylla_request_response_frame = -1;
-static int hf_scylla_timeout = -1;
-static int hf_scylla_verb = -1;
-static int hf_scylla_msg_id = -1;
-static int hf_scylla_len = -1;
-static int hf_scylla_response = -1;
-static int hf_scylla_response_size = -1;
-static int hf_scylla_response_request_frame = -1;
-static int hf_scylla_negotiation_magic = -1;
-static int hf_scylla_negotiation_size = -1;
-static int hf_scylla_payload = -1; // TODO: dissect everything, so that generic "payload" is not needed
+static int hf_scylla_request;
+static int hf_scylla_request_response_frame;
+static int hf_scylla_timeout;
+static int hf_scylla_verb;
+static int hf_scylla_msg_id;
+static int hf_scylla_len;
+static int hf_scylla_response;
+static int hf_scylla_response_size;
+static int hf_scylla_response_request_frame;
+static int hf_scylla_negotiation_magic;
+static int hf_scylla_negotiation_size;
+static int hf_scylla_payload; // TODO: dissect everything, so that generic "payload" is not needed
 
 // Mutation
-static int hf_scylla_mut_size1 = -1;
-static int hf_scylla_mut_size2 = -1;
-static int hf_scylla_mut_table_id = -1;
-static int hf_scylla_mut_schema_id = -1;
-static int hf_scylla_mut_len_pkeys = -1;
-static int hf_scylla_mut_num_pkeys = -1;
-static int hf_scylla_mut_len_pkey = -1;
-static int hf_scylla_mut_pkey = -1;
+static int hf_scylla_mut_size1;
+static int hf_scylla_mut_size2;
+static int hf_scylla_mut_table_id;
+static int hf_scylla_mut_schema_id;
+static int hf_scylla_mut_len_pkeys;
+static int hf_scylla_mut_num_pkeys;
+static int hf_scylla_mut_len_pkey;
+static int hf_scylla_mut_pkey;
 
 // Read data
-static int hf_scylla_read_data_timeout = -1;
-static int hf_scylla_read_data_table_id = -1;
-static int hf_scylla_read_data_schema_version = -1;
+static int hf_scylla_read_data_timeout;
+static int hf_scylla_read_data_table_id;
+static int hf_scylla_read_data_schema_version;
 
-static gint ett_scylla = -1;
-static gint ett_scylla_header = -1;
-static gint ett_scylla_response = -1;
-static gint ett_scylla_negotiation = -1;
-static gint ett_scylla_mut = -1;
-static gint ett_scylla_mut_pkey = -1;
-static gint ett_scylla_read_data = -1;
+static gint ett_scylla;
+static gint ett_scylla_header;
+static gint ett_scylla_response;
+static gint ett_scylla_negotiation;
+static gint ett_scylla_mut;
+static gint ett_scylla_mut_pkey;
+static gint ett_scylla_read_data;
 
-static gboolean scylla_desegment = TRUE;
+static bool scylla_desegment = true;
 
-static expert_field ei_scylla_response_missing = EI_INIT;
+static expert_field ei_scylla_response_missing;
 
 enum scylla_packets {
     CLIENT_ID = 0,
@@ -527,14 +529,13 @@ proto_register_scylla(void)
     proto_register_subtree_array(ett, array_length(ett));
     expert_scylla = expert_register_protocol(proto_scylla);
     expert_register_field_array(expert_scylla, ei, array_length(ei));
+
+    scylla_handle = register_dissector("scylla", dissect_scylla, proto_scylla);
 }
 
 void
 proto_reg_handoff_scylla(void)
 {
-    static dissector_handle_t scylla_handle;
-
-    scylla_handle = create_dissector_handle(dissect_scylla, proto_scylla);
     dissector_add_uint_with_preference("tcp.port", SCYLLA_PORT, scylla_handle);
 }
 
