@@ -36,109 +36,111 @@
 void proto_register_sercosiii(void);
 void proto_reg_handoff_sercosiii(void);
 
+static dissector_handle_t siii_handle;
+
 /* Initialize the protocol and registered fields */
-static gint proto_siii = -1;
+static gint proto_siii;
 
 /* Initialize the subtree pointers */
-static gint ett_siii = -1;
-static gint ett_siii_header = -1;
-static gint ett_siii_mst = -1;
-static gint ett_siii_mst_teltype = -1;
-static gint ett_siii_mst_phase = -1;
-static gint ett_siii_mdt = -1;
-static gint ett_siii_mdt_svc = -1;
-static gint ett_siii_mdt_devctrls = -1;
-static gint ett_siii_mdt_version = -1;
-static gint ett_siii_mdt_svc_channel = -1;
-static gint ett_siii_mdt_dev_control = -1;
-static gint ett_siii_mdt_devctrl = -1;
-static gint ett_siii_mdt_svcctrl = -1;
-static gint ett_siii_mdt_svcinfo = -1;
-static gint ett_siii_at_svcstat = -1;
-static gint ett_siii_at_svcinfo = -1;
-static gint ett_siii_mdt_svch_data_error_info = -1;
-static gint ett_siii_mdt_svch_data = -1;
-static gint ett_siii_at_devstatus = -1;
-static gint ett_siii_at_sercosaddress = -1;
-static gint ett_siii_at = -1;
-static gint ett_siii_at_svc = -1;
-static gint ett_siii_at_sercos_address = -1;
-static gint ett_siii_at_devstats = -1;
-static gint ett_siii_at_svc_channel = -1;
-static gint ett_siii_at_dev_status = -1;
-static gint ett_siii_mdt_hp = -1;
-static gint ett_siii_at_hp = -1;
-static gint ett_siii_mdt_hp_ctrl = -1;
-static gint ett_siii_mdt_hp_info = -1;
-static gint ett_siii_at_hp_stat = -1;
-static gint ett_siii_at_hp_info = -1;
-static gint ett_siii_recognized_devices = -1;
+static gint ett_siii;
+static gint ett_siii_header;
+static gint ett_siii_mst;
+static gint ett_siii_mst_teltype;
+static gint ett_siii_mst_phase;
+static gint ett_siii_mdt;
+static gint ett_siii_mdt_svc;
+static gint ett_siii_mdt_devctrls;
+static gint ett_siii_mdt_version;
+static gint ett_siii_mdt_svc_channel;
+static gint ett_siii_mdt_dev_control;
+static gint ett_siii_mdt_devctrl;
+static gint ett_siii_mdt_svcctrl;
+static gint ett_siii_mdt_svcinfo;
+static gint ett_siii_at_svcstat;
+static gint ett_siii_at_svcinfo;
+static gint ett_siii_mdt_svch_data_error_info;
+static gint ett_siii_mdt_svch_data;
+static gint ett_siii_at_devstatus;
+static gint ett_siii_at_sercosaddress;
+static gint ett_siii_at;
+static gint ett_siii_at_svc;
+static gint ett_siii_at_sercos_address;
+static gint ett_siii_at_devstats;
+static gint ett_siii_at_svc_channel;
+static gint ett_siii_at_dev_status;
+static gint ett_siii_mdt_hp;
+static gint ett_siii_at_hp;
+static gint ett_siii_mdt_hp_ctrl;
+static gint ett_siii_mdt_hp_info;
+static gint ett_siii_at_hp_stat;
+static gint ett_siii_at_hp_info;
+static gint ett_siii_recognized_devices;
 
-static gint hf_siii_mdt_version = -1;
-static gint hf_siii_mdt_version_initprocvers = -1;
-static gint hf_siii_mdt_version_num_mdt_at_cp1_2 = -1;
-static gint hf_siii_mdt_version_switch_off_sercos_telegrams = -1;
-static gint hf_siii_mdt_version_fast_cp_switch = -1;
-static gint hf_siii_mdt_version_transmission_of_communication_parameters_mdt0_cp0 = -1;
-static gint hf_siii_mdt_dev_control_top_control = -1;
-static gint hf_siii_at_dev_control_ident = -1;
-static gint hf_siii_mdt_dev_control_change_topology = -1;
-static gint hf_siii_mdt_dev_control = -1;
-static gint hf_siii_mst_channel = -1;
-static gint hf_siii_mst_type = -1;
-static gint hf_siii_mst_cyclecntvalid = -1;
-static gint hf_siii_mst_telno = -1;
-static gint hf_siii_mst_phase = -1;
-static gint hf_siii_mst_cyclecnt = -1;
-static gint hf_siii_mst_crc32 = -1;
-static gint hf_siii_mdt_svch_dbe = -1;
-static gint hf_siii_mdt_svch_eot = -1;
-static gint hf_siii_mdt_svch_rw = -1;
-static gint hf_siii_mdt_svch_mhs = -1;
-static gint hf_siii_mdt_svch_info = -1;
-static gint hf_siii_at_svch_valid = -1;
-static gint hf_siii_at_svch_error = -1;
-static gint hf_siii_at_svch_busy = -1;
-static gint hf_siii_at_svch_ahs = -1;
-static gint hf_siii_at_svch_info = -1;
-static gint hf_siii_mdt_svch_idn = -1;
-static gint hf_siii_mdt_svch_ctrl = -1;
-static gint hf_siii_at_svch_stat = -1;
-/* static gint hf_siii_svch_data_telofs_telno = -1; */
-/* static gint hf_siii_svch_data_telofs_mdt_at = -1; */
-/* static gint hf_siii_svch_data_telofs_offset = -1; */
-/* static gint hf_siii_svch_data_proccmd_proccmdexec = -1; */
-/* static gint hf_siii_svch_data_proccmd_proccmd = -1; */
-static gint hf_siii_at_cp0_support_functions = -1;
-static gint hf_siii_at_cp0_device_address = -1;
-static gint hf_siii_at_dev_status = -1;
-static gint hf_siii_at_dev_status_commwarning = -1;
-static gint hf_siii_at_dev_status_change_topology = -1;
-static gint hf_siii_at_dev_status_top_status = -1;
-static gint hf_siii_at_dev_status_inactive_port_status = -1;
-static gint hf_siii_at_dev_status_errorconnection = -1;
-static gint hf_siii_at_dev_status_slave_valid = -1;
-static gint hf_siii_at_dev_status_proc_command_change = -1;
-static gint hf_siii_at_dev_status_parameterization_level_active = -1;
-static gint hf_siii_mdt_hotplug_address = -1;
-static gint hf_siii_mdt_hp_ctrl = -1;
-static gint hf_siii_mdt_hp_info = -1;
-static gint hf_siii_at_hotplug_address = -1;
-static gint hf_siii_at_hp_stat = -1;
-static gint hf_siii_at_hp_info = -1;
-static gint hf_siii_mdt_hotplug_control_param = -1;
-static gint hf_siii_mdt_hotplug_control_svc_switch = -1;
-static gint hf_siii_at_hotplug_status_param = -1;
-static gint hf_siii_at_hotplug_status_hp0_finished = -1;
-static gint hf_siii_at_hotplug_status_error = -1;
-static gint hf_siii_service_channels = -1;
-static gint hf_siii_device_controls = -1;
-static gint hf_siii_device_status = -1;
-static gint hf_siii_idn_code = -1;
-static gint hf_siii_at_cp0_num_devices = -1;
-static gint hf_siii_at_cp0_sercos_address = -1;
+static gint hf_siii_mdt_version;
+static gint hf_siii_mdt_version_initprocvers;
+static gint hf_siii_mdt_version_num_mdt_at_cp1_2;
+static gint hf_siii_mdt_version_switch_off_sercos_telegrams;
+static gint hf_siii_mdt_version_fast_cp_switch;
+static gint hf_siii_mdt_version_transmission_of_communication_parameters_mdt0_cp0;
+static gint hf_siii_mdt_dev_control_top_control;
+static gint hf_siii_at_dev_control_ident;
+static gint hf_siii_mdt_dev_control_change_topology;
+static gint hf_siii_mdt_dev_control;
+static gint hf_siii_mst_channel;
+static gint hf_siii_mst_type;
+static gint hf_siii_mst_cyclecntvalid;
+static gint hf_siii_mst_telno;
+static gint hf_siii_mst_phase;
+static gint hf_siii_mst_cyclecnt;
+static gint hf_siii_mst_crc32;
+static gint hf_siii_mdt_svch_dbe;
+static gint hf_siii_mdt_svch_eot;
+static gint hf_siii_mdt_svch_rw;
+static gint hf_siii_mdt_svch_mhs;
+static gint hf_siii_mdt_svch_info;
+static gint hf_siii_at_svch_valid;
+static gint hf_siii_at_svch_error;
+static gint hf_siii_at_svch_busy;
+static gint hf_siii_at_svch_ahs;
+static gint hf_siii_at_svch_info;
+static gint hf_siii_mdt_svch_idn;
+static gint hf_siii_mdt_svch_ctrl;
+static gint hf_siii_at_svch_stat;
+/* static gint hf_siii_svch_data_telofs_telno; */
+/* static gint hf_siii_svch_data_telofs_mdt_at; */
+/* static gint hf_siii_svch_data_telofs_offset; */
+/* static gint hf_siii_svch_data_proccmd_proccmdexec; */
+/* static gint hf_siii_svch_data_proccmd_proccmd; */
+static gint hf_siii_at_cp0_support_functions;
+static gint hf_siii_at_cp0_device_address;
+static gint hf_siii_at_dev_status;
+static gint hf_siii_at_dev_status_commwarning;
+static gint hf_siii_at_dev_status_change_topology;
+static gint hf_siii_at_dev_status_top_status;
+static gint hf_siii_at_dev_status_inactive_port_status;
+static gint hf_siii_at_dev_status_errorconnection;
+static gint hf_siii_at_dev_status_slave_valid;
+static gint hf_siii_at_dev_status_proc_command_change;
+static gint hf_siii_at_dev_status_parameterization_level_active;
+static gint hf_siii_mdt_hotplug_address;
+static gint hf_siii_mdt_hp_ctrl;
+static gint hf_siii_mdt_hp_info;
+static gint hf_siii_at_hotplug_address;
+static gint hf_siii_at_hp_stat;
+static gint hf_siii_at_hp_info;
+static gint hf_siii_mdt_hotplug_control_param;
+static gint hf_siii_mdt_hotplug_control_svc_switch;
+static gint hf_siii_at_hotplug_status_param;
+static gint hf_siii_at_hotplug_status_hp0_finished;
+static gint hf_siii_at_hotplug_status_error;
+static gint hf_siii_service_channels;
+static gint hf_siii_device_controls;
+static gint hf_siii_device_status;
+static gint hf_siii_idn_code;
+static gint hf_siii_at_cp0_num_devices;
+static gint hf_siii_at_cp0_sercos_address;
 
-static expert_field ei_siii_cp_unknown = EI_INIT;
+static expert_field ei_siii_cp_unknown;
 
 
 /* Allow heuristic dissection */
@@ -1155,8 +1157,8 @@ dissect_siii(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
   proto_item *ti;
   proto_tree *siii_tree;
   guint       type;
-  const char *tel_ch   = "?";
-  const char *tel_type = "?";
+  const char *tel_ch;
+  const char *tel_type;
   guint       tel_no   = 0;
   heur_dtbl_entry_t *hdtbl_entry;
 
@@ -1607,10 +1609,10 @@ proto_register_sercosiii(void)
   proto_siii = proto_register_protocol("SERCOS III V1.1",
       "SERCOS III V1.1", "siii");
 
-  register_dissector("sercosiii", dissect_siii, proto_siii);
+  siii_handle = register_dissector("sercosiii", dissect_siii, proto_siii);
 
   /* subdissector code */
-  heur_subdissector_list = register_heur_dissector_list("sercosiii", proto_siii);
+  heur_subdissector_list = register_heur_dissector_list_with_description("sercosiii", "SERCOS III payload pre-check", proto_siii);
 
   /* Required function calls to register the header fields and subtrees used */
   proto_register_field_array(proto_siii, hf, array_length(hf));
@@ -1622,9 +1624,6 @@ proto_register_sercosiii(void)
 void
 proto_reg_handoff_sercosiii(void)
 {
-  dissector_handle_t siii_handle;
-
-  siii_handle = create_dissector_handle(dissect_siii, proto_siii);
   dissector_add_uint("ethertype", ETHERTYPE_SERCOS, siii_handle);
 }
 
