@@ -20,28 +20,28 @@
 #define TXP_MIN_TELEGRAM_LENGTH 22
 
 /* Wireshark ID of the AP1 protocol */
-static gint proto_ap = -1;
+static gint proto_ap;
 
-static gint hf_ap_protoid = -1;
-static gint hf_ap_mpxadr = -1;
-static gint hf_ap_comcls = -1;
-static gint hf_ap_comcod = -1;
-static gint hf_ap_modfr1 = -1;
-static gint hf_ap_modfr2 = -1;
-static gint hf_ap_errcls = -1;
-static gint hf_ap_errcod = -1;
-static gint hf_ap_rosctr = -1;
-static gint hf_ap_sgsqnr = -1;
-static gint hf_ap_tactid = -1;
-static gint hf_ap_tasqnr = -1;
-static gint hf_ap_spare = -1;
-static gint hf_ap_pduref = -1;
-static gint hf_ap_pduid = -1;
-static gint hf_ap_pdulg = -1;
-static gint hf_ap_parlg = -1;
-static gint hf_ap_datlg = -1;
+static gint hf_ap_protoid;
+static gint hf_ap_mpxadr;
+static gint hf_ap_comcls;
+static gint hf_ap_comcod;
+static gint hf_ap_modfr1;
+static gint hf_ap_modfr2;
+static gint hf_ap_errcls;
+static gint hf_ap_errcod;
+static gint hf_ap_rosctr;
+static gint hf_ap_sgsqnr;
+static gint hf_ap_tactid;
+static gint hf_ap_tasqnr;
+static gint hf_ap_spare;
+static gint hf_ap_pduref;
+static gint hf_ap_pduid;
+static gint hf_ap_pdulg;
+static gint hf_ap_parlg;
+static gint hf_ap_datlg;
 
-static gint ett_ap = -1;
+static gint ett_ap;
 
 static heur_dissector_list_t ap_heur_subdissector_list;
 
@@ -56,17 +56,17 @@ static const value_string vs_protid[] = {
         {0, NULL}
 };
 
-static gboolean
+static bool
 dissect_ap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree _U_, void *data _U_)
 {
     /*----------------- Heuristic Checks - Begin */
     /* 1) check for minimum length */
     if (tvb_captured_length(tvb) < TXP_MIN_TELEGRAM_LENGTH)
-        return FALSE;
+        return false;
 
     /* 2) protocol id == 0 */
     if (tvb_get_guint8(tvb, 0) != 0)
-        return FALSE;
+        return false;
     /*----------------- Heuristic Checks - End */
 
     col_set_str(pinfo->cinfo, COL_PROTOCOL, PROTO_TAG_AP);
@@ -85,9 +85,9 @@ dissect_ap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree _U_, void *data _
 
     /* check pdu and data length */
     if (pdulg != tvb_captured_length(tvb))
-        return FALSE;
+        return false;
     if (datlg != tvb_captured_length(tvb) - 22)
-        return FALSE;
+        return false;
 
     switch (comcls) {
         case 0x0: {
@@ -158,7 +158,7 @@ dissect_ap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree _U_, void *data _
         }
     }
 
-    return TRUE;
+    return true;
 }
 
 void
@@ -197,7 +197,7 @@ proto_register_ap(void)
 
     proto_register_field_array(proto_ap, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length (ett));
-    ap_heur_subdissector_list = register_heur_dissector_list("sinecap", proto_ap);
+    ap_heur_subdissector_list = register_heur_dissector_list_with_description("sinecap", "SINEC AP data", proto_ap);
 }
 
 void
