@@ -25,6 +25,8 @@
 void proto_register_slow_protocols(void);
 void proto_reg_handoff_slow_protocols(void);
 
+static dissector_handle_t slow_protocols_handle;
+
 static dissector_table_t slow_protocols_dissector_table;
 
 static const value_string subtype_vals[] = {
@@ -36,13 +38,13 @@ static const value_string subtype_vals[] = {
 };
 
 /* Initialise the protocol and registered fields */
-static int proto_slow = -1;
+static int proto_slow;
 
-static int hf_slow_subtype = -1;
+static int hf_slow_subtype;
 
 /* Initialise the subtree pointers */
 
-static gint ett_slow = -1;
+static gint ett_slow;
 
 /*
  * Name: dissect_slow_protocols
@@ -121,6 +123,9 @@ proto_register_slow_protocols(void)
     proto_register_field_array(proto_slow, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
 
+    /* Register the dissector handle */
+    slow_protocols_handle = register_dissector("slow", dissect_slow_protocols, proto_slow);
+
     /* subdissector code */
     slow_protocols_dissector_table = register_dissector_table("slow.subtype",
                                                               "Slow protocol subtype",
@@ -130,14 +135,11 @@ proto_register_slow_protocols(void)
 void
 proto_reg_handoff_slow_protocols(void)
 {
-    dissector_handle_t slow_protocols_handle;
-
-    slow_protocols_handle = create_dissector_handle(dissect_slow_protocols, proto_slow);
     dissector_add_uint("ethertype", ETHERTYPE_SLOW_PROTOCOLS, slow_protocols_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
