@@ -22,78 +22,78 @@
 
 void proto_register_smb_browse(void);
 
-static int proto_smb_browse = -1;
-static int hf_command = -1;
-static int hf_update_count = -1;
-static int hf_periodicity = -1;
-static int hf_server_name = -1;
-static int hf_mb_server_name = -1;
-static int hf_mb_reset_command = -1;
-static int hf_mb_reset_demote = -1;
-static int hf_mb_reset_flush = -1;
-static int hf_mb_reset_stop = -1;
-static int hf_os_major = -1;
-static int hf_os_minor = -1;
-static int hf_server_type = -1;
-static int hf_server_type_workstation = -1;
-static int hf_server_type_server = -1;
-static int hf_server_type_sql = -1;
-static int hf_server_type_domain = -1;
-static int hf_server_type_backup = -1;
-static int hf_server_type_time = -1;
-static int hf_server_type_apple = -1;
-static int hf_server_type_novell = -1;
-static int hf_server_type_member = -1;
-static int hf_server_type_print = -1;
-static int hf_server_type_dialin = -1;
-static int hf_server_type_xenix = -1;
-static int hf_server_type_ntw = -1;
-static int hf_server_type_wfw = -1;
-static int hf_server_type_nts = -1;
-static int hf_server_type_potentialb = -1;
-static int hf_server_type_backupb = -1;
-static int hf_server_type_masterb = -1;
-static int hf_server_type_domainmasterb = -1;
-static int hf_server_type_osf = -1;
-static int hf_server_type_vms = -1;
-static int hf_server_type_w95 = -1;
-static int hf_server_type_dfs = -1;
-static int hf_server_type_local = -1;
-static int hf_server_type_domainenum = -1;
-static int hf_election_version = -1;
-static int hf_proto_major = -1;
-static int hf_proto_minor = -1;
-static int hf_sig_const = -1;
-static int hf_server_comment = -1;
-static int hf_unused_flags = -1;
-static int hf_response_computer_name = -1;
-static int hf_election_criteria = -1;
-static int hf_election_desire = -1;
-static int hf_election_desire_flags_backup = -1;
-static int hf_election_desire_flags_standby = -1;
-static int hf_election_desire_flags_master = -1;
-static int hf_election_desire_flags_domain_master = -1;
-static int hf_election_desire_flags_wins = -1;
-static int hf_election_desire_flags_nt = -1;
-/* static int hf_election_revision = -1; */
-static int hf_election_os = -1;
-static int hf_election_os_wfw = -1;
-static int hf_election_os_ntw = -1;
-static int hf_election_os_nts = -1;
-static int hf_server_uptime = -1;
-static int hf_backup_count = -1;
-static int hf_backup_token = -1;
-static int hf_backup_server = -1;
-static int hf_browser_to_promote = -1;
-static int hf_windows_version = -1;
-static int hf_mysterious_field = -1;
+static int proto_smb_browse;
+static int hf_command;
+static int hf_update_count;
+static int hf_periodicity;
+static int hf_server_name;
+static int hf_mb_server_name;
+static int hf_mb_reset_command;
+static int hf_mb_reset_demote;
+static int hf_mb_reset_flush;
+static int hf_mb_reset_stop;
+static int hf_os_major;
+static int hf_os_minor;
+static int hf_server_type;
+static int hf_server_type_workstation;
+static int hf_server_type_server;
+static int hf_server_type_sql;
+static int hf_server_type_domain;
+static int hf_server_type_backup;
+static int hf_server_type_time;
+static int hf_server_type_apple;
+static int hf_server_type_novell;
+static int hf_server_type_member;
+static int hf_server_type_print;
+static int hf_server_type_dialin;
+static int hf_server_type_xenix;
+static int hf_server_type_ntw;
+static int hf_server_type_wfw;
+static int hf_server_type_nts;
+static int hf_server_type_potentialb;
+static int hf_server_type_backupb;
+static int hf_server_type_masterb;
+static int hf_server_type_domainmasterb;
+static int hf_server_type_osf;
+static int hf_server_type_vms;
+static int hf_server_type_w95;
+static int hf_server_type_dfs;
+static int hf_server_type_local;
+static int hf_server_type_domainenum;
+static int hf_election_version;
+static int hf_proto_major;
+static int hf_proto_minor;
+static int hf_sig_const;
+static int hf_server_comment;
+static int hf_unused_flags;
+static int hf_response_computer_name;
+static int hf_election_criteria;
+static int hf_election_desire;
+static int hf_election_desire_flags_backup;
+static int hf_election_desire_flags_standby;
+static int hf_election_desire_flags_master;
+static int hf_election_desire_flags_domain_master;
+static int hf_election_desire_flags_wins;
+static int hf_election_desire_flags_nt;
+/* static int hf_election_revision; */
+static int hf_election_os;
+static int hf_election_os_wfw;
+static int hf_election_os_ntw;
+static int hf_election_os_nts;
+static int hf_server_uptime;
+static int hf_backup_count;
+static int hf_backup_token;
+static int hf_backup_server;
+static int hf_browser_to_promote;
+static int hf_windows_version;
+static int hf_mysterious_field;
 
-static gint ett_browse = -1;
-static gint ett_browse_flags = -1;
-static gint ett_browse_election_criteria = -1;
-static gint ett_browse_election_os = -1;
-static gint ett_browse_election_desire = -1;
-static gint ett_browse_reset_cmd_flags = -1;
+static gint ett_browse;
+static gint ett_browse_flags;
+static gint ett_browse_election_criteria;
+static gint ett_browse_election_os;
+static gint ett_browse_election_desire;
+static gint ett_browse_reset_cmd_flags;
 
 #define SERVER_WORKSTATION		 0
 #define SERVER_SERVER			 1
