@@ -25,43 +25,45 @@
 void proto_register_smb_direct(void);
 void proto_reg_handoff_smb_direct(void);
 
-static int proto_smb_direct = -1;
+static dissector_handle_t smb_direct_handle;
 
-static gint ett_smb_direct = -1;
-static gint ett_smb_direct_hdr = -1;
-static gint ett_smb_direct_flags = -1;
-static gint ett_smb_direct_fragment = -1;
-static gint ett_smb_direct_fragments = -1;
+static int proto_smb_direct;
 
-static int hf_smb_direct_negotiate_request = -1;
-static int hf_smb_direct_negotiate_response = -1;
-static int hf_smb_direct_data_message = -1;
-static int hf_smb_direct_min_version = -1;
-static int hf_smb_direct_max_version = -1;
-static int hf_smb_direct_negotiated_version = -1;
-static int hf_smb_direct_credits_requested = -1;
-static int hf_smb_direct_credits_granted = -1;
-static int hf_smb_direct_status = -1;
-static int hf_smb_direct_max_read_write_size = -1;
-static int hf_smb_direct_preferred_send_size = -1;
-static int hf_smb_direct_max_receive_size = -1;
-static int hf_smb_direct_max_fragmented_size = -1;
-static int hf_smb_direct_flags = -1;
-static int hf_smb_direct_flags_response_requested = -1;
-static int hf_smb_direct_remaining_length = -1;
-static int hf_smb_direct_data_offset = -1;
-static int hf_smb_direct_data_length = -1;
-static int hf_smb_direct_fragments = -1;
-static int hf_smb_direct_fragment = -1;
-static int hf_smb_direct_fragment_overlap = -1;
-static int hf_smb_direct_fragment_overlap_conflict = -1;
-static int hf_smb_direct_fragment_multiple_tails = -1;
-static int hf_smb_direct_fragment_too_long_fragment = -1;
-static int hf_smb_direct_fragment_error = -1;
-static int hf_smb_direct_fragment_count = -1;
-static int hf_smb_direct_reassembled_in = -1;
-static int hf_smb_direct_reassembled_length = -1;
-static int hf_smb_direct_reassembled_data = -1;
+static gint ett_smb_direct;
+static gint ett_smb_direct_hdr;
+static gint ett_smb_direct_flags;
+static gint ett_smb_direct_fragment;
+static gint ett_smb_direct_fragments;
+
+static int hf_smb_direct_negotiate_request;
+static int hf_smb_direct_negotiate_response;
+static int hf_smb_direct_data_message;
+static int hf_smb_direct_min_version;
+static int hf_smb_direct_max_version;
+static int hf_smb_direct_negotiated_version;
+static int hf_smb_direct_credits_requested;
+static int hf_smb_direct_credits_granted;
+static int hf_smb_direct_status;
+static int hf_smb_direct_max_read_write_size;
+static int hf_smb_direct_preferred_send_size;
+static int hf_smb_direct_max_receive_size;
+static int hf_smb_direct_max_fragmented_size;
+static int hf_smb_direct_flags;
+static int hf_smb_direct_flags_response_requested;
+static int hf_smb_direct_remaining_length;
+static int hf_smb_direct_data_offset;
+static int hf_smb_direct_data_length;
+static int hf_smb_direct_fragments;
+static int hf_smb_direct_fragment;
+static int hf_smb_direct_fragment_overlap;
+static int hf_smb_direct_fragment_overlap_conflict;
+static int hf_smb_direct_fragment_multiple_tails;
+static int hf_smb_direct_fragment_too_long_fragment;
+static int hf_smb_direct_fragment_error;
+static int hf_smb_direct_fragment_count;
+static int hf_smb_direct_reassembled_in;
+static int hf_smb_direct_reassembled_length;
+static int hf_smb_direct_reassembled_data;
 
 static const fragment_items smb_direct_frag_items = {
 	&ett_smb_direct_fragment,
@@ -91,7 +93,7 @@ enum SMB_DIRECT_HDR_TYPE {
 
 static heur_dissector_list_t smb_direct_heur_subdissector_list;
 
-static gboolean smb_direct_reassemble = TRUE;
+static bool smb_direct_reassemble = true;
 static reassembly_table smb_direct_reassembly_table;
 
 static void
@@ -317,10 +319,6 @@ dissect_smb_direct(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
 	case SMB_DIRECT_HDR_DATA:
 		col_append_str(pinfo->cinfo, COL_INFO, "DataMessage");
 
-		if (tree == NULL) {
-			break;
-		}
-
 		rlen = MIN(rlen, 24);
 
 		item = proto_tree_add_item(tree, hf_smb_direct_data_message, tvb, 0, rlen, ENC_NA);
@@ -459,7 +457,7 @@ is_smb_direct(tvbuff_t *tvb, packet_info *pinfo _U_)
 	return SMB_DIRECT_HDR_UNKNOWN;
 }
 
-static gboolean
+static bool
 dissect_smb_direct_iwarp_heur(tvbuff_t *tvb, packet_info *pinfo,
 			      proto_tree *parent_tree, void *data)
 {
@@ -467,7 +465,7 @@ dissect_smb_direct_iwarp_heur(tvbuff_t *tvb, packet_info *pinfo,
 	enum SMB_DIRECT_HDR_TYPE hdr_type;
 
 	if (info == NULL) {
-		return FALSE;
+		return false;
 	}
 
 	switch (info->opcode) {
@@ -477,16 +475,16 @@ dissect_smb_direct_iwarp_heur(tvbuff_t *tvb, packet_info *pinfo,
 	case RDMA_SEND_SE_INVALIDATE:
 		break;
 	default:
-		return FALSE;
+		return false;
 	}
 
 	hdr_type = is_smb_direct(tvb, pinfo);
 	if (hdr_type == SMB_DIRECT_HDR_UNKNOWN) {
-		return FALSE;
+		return false;
 	}
 
 	dissect_smb_direct(tvb, pinfo, parent_tree, hdr_type);
-	return TRUE;
+	return true;
 }
 
 static int
@@ -523,7 +521,7 @@ dissect_smb_direct_infiniband(tvbuff_t *tvb, packet_info *pinfo,
 	return tvb_captured_length(tvb);
 }
 
-static gboolean
+static bool
 dissect_smb_direct_infiniband_heur(tvbuff_t *tvb, packet_info *pinfo,
 				proto_tree *parent_tree, void *data)
 {
@@ -666,7 +664,9 @@ void proto_register_smb_direct(void)
 	proto_register_subtree_array(ett, array_length(ett));
 	proto_register_field_array(proto_smb_direct, hf, array_length(hf));
 
-	smb_direct_heur_subdissector_list = register_heur_dissector_list("smb_direct", proto_smb_direct);
+	smb_direct_handle = register_dissector("smb_direct", dissect_smb_direct_infiniband, proto_smb_direct);
+
+	smb_direct_heur_subdissector_list = register_heur_dissector_list_with_description("smb_direct", "SMB-Direct payload", proto_smb_direct);
 
 	smb_direct_module = prefs_register_protocol(proto_smb_direct, NULL);
 	prefs_register_bool_preference(smb_direct_module,
@@ -689,7 +689,7 @@ proto_reg_handoff_smb_direct(void)
 				dissect_smb_direct_infiniband_heur,
 				"SMB Direct Infiniband", "smb_direct_infiniband",
 				proto_smb_direct, HEURISTIC_ENABLE);
-	dissector_add_for_decode_as("infiniband", create_dissector_handle( dissect_smb_direct_infiniband, proto_smb_direct ) );
+	dissector_add_for_decode_as("infiniband", smb_direct_handle);
 
 }
 
