@@ -19,64 +19,64 @@
 
 void proto_register_smb_logon(void);
 
-static int proto_smb_logon = -1;
-static int hf_command = -1;
-static int hf_computer_name = -1;
-static int hf_unicode_computer_name = -1;
-static int hf_server_name = -1;
-static int hf_user_name = -1;
-static int hf_domain_name = -1;
-static int hf_server_dns_name = -1;
-static int hf_forest_dns_name = -1;
-static int hf_domain_dns_name = -1;
-static int hf_mailslot_name = -1;
-static int hf_pdc_name = -1;
-static int hf_unicode_pdc_name = -1;
-static int hf_script_name = -1;
-static int hf_nt_version = -1;
-static int hf_lmnt_token = -1;
-static int hf_lm_token = -1;
-static int hf_major_version = -1;
-static int hf_minor_version = -1;
-static int hf_os_version = -1;
-static int hf_signature = -1;
-static int hf_date_time = -1;
-static int hf_update_type = -1;
-static int hf_request_count = -1;
-static int hf_account_control = -1;
-static int hf_flags_autolock = -1;
-static int hf_flags_expire = -1;
-static int hf_flags_server_trust = -1;
-static int hf_flags_workstation_trust = -1;
-static int hf_flags_interdomain_trust = -1;
-static int hf_flags_mns_user = -1;
-static int hf_flags_normal_user = -1;
-static int hf_flags_temp_dup_user = -1;
-static int hf_flags_password_required = -1;
-static int hf_flags_homedir_required = -1;
-static int hf_flags_enabled = -1;
-static int hf_domain_sid_size = -1;
-static int hf_low_serial = -1;
-static int hf_pulse = -1;
-static int hf_random = -1;
-static int hf_db_count = -1;
-static int hf_db_index = -1;
-static int hf_large_serial = -1;
-static int hf_nt_date_time = -1;
+static int proto_smb_logon;
+static int hf_command;
+static int hf_computer_name;
+static int hf_unicode_computer_name;
+static int hf_server_name;
+static int hf_user_name;
+static int hf_domain_name;
+static int hf_server_dns_name;
+static int hf_forest_dns_name;
+static int hf_domain_dns_name;
+static int hf_mailslot_name;
+static int hf_pdc_name;
+static int hf_unicode_pdc_name;
+static int hf_script_name;
+static int hf_nt_version;
+static int hf_lmnt_token;
+static int hf_lm_token;
+static int hf_major_version;
+static int hf_minor_version;
+static int hf_os_version;
+static int hf_signature;
+static int hf_date_time;
+static int hf_update_type;
+static int hf_request_count;
+static int hf_account_control;
+static int hf_flags_autolock;
+static int hf_flags_expire;
+static int hf_flags_server_trust;
+static int hf_flags_workstation_trust;
+static int hf_flags_interdomain_trust;
+static int hf_flags_mns_user;
+static int hf_flags_normal_user;
+static int hf_flags_temp_dup_user;
+static int hf_flags_password_required;
+static int hf_flags_homedir_required;
+static int hf_flags_enabled;
+static int hf_domain_sid_size;
+static int hf_low_serial;
+static int hf_pulse;
+static int hf_random;
+static int hf_db_count;
+static int hf_db_index;
+static int hf_large_serial;
+static int hf_nt_date_time;
 
-static int hf_unknown8 = -1;
-static int hf_unknown32 = -1;
+static int hf_unknown8;
+static int hf_unknown32;
 
-static int hf_domain_guid = -1;
-static int hf_server_ip = -1;
+static int hf_domain_guid;
+static int hf_server_ip;
 
-static int hf_server_site_name = -1;
-static int hf_client_site_name = -1;
-static int hf_data = -1;
+static int hf_server_site_name;
+static int hf_client_site_name;
+static int hf_data;
 
-static int ett_smb_logon = -1;
-static int ett_smb_account_flags = -1;
-static int ett_smb_db_info = -1;
+static int ett_smb_logon;
+static int ett_smb_account_flags;
+static int ett_smb_db_info;
 
 #define ACC_FLAG_AUTO_LOCKED        0x00000400
 #define ACC_FLAG_EXPIRE             0x00000200
@@ -1133,8 +1133,7 @@ proto_register_smb_logon( void)
 		&ett_smb_db_info
 	};
 
-	proto_smb_logon = proto_register_protocol(
-		"Microsoft Windows Logon Protocol (Old)", "SMB_NETLOGON", "smb_netlogon");
+	proto_smb_logon = proto_register_protocol("Microsoft Windows Logon Protocol (Old)", "SMB_NETLOGON", "smb_netlogon");
 
 	proto_register_field_array(proto_smb_logon, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
