@@ -23,26 +23,26 @@
 void proto_register_smb_sidsnooping(void);
 
 #if 0
-static int hf_lsa = -1;
-static int hf_lsa_opnum = -1;
+static int hf_lsa;
+static int hf_lsa_opnum;
 #endif
-static int hf_lsa_info_level = -1;
-static int hf_lsa_domain = -1;
-static int hf_nt_domain_sid = -1;
-static int hf_samr_hnd = -1;
-static int hf_samr_rid = -1;
-static int hf_samr_acct_name = -1;
-static int hf_samr_level = -1;
+static int hf_lsa_info_level;
+static int hf_lsa_domain;
+static int hf_nt_domain_sid;
+static int hf_samr_hnd;
+static int hf_samr_rid;
+static int hf_samr_acct_name;
+static int hf_samr_level;
 
 
-GHashTable *sid_name_table = NULL;
+GHashTable *sid_name_table;
 
 
-static GHashTable *ctx_handle_table = NULL;
+static GHashTable *ctx_handle_table;
 
 
-static gboolean lsa_policy_information_tap_installed = FALSE;
-static gboolean samr_query_dispinfo_tap_installed = FALSE;
+static gboolean lsa_policy_information_tap_installed;
+static gboolean samr_query_dispinfo_tap_installed;
 
 
 const char *
