@@ -91,7 +91,9 @@ typedef struct _smb2_sesid_info_t {
 	char *domain_name;
 	char *host_name;
 	guint16 server_port;
-	guint8 session_key[NTLMSSP_KEY_LEN];
+	guint32 session_key_frame;
+	guint session_key_len;
+	guint8 session_key[NTLMSSP_KEY_LEN*2];
 	guint8 signing_key[NTLMSSP_KEY_LEN];
 	guint8 client_decryption_key16[AES_KEY_SIZE];
 	guint8 server_decryption_key16[AES_KEY_SIZE];
@@ -161,7 +163,7 @@ typedef struct _smb2_conv_info_t {
 #define SMB2_FLAGS_ATTR_HIDDEN		0x00000002
 #define SMB2_FLAGS_ATTR_READONLY	0x00000001
 
-/* SMB2 FILE TYPES ASIGNED TO EXPORT OBJECTS */
+/* SMB2 FILE TYPES ASSIGNED TO EXPORT OBJECTS */
 #define SMB2_FID_TYPE_UNKNOWN			0
 #define SMB2_FID_TYPE_FILE			1
 #define SMB2_FID_TYPE_DIR			2
