@@ -28,12 +28,20 @@
 #include <epan/tap.h>
 #include "packet-tcp.h"
 #include "packet-tls.h"
-#include "packet-http.h"
+#include "packet-media-type.h"
 
-#ifdef HAVE_ZLIB
+#if defined(HAVE_ZLIB) && !defined(HAVE_ZLIBNG)
 #define ZLIB_CONST
+#define ZLIB_PREFIX(x) x
 #include <zlib.h>
-#endif
+typedef z_stream zlib_stream;
+#endif /* HAVE_ZLIB */
+
+#ifdef HAVE_ZLIBNG
+#define ZLIB_PREFIX(x) zng_ ## x
+#include <zlib-ng.h>
+typedef zng_stream zlib_stream;
+#endif /* HAVE_ZLIBNG */
 
 void proto_register_spdy(void);
 void proto_reg_handoff_spdy(void);
@@ -47,10 +55,16 @@ void proto_reg_handoff_spdy(void);
  * entities and for decompressing request & reply header blocks.
  */
 typedef struct _spdy_conv_t {
-#ifdef HAVE_ZLIB
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+#ifdef HAVE_ZLIBNG
+  zng_streamp rqst_decompressor;
+  zng_streamp rply_decompressor;
+  uint32_t     dictionary_id;
+#else
   z_streamp rqst_decompressor;
   z_streamp rply_decompressor;
   uLong     dictionary_id;
+#endif
 #endif
   wmem_tree_t  *streams;
 } spdy_conv_t;
@@ -166,7 +180,7 @@ typedef struct _spdy_data_frame_t {
 } spdy_data_frame_t;
 
 typedef struct _spdy_stream_info_t {
-  http_type_t message_type;
+  media_container_type_t container_type;
   gchar *content_type;
   gchar *content_type_parameters;
   gchar *content_encoding;
@@ -177,76 +191,76 @@ typedef struct _spdy_stream_info_t {
 
 /* Handles for metadata population. */
 
-static int spdy_tap = -1;
-static int spdy_eo_tap = -1;
+static int spdy_tap;
+static int spdy_eo_tap;
 
-static int proto_spdy = -1;
-static int hf_spdy_data = -1;
-static int hf_spdy_control_bit = -1;
-static int hf_spdy_version = -1;
-static int hf_spdy_type = -1;
-static int hf_spdy_flags = -1;
-static int hf_spdy_flags_fin = -1;
-static int hf_spdy_flags_unidirectional = -1;
-static int hf_spdy_flags_clear_settings = -1;
-static int hf_spdy_flags_persist_value = -1;
-static int hf_spdy_flags_persisted = -1;
-static int hf_spdy_length = -1;
-static int hf_spdy_header_block = -1;
-static int hf_spdy_header = -1;
-static int hf_spdy_header_name = -1;
-static int hf_spdy_header_value = -1;
-static int hf_spdy_streamid = -1;
-static int hf_spdy_associated_streamid = -1;
-static int hf_spdy_priority = -1;
-static int hf_spdy_unused = -1;
-static int hf_spdy_slot = -1;
-static int hf_spdy_num_headers = -1;
-static int hf_spdy_rst_stream_status = -1;
-static int hf_spdy_num_settings = -1;
-static int hf_spdy_setting = -1;
-static int hf_spdy_setting_id = -1;
-static int hf_spdy_setting_value = -1;
-static int hf_spdy_ping_id = -1;
-static int hf_spdy_goaway_last_good_stream_id = -1;
-static int hf_spdy_goaway_status = -1;
-static int hf_spdy_window_update_delta = -1;
+static int proto_spdy;
+static int hf_spdy_data;
+static int hf_spdy_control_bit;
+static int hf_spdy_version;
+static int hf_spdy_type;
+static int hf_spdy_flags;
+static int hf_spdy_flags_fin;
+static int hf_spdy_flags_unidirectional;
+static int hf_spdy_flags_clear_settings;
+static int hf_spdy_flags_persist_value;
+static int hf_spdy_flags_persisted;
+static int hf_spdy_length;
+static int hf_spdy_header_block;
+static int hf_spdy_header;
+static int hf_spdy_header_name;
+static int hf_spdy_header_value;
+static int hf_spdy_streamid;
+static int hf_spdy_associated_streamid;
+static int hf_spdy_priority;
+static int hf_spdy_unused;
+static int hf_spdy_slot;
+static int hf_spdy_num_headers;
+static int hf_spdy_rst_stream_status;
+static int hf_spdy_num_settings;
+static int hf_spdy_setting;
+static int hf_spdy_setting_id;
+static int hf_spdy_setting_value;
+static int hf_spdy_ping_id;
+static int hf_spdy_goaway_last_good_stream_id;
+static int hf_spdy_goaway_status;
+static int hf_spdy_window_update_delta;
 
-static gint ett_spdy = -1;
-static gint ett_spdy_flags = -1;
-static gint ett_spdy_header_block = -1;
-static gint ett_spdy_header = -1;
-static gint ett_spdy_setting = -1;
+static gint ett_spdy;
+static gint ett_spdy_flags;
+static gint ett_spdy_header_block;
+static gint ett_spdy_header;
+static gint ett_spdy_setting;
 
-static gint ett_spdy_encoded_entity = -1;
+static gint ett_spdy_encoded_entity;
 
-static expert_field ei_spdy_inflation_failed = EI_INIT;
-static expert_field ei_spdy_mal_frame_data = EI_INIT;
-static expert_field ei_spdy_mal_setting_frame = EI_INIT;
-static expert_field ei_spdy_invalid_rst_stream = EI_INIT;
-static expert_field ei_spdy_invalid_go_away = EI_INIT;
-static expert_field ei_spdy_invalid_frame_type = EI_INIT;
-static expert_field ei_spdy_reassembly_info = EI_INIT;
+static expert_field ei_spdy_inflation_failed;
+static expert_field ei_spdy_mal_frame_data;
+static expert_field ei_spdy_mal_setting_frame;
+static expert_field ei_spdy_invalid_rst_stream;
+static expert_field ei_spdy_invalid_go_away;
+static expert_field ei_spdy_invalid_frame_type;
+static expert_field ei_spdy_reassembly_info;
 
 static dissector_handle_t media_handle;
 static dissector_handle_t spdy_handle;
 static dissector_table_t media_type_subdissector_table;
 static dissector_table_t port_subdissector_table;
 
-static gboolean spdy_assemble_entity_bodies = TRUE;
+static bool spdy_assemble_entity_bodies = true;
 
 /*
  * Decompression of zlib encoded entities.
  */
-#ifdef HAVE_ZLIB
-static gboolean spdy_decompress_body = TRUE;
-static gboolean spdy_decompress_headers = TRUE;
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+static bool spdy_decompress_body = true;
+static bool spdy_decompress_headers = true;
 #else
-static gboolean spdy_decompress_body = FALSE;
-static gboolean spdy_decompress_headers = FALSE;
+static bool spdy_decompress_body;
+static bool spdy_decompress_headers;
 #endif
 
-#ifdef HAVE_ZLIB
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
 static const char spdy_dictionary[] = {
   0x00, 0x00, 0x00, 0x07, 0x6f, 0x70, 0x74, 0x69,  /* - - - - o p t i */
   0x6f, 0x6e, 0x73, 0x00, 0x00, 0x00, 0x04, 0x68,  /* o n s - - - - h */
@@ -432,11 +446,13 @@ static const char spdy_dictionary[] = {
  * streams to avoid memory leaks.
  * XXX: can we be more aggressive and call this sooner for finished streams?
  */
-static gboolean inflate_end_cb (wmem_allocator_t *allocator _U_,
+static bool inflate_end_cb (wmem_allocator_t *allocator _U_,
     wmem_cb_event_t event _U_, void *user_data) {
-
-  inflateEnd((z_streamp)user_data);
-
+#ifdef HAVE_ZLIBNG
+  ZLIB_PREFIX(inflateEnd)((zng_streamp)user_data);
+#else
+  ZLIB_PREFIX(inflateEnd)((z_streamp)user_data);
+#endif
   return FALSE;
 }
 #endif
@@ -457,7 +473,7 @@ spdy_init_protocol(void)
 static spdy_conv_t * get_or_create_spdy_conversation_data(packet_info *pinfo) {
   conversation_t  *conversation;
   spdy_conv_t *conv_data;
-#ifdef HAVE_ZLIB
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
   int retcode;
 #endif
 
@@ -471,14 +487,14 @@ static spdy_conv_t * get_or_create_spdy_conversation_data(packet_info *pinfo) {
 
     conv_data->streams = NULL;
     if (spdy_decompress_headers) {
-#ifdef HAVE_ZLIB
-      conv_data->rqst_decompressor = wmem_new0(wmem_file_scope(), z_stream);
-      conv_data->rply_decompressor = wmem_new0(wmem_file_scope(), z_stream);
-      retcode = inflateInit(conv_data->rqst_decompressor);
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+      conv_data->rqst_decompressor = wmem_new0(wmem_file_scope(), zlib_stream);
+      conv_data->rply_decompressor = wmem_new0(wmem_file_scope(), zlib_stream);
+      retcode = ZLIB_PREFIX(inflateInit)(conv_data->rqst_decompressor);
       if (retcode == Z_OK) {
         wmem_register_callback(wmem_file_scope(), inflate_end_cb,
             conv_data->rqst_decompressor);
-        retcode = inflateInit(conv_data->rply_decompressor);
+        retcode = ZLIB_PREFIX(inflateInit)(conv_data->rply_decompressor);
         if (retcode == Z_OK) {
           wmem_register_callback(wmem_file_scope(), inflate_end_cb,
               conv_data->rply_decompressor);
@@ -486,8 +502,8 @@ static spdy_conv_t * get_or_create_spdy_conversation_data(packet_info *pinfo) {
       }
 
       /* XXX - use wsutil/adler32.h? */
-      conv_data->dictionary_id = adler32(0L, Z_NULL, 0);
-      conv_data->dictionary_id = adler32(conv_data->dictionary_id,
+      conv_data->dictionary_id = ZLIB_PREFIX(adler32)(0L, Z_NULL, 0);
+      conv_data->dictionary_id = ZLIB_PREFIX(adler32)(conv_data->dictionary_id,
                                          spdy_dictionary,
                                          (uInt)sizeof(spdy_dictionary));
 #endif
@@ -504,7 +520,7 @@ static spdy_conv_t * get_or_create_spdy_conversation_data(packet_info *pinfo) {
  */
 static void spdy_save_stream_info(spdy_conv_t *conv_data,
                                   guint32 stream_id,
-                                  http_type_t message_type,
+                                  media_container_type_t container_type,
                                   gchar *content_type,
                                   gchar *content_type_params,
                                   gchar *content_encoding) {
@@ -514,8 +530,8 @@ static void spdy_save_stream_info(spdy_conv_t *conv_data,
     conv_data->streams = wmem_tree_new(wmem_file_scope());
   }
 
-  si = (spdy_stream_info_t *)wmem_alloc(wmem_file_scope(), sizeof(spdy_stream_info_t));
-  si->message_type = message_type;
+  si = wmem_new(wmem_file_scope(), spdy_stream_info_t);
+  si->container_type = container_type;
   si->content_type = content_type;
   si->content_type_parameters = content_type_params;
   si->content_encoding = content_encoding;
@@ -717,7 +733,7 @@ static int dissect_spdy_data_payload(tvbuff_t *tvb,
   dissector_handle_t handle;
   guint num_data_frames;
   gboolean dissected;
-  http_message_info_t message_info;
+  media_content_info_t content_info;
 
   /* Add frame description. */
   proto_item_append_text(spdy_proto, ", Stream: %d, Length: %d",
@@ -747,7 +763,7 @@ static int dissect_spdy_data_payload(tvbuff_t *tvb,
       next_tvb = tvb_new_subset_length(tvb, offset, frame->length);
       is_single_chunk = num_data_frames == 0 &&
           (frame->flags & SPDY_FLAG_FIN) != 0;
-      if (!pinfo->fd->flags.visited) {
+      if (!pinfo->fd->visited) {
         if (!is_single_chunk) {
           if (spdy_assemble_entity_bodies) {
             copied_data = (guint8 *)tvb_memdup(wmem_file_scope(),next_tvb, 0, frame->length);
@@ -812,7 +828,7 @@ static int dissect_spdy_data_payload(tvbuff_t *tvb,
       if (spdy_decompress_body &&
           (g_ascii_strcasecmp(si->content_encoding, "gzip") == 0 ||
            g_ascii_strcasecmp(si->content_encoding, "deflate") == 0)) {
-        uncomp_tvb = tvb_child_uncompress(tvb, data_tvb, 0,
+        uncomp_tvb = tvb_child_uncompress_zlib(tvb, data_tvb, 0,
                                                tvb_reported_length(data_tvb));
       }
       /*
@@ -828,7 +844,7 @@ static int dissect_spdy_data_payload(tvbuff_t *tvb,
         wmem_list_frame_t *frame_item;
         spdy_data_frame_t *df;
         guint32 framenum = 0;
-        wmem_strbuf_t *str_frames = wmem_strbuf_new(wmem_packet_scope(), "");
+        wmem_strbuf_t *str_frames = wmem_strbuf_new(pinfo->pool, "");
 
         frame_item = wmem_list_frame_next(wmem_list_head(dflist));
         while (frame_item != NULL) {
@@ -893,7 +909,7 @@ static int dissect_spdy_data_payload(tvbuff_t *tvb,
        * for that content type?
        */
       if (si->content_type_parameters) {
-        media_str = wmem_strdup(wmem_packet_scope(), si->content_type_parameters);
+        media_str = wmem_strdup(pinfo->pool, si->content_type_parameters);
       }
       /*
        * Calling the string handle for the media type
@@ -904,14 +920,14 @@ static int dissect_spdy_data_payload(tvbuff_t *tvb,
       handle = dissector_get_string_handle(media_type_subdissector_table,
                                            si->content_type);
     }
-    message_info.type = si->message_type;
-    message_info.media_str = media_str;
-    message_info.data = NULL;
+    content_info.type = si->container_type;
+    content_info.media_str = media_str;
+    content_info.data = NULL;
     if (handle != NULL) {
       /*
        * We have a subdissector - call it.
        */
-      dissected = call_dissector_with_data(handle, data_tvb, pinfo, spdy_tree, &message_info);
+      dissected = call_dissector_with_data(handle, data_tvb, pinfo, spdy_tree, &content_info);
     } else {
       dissected = FALSE;
     }
@@ -921,7 +937,7 @@ static int dissect_spdy_data_payload(tvbuff_t *tvb,
        * Calling the default media handle if there is a content-type that
        * wasn't handled above.
        */
-      call_dissector_with_data(media_handle, next_tvb, pinfo, spdy_tree, &message_info);
+      call_dissector_with_data(media_handle, next_tvb, pinfo, spdy_tree, &content_info);
     } else {
       /* Call the default data dissector */
       call_data_dissector(next_tvb, pinfo, spdy_tree);
@@ -938,7 +954,7 @@ body_dissected:
   return frame->length;
 }
 
-#ifdef HAVE_ZLIB
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
 /*
  * Performs header decompression.
  *
@@ -948,14 +964,19 @@ body_dissected:
 #define DECOMPRESS_BUFSIZE   16384
 
 static guint8* spdy_decompress_header_block(tvbuff_t *tvb,
+                                            packet_info *pinfo,
+#ifdef HAVE_ZLIBNG
+                                            zng_streamp decomp,
+#else
                                             z_streamp decomp,
+#endif
                                             uLong dictionary_id,
                                             int offset,
                                             guint32 length,
                                             guint *uncomp_length) {
   int retcode;
   const guint8 *hptr = tvb_get_ptr(tvb, offset, length);
-  guint8 *uncomp_block = (guint8 *)wmem_alloc(wmem_packet_scope(), DECOMPRESS_BUFSIZE);
+  guint8 *uncomp_block = (guint8 *)wmem_alloc(pinfo->pool, DECOMPRESS_BUFSIZE);
 
 #ifdef z_const
   decomp->next_in = (z_const Bytef *)hptr;
@@ -967,14 +988,14 @@ DIAG_ON(cast-qual)
   decomp->avail_in = length;
   decomp->next_out = uncomp_block;
   decomp->avail_out = DECOMPRESS_BUFSIZE;
-  retcode = inflate(decomp, Z_SYNC_FLUSH);
+  retcode = ZLIB_PREFIX(inflate)(decomp, Z_SYNC_FLUSH);
   if (retcode == Z_NEED_DICT) {
     if (decomp->adler == dictionary_id) {
-      retcode = inflateSetDictionary(decomp,
+      retcode = ZLIB_PREFIX(inflateSetDictionary)(decomp,
                                      spdy_dictionary,
                                      sizeof(spdy_dictionary));
       if (retcode == Z_OK) {
-        retcode = inflate(decomp, Z_SYNC_FLUSH);
+        retcode = ZLIB_PREFIX(inflate)(decomp, Z_SYNC_FLUSH);
       }
     }
   }
@@ -1149,8 +1170,12 @@ static int dissect_spdy_header_payload(
     if (header_info == NULL) {
       guint8 *uncomp_ptr = NULL;
       guint uncomp_length = 0;
-#ifdef HAVE_ZLIB
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+#ifdef HAVE_ZLIBNG
+      zng_streamp decomp;
+#else
       z_streamp decomp;
+#endif
 
       /* Get our decompressor. */
       if (stream_id % 2 == 0) {
@@ -1173,6 +1198,7 @@ static int dissect_spdy_header_payload(
 
       /* Decompress. */
       uncomp_ptr = spdy_decompress_header_block(tvb,
+                                                pinfo,
                                                 decomp,
                                                 conv_data->dictionary_id,
                                                 offset,
@@ -1239,7 +1265,7 @@ static int dissect_spdy_header_payload(
                              "Not enough frame data for header name.");
       break;
     }
-    header_name = (gchar *)tvb_get_string_enc(wmem_packet_scope(), header_tvb,
+    header_name = (gchar *)tvb_get_string_enc(pinfo->pool, header_tvb,
                                                     hdr_offset,
                                                     header_name_length, ENC_ASCII|ENC_NA);
     hdr_offset += header_name_length;
@@ -1258,7 +1284,7 @@ static int dissect_spdy_header_payload(
                              "Not enough frame data for header value.");
       break;
     }
-    header_value = (gchar *)tvb_get_string_enc(wmem_packet_scope(),header_tvb,
+    header_value = (gchar *)tvb_get_string_enc(pinfo->pool,header_tvb,
                                                      hdr_offset,
                                                      header_value_length, ENC_ASCII|ENC_NA);
     hdr_offset += header_value_length;
@@ -1322,10 +1348,10 @@ static int dissect_spdy_header_payload(
    * If we expect data on this stream, we need to remember the content
    * type and content encoding.
    */
-  if (content_type != NULL && !pinfo->fd->flags.visited) {
+  if (content_type != NULL && !pinfo->fd->visited) {
     gchar *content_type_params = spdy_parse_content_type(content_type);
     spdy_save_stream_info(conv_data, stream_id,
-                          (hdr_status == NULL) ? HTTP_REQUEST : HTTP_RESPONSE,
+                          (hdr_status == NULL) ? MEDIA_CONTAINER_HTTP_REQUEST : MEDIA_CONTAINER_HTTP_RESPONSE,
                           content_type, content_type_params, content_encoding);
   }
 
@@ -1661,7 +1687,7 @@ static int dissect_spdy(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
  * Looks for SPDY frame at tvb start.
  * If not enough data for either, requests more via desegment struct.
  */
-static gboolean dissect_spdy_heur(tvbuff_t *tvb,
+static bool dissect_spdy_heur(tvbuff_t *tvb,
                                   packet_info *pinfo,
                                   proto_tree *tree,
                                    void *data _U_)
@@ -1676,15 +1702,15 @@ static gboolean dissect_spdy_heur(tvbuff_t *tvb,
    */
   guint8 first_byte = tvb_get_guint8(tvb, 0);
   if (first_byte != 0x80 && first_byte != 0x0) {
-    return FALSE;
+    return false;
   }
 
   /* Attempt dissection. */
   if (dissect_spdy(tvb, pinfo, tree, NULL) != 0) {
-    return TRUE;
+    return true;
   }
 
-  return FALSE;
+  return false;
 }
 
 /*
@@ -1732,7 +1758,7 @@ void proto_register_spdy(void)
       }
     },
     { &hf_spdy_flags_unidirectional,
-      { "Unidirectional", "spdy.flags.fin",
+      { "Unidirectional", "spdy.flags.unidirectional",
         FT_BOOLEAN, 8,
         TFS(&tfs_set_notset), SPDY_FLAG_UNIDIRECTIONAL,
         NULL, HFILL
@@ -1816,7 +1842,7 @@ void proto_register_spdy(void)
     { &hf_spdy_slot,
       { "Slot",       "spdy.slot",
           FT_UINT16, BASE_DEC, NULL, 0x00FF,
-          "Specifying the index in the server's CREDENTIAL vector of the client certificate to be used for this reques", HFILL
+          "Specifying the index in the server's CREDENTIAL vector of the client certificate to be used for this request", HFILL
       }
     },
     { &hf_spdy_num_headers,
@@ -1857,7 +1883,7 @@ void proto_register_spdy(void)
     },
     { &hf_spdy_ping_id,
       { "Ping ID",        "spdy.ping_id",
-          FT_UINT24, BASE_DEC, NULL, 0x0,
+          FT_UINT32, BASE_DEC, NULL, 0x0,
           NULL, HFILL
       }
     },
