@@ -44,25 +44,25 @@ void proto_register_ssyncp(void);
 
 static dissector_handle_t ssyncp_handle;
 
-static int proto_ssyncp = -1;
-static int hf_ssyncp_direction = -1;
-static int hf_ssyncp_seq = -1;
-static int hf_ssyncp_encrypted = -1;
-static int hf_ssyncp_seq_delta = -1;
-static int hf_ssyncp_timestamp = -1;
-static int hf_ssyncp_timestamp_reply = -1;
-static int hf_ssyncp_frag_seq = -1;
-static int hf_ssyncp_frag_final = -1;
-static int hf_ssyncp_frag_idx = -1;
-static int hf_ssyncp_rtt_to_server = -1;
-static int hf_ssyncp_rtt_to_client = -1;
+static int proto_ssyncp;
+static int hf_ssyncp_direction;
+static int hf_ssyncp_seq;
+static int hf_ssyncp_encrypted;
+static int hf_ssyncp_seq_delta;
+static int hf_ssyncp_timestamp;
+static int hf_ssyncp_timestamp_reply;
+static int hf_ssyncp_frag_seq;
+static int hf_ssyncp_frag_final;
+static int hf_ssyncp_frag_idx;
+static int hf_ssyncp_rtt_to_server;
+static int hf_ssyncp_rtt_to_client;
 
 /* Initialize the subtree pointers */
-static gint ett_ssyncp = -1;
-static gint ett_ssyncp_decrypted = -1;
+static gint ett_ssyncp;
+static gint ett_ssyncp_decrypted;
 
-static expert_field ei_ssyncp_fragmented = EI_INIT;
-static expert_field ei_ssyncp_bad_key = EI_INIT;
+static expert_field ei_ssyncp_fragmented;
+static expert_field ei_ssyncp_bad_key;
 
 static const char *pref_ssyncp_key;
 static char ssyncp_raw_aes_key[16];
@@ -133,8 +133,12 @@ dissect_ssyncp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
         conversation_t *conversation = find_or_create_conversation(pinfo);
         ssyncp_info = (ssyncp_conv_info_t *)conversation_get_proto_data(conversation, proto_ssyncp);
         if (!ssyncp_info) {
-            ssyncp_info = wmem_new0(wmem_file_scope(), ssyncp_conv_info_t);
+            ssyncp_info = wmem_new(wmem_file_scope(), ssyncp_conv_info_t);
             conversation_add_proto_data(conversation, proto_ssyncp, ssyncp_info);
+            ssyncp_info->seen_packet[0] = FALSE;
+            ssyncp_info->seen_packet[1] = FALSE;
+            ssyncp_info->clock_seen[0] = FALSE;
+            ssyncp_info->clock_seen[1] = FALSE;
         }
 
         ssyncp_pinfo = wmem_new(wmem_file_scope(), ssyncp_packet_info_t);
@@ -251,7 +255,7 @@ dissect_ssyncp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
         tvbuff_t *decrypted_tvb = tvb_new_child_real_data(tvb, decrypted, decrypted_len, decrypted_len);
         add_new_data_source(pinfo, decrypted_tvb, "Decrypted data");
 
-        if (!pinfo->fd->visited && ssyncp_info) {
+        if (!pinfo->fd->visited) {
             guint16 our_clock16 = ((guint64)pinfo->abs_ts.secs * 1000 + pinfo->abs_ts.nsecs / 1000000) & 0xffff;
             guint16 sender_ts = tvb_get_guint16(decrypted_tvb, 0, ENC_BIG_ENDIAN);
             guint16 reply_ts = tvb_get_guint16(decrypted_tvb, 2, ENC_BIG_ENDIAN);
@@ -291,7 +295,7 @@ dissect_ssyncp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
             return tvb_captured_length(tvb);
         }
 
-        tvbuff_t *inflated_tvb = tvb_child_uncompress(decrypted_tvb, decrypted_tvb, 14, decrypted_len - 14);
+        tvbuff_t *inflated_tvb = tvb_child_uncompress_zlib(decrypted_tvb, decrypted_tvb, 14, decrypted_len - 14);
         if (inflated_tvb == NULL)
             return tvb_captured_length(tvb);
         add_new_data_source(pinfo, inflated_tvb, "Inflated data");
