@@ -24,35 +24,35 @@
 void proto_register_starteam(void);
 void proto_reg_handoff_starteam(void);
 
-static int proto_starteam = -1;
+static int proto_starteam;
 
-static int hf_starteam_mdh_session_tag = -1;
-static int hf_starteam_mdh_ctimestamp = -1;
-static int hf_starteam_mdh_flags = -1;
-static int hf_starteam_mdh_keyid = -1;
-static int hf_starteam_mdh_reserved = -1;
-static int hf_starteam_ph_signature = -1;
-static int hf_starteam_ph_packet_size = -1;
-static int hf_starteam_ph_data_size = -1;
-static int hf_starteam_ph_data_flags = -1;
-static int hf_starteam_id_revision_level = -1;
-static int hf_starteam_id_client = -1;
-static int hf_starteam_id_connect = -1;
-static int hf_starteam_id_component = -1;
-static int hf_starteam_id_command = -1;
-static int hf_starteam_id_command_time = -1;
-static int hf_starteam_id_command_userid = -1;
-static int hf_starteam_data_data = -1;
+static int hf_starteam_mdh_session_tag;
+static int hf_starteam_mdh_ctimestamp;
+static int hf_starteam_mdh_flags;
+static int hf_starteam_mdh_keyid;
+static int hf_starteam_mdh_reserved;
+static int hf_starteam_ph_signature;
+static int hf_starteam_ph_packet_size;
+static int hf_starteam_ph_data_size;
+static int hf_starteam_ph_data_flags;
+static int hf_starteam_id_revision_level;
+static int hf_starteam_id_client;
+static int hf_starteam_id_connect;
+static int hf_starteam_id_component;
+static int hf_starteam_id_command;
+static int hf_starteam_id_command_time;
+static int hf_starteam_id_command_userid;
+static int hf_starteam_data_data;
 
-static gint ett_starteam = -1;
-static gint ett_starteam_mdh = -1;
-static gint ett_starteam_ph = -1;
-static gint ett_starteam_id = -1;
-static gint ett_starteam_data = -1;
+static gint ett_starteam;
+static gint ett_starteam_mdh;
+static gint ett_starteam_ph;
+static gint ett_starteam_id;
+static gint ett_starteam_data;
 
 static dissector_handle_t starteam_tcp_handle;
 
-static gboolean starteam_desegment = TRUE;
+static bool starteam_desegment = true;
 
 #define STARTEAM_MAGIC    0x416C616E /* "Alan" */
 
@@ -583,7 +583,7 @@ dissect_starteam_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void*
 }
 
 
-static gboolean
+static bool
 dissect_starteam_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
   if(tvb_captured_length(tvb) >= 32){
@@ -607,11 +607,11 @@ dissect_starteam_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void
 
         /* Dissect the packet */
         dissect_starteam(tvb, pinfo, tree, data);
-        return TRUE;
+        return true;
       }
     }
   }
-  return FALSE;
+  return false;
 }
 
 void
@@ -683,6 +683,8 @@ proto_register_starteam(void)
   proto_register_field_array(proto_starteam, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
 
+  starteam_tcp_handle = register_dissector("starteam", dissect_starteam_tcp, proto_starteam);
+
   starteam_module = prefs_register_protocol(proto_starteam, NULL);
   prefs_register_bool_preference(starteam_module, "desegment",
     "Reassemble StarTeam messages spanning multiple TCP segments",
@@ -696,7 +698,6 @@ void
 proto_reg_handoff_starteam(void)
 {
   heur_dissector_add("tcp", dissect_starteam_heur, "StarTeam over TCP", "starteam_tcp", proto_starteam, HEURISTIC_ENABLE);
-  starteam_tcp_handle = create_dissector_handle(dissect_starteam_tcp, proto_starteam);
 }
 
 /*
