@@ -40,24 +40,24 @@ void proto_reg_handoff_stcsig(void);
 #define PROTO_SHORT_NAME "STCSIG"
 #define PROTO_LONG_NAME "Spirent Test Center Signature"
 
-static int proto_stcsig = -1;
+static int proto_stcsig;
 
-static int hf_stcsig_csp = -1;
-static int hf_stcsig_iv = -1;
-static int hf_stcsig_prbseq = -1;
-static int hf_stcsig_rawdata = -1;
-static int hf_stcsig_seqnum_complement = -1;
-static int hf_stcsig_seqnum_edm = -1;
-static int hf_stcsig_seqnum_sm = -1;
-static int hf_stcsig_streamid = -1;
-static int hf_stcsig_streamindex = -1;
-static int hf_stcsig_streamtype = -1;
-static int hf_stcsig_timestamp = -1;
-static int hf_stcsig_tslr = -1;
-static int hf_stcsig_unknown = -1;
+static int hf_stcsig_csp;
+static int hf_stcsig_iv;
+static int hf_stcsig_prbseq;
+static int hf_stcsig_rawdata;
+static int hf_stcsig_seqnum_complement;
+static int hf_stcsig_seqnum_edm;
+static int hf_stcsig_seqnum_sm;
+static int hf_stcsig_streamid;
+static int hf_stcsig_streamindex;
+static int hf_stcsig_streamtype;
+static int hf_stcsig_timestamp;
+static int hf_stcsig_tslr;
+static int hf_stcsig_unknown;
 
-static gint ett_stcsig = -1;
-static gint ett_stcsig_streamid = -1;
+static gint ett_stcsig;
+static gint ett_stcsig_streamid;
 
 static const true_false_string tfs_end_start = { "EndOfFrame", "StartOfFrame" };
 
@@ -236,7 +236,7 @@ dissect_stcsig(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _
 	proto_tree_add_item(stcsig_tree, hf_stcsig_iv, stcsig_tvb, 0, 1, ENC_NA);
 	ti = proto_tree_add_item(stcsig_tree, hf_stcsig_streamid, stcsig_tvb, 1, 4, ENC_BIG_ENDIAN);
 	stcsig_streamid_tree = proto_item_add_subtree(ti, ett_stcsig_streamid);
-	/* This subtree is mostly an optical hierachy, auto expand it */
+	/* This subtree is mostly an optical hierarchy, auto expand it */
 	tree_expanded_set(ett_stcsig_streamid, TRUE);
 	proto_tree_add_item(stcsig_streamid_tree, hf_stcsig_csp, stcsig_tvb, 1, 2, ENC_BIG_ENDIAN);
 	proto_tree_add_item(stcsig_streamid_tree, hf_stcsig_streamtype, stcsig_tvb, 3, 1, ENC_NA);
@@ -340,12 +340,10 @@ proto_register_stcsig(void)
 
 	proto_stcsig = proto_register_protocol(PROTO_LONG_NAME, PROTO_SHORT_NAME, "stcsig");
 
-	register_dissector("stcsig", dissect_stcsig, proto_stcsig);
-
 	proto_register_field_array(proto_stcsig, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
-	stcsig_handle = register_dissector(PROTO_SHORT_NAME, dissect_stcsig, proto_stcsig);
+	stcsig_handle = register_dissector("stcsig", dissect_stcsig, proto_stcsig);
 	register_postdissector(stcsig_handle);
 
 	/* STCSIG is a rarely used case, disable it by default for performance reasons. */
