@@ -29,55 +29,57 @@
 void proto_reg_handoff_steam_ihs_discovery(void);
 void proto_register_steam_ihs_discovery(void);
 
-static int proto_steam_ihs_discovery = -1;
+static dissector_handle_t steam_ihs_discovery_handle;
 
-static int hf_steam_ihs_discovery_signature = -1;
-static int hf_steam_ihs_discovery_header_length = -1;
-static int hf_steam_ihs_discovery_header_clientid = -1;
-static int hf_steam_ihs_discovery_header_msgtype = -1;
-static int hf_steam_ihs_discovery_header_instanceid = -1;
-static int hf_steam_ihs_discovery_body_length = -1;
-static int hf_steam_ihs_discovery_body_discovery_seqnum = -1;
-static int hf_steam_ihs_discovery_body_discovery_clientids = -1;
-static int hf_steam_ihs_discovery_body_status_version = -1;
-static int hf_steam_ihs_discovery_body_status_minversion = -1;
-static int hf_steam_ihs_discovery_body_status_connectport = -1;
-static int hf_steam_ihs_discovery_body_status_hostname = -1;
-static int hf_steam_ihs_discovery_body_status_enabledservices = -1;
-static int hf_steam_ihs_discovery_body_status_ostype = -1;
-static int hf_steam_ihs_discovery_body_status_is64bit = -1;
-static int hf_steam_ihs_discovery_body_status_euniverse = -1;
-static int hf_steam_ihs_discovery_body_status_timestamp = -1;
-static int hf_steam_ihs_discovery_body_status_screenlocked = -1;
-static int hf_steam_ihs_discovery_body_status_gamesrunning = -1;
-static int hf_steam_ihs_discovery_body_status_macaddresses = -1;
-static int hf_steam_ihs_discovery_body_status_user_steamid = -1;
-static int hf_steam_ihs_discovery_body_status_user_authkeyid = -1;
-static int hf_steam_ihs_discovery_body_authrequest_devicetoken = -1;
-static int hf_steam_ihs_discovery_body_authrequest_devicename = -1;
-static int hf_steam_ihs_discovery_body_authrequest_encryptedrequest = -1;
-static int hf_steam_ihs_discovery_body_authresponse_authresult = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_requestid = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_maximumresolutionx = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_maximumresolutiony = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_audiochannelcount = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_deviceversion = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_streamdesktop = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_devicetoken = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_pin = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_enablevideostreaming = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_enableaudiostreaming = -1;
-static int hf_steam_ihs_discovery_body_streamingrequest_enableinputstreaming = -1;
-static int hf_steam_ihs_discovery_body_streamingcancelrequest_requestid = -1;
-static int hf_steam_ihs_discovery_body_streamingresponse_requestid = -1;
-static int hf_steam_ihs_discovery_body_streamingresponse_result = -1;
-static int hf_steam_ihs_discovery_body_streamingresponse_port = -1;
-static int hf_steam_ihs_discovery_body_streamingresponse_encryptedsessionkey = -1;
-static int hf_steam_ihs_discovery_body_streamingresponse_virtualherelicenseddevicecount = -1;
-static int hf_steam_ihs_discovery_body_proofrequest_challenge = -1;
-static int hf_steam_ihs_discovery_body_proofresponse_response = -1;
-static int hf_steam_ihs_discovery_unknown_data = -1;
-static int hf_steam_ihs_discovery_unknown_number = -1;
+static int proto_steam_ihs_discovery;
+
+static int hf_steam_ihs_discovery_signature;
+static int hf_steam_ihs_discovery_header_length;
+static int hf_steam_ihs_discovery_header_clientid;
+static int hf_steam_ihs_discovery_header_msgtype;
+static int hf_steam_ihs_discovery_header_instanceid;
+static int hf_steam_ihs_discovery_body_length;
+static int hf_steam_ihs_discovery_body_discovery_seqnum;
+static int hf_steam_ihs_discovery_body_discovery_clientids;
+static int hf_steam_ihs_discovery_body_status_version;
+static int hf_steam_ihs_discovery_body_status_minversion;
+static int hf_steam_ihs_discovery_body_status_connectport;
+static int hf_steam_ihs_discovery_body_status_hostname;
+static int hf_steam_ihs_discovery_body_status_enabledservices;
+static int hf_steam_ihs_discovery_body_status_ostype;
+static int hf_steam_ihs_discovery_body_status_is64bit;
+static int hf_steam_ihs_discovery_body_status_euniverse;
+static int hf_steam_ihs_discovery_body_status_timestamp;
+static int hf_steam_ihs_discovery_body_status_screenlocked;
+static int hf_steam_ihs_discovery_body_status_gamesrunning;
+static int hf_steam_ihs_discovery_body_status_macaddresses;
+static int hf_steam_ihs_discovery_body_status_user_steamid;
+static int hf_steam_ihs_discovery_body_status_user_authkeyid;
+static int hf_steam_ihs_discovery_body_authrequest_devicetoken;
+static int hf_steam_ihs_discovery_body_authrequest_devicename;
+static int hf_steam_ihs_discovery_body_authrequest_encryptedrequest;
+static int hf_steam_ihs_discovery_body_authresponse_authresult;
+static int hf_steam_ihs_discovery_body_streamingrequest_requestid;
+static int hf_steam_ihs_discovery_body_streamingrequest_maximumresolutionx;
+static int hf_steam_ihs_discovery_body_streamingrequest_maximumresolutiony;
+static int hf_steam_ihs_discovery_body_streamingrequest_audiochannelcount;
+static int hf_steam_ihs_discovery_body_streamingrequest_deviceversion;
+static int hf_steam_ihs_discovery_body_streamingrequest_streamdesktop;
+static int hf_steam_ihs_discovery_body_streamingrequest_devicetoken;
+static int hf_steam_ihs_discovery_body_streamingrequest_pin;
+static int hf_steam_ihs_discovery_body_streamingrequest_enablevideostreaming;
+static int hf_steam_ihs_discovery_body_streamingrequest_enableaudiostreaming;
+static int hf_steam_ihs_discovery_body_streamingrequest_enableinputstreaming;
+static int hf_steam_ihs_discovery_body_streamingcancelrequest_requestid;
+static int hf_steam_ihs_discovery_body_streamingresponse_requestid;
+static int hf_steam_ihs_discovery_body_streamingresponse_result;
+static int hf_steam_ihs_discovery_body_streamingresponse_port;
+static int hf_steam_ihs_discovery_body_streamingresponse_encryptedsessionkey;
+static int hf_steam_ihs_discovery_body_streamingresponse_virtualherelicenseddevicecount;
+static int hf_steam_ihs_discovery_body_proofrequest_challenge;
+static int hf_steam_ihs_discovery_body_proofresponse_response;
+static int hf_steam_ihs_discovery_unknown_data;
+static int hf_steam_ihs_discovery_unknown_number;
 
 static const val64_string hf_steam_ihs_discovery_header_msgtype_strings[] = {
     {  0, "Client Discovery" },
@@ -123,18 +125,17 @@ static const val64_string hf_steam_ihs_discovery_body_streamingresponse_result_s
     { 0, NULL }
 };
 
-static expert_field ei_steam_ihs_discovery_unknown_data = EI_INIT;
-static expert_field ei_steam_ihs_discovery_unknown_number = EI_INIT;
-static expert_field ei_steam_ihs_discovery_unknown_lengthdelimited = EI_INIT;
-static expert_field ei_steam_ihs_discovery_invalid_wiretype = EI_INIT;
-static expert_field ei_steam_ihs_discovery_invalid_length = EI_INIT;
+static expert_field ei_steam_ihs_discovery_unknown_data;
+static expert_field ei_steam_ihs_discovery_unknown_number;
+static expert_field ei_steam_ihs_discovery_unknown_lengthdelimited;
+static expert_field ei_steam_ihs_discovery_invalid_wiretype;
+static expert_field ei_steam_ihs_discovery_invalid_length;
 
 #define STEAM_IHS_DISCOVERY_UDP_PORT 27036
-static guint udp_port_pref = STEAM_IHS_DISCOVERY_UDP_PORT;
 
 /* Initialize the subtree pointers */
-static gint ett_steam_ihs_discovery = -1;
-static gint ett_steam_ihs_discovery_body_status_user = -1;
+static gint ett_steam_ihs_discovery;
+static gint ett_steam_ihs_discovery_body_status_user;
 
 #define STEAM_IHS_DISCOVERY_MIN_LENGTH 12
 #define STEAM_IHS_DISCOVERY_SIGNATURE_LENGTH 8
@@ -1119,7 +1120,6 @@ dissect_steam_ihs_discovery(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 void
 proto_register_steam_ihs_discovery(void)
 {
-    module_t        *steam_ihs_discovery_module;
     expert_module_t *expert_steam_ihs_discovery;
 
     static hf_register_info hf[] = {
@@ -1406,6 +1406,9 @@ proto_register_steam_ihs_discovery(void)
     proto_steam_ihs_discovery = proto_register_protocol("Steam In-Home Streaming Discovery Protocol",
             "Steam IHS Discovery", "steam_ihs_discovery");
 
+    /* Register the dissector handle */
+    steam_ihs_discovery_handle = register_dissector("steam_ihs_discovery", dissect_steam_ihs_discovery, proto_steam_ihs_discovery);
+
     /* Required function calls to register the header fields and subtrees */
     proto_register_field_array(proto_steam_ihs_discovery, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
@@ -1414,35 +1417,14 @@ proto_register_steam_ihs_discovery(void)
     expert_steam_ihs_discovery = expert_register_protocol(proto_steam_ihs_discovery);
     expert_register_field_array(expert_steam_ihs_discovery, ei, array_length(ei));
 
-    /* Register a preferences module. */
-    steam_ihs_discovery_module = prefs_register_protocol(proto_steam_ihs_discovery,
-            proto_reg_handoff_steam_ihs_discovery);
-
-    /* Register an example port preference */
-    prefs_register_uint_preference(steam_ihs_discovery_module, "udp.port", "steam_ihs_discovery UDP Port",
-            " Steam IHS Discovery UDP port if other than the default",
-            10, &udp_port_pref);
+    /* Register a preferences module - handled by Decode As. */
+    /* steam_ihs_discovery_module = prefs_register_protocol(proto_steam_ihs_discovery, NULL); */
 }
 
 void
 proto_reg_handoff_steam_ihs_discovery(void)
 {
-    static gboolean initialized = FALSE;
-    static dissector_handle_t steam_ihs_discovery_handle;
-    static int current_port;
-
-    if (!initialized) {
-        steam_ihs_discovery_handle = create_dissector_handle(dissect_steam_ihs_discovery,
-                proto_steam_ihs_discovery);
-        initialized = TRUE;
-
-    } else {
-        dissector_delete_uint("udp.port", current_port, steam_ihs_discovery_handle);
-    }
-
-    current_port = udp_port_pref;
-
-    dissector_add_uint("udp.port", current_port, steam_ihs_discovery_handle);
+    dissector_add_uint_with_preference("udp.port", STEAM_IHS_DISCOVERY_UDP_PORT, steam_ihs_discovery_handle);
 }
 
 /*
