@@ -25,8 +25,8 @@
 
 #include "packet-ip.h"
 
-static gboolean pref_reassemble = TRUE;
-static gboolean pref_check_checksum = FALSE;
+static bool pref_reassemble = true;
+static bool pref_check_checksum;
 
 /* IANA  ref:
  * https://www.iana.org/assignments/service-names-port-numbers/service-names-port-numbers.xhtml
@@ -53,74 +53,74 @@ static gboolean pref_check_checksum = FALSE;
 void proto_register_stt(void);
 void proto_reg_handoff_stt(void);
 
-static int proto_stt = -1;
+static int proto_stt;
 
-static int hf_stt_stream_id = -1;
-static int hf_stt_dport = -1;
-static int hf_stt_pkt_len = -1;
-static int hf_stt_seg_off = -1;
-static int hf_stt_pkt_id = -1;
-static int hf_stt_checksum = -1;
-static int hf_stt_checksum_status = -1;
-static int hf_stt_tcp_data = -1;
-static int hf_stt_tcp_data_offset = -1;
-static int hf_stt_tcp_flags = -1;
-static int hf_stt_tcp_rsvd = -1;
-static int hf_stt_tcp_ns = -1;
-static int hf_stt_tcp_cwr = -1;
-static int hf_stt_tcp_ece = -1;
-static int hf_stt_tcp_urg = -1;
-static int hf_stt_tcp_ack = -1;
-static int hf_stt_tcp_psh = -1;
-static int hf_stt_tcp_rst = -1;
-static int hf_stt_tcp_syn = -1;
-static int hf_stt_tcp_fin = -1;
-static int hf_stt_tcp_window = -1;
-static int hf_stt_tcp_urg_ptr = -1;
+static int hf_stt_stream_id;
+static int hf_stt_dport;
+static int hf_stt_pkt_len;
+static int hf_stt_seg_off;
+static int hf_stt_pkt_id;
+static int hf_stt_checksum;
+static int hf_stt_checksum_status;
+static int hf_stt_tcp_data;
+static int hf_stt_tcp_data_offset;
+static int hf_stt_tcp_flags;
+static int hf_stt_tcp_rsvd;
+static int hf_stt_tcp_ns;
+static int hf_stt_tcp_cwr;
+static int hf_stt_tcp_ece;
+static int hf_stt_tcp_urg;
+static int hf_stt_tcp_ack;
+static int hf_stt_tcp_psh;
+static int hf_stt_tcp_rst;
+static int hf_stt_tcp_syn;
+static int hf_stt_tcp_fin;
+static int hf_stt_tcp_window;
+static int hf_stt_tcp_urg_ptr;
 
-static int hf_stt_version = -1;
-static int hf_stt_flags = -1;
-static int hf_stt_flag_rsvd = -1;
-static int hf_stt_flag_tcp = -1;
-static int hf_stt_flag_ipv4 = -1;
-static int hf_stt_flag_partial = -1;
-static int hf_stt_flag_verified = -1;
-static int hf_stt_l4_offset = -1;
-static int hf_stt_reserved_8 = -1;
-static int hf_stt_mss = -1;
-static int hf_stt_vlan = -1;
-static int hf_stt_pcp = -1;
-static int hf_stt_v = -1;
-static int hf_stt_vlan_id= -1;
-static int hf_stt_context_id = -1;
-static int hf_stt_padding = -1;
+static int hf_stt_version;
+static int hf_stt_flags;
+static int hf_stt_flag_rsvd;
+static int hf_stt_flag_tcp;
+static int hf_stt_flag_ipv4;
+static int hf_stt_flag_partial;
+static int hf_stt_flag_verified;
+static int hf_stt_l4_offset;
+static int hf_stt_reserved_8;
+static int hf_stt_mss;
+static int hf_stt_vlan;
+static int hf_stt_pcp;
+static int hf_stt_v;
+static int hf_stt_vlan_id;
+static int hf_stt_context_id;
+static int hf_stt_padding;
 
-static int hf_segments = -1;
-static int hf_segment = -1;
-static int hf_segment_overlap = -1;
-static int hf_segment_overlap_conflict = -1;
-static int hf_segment_multiple_tails = -1;
-static int hf_segment_too_long_fragment = -1;
-static int hf_segment_error = -1;
-static int hf_segment_count = -1;
-static int hf_reassembled_in = -1;
-static int hf_reassembled_length = -1;
+static int hf_segments;
+static int hf_segment;
+static int hf_segment_overlap;
+static int hf_segment_overlap_conflict;
+static int hf_segment_multiple_tails;
+static int hf_segment_too_long_fragment;
+static int hf_segment_error;
+static int hf_segment_count;
+static int hf_reassembled_in;
+static int hf_reassembled_length;
 
-static int ett_stt = -1;
-static int ett_stt_tcp_data = -1;
-static int ett_stt_tcp_flags = -1;
-static int ett_stt_flgs = -1;
-static int ett_stt_vlan = -1;
-static int ett_segment = -1;
-static int ett_segments = -1;
+static int ett_stt;
+static int ett_stt_tcp_data;
+static int ett_stt_tcp_flags;
+static int ett_stt_flgs;
+static int ett_stt_vlan;
+static int ett_segment;
+static int ett_segments;
 
 static reassembly_table stt_reassembly_table;
 
-static expert_field ei_stt_ver_unknown = EI_INIT;
-static expert_field ei_stt_checksum_bad = EI_INIT;
-static expert_field ei_stt_data_offset_bad = EI_INIT;
-static expert_field ei_stt_l4_offset = EI_INIT;
-static expert_field ei_stt_mss = EI_INIT;
+static expert_field ei_stt_ver_unknown;
+static expert_field ei_stt_checksum_bad;
+static expert_field ei_stt_data_offset_bad;
+static expert_field ei_stt_l4_offset;
+static expert_field ei_stt_mss;
 
 static dissector_handle_t eth_handle;
 
@@ -509,23 +509,23 @@ dissect_stt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     pinfo->fragmented = frag_save;
 }
 
-static gboolean
+static bool
 dissect_stt_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
                  void *iph)
 {
     /* Make sure we at least have a TCP header */
     if (ws_ip_protocol(iph) != IP_PROTO_TCP ||
         tvb_captured_length(tvb) < STT_TCP_HDR_LEN) {
-        return FALSE;
+        return false;
     }
 
     /* Check the TCP destination port */
     if (tvb_get_ntohs(tvb, STT_TCP_OFF_DPORT) != TCP_PORT_STT) {
-        return FALSE;
+        return false;
     }
 
     dissect_stt(tvb, pinfo, tree);
-    return TRUE;
+    return true;
 }
 
 /* Register STT with Wireshark */
@@ -816,7 +816,7 @@ proto_register_stt(void)
         { &hf_segments,
           { "Reassembled STT Segments", "stt.segments",
             FT_NONE, BASE_NONE, NULL, 0x0,
-            "STT Segments", HFILL
+            NULL, HFILL
           },
         },
         { &hf_reassembled_in,
