@@ -24,9 +24,9 @@
 
 #include <wsutil/utf8_entities.h>
 
-#define PROTOCOL_NAME	    "IEEE C37.118 Synchrophasor Protocol"
-#define PROTOCOL_SHORT_NAME "SYNCHROPHASOR"
-#define PROTOCOL_ABBREV	    "synphasor"
+#define PNAME "IEEE C37.118 Synchrophasor Protocol"
+#define PSNAME "SYNCHROPHASOR"
+#define PFNAME "synphasor"
 
 /* forward references */
 void proto_register_synphasor(void);
@@ -34,7 +34,7 @@ void proto_reg_handoff_synphasor(void);
 
 /* global variables */
 
-static int proto_synphasor	 = -1;
+static int proto_synphasor;
 
 /* user preferences */
 #define SYNPHASOR_TCP_PORT  4712 /* Not IANA registered */
@@ -47,133 +47,134 @@ static int proto_synphasor	 = -1;
 #define G_PMU_ID_LEN 16
 
 /* the ett... variables hold the state (open/close) of the treeview in the GUI */
-static gint ett_synphasor			= -1; /* root element for this protocol */
-  /* used in the common header */
-  static gint ett_frtype			= -1;
-  static gint ett_timequal			= -1;
-  /* used for config frames */
-  static gint ett_conf				= -1;
-    static gint ett_conf_station		= -1;
-      static gint ett_conf_format		= -1;
-      static gint ett_conf_phnam		= -1;
-      static gint ett_conf_annam		= -1;
-      static gint ett_conf_dgnam		= -1;
-      static gint ett_conf_phconv		= -1;
-      static gint ett_conf_phlist		= -1;
-      static gint ett_conf_phflags		= -1;
-      static gint ett_conf_phmod_flags		= -1;
-      static gint ett_conf_ph_user_flags	= -1;
-      static gint ett_conf_anconv		= -1;
-      static gint ett_conf_anlist		= -1;
-      static gint ett_conf_dgmask		= -1;
-      static gint ett_conf_chnam		= -1;
-      static gint ett_conf_wgs84		= -1;
-  /* used for data frames */
-  static gint ett_data				= -1;
-    static gint ett_data_block			= -1;
-      static gint ett_data_stat			= -1;
-      static gint ett_data_phasors		= -1;
-      static gint ett_data_analog		= -1;
-      static gint ett_data_digital		= -1;
-  /* used for command frames */
-  static gint ett_command			= -1;
-  static gint ett_status_word_mask		= -1;
+static gint ett_synphasor; /* root element for this protocol */
+/* used in the common header */
+static gint ett_frtype;
+static gint ett_timequal;
+/* used for config frames */
+static gint ett_conf;
+static gint ett_conf_station;
+static gint ett_conf_format;
+static gint ett_conf_phnam;
+static gint ett_conf_annam;
+static gint ett_conf_dgnam;
+static gint ett_conf_phconv;
+static gint ett_conf_phlist;
+static gint ett_conf_phflags;
+static gint ett_conf_phmod_flags;
+static gint ett_conf_ph_user_flags;
+static gint ett_conf_anconv;
+static gint ett_conf_anlist;
+static gint ett_conf_dgmask;
+static gint ett_conf_chnam;
+static gint ett_conf_wgs84;
+/* used for data frames */
+static gint ett_data;
+static gint ett_data_block;
+static gint ett_data_stat;
+static gint ett_data_phasors;
+static gint ett_data_analog;
+static gint ett_data_digital;
+/* used for command frames */
+static gint ett_command;
+static gint ett_status_word_mask;
 
 /* handles to the header fields hf[] in proto_register_synphasor() */
-static int hf_sync			= -1;
-static int hf_sync_frtype		= -1;
-static int hf_sync_version		= -1;
-static int hf_station_name_len		= -1;
-static int hf_station_name		= -1;
-static int hf_idcode_stream_source	= -1;
-static int hf_idcode_data_source	= -1;
-static int hf_g_pmu_id			= -1;
-static int hf_frsize			= -1;
-static int hf_soc			= -1;
-static int hf_timeqal_lsdir		= -1;
-static int hf_timeqal_lsocc		= -1;
-static int hf_timeqal_lspend		= -1;
-static int hf_timeqal_timequalindic	= -1;
-static int hf_fracsec_raw		= -1;
-static int hf_fracsec_ms		= -1;
-static int hf_cont_idx			= -1;
-static int hf_conf_timebase		= -1;
-static int hf_conf_numpmu		= -1;
-static int hf_conf_formatb3		= -1;
-static int hf_conf_formatb2		= -1;
-static int hf_conf_formatb1		= -1;
-static int hf_conf_formatb0		= -1;
-static int hf_conf_chnam_len		= -1;
-static int hf_conf_chnam		= -1;
-static int hf_conf_phasor_mod_b15	= -1;
-static int hf_conf_phasor_mod_b10	= -1;
-static int hf_conf_phasor_mod_b09	= -1;
-static int hf_conf_phasor_mod_b08	= -1;
-static int hf_conf_phasor_mod_b07	= -1;
-static int hf_conf_phasor_mod_b06	= -1;
-static int hf_conf_phasor_mod_b05	= -1;
-static int hf_conf_phasor_mod_b04	= -1;
-static int hf_conf_phasor_mod_b03	= -1;
-static int hf_conf_phasor_mod_b02	= -1;
-static int hf_conf_phasor_mod_b01	= -1;
-static int hf_conf_phasor_type_b03	= -1;
-static int hf_conf_phasor_type_b02to00	= -1;
-static int hf_conf_phasor_user_data	= -1;
-static int hf_conf_phasor_scale_factor	= -1;
-static int hf_conf_phasor_angle_offset	= -1;
-static int hf_conf_analog_scale_factor	= -1;
-static int hf_conf_analog_offset	= -1;
-static int hf_conf_pmu_lat		= -1;
-static int hf_conf_pmu_lon		= -1;
-static int hf_conf_pmu_elev		= -1;
-static int hf_conf_pmu_lat_unknown	= -1;
-static int hf_conf_pmu_lon_unknown	= -1;
-static int hf_conf_pmu_elev_unknown	= -1;
-static int hf_conf_svc_class		= -1;
-static int hf_conf_window		= -1;
-static int hf_conf_grp_dly		= -1;
-static int hf_conf_fnom			= -1;
-static int hf_conf_cfgcnt		= -1;
-static int hf_data_statb15to14		= -1;
-static int hf_data_statb13		= -1;
-static int hf_data_statb12		= -1;
-static int hf_data_statb11		= -1;
-static int hf_data_statb10		= -1;
-static int hf_data_statb09		= -1;
-static int hf_data_statb08to06		= -1;
-static int hf_data_statb05to04		= -1;
-static int hf_data_statb03to00		= -1;
-static int hf_command			= -1;
-static int hf_cfg_frame_num		= -1;
+static int hf_sync;
+static int hf_sync_frtype;
+static int hf_sync_version;
+static int hf_station_name_len;
+static int hf_station_name;
+static int hf_idcode_stream_source;
+static int hf_idcode_data_source;
+static int hf_g_pmu_id;
+static int hf_frsize;
+static int hf_soc;
+static int hf_timeqal_lsdir;
+static int hf_timeqal_lsocc;
+static int hf_timeqal_lspend;
+static int hf_timeqal_timequalindic;
+static int hf_fracsec_raw;
+static int hf_fracsec_ms;
+static int hf_cont_idx;
+static int hf_conf_timebase;
+static int hf_conf_numpmu;
+static int hf_conf_formatb3;
+static int hf_conf_formatb2;
+static int hf_conf_formatb1;
+static int hf_conf_formatb0;
+static int hf_conf_chnam_len;
+static int hf_conf_chnam;
+static int hf_conf_phasor_mod_b15;
+static int hf_conf_phasor_mod_b10;
+static int hf_conf_phasor_mod_b09;
+static int hf_conf_phasor_mod_b08;
+static int hf_conf_phasor_mod_b07;
+static int hf_conf_phasor_mod_b06;
+static int hf_conf_phasor_mod_b05;
+static int hf_conf_phasor_mod_b04;
+static int hf_conf_phasor_mod_b03;
+static int hf_conf_phasor_mod_b02;
+static int hf_conf_phasor_mod_b01;
+static int hf_conf_phasor_type_b03;
+static int hf_conf_phasor_type_b02to00;
+static int hf_conf_phasor_user_data;
+static int hf_conf_phasor_scale_factor;
+static int hf_conf_phasor_angle_offset;
+static int hf_conf_analog_scale_factor;
+static int hf_conf_analog_offset;
+static int hf_conf_pmu_lat;
+static int hf_conf_pmu_lon;
+static int hf_conf_pmu_elev;
+static int hf_conf_pmu_lat_unknown;
+static int hf_conf_pmu_lon_unknown;
+static int hf_conf_pmu_elev_unknown;
+static int hf_conf_svc_class;
+static int hf_conf_window;
+static int hf_conf_grp_dly;
+static int hf_conf_fnom;
+static int hf_conf_cfgcnt;
+static int hf_data_statb15to14;
+static int hf_data_statb13;
+static int hf_data_statb12;
+static int hf_data_statb11;
+static int hf_data_statb10;
+static int hf_data_statb09;
+static int hf_data_statb08to06;
+static int hf_data_statb05to04;
+static int hf_data_statb03to00;
+static int hf_command;
+static int hf_cfg_frame_num;
 
 /* Generated from convert_proto_tree_add_text.pl */
-static int hf_synphasor_data					= -1;
-static int hf_synphasor_checksum				= -1;
-static int hf_synphasor_checksum_status				= -1;
-static int hf_synphasor_num_phasors				= -1;
-static int hf_synphasor_num_analog_values			= -1;
-static int hf_synphasor_num_digital_status_words		= -1;
-static int hf_synphasor_rate_of_transmission			= -1;
-static int hf_synphasor_phasor					= -1;
-static int hf_synphasor_actual_frequency_value			= -1;
-static int hf_synphasor_rate_change_frequency			= -1;
-static int hf_synphasor_frequency_deviation_from_nominal	= -1;
-static int hf_synphasor_analog_value				= -1;
-static int hf_synphasor_digital_status_word			= -1;
-static int hf_synphasor_conversion_factor			= -1;
-static int hf_synphasor_factor_for_analog_value			= -1;
-static int hf_synphasor_channel_name				= -1;
-static int hf_synphasor_extended_frame_data			= -1;
-static int hf_synphasor_unknown_data				= -1;
-static int hf_synphasor_status_word_mask_normal_state		= -1;
-static int hf_synphasor_status_word_mask_valid_bits		= -1;
+static int hf_synphasor_data;
+static int hf_synphasor_checksum;
+static int hf_synphasor_checksum_status;
+static int hf_synphasor_num_phasors;
+static int hf_synphasor_num_analog_values;
+static int hf_synphasor_num_digital_status_words;
+static int hf_synphasor_rate_of_transmission;
+static int hf_synphasor_phasor;
+static int hf_synphasor_actual_frequency_value;
+static int hf_synphasor_rate_change_frequency;
+static int hf_synphasor_frequency_deviation_from_nominal;
+static int hf_synphasor_analog_value;
+static int hf_synphasor_digital_status_word;
+static int hf_synphasor_conversion_factor;
+static int hf_synphasor_factor_for_analog_value;
+static int hf_synphasor_channel_name;
+static int hf_synphasor_extended_frame_data;
+static int hf_synphasor_unknown_data;
+static int hf_synphasor_status_word_mask_normal_state;
+static int hf_synphasor_status_word_mask_valid_bits;
 
-static expert_field ei_synphasor_extended_frame_data	= EI_INIT;
-static expert_field ei_synphasor_checksum		= EI_INIT;
-static expert_field ei_synphasor_data_error		= EI_INIT;
-static expert_field ei_synphasor_pmu_not_sync		= EI_INIT;
+static expert_field ei_synphasor_extended_frame_data;
+static expert_field ei_synphasor_checksum;
+static expert_field ei_synphasor_data_error;
+static expert_field ei_synphasor_pmu_not_sync;
 
 static dissector_handle_t synphasor_udp_handle;
+static dissector_handle_t synphasor_tcp_handle;
 
 /* the different frame types for this protocol */
 enum FrameType {
@@ -468,7 +469,7 @@ static const value_string      data_statb03to00names[] = {
 	{   0, NULL				}
 };
 
-/* strings to decode the commands (CMD Field) acording Table 15, p.26
+/* strings to decode the commands (CMD Field) according Table 15, p.26
 *  0000 0000 0000 0001  -  Turn off transmission of data frames
 *  0000 0000 0000 0010  -  Turn on transmission of data frames
 *  0000 0000 0000 0011  -  Send HDR frame
@@ -1849,7 +1850,7 @@ static int dissect_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, v
 		return 0;
 
 	/* write the protocol name to the info column */
-	col_set_str(pinfo->cinfo, COL_PROTOCOL, PROTOCOL_SHORT_NAME);
+	col_set_str(pinfo->cinfo, COL_PROTOCOL, PSNAME);
 
 	frame_type = tvb_get_guint8(tvb, 1) >> 4;
 
@@ -2340,12 +2341,11 @@ void proto_register_synphasor(void)
 	expert_module_t* expert_synphasor;
 
 	/* register protocol */
-	proto_synphasor = proto_register_protocol(PROTOCOL_NAME,
-						  PROTOCOL_SHORT_NAME,
-						  PROTOCOL_ABBREV);
+	proto_synphasor = proto_register_protocol(PNAME, PSNAME, PFNAME);
 
 	/* Registering protocol to be called by another dissector */
 	synphasor_udp_handle = register_dissector("synphasor", dissect_udp, proto_synphasor);
+	synphasor_tcp_handle = register_dissector("synphasor.tcp", dissect_tcp, proto_synphasor);
 
 	proto_register_field_array(proto_synphasor, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
@@ -2357,13 +2357,9 @@ void proto_register_synphasor(void)
 /* called at startup and when the preferences change */
 void proto_reg_handoff_synphasor(void)
 {
-	dissector_handle_t synphasor_tcp_handle;
-
-	synphasor_tcp_handle = create_dissector_handle(dissect_tcp, proto_synphasor);
 	dissector_add_for_decode_as("rtacser.data", synphasor_udp_handle);
 	dissector_add_uint_with_preference("udp.port", SYNPHASOR_UDP_PORT, synphasor_udp_handle);
 	dissector_add_uint_with_preference("tcp.port", SYNPHASOR_TCP_PORT, synphasor_tcp_handle);
-
 } /* proto_reg_handoff_synphasor() */
 
 /*
