@@ -29,7 +29,7 @@
 #include <epan/exceptions.h>
 #include <epan/packet.h>
 #include <epan/expert.h>
-
+#include <wiretap/wtap.h>
 #include <wsutil/strtoi.h>
 
 #include "packet-syslog.h"
@@ -42,133 +42,133 @@ void proto_reg_handoff_systemd_journal(void);
 void proto_register_systemd_journal(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_systemd_journal = -1;
+static int proto_systemd_journal;
 
 // Official entries, listed in
 // https://www.freedesktop.org/software/systemd/man/systemd.journal-fields.html
 // as of 2018-08.
-static int hf_sj_message = -1;
-static int hf_sj_message_id = -1;
-static int hf_sj_priority = -1;
-static int hf_sj_code_file = -1;
-static int hf_sj_code_line = -1;
-static int hf_sj_code_func = -1;
-static int hf_sj_errno = -1;
-static int hf_sj_syslog_facility = -1;
-static int hf_sj_syslog_identifier = -1;
-static int hf_sj_syslog_pid = -1;
+static int hf_sj_message;
+static int hf_sj_message_id;
+static int hf_sj_priority;
+static int hf_sj_code_file;
+static int hf_sj_code_line;
+static int hf_sj_code_func;
+static int hf_sj_errno;
+static int hf_sj_syslog_facility;
+static int hf_sj_syslog_identifier;
+static int hf_sj_syslog_pid;
 
-static int hf_sj_pid = -1;
-static int hf_sj_uid = -1;
-static int hf_sj_gid = -1;
-static int hf_sj_comm = -1;
-static int hf_sj_exe = -1;
-static int hf_sj_cmdline = -1;
-static int hf_sj_cap_effective = -1;
-static int hf_sj_audit_session = -1;
-static int hf_sj_audit_loginuid = -1;
-static int hf_sj_systemd_cgroup = -1;
-static int hf_sj_systemd_slice = -1;
-static int hf_sj_systemd_unit = -1;
-static int hf_sj_systemd_user_unit = -1;
-static int hf_sj_systemd_session = -1;
-static int hf_sj_systemd_owner_uid = -1;
+static int hf_sj_pid;
+static int hf_sj_uid;
+static int hf_sj_gid;
+static int hf_sj_comm;
+static int hf_sj_exe;
+static int hf_sj_cmdline;
+static int hf_sj_cap_effective;
+static int hf_sj_audit_session;
+static int hf_sj_audit_loginuid;
+static int hf_sj_systemd_cgroup;
+static int hf_sj_systemd_slice;
+static int hf_sj_systemd_unit;
+static int hf_sj_systemd_user_unit;
+static int hf_sj_systemd_session;
+static int hf_sj_systemd_owner_uid;
 
-static int hf_sj_selinux_context = -1;
-static int hf_sj_source_realtime_timestamp = -1;
-static int hf_sj_boot_id = -1;
-static int hf_sj_machine_id = -1;
-static int hf_sj_systemd_invocation_id = -1;
-static int hf_sj_hostname = -1;
-static int hf_sj_transport = -1;
-static int hf_sj_stream_id = -1;
-static int hf_sj_line_break = -1;
+static int hf_sj_selinux_context;
+static int hf_sj_source_realtime_timestamp;
+static int hf_sj_boot_id;
+static int hf_sj_machine_id;
+static int hf_sj_systemd_invocation_id;
+static int hf_sj_hostname;
+static int hf_sj_transport;
+static int hf_sj_stream_id;
+static int hf_sj_line_break;
 
-static int hf_sj_kernel_device = -1;
-static int hf_sj_kernel_subsystem = -1;
-static int hf_sj_udev_sysname = -1;
-static int hf_sj_udev_devnode = -1;
-static int hf_sj_udev_devlink = -1;
+static int hf_sj_kernel_device;
+static int hf_sj_kernel_subsystem;
+static int hf_sj_udev_sysname;
+static int hf_sj_udev_devnode;
+static int hf_sj_udev_devlink;
 
-static int hf_sj_coredump_unit = -1;
-static int hf_sj_coredump_user_unit = -1;
-static int hf_sj_object_pid = -1;
-static int hf_sj_object_uid = -1;
-static int hf_sj_object_gid = -1;
-static int hf_sj_object_comm = -1;
-static int hf_sj_object_exe = -1;
-static int hf_sj_object_cmdline = -1;
-static int hf_sj_object_audit_session = -1;
-static int hf_sj_object_audit_loginuid = -1;
-static int hf_sj_object_cap_effective = -1;
-static int hf_sj_object_selinux_context = -1;
-static int hf_sj_object_systemd_cgroup = -1;
-static int hf_sj_object_systemd_session = -1;
-static int hf_sj_object_systemd_owner_uid = -1;
-static int hf_sj_object_systemd_unit = -1;
-static int hf_sj_object_systemd_user_unit = -1;
-static int hf_sj_object_systemd_slice = -1;
-static int hf_sj_object_systemd_user_slice = -1;
-static int hf_sj_object_systemd_invocation_id = -1;
+static int hf_sj_coredump_unit;
+static int hf_sj_coredump_user_unit;
+static int hf_sj_object_pid;
+static int hf_sj_object_uid;
+static int hf_sj_object_gid;
+static int hf_sj_object_comm;
+static int hf_sj_object_exe;
+static int hf_sj_object_cmdline;
+static int hf_sj_object_audit_session;
+static int hf_sj_object_audit_loginuid;
+static int hf_sj_object_cap_effective;
+static int hf_sj_object_selinux_context;
+static int hf_sj_object_systemd_cgroup;
+static int hf_sj_object_systemd_session;
+static int hf_sj_object_systemd_owner_uid;
+static int hf_sj_object_systemd_unit;
+static int hf_sj_object_systemd_user_unit;
+static int hf_sj_object_systemd_slice;
+static int hf_sj_object_systemd_user_slice;
+static int hf_sj_object_systemd_invocation_id;
 
-static int hf_sj_cursor = -1;
-static int hf_sj_realtime_timestamp = -1;
-static int hf_sj_monotonic_timestamp = -1;
+static int hf_sj_cursor;
+static int hf_sj_realtime_timestamp;
+static int hf_sj_monotonic_timestamp;
 
 // Unofficial(?) fields. Not listed in the documentation but present in logs.
-static int hf_sj_result = -1;
-static int hf_sj_source_monotonic_timestamp = -1;
-static int hf_sj_journal_name = -1;
-static int hf_sj_journal_path = -1;
-static int hf_sj_current_use = -1;
-static int hf_sj_current_use_pretty = -1;
-static int hf_sj_max_use = -1;
-static int hf_sj_max_use_pretty = -1;
-static int hf_sj_disk_keep_free = -1;
-static int hf_sj_disk_keep_free_pretty = -1;
-static int hf_sj_disk_available = -1;
-static int hf_sj_disk_available_pretty = -1;
-static int hf_sj_limit = -1;
-static int hf_sj_limit_pretty = -1;
-static int hf_sj_available = -1;
-static int hf_sj_available_pretty = -1;
-static int hf_sj_audit_type = -1;
-static int hf_sj_audit_id = -1;
-static int hf_sj_audit_field_apparmor = -1;
-static int hf_sj_audit_field_operation = -1;
-static int hf_sj_audit_field_profile = -1;
-static int hf_sj_audit_field_name = -1;
-static int hf_sj_seat_id = -1;
-static int hf_sj_kernel_usec = -1;
-static int hf_sj_userspace_usec = -1;
-static int hf_sj_session_id = -1;
-static int hf_sj_user_id = -1;
-static int hf_sj_leader = -1;
-static int hf_sj_job_type = -1;
-static int hf_sj_job_result = -1;
-static int hf_sj_user_invocation_id = -1;
-static int hf_sj_systemd_user_slice = -1;
+static int hf_sj_result;
+static int hf_sj_source_monotonic_timestamp;
+static int hf_sj_journal_name;
+static int hf_sj_journal_path;
+static int hf_sj_current_use;
+static int hf_sj_current_use_pretty;
+static int hf_sj_max_use;
+static int hf_sj_max_use_pretty;
+static int hf_sj_disk_keep_free;
+static int hf_sj_disk_keep_free_pretty;
+static int hf_sj_disk_available;
+static int hf_sj_disk_available_pretty;
+static int hf_sj_limit;
+static int hf_sj_limit_pretty;
+static int hf_sj_available;
+static int hf_sj_available_pretty;
+static int hf_sj_audit_type;
+static int hf_sj_audit_id;
+static int hf_sj_audit_field_apparmor;
+static int hf_sj_audit_field_operation;
+static int hf_sj_audit_field_profile;
+static int hf_sj_audit_field_name;
+static int hf_sj_seat_id;
+static int hf_sj_kernel_usec;
+static int hf_sj_userspace_usec;
+static int hf_sj_session_id;
+static int hf_sj_user_id;
+static int hf_sj_leader;
+static int hf_sj_job_type;
+static int hf_sj_job_result;
+static int hf_sj_user_invocation_id;
+static int hf_sj_systemd_user_slice;
 
 // Metadata.
-static int hf_sj_binary_data_len = -1;
-static int hf_sj_unknown_field = -1;
-static int hf_sj_unknown_field_name = -1;
-static int hf_sj_unknown_field_value = -1;
-static int hf_sj_unknown_field_data = -1;
-static int hf_sj_unhandled_field_type = -1;
+static int hf_sj_binary_data_len;
+static int hf_sj_unknown_field;
+static int hf_sj_unknown_field_name;
+static int hf_sj_unknown_field_value;
+static int hf_sj_unknown_field_data;
+static int hf_sj_unhandled_field_type;
 
-static expert_field ei_unhandled_field_type = EI_INIT;
-static expert_field ei_nonbinary_field = EI_INIT;
-static expert_field ei_undecoded_field = EI_INIT;
+static expert_field ei_unhandled_field_type;
+static expert_field ei_nonbinary_field;
+static expert_field ei_undecoded_field;
 
-static dissector_handle_t sje_handle = NULL;
+static dissector_handle_t sje_handle;
 
 #define MAX_DATA_SIZE 262144 // WTAP_MAX_PACKET_SIZE_STANDARD. Increase if needed.
 
 /* Initialize the subtree pointers */
-static gint ett_systemd_journal_entry = -1;
-static gint ett_systemd_binary_data = -1;
-static gint ett_systemd_unknown_field = -1;
+static gint ett_systemd_journal_entry;
+static gint ett_systemd_binary_data;
+static gint ett_systemd_unknown_field;
 
 // XXX Use a value_string instead?
 typedef struct _journal_field_hf_map {
@@ -369,7 +369,7 @@ dissect_systemd_journal_line_entry(tvbuff_t *tvb, packet_info *pinfo _U_, proto_
                 default:
                 {
                     proto_item *expert_ti = proto_tree_add_item(sje_tree, hf_sj_unhandled_field_type, tvb, offset, line_len,
-                                                                    ENC_UTF_8|ENC_NA);
+                                                                    ENC_UTF_8);
                     expert_add_info(pinfo, expert_ti, &ei_unhandled_field_type);
                     break;
                 }
@@ -386,8 +386,8 @@ dissect_systemd_journal_line_entry(tvbuff_t *tvb, packet_info *pinfo _U_, proto_
             proto_item *unk_ti = proto_tree_add_none_format(sje_tree, hf_sj_unknown_field, tvb, offset, line_len,
                                                             "Unknown text field: %s", tvb_get_string_enc(pinfo->pool, tvb, offset, eq_off - offset - 1, ENC_UTF_8));
             proto_tree *unk_tree = proto_item_add_subtree(unk_ti, ett_systemd_unknown_field);
-            proto_tree_add_item(unk_tree, hf_sj_unknown_field_name, tvb, offset, eq_off - offset - 1, ENC_UTF_8|ENC_NA);
-            proto_tree_add_item(unk_tree, hf_sj_unknown_field_value, tvb, eq_off, val_len, ENC_UTF_8|ENC_NA);
+            proto_tree_add_item(unk_tree, hf_sj_unknown_field_name, tvb, offset, eq_off - offset - 1, ENC_UTF_8);
+            proto_tree_add_item(unk_tree, hf_sj_unknown_field_value, tvb, eq_off, val_len, ENC_UTF_8);
             offset = next_offset;
             continue;
         }
@@ -413,8 +413,8 @@ dissect_systemd_journal_line_entry(tvbuff_t *tvb, packet_info *pinfo _U_, proto_
                         proto_item *unk_ti = proto_tree_add_none_format(sje_tree, hf_sj_unknown_field, tvb, offset, line_len,
                                                                         "Unknown data field: %s", tvb_format_text(pinfo->pool, tvb, offset, eq_off - offset - 1));
                         proto_tree *unk_tree = proto_item_add_subtree(unk_ti, ett_systemd_unknown_field);
-                        proto_item *expert_ti = proto_tree_add_item(unk_tree, hf_sj_unknown_field_name, tvb, offset, offset + noeql_len, ENC_UTF_8|ENC_NA);
-                        proto_tree_add_item(unk_tree, hf_sj_unknown_field_data, tvb, data_off, (int) data_len, ENC_UTF_8|ENC_NA);
+                        proto_item *expert_ti = proto_tree_add_item(unk_tree, hf_sj_unknown_field_name, tvb, offset, offset + noeql_len, ENC_UTF_8);
+                        proto_tree_add_item(unk_tree, hf_sj_unknown_field_data, tvb, data_off, (int) data_len, ENC_UTF_8);
                         expert_add_info(pinfo, expert_ti, &ei_nonbinary_field);
                     }
                 }
@@ -437,11 +437,11 @@ proto_register_systemd_journal(void)
     static hf_register_info hf[] = {
         { &hf_sj_message,
           { "Message", "systemd_journal.message",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_message_id,
           { "Message ID", "systemd_journal.message_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_priority,
           { "Priority", "systemd_journal.priority",
@@ -449,7 +449,7 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_code_file,
           { "Code file", "systemd_journal.code_file",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_code_line,
           { "Code line", "systemd_journal.code_line",
@@ -457,7 +457,7 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_code_func,
           { "Code func", "systemd_journal.code_func",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_errno,
           { "Errno", "systemd_journal.errno",
@@ -469,7 +469,7 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_syslog_identifier,
           { "Syslog identifier", "systemd_journal.syslog_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_syslog_pid,
           { "Syslog PID", "systemd_journal.syslog_pid",
@@ -490,19 +490,19 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_comm,
           { "Command name", "systemd_journal.comm",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_exe,
           { "Executable path", "systemd_journal.exe",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_cmdline,
           { "Command line", "systemd_journal.cmdline",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_cap_effective,
           { "Effective capability", "systemd_journal.cap_effective",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_audit_session,
           { "Audit session", "systemd_journal.audit_session",
@@ -515,19 +515,19 @@ proto_register_systemd_journal(void)
 
         { &hf_sj_systemd_cgroup,
           { "Systemd cgroup", "systemd_journal.systemd_cgroup",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_systemd_slice,
           { "Systemd slice", "systemd_journal.systemd_slice",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_systemd_unit,
           { "Systemd unit", "systemd_journal.systemd_unit",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_systemd_user_unit,
           { "Systemd user unit", "systemd_journal.systemd_user_unit",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_systemd_session,
           { "Systemd session", "systemd_journal.systemd_session",
@@ -540,7 +540,7 @@ proto_register_systemd_journal(void)
 
         { &hf_sj_selinux_context,
           { "SELinux context", "systemd_journal.selinux_context",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_source_realtime_timestamp,
           { "Source realtime timestamp", "systemd_journal.source_realtime_timestamp",
@@ -548,61 +548,61 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_boot_id,
           { "Boot ID", "systemd_journal.boot_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_machine_id,
           { "Machine ID", "systemd_journal.machine_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_systemd_invocation_id,
           { "Systemd invocation ID", "systemd_journal.systemd_invocation_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_hostname,
           { "Hostname", "systemd_journal.hostname",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_transport,
           { "Transport", "systemd_journal.transport",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_stream_id,
           { "Stream ID", "systemd_journal.stream_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_line_break,
           { "Line break", "systemd_journal.line_break",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
 
         { &hf_sj_kernel_device,
           { "Kernel device", "systemd_journal.kernel_device",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_kernel_subsystem,
           { "Kernel subsystem", "systemd_journal.kernel_subsystem",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_udev_sysname,
           { "Device tree name", "systemd_journal.udev_sysname",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_udev_devnode,
           { "Device tree node", "systemd_journal.udev_devnode",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_udev_devlink,
           { "Device tree symlink", "systemd_journal.udev_devlink",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
 
         { &hf_sj_coredump_unit,
           { "Coredump unit", "systemd_journal.coredump_unit",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_coredump_user_unit,
           { "Coredump user unit", "systemd_journal.coredump_user_unit",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_pid,
           { "Object PID", "systemd_journal.object_pid",
@@ -618,15 +618,15 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_object_comm,
           { "Object command name", "systemd_journal.object_comm",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_exe,
           { "Object executable path", "systemd_journal.object_exe",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_cmdline,
           { "Object command line", "systemd_journal.object_cmdline",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_audit_session,
           { "Object audit session", "systemd_journal.object_audit_session",
@@ -642,11 +642,11 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_object_selinux_context,
           { "Object SELinux context", "systemd_journal.object_selinux_context",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_systemd_cgroup,
           { "Object systemd cgroup", "systemd_journal.object_systemd_cgroup",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_systemd_session,
           { "Object systemd session", "systemd_journal.object_systemd_session",
@@ -658,28 +658,28 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_object_systemd_unit,
           { "Object systemd unit", "systemd_journal.object_systemd_unit",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_systemd_user_unit,
           { "Object systemd user unit", "systemd_journal.object_systemd_user_unit",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_systemd_slice,
           { "Object systemd slice", "systemd_journal.object_systemd_slice",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_systemd_user_slice,
           { "Object systemd user slice", "systemd_journal.object_systemd_user_slice",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_object_systemd_invocation_id,
           { "Object systemd invocation ID", "systemd_journal.object_systemd_invocation_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
 
         { &hf_sj_cursor,
           { "Cursor", "systemd_journal.cursor",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_realtime_timestamp,
           { "Realtime Timestamp", "systemd_journal.realtime_timestamp",
@@ -692,11 +692,11 @@ proto_register_systemd_journal(void)
 
         { &hf_sj_journal_name,
           { "Journal name", "systemd_journal.journal_name",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_journal_path,
           { "Journal path", "systemd_journal.journal_path",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_current_use,
           { "Current use", "systemd_journal.current_use",
@@ -704,7 +704,7 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_current_use_pretty,
           { "Human readable current use", "systemd_journal.current_use_pretty",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_max_use,
           { "Max use", "systemd_journal.max_use",
@@ -712,7 +712,7 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_max_use_pretty,
           { "Human readable max use", "systemd_journal.max_use_pretty",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_disk_keep_free,
           { "Disk keep free", "systemd_journal.disk_keep_free",
@@ -720,7 +720,7 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_disk_keep_free_pretty,
           { "Human readable disk keep free", "systemd_journal.disk_keep_free_pretty",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_disk_available,
           { "Disk available", "systemd_journal.disk_available",
@@ -728,7 +728,7 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_disk_available_pretty,
           { "Human readable disk available", "systemd_journal.disk_available_pretty",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_limit,
           { "Limit", "systemd_journal.limit",
@@ -736,7 +736,7 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_limit_pretty,
           { "Human readable limit", "systemd_journal.limit_pretty",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_available,
           { "Available", "systemd_journal.available",
@@ -744,11 +744,11 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_available_pretty,
           { "Human readable available", "systemd_journal.available_pretty",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_result,
           { "Result", "systemd_journal.result",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_source_monotonic_timestamp,
           { "Source monotonic timestamp", "systemd_journal.source_monotonic_timestamp",
@@ -764,23 +764,23 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_audit_field_apparmor,
           { "Audit field AppArmor", "systemd_journal.audit_field_apparmor",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_audit_field_operation,
           { "Audit field operation", "systemd_journal.audit_field_operation",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_audit_field_profile,
           { "Audit field profile", "systemd_journal.audit_field_profile",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_audit_field_name,
           { "Audit field name", "systemd_journal.audit_field_name",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_seat_id,
           { "Seat ID", "systemd_journal.seat_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_kernel_usec,
           { "Kernel microseconds", "systemd_journal.kernel_usec",
@@ -796,7 +796,7 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_user_id,
           { "User ID", "systemd_journal.user_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_leader,
           { "Leader", "systemd_journal.leader",
@@ -804,19 +804,19 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_job_type,
           { "Job type", "systemd_journal.job_type",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_job_result,
           { "Job result", "systemd_journal.job_result",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_user_invocation_id,
           { "User invocation ID", "systemd_journal.user_invocation_id",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_systemd_user_slice,
           { "Systemd user slice", "systemd_journal.systemd_user_slice",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
 
         { &hf_sj_binary_data_len,
@@ -829,19 +829,19 @@ proto_register_systemd_journal(void)
         },
         { &hf_sj_unknown_field_name,
           { "Field name", "systemd_journal.field.name",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_unknown_field_value,
           { "Field value", "systemd_journal.field.value",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_unknown_field_data,
           { "Field data", "systemd_journal.field.data",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         },
         { &hf_sj_unhandled_field_type,
           { "Field data", "systemd_journal.unhandled_field_type",
-            FT_STRING, STR_UNICODE, NULL, 0x0, NULL, HFILL }
+            FT_STRING, BASE_NONE, NULL, 0x0, NULL, HFILL }
         }
     };
 
