@@ -17,6 +17,7 @@
 
 #include <epan/packet.h>
 #include <epan/expert.h>
+#include <epan/charsets.h>
 
 #include "packet-t38.h"
 #include "packet-t30.h"
@@ -24,120 +25,120 @@
 void proto_register_t30(void);
 
 /* T30 */
-static int proto_t30 = -1;
-static int hf_t30_Address = -1;
-static int hf_t30_Control = -1;
-static int hf_t30_Facsimile_Control = -1;
-static int hf_t30_fif_sm = -1;
-static int hf_t30_fif_rtif = -1;
-static int hf_t30_fif_3gmn = -1;
-static int hf_t30_fif_v8c = -1;
-static int hf_t30_fif_op = -1;
-static int hf_t30_fif_rtfc = -1;
-static int hf_t30_fif_rfo = -1;
-static int hf_t30_fif_dsr = -1;
-static int hf_t30_fif_dsr_dcs = -1;
-static int hf_t30_fif_res = -1;
-static int hf_t30_fif_tdcc = -1;
-static int hf_t30_fif_rwc = -1;
-static int hf_t30_fif_rw_dcs = -1;
-static int hf_t30_fif_rlc = -1;
-static int hf_t30_fif_rl_dcs = -1;
-static int hf_t30_fif_msltcr = -1;
-static int hf_t30_fif_mslt_dcs = -1;
-static int hf_t30_fif_ext = -1;
-static int hf_t30_fif_cm = -1;
-static int hf_t30_fif_ecm = -1;
-static int hf_t30_fif_fs_dcs = -1;
-static int hf_t30_fif_t6 = -1;
-static int hf_t30_fif_fvc = -1;
-static int hf_t30_fif_mspc = -1;
-static int hf_t30_fif_ps = -1;
-static int hf_t30_fif_t43 = -1;
-static int hf_t30_fif_pi = -1;
-static int hf_t30_fif_vc32k = -1;
-static int hf_t30_fif_r8x15 = -1;
-static int hf_t30_fif_300x300 = -1;
-static int hf_t30_fif_r16x15 = -1;
-static int hf_t30_fif_ibrp = -1;
-static int hf_t30_fif_mbrp = -1;
-static int hf_t30_fif_msltchr = -1;
-static int hf_t30_fif_rts = -1;
-static int hf_t30_fif_sp = -1;
-static int hf_t30_fif_sc = -1;
-static int hf_t30_fif_passw = -1;
-static int hf_t30_fif_sit = -1;
-static int hf_t30_fif_rttd = -1;
-static int hf_t30_fif_bft = -1;
-static int hf_t30_fif_dtm = -1;
-static int hf_t30_fif_edi = -1;
-static int hf_t30_fif_btm = -1;
-static int hf_t30_fif_rttcmmd = -1;
-static int hf_t30_fif_chrm = -1;
-static int hf_t30_fif_mm = -1;
-static int hf_t30_fif_pm26 = -1;
-static int hf_t30_fif_dnc = -1;
-static int hf_t30_fif_do = -1;
-static int hf_t30_fif_jpeg = -1;
-static int hf_t30_fif_fcm = -1;
-static int hf_t30_fif_pht = -1;
-static int hf_t30_fif_12c = -1;
-static int hf_t30_fif_ns = -1;
-static int hf_t30_fif_ci = -1;
-static int hf_t30_fif_cgr = -1;
-static int hf_t30_fif_nalet = -1;
-static int hf_t30_fif_naleg = -1;
-static int hf_t30_fif_spscb = -1;
-static int hf_t30_fif_spsco = -1;
-static int hf_t30_fif_hkm = -1;
-static int hf_t30_fif_rsa = -1;
-static int hf_t30_fif_oc = -1;
-static int hf_t30_fif_hfx40 = -1;
-static int hf_t30_fif_acn2c = -1;
-static int hf_t30_fif_acn3c = -1;
-static int hf_t30_fif_hfx40i = -1;
-static int hf_t30_fif_ahsn2 = -1;
-static int hf_t30_fif_ahsn3 = -1;
-static int hf_t30_fif_t441 = -1;
-static int hf_t30_fif_t442 = -1;
-static int hf_t30_fif_t443 = -1;
-static int hf_t30_fif_plmss = -1;
-static int hf_t30_fif_cg300 = -1;
-static int hf_t30_fif_100x100cg = -1;
-static int hf_t30_fif_spcbft = -1;
-static int hf_t30_fif_ebft = -1;
-static int hf_t30_fif_isp = -1;
-static int hf_t30_fif_ira = -1;
-static int hf_t30_fif_600x600 = -1;
-static int hf_t30_fif_1200x1200 = -1;
-static int hf_t30_fif_300x600 = -1;
-static int hf_t30_fif_400x800 = -1;
-static int hf_t30_fif_600x1200 = -1;
-static int hf_t30_fif_cg600x600 = -1;
-static int hf_t30_fif_cg1200x1200 = -1;
-static int hf_t30_fif_dspcam = -1;
-static int hf_t30_fif_dspccm = -1;
-static int hf_t30_fif_bwmrcp = -1;
-static int hf_t30_fif_t45 = -1;
-static int hf_t30_fif_sdmc = -1;
-static int hf_t30_fif_number = -1;
-static int hf_t30_fif_country_code = -1;
-static int hf_t30_fif_non_stand_bytes = -1;
-static int hf_t30_t4_frame_num = -1;
-static int hf_t30_t4_data = -1;
-static int hf_t30_partial_page_fcf2 = -1;
-static int hf_t30_partial_page_i1 = -1;
-static int hf_t30_partial_page_i2 = -1;
-static int hf_t30_partial_page_i3 = -1;
-static int hf_t30_partial_page_request_frame_count = -1;
-static int hf_t30_partial_page_request_frames = -1;
+static int proto_t30;
+static int hf_t30_Address;
+static int hf_t30_Control;
+static int hf_t30_Facsimile_Control;
+static int hf_t30_fif_sm;
+static int hf_t30_fif_rtif;
+static int hf_t30_fif_3gmn;
+static int hf_t30_fif_v8c;
+static int hf_t30_fif_op;
+static int hf_t30_fif_rtfc;
+static int hf_t30_fif_rfo;
+static int hf_t30_fif_dsr;
+static int hf_t30_fif_dsr_dcs;
+static int hf_t30_fif_res;
+static int hf_t30_fif_tdcc;
+static int hf_t30_fif_rwc;
+static int hf_t30_fif_rw_dcs;
+static int hf_t30_fif_rlc;
+static int hf_t30_fif_rl_dcs;
+static int hf_t30_fif_msltcr;
+static int hf_t30_fif_mslt_dcs;
+static int hf_t30_fif_ext;
+static int hf_t30_fif_cm;
+static int hf_t30_fif_ecm;
+static int hf_t30_fif_fs_dcs;
+static int hf_t30_fif_t6;
+static int hf_t30_fif_fvc;
+static int hf_t30_fif_mspc;
+static int hf_t30_fif_ps;
+static int hf_t30_fif_t43;
+static int hf_t30_fif_pi;
+static int hf_t30_fif_vc32k;
+static int hf_t30_fif_r8x15;
+static int hf_t30_fif_300x300;
+static int hf_t30_fif_r16x15;
+static int hf_t30_fif_ibrp;
+static int hf_t30_fif_mbrp;
+static int hf_t30_fif_msltchr;
+static int hf_t30_fif_rts;
+static int hf_t30_fif_sp;
+static int hf_t30_fif_sc;
+static int hf_t30_fif_passw;
+static int hf_t30_fif_sit;
+static int hf_t30_fif_rttd;
+static int hf_t30_fif_bft;
+static int hf_t30_fif_dtm;
+static int hf_t30_fif_edi;
+static int hf_t30_fif_btm;
+static int hf_t30_fif_rttcmmd;
+static int hf_t30_fif_chrm;
+static int hf_t30_fif_mm;
+static int hf_t30_fif_pm26;
+static int hf_t30_fif_dnc;
+static int hf_t30_fif_do;
+static int hf_t30_fif_jpeg;
+static int hf_t30_fif_fcm;
+static int hf_t30_fif_pht;
+static int hf_t30_fif_12c;
+static int hf_t30_fif_ns;
+static int hf_t30_fif_ci;
+static int hf_t30_fif_cgr;
+static int hf_t30_fif_nalet;
+static int hf_t30_fif_naleg;
+static int hf_t30_fif_spscb;
+static int hf_t30_fif_spsco;
+static int hf_t30_fif_hkm;
+static int hf_t30_fif_rsa;
+static int hf_t30_fif_oc;
+static int hf_t30_fif_hfx40;
+static int hf_t30_fif_acn2c;
+static int hf_t30_fif_acn3c;
+static int hf_t30_fif_hfx40i;
+static int hf_t30_fif_ahsn2;
+static int hf_t30_fif_ahsn3;
+static int hf_t30_fif_t441;
+static int hf_t30_fif_t442;
+static int hf_t30_fif_t443;
+static int hf_t30_fif_plmss;
+static int hf_t30_fif_cg300;
+static int hf_t30_fif_100x100cg;
+static int hf_t30_fif_spcbft;
+static int hf_t30_fif_ebft;
+static int hf_t30_fif_isp;
+static int hf_t30_fif_ira;
+static int hf_t30_fif_600x600;
+static int hf_t30_fif_1200x1200;
+static int hf_t30_fif_300x600;
+static int hf_t30_fif_400x800;
+static int hf_t30_fif_600x1200;
+static int hf_t30_fif_cg600x600;
+static int hf_t30_fif_cg1200x1200;
+static int hf_t30_fif_dspcam;
+static int hf_t30_fif_dspccm;
+static int hf_t30_fif_bwmrcp;
+static int hf_t30_fif_t45;
+static int hf_t30_fif_sdmc;
+static int hf_t30_fif_number;
+static int hf_t30_fif_country_code;
+static int hf_t30_fif_non_stand_bytes;
+static int hf_t30_t4_frame_num;
+static int hf_t30_t4_data;
+static int hf_t30_partial_page_fcf2;
+static int hf_t30_partial_page_i1;
+static int hf_t30_partial_page_i2;
+static int hf_t30_partial_page_i3;
+static int hf_t30_partial_page_request_frame_count;
+static int hf_t30_partial_page_request_frames;
 
-static gint ett_t30 = -1;
-static gint ett_t30_fif = -1;
+static gint ett_t30;
+static gint ett_t30_fif;
 
-static expert_field ei_t30_bad_length = EI_INIT;
-static expert_field ei_t30_Address_FF = EI_INIT;
-static expert_field ei_t30_Control_C0C8 = EI_INIT;
+static expert_field ei_t30_bad_length;
+static expert_field ei_t30_Address_FF;
+static expert_field ei_t30_Control_C0C8;
 
 static const value_string t30_control_vals[] = {
     { 0xC0, "non-final frames within the procedure" },
@@ -492,24 +493,23 @@ reverse_byte(guint8 val)
 
 #define LENGTH_T30_NUM  20
 static gchar *
-t30_get_string_numbers(tvbuff_t *tvb, int offset, int len)
+t30_get_string_numbers(wmem_allocator_t *pool, tvbuff_t *tvb, int offset, int len)
 {
-    gchar *buf;
+    gchar buf[LENGTH_T30_NUM+1];
     int    i;
 
     /* the length must be 20 bytes per T30 rec*/
     if (len != LENGTH_T30_NUM)
         return NULL;
 
-    buf=(gchar *)wmem_alloc(wmem_packet_scope(), LENGTH_T30_NUM+1);
-
     for (i=0; i<LENGTH_T30_NUM; i++)
         buf[LENGTH_T30_NUM-i-1] = reverse_byte(tvb_get_guint8(tvb, offset+i));
 
     /* add end of string */
     buf[LENGTH_T30_NUM] = '\0';
 
-    return g_strstrip(buf);
+    char *s = g_strstrip(buf);
+    return get_utf_8_string(pool, s, (int)strlen(s));
 
 }
 
@@ -518,15 +518,14 @@ dissect_t30_numbers(tvbuff_t *tvb, int offset, packet_info *pinfo, int len, prot
 {
     gchar *str_num;
 
-    str_num = t30_get_string_numbers(tvb, offset, len);
+    str_num = t30_get_string_numbers(pinfo->pool, tvb, offset, len);
     if (str_num) {
-        proto_tree_add_string_format_value(tree, hf_t30_fif_number, tvb, offset, LENGTH_T30_NUM, str_num,
-                                     "%s", str_num);
+        proto_tree_add_string(tree, hf_t30_fif_number, tvb, offset, LENGTH_T30_NUM, str_num);
 
-        col_append_fstr(pinfo->cinfo, COL_INFO, " - Number:%s", str_num );
+        col_append_fstr(pinfo->cinfo, COL_INFO, " - Number:%s", str_num);
 
         if (t38)
-            g_snprintf(t38->desc, MAX_T38_DESC, "Num: %s", str_num);
+            snprintf(t38->desc, MAX_T38_DESC, "Num: %s", str_num);
     }
     else {
         proto_tree_add_expert_format(tree, pinfo, &ei_t30_bad_length, tvb, offset, -1,
@@ -555,7 +554,7 @@ dissect_t30_facsimile_coded_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
     col_append_fstr(pinfo->cinfo, COL_INFO, " - Frame num:%d", reverse_byte(octet));
 
     if (t38)
-        g_snprintf(t38->desc, MAX_T38_DESC, "Frm num: %d", reverse_byte(octet));
+        snprintf(t38->desc, MAX_T38_DESC, "Frm num: %d", reverse_byte(octet));
 
     proto_tree_add_item(tree, hf_t30_t4_data, tvb, offset, len-1, ENC_NA);
 }
@@ -610,7 +609,7 @@ dissect_t30_partial_page_signal(tvbuff_t *tvb, int offset, packet_info *pinfo, i
     col_append_fstr(pinfo->cinfo, COL_INFO, " - PC:%d BC:%d FC:%d", page_count, block_count, frame_count);
 
     if (t38)
-        g_snprintf(t38->desc, MAX_T38_DESC,
+        snprintf(t38->desc, MAX_T38_DESC,
                    "PC:%d BC:%d FC:%d", page_count, block_count, frame_count);
 
 }
@@ -618,10 +617,11 @@ dissect_t30_partial_page_signal(tvbuff_t *tvb, int offset, packet_info *pinfo, i
 static void
 dissect_t30_partial_page_request(tvbuff_t *tvb, int offset, packet_info *pinfo, int len, proto_tree *tree)
 {
+    int start_offset;
     int frame_count = 0;
     int frame;
 #define BUF_SIZE  (10*1 + 90*2 + 156*3 + 256*2 + 1) /* 0..9 + 10..99 + 100..255 + 256*', ' + \0 */
-    gchar *buf = (gchar *)wmem_alloc(wmem_packet_scope(), BUF_SIZE);
+    gchar *buf = (gchar *)wmem_alloc(pinfo->pool, BUF_SIZE);
     gchar *buf_top = buf;
 
     if (len != 32) {
@@ -631,6 +631,7 @@ dissect_t30_partial_page_request(tvbuff_t *tvb, int offset, packet_info *pinfo,
         return;
     }
 
+    start_offset = offset;
     for (frame=0; frame < 255; ) {
         guint8 octet = tvb_get_guint8(tvb, offset);
         guint8 bit = 1<<7;
@@ -639,7 +640,7 @@ dissect_t30_partial_page_request(tvbuff_t *tvb, int offset, packet_info *pinfo,
             if (octet & bit) {
                 ++frame_count;
                 DISSECTOR_ASSERT((buf_top-buf) < BUF_SIZE);
-                buf_top += g_snprintf(buf_top, BUF_SIZE - (gulong)(buf_top - buf), "%u, ", frame);
+                buf_top += snprintf(buf_top, BUF_SIZE - (buf_top - buf), "%u, ", frame);
             }
             bit >>= 1;
             ++frame;
@@ -649,7 +650,7 @@ dissect_t30_partial_page_request(tvbuff_t *tvb, int offset, packet_info *pinfo,
     proto_tree_add_uint(tree, hf_t30_partial_page_request_frame_count, tvb, offset, 1, frame_count);
     if (buf_top > buf+1) {
         buf_top[-2] = '\0';
-        proto_tree_add_string_format_value(tree, hf_t30_partial_page_request_frames, tvb, offset, (gint)(buf_top-buf),
+        proto_tree_add_string_format_value(tree, hf_t30_partial_page_request_frames, tvb, start_offset, offset - start_offset,
                                      buf, "%s", buf);
     }
 
@@ -690,7 +691,7 @@ dissect_t30_dis_dtc(tvbuff_t *tvb, int offset, packet_info *pinfo, int len, prot
                             val_to_str_ext_const((octet&0x3C) >> 2, &t30_data_signalling_rate_vals_ext, "<unknown>"));
 
         if (t38)
-          g_snprintf(t38->desc, MAX_T38_DESC,
+          snprintf(t38->desc, MAX_T38_DESC,
                      "DSR:%s",
                      val_to_str_ext_const((octet&0x3C) >> 2, &t30_data_signalling_rate_vals_ext, "<unknown>"));
     }
@@ -701,7 +702,7 @@ dissect_t30_dis_dtc(tvbuff_t *tvb, int offset, packet_info *pinfo, int len, prot
                             val_to_str_ext_const((octet&0x3C) >> 2, &t30_data_signalling_rate_dcs_vals_ext, "<unknown>"));
 
         if (t38)
-          g_snprintf(t38->desc, MAX_T38_DESC,
+          snprintf(t38->desc, MAX_T38_DESC,
                      "DSR:%s",
                      val_to_str_ext_const((octet&0x3C) >> 2, &t30_data_signalling_rate_dcs_vals_ext, "<unknown>"));
     }
@@ -1400,7 +1401,7 @@ proto_register_t30(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
