@@ -43,29 +43,29 @@ static dissector_handle_t tacplus_handle;
 static void md5_xor( guint8 *data, const char *key, int data_len, guint8 *session_id, guint8 version, guint8 seq_no );
 static int  dissect_tacplus_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data);
 
-static int proto_tacacs = -1;
-static int hf_tacacs_version = -1;
-static int hf_tacacs_type = -1;
-static int hf_tacacs_nonce = -1;
-static int hf_tacacs_userlen = -1;
-static int hf_tacacs_passlen = -1;
-static int hf_tacacs_response = -1;
-static int hf_tacacs_reason = -1;
-static int hf_tacacs_result1 = -1;
-static int hf_tacacs_destaddr = -1;
-static int hf_tacacs_destport = -1;
-static int hf_tacacs_line = -1;
-static int hf_tacacs_result2 = -1;
-static int hf_tacacs_result3 = -1;
-static int hf_tacacs_username = -1;
-static int hf_tacacs_password = -1;
+static int proto_tacacs;
+static int hf_tacacs_version;
+static int hf_tacacs_type;
+static int hf_tacacs_nonce;
+static int hf_tacacs_userlen;
+static int hf_tacacs_passlen;
+static int hf_tacacs_response;
+static int hf_tacacs_reason;
+static int hf_tacacs_result1;
+static int hf_tacacs_destaddr;
+static int hf_tacacs_destport;
+static int hf_tacacs_line;
+static int hf_tacacs_result2;
+static int hf_tacacs_result3;
+static int hf_tacacs_username;
+static int hf_tacacs_password;
 
-static gint ett_tacacs = -1;
+static gint ett_tacacs;
 
-static gboolean tacplus_preference_desegment = TRUE;
+static bool tacplus_preference_desegment = true;
 
 static const char *tacplus_opt_key;
-static GSList *tacplus_keys = NULL;
+static GSList *tacplus_keys;
 
 #define ADDR_INVLD "invalid"
 
@@ -272,85 +272,85 @@ proto_reg_handoff_tacacs(void)
 	dissector_add_uint_with_preference("udp.port", UDP_PORT_TACACS, tacacs_handle);
 }
 
-static int proto_tacplus = -1;
-static int hf_tacplus_response = -1;
-static int hf_tacplus_request = -1;
-static int hf_tacplus_majvers = -1;
-static int hf_tacplus_minvers = -1;
-static int hf_tacplus_type = -1;
-static int hf_tacplus_seqno = -1;
-static int hf_tacplus_flags = -1;
-static int hf_tacplus_flags_payload_type = -1;
-static int hf_tacplus_flags_connection_type = -1;
-static int hf_tacplus_acct_flags = -1;
-static int hf_tacplus_acct_flags_more = -1;
-static int hf_tacplus_acct_flags_start = -1;
-static int hf_tacplus_acct_flags_stop = -1;
-static int hf_tacplus_acct_flags_watchdog = -1;
-static int hf_tacplus_session_id = -1;
-static int hf_tacplus_packet_len = -1;
-static int hf_tacplus_auth_password = -1;
-static int hf_tacplus_port = -1;
-static int hf_tacplus_remote_address = -1;
-static int hf_tacplus_chap_challenge = -1;
-static int hf_tacplus_chap_response = -1;
-static int hf_tacplus_mschap_challenge = -1;
-static int hf_tacplus_mschap_response = -1;
-static int hf_tacplus_arap_nas_challenge = -1;
-static int hf_tacplus_arap_remote_challenge = -1;
-static int hf_tacplus_arap_remote_response = -1;
-static int hf_tacplus_privilege_level = -1;
-static int hf_tacplus_authentication_type = -1;
-static int hf_tacplus_service = -1;
-static int hf_tacplus_user_len = -1;
-static int hf_tacplus_user = -1;
-static int hf_tacplus_port_len = -1;
-static int hf_tacplus_remote_address_len = -1;
-static int hf_tacplus_arg_length = -1;
-static int hf_tacplus_arg_value = -1;
-static int hf_tacplus_chap_id = -1;
-static int hf_tacplus_mschap_id = -1;
-static int hf_tacplus_authen_action = -1;
-static int hf_tacplus_body_authen_req_cont_flags = -1;
-static int hf_tacplus_body_authen_req_cont_user_length = -1;
-static int hf_tacplus_body_authen_req_cont_user = -1;
-static int hf_tacplus_body_authen_req_cont_data_length = -1;
-static int hf_tacplus_body_authen_rep_status = -1;
-static int hf_tacplus_body_authen_rep_flags = -1;
-static int hf_tacplus_body_authen_rep_server_msg_len = -1;
-static int hf_tacplus_body_authen_rep_server_msg = -1;
-static int hf_tacplus_body_authen_rep_server_data_len = -1;
-static int hf_tacplus_body_author_req_auth_method = -1;
-static int hf_tacplus_body_author_req_arg_count = -1;
-static int hf_tacplus_body_author_rep_auth_status = -1;
-static int hf_tacplus_body_author_rep_server_msg_len = -1;
-static int hf_tacplus_body_author_rep_server_data_len = -1;
-static int hf_tacplus_body_author_rep_arg_count = -1;
-static int hf_tacplus_acct_authen_method = -1;
-static int hf_tacplus_acct_arg_count = -1;
-static int hf_tacplus_body_acct_status = -1;
-static int hf_tacplus_body_acct_server_msg_len = -1;
-static int hf_tacplus_body_acct_server_msg = -1;
-static int hf_tacplus_body_acct_data_len = -1;
-static int hf_tacplus_body_acct_data = -1;
-static int hf_tacplus_data = -1;
+static int proto_tacplus;
+static int hf_tacplus_response;
+static int hf_tacplus_request;
+static int hf_tacplus_majvers;
+static int hf_tacplus_minvers;
+static int hf_tacplus_type;
+static int hf_tacplus_seqno;
+static int hf_tacplus_flags;
+static int hf_tacplus_flags_payload_type;
+static int hf_tacplus_flags_connection_type;
+static int hf_tacplus_acct_flags;
+static int hf_tacplus_acct_flags_more;
+static int hf_tacplus_acct_flags_start;
+static int hf_tacplus_acct_flags_stop;
+static int hf_tacplus_acct_flags_watchdog;
+static int hf_tacplus_session_id;
+static int hf_tacplus_packet_len;
+static int hf_tacplus_auth_password;
+static int hf_tacplus_port;
+static int hf_tacplus_remote_address;
+static int hf_tacplus_chap_challenge;
+static int hf_tacplus_chap_response;
+static int hf_tacplus_mschap_challenge;
+static int hf_tacplus_mschap_response;
+static int hf_tacplus_arap_nas_challenge;
+static int hf_tacplus_arap_remote_challenge;
+static int hf_tacplus_arap_remote_response;
+static int hf_tacplus_privilege_level;
+static int hf_tacplus_authentication_type;
+static int hf_tacplus_service;
+static int hf_tacplus_user_len;
+static int hf_tacplus_user;
+static int hf_tacplus_port_len;
+static int hf_tacplus_remote_address_len;
+static int hf_tacplus_arg_length;
+static int hf_tacplus_arg_value;
+static int hf_tacplus_chap_id;
+static int hf_tacplus_mschap_id;
+static int hf_tacplus_authen_action;
+static int hf_tacplus_body_authen_req_cont_flags;
+static int hf_tacplus_body_authen_req_cont_user_length;
+static int hf_tacplus_body_authen_req_cont_user;
+static int hf_tacplus_body_authen_req_cont_data_length;
+static int hf_tacplus_body_authen_rep_status;
+static int hf_tacplus_body_authen_rep_flags;
+static int hf_tacplus_body_authen_rep_server_msg_len;
+static int hf_tacplus_body_authen_rep_server_msg;
+static int hf_tacplus_body_authen_rep_server_data_len;
+static int hf_tacplus_body_author_req_auth_method;
+static int hf_tacplus_body_author_req_arg_count;
+static int hf_tacplus_body_author_rep_auth_status;
+static int hf_tacplus_body_author_rep_server_msg_len;
+static int hf_tacplus_body_author_rep_server_data_len;
+static int hf_tacplus_body_author_rep_arg_count;
+static int hf_tacplus_acct_authen_method;
+static int hf_tacplus_acct_arg_count;
+static int hf_tacplus_body_acct_status;
+static int hf_tacplus_body_acct_server_msg_len;
+static int hf_tacplus_body_acct_server_msg;
+static int hf_tacplus_body_acct_data_len;
+static int hf_tacplus_body_acct_data;
+static int hf_tacplus_data;
 /* Generated from convert_proto_tree_add_text.pl */
-static int hf_tacplus_ascii_length = -1;
-static int hf_tacplus_arap_data_length = -1;
-static int hf_tacplus_mschap_data_length = -1;
-static int hf_tacplus_chap_data_length = -1;
-static int hf_tacplus_password_length = -1;
-static int hf_tacplus_data_length = -1;
+static int hf_tacplus_ascii_length;
+static int hf_tacplus_arap_data_length;
+static int hf_tacplus_mschap_data_length;
+static int hf_tacplus_chap_data_length;
+static int hf_tacplus_password_length;
+static int hf_tacplus_data_length;
 
-static gint ett_tacplus = -1;
-static gint ett_tacplus_body = -1;
-static gint ett_tacplus_body_chap = -1;
-static gint ett_tacplus_flags = -1;
-static gint ett_tacplus_acct_flags = -1;
+static gint ett_tacplus;
+static gint ett_tacplus_body;
+static gint ett_tacplus_body_chap;
+static gint ett_tacplus_flags;
+static gint ett_tacplus_acct_flags;
 
-static expert_field ei_tacplus_packet_len_invalid = EI_INIT;
-static expert_field ei_tacplus_unencrypted = EI_INIT;
-static expert_field ei_tacplus_bogus_data = EI_INIT;
+static expert_field ei_tacplus_packet_len_invalid;
+static expert_field ei_tacplus_unencrypted;
+static expert_field ei_tacplus_bogus_data;
 
 typedef struct _tacplus_key_entry {
 	address *s; /* Server address */
