@@ -7,19 +7,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 /*
@@ -42,49 +30,49 @@ void proto_reg_handoff_tapa(void);
 void proto_register_tapa(void);
 
 /* protocol handles */
-static int proto_tapa = -1;
+static int proto_tapa;
 
 /* ett handles */
-static int ett_tapa_discover = -1;
-static int ett_tapa_discover_req = -1;
-static int ett_tapa_tunnel = -1;
+static int ett_tapa_discover;
+static int ett_tapa_discover_req;
+static int ett_tapa_tunnel;
 
 /* hf elements */
-static int hf_tapa_discover_type = -1;
-static int hf_tapa_discover_flags = -1;
-static int hf_tapa_discover_length = -1;
-static int hf_tapa_discover_unknown = -1;
+static int hf_tapa_discover_type;
+static int hf_tapa_discover_flags;
+static int hf_tapa_discover_length;
+static int hf_tapa_discover_unknown;
 
-static int hf_tapa_discover_req_type = -1;
-static int hf_tapa_discover_req_pad = -1;
-static int hf_tapa_discover_req_length = -1;
-static int hf_tapa_discover_req_value = -1;
+static int hf_tapa_discover_req_type;
+static int hf_tapa_discover_req_pad;
+static int hf_tapa_discover_req_length;
+static int hf_tapa_discover_req_value;
 
-static int hf_tapa_discover_newtlv_type = -1;
-static int hf_tapa_discover_newtlv_pad = -1;
-static int hf_tapa_discover_newtlv_length = -1;
-static int hf_tapa_discover_newtlv_valuetext = -1;
-static int hf_tapa_discover_newtlv_valuehex = -1;
+static int hf_tapa_discover_newtlv_type;
+static int hf_tapa_discover_newtlv_pad;
+static int hf_tapa_discover_newtlv_length;
+static int hf_tapa_discover_newtlv_valuetext;
+static int hf_tapa_discover_newtlv_valuehex;
 
-static int hf_tapa_discover_reply_switchip = -1;
-static int hf_tapa_discover_reply_unused = -1;
-static int hf_tapa_discover_reply_bias = -1;
-static int hf_tapa_discover_reply_pad = -1;
+static int hf_tapa_discover_reply_switchip;
+static int hf_tapa_discover_reply_unused;
+static int hf_tapa_discover_reply_bias;
+static int hf_tapa_discover_reply_pad;
 
-static int hf_tapa_tunnel_version = -1;
-static int hf_tapa_tunnel_five = -1;
-static int hf_tapa_tunnel_type = -1;
-static int hf_tapa_tunnel_zero = -1;
-static int hf_tapa_tunnel_dmac = -1;
-static int hf_tapa_tunnel_smac = -1;
-static int hf_tapa_tunnel_seqno = -1;
-static int hf_tapa_tunnel_length = -1;
-static int hf_tapa_tunnel_0804 = -1;
-static int hf_tapa_tunnel_tagsetc = -1;
+static int hf_tapa_tunnel_version;
+static int hf_tapa_tunnel_five;
+static int hf_tapa_tunnel_type;
+static int hf_tapa_tunnel_zero;
+static int hf_tapa_tunnel_dmac;
+static int hf_tapa_tunnel_smac;
+static int hf_tapa_tunnel_seqno;
+static int hf_tapa_tunnel_length;
+static int hf_tapa_tunnel_0804;
+static int hf_tapa_tunnel_tagsetc;
 
-static int hf_tapa_tunnel_remaining = -1;
+static int hf_tapa_tunnel_remaining;
 
-static expert_field ei_tapa_length_too_short = EI_INIT;
+static expert_field ei_tapa_length_too_short;
 
 static dissector_handle_t tapa_handle;
 
@@ -162,7 +150,7 @@ dissect_tapa_discover_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tapa_
 		ENC_BIG_ENDIAN);
 
 	col_append_fstr(pinfo->cinfo, COL_INFO, ", Switch: %s",
-			tvb_ip_to_str(tvb, offset));
+			tvb_ip_to_str(pinfo->pool, tvb, offset));
 
 	offset += 4;
 
@@ -195,7 +183,7 @@ dissect_tapa_discover_req(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tapa_di
 		item_type = tvb_get_guint8(tvb, offset);
 		item_type_text = val_to_str(item_type, tapa_discover_request_vals, "%d");
 		item_length = tvb_get_ntohs(tvb, offset + 2);
-		item_text = tvb_format_text(tvb, offset + 4, item_length);
+		item_text = tvb_format_text(pinfo->pool, tvb, offset + 4, item_length);
 
 		col_append_fstr(pinfo->cinfo, COL_INFO, ", %s: %s",
 				item_type_text, item_text);
@@ -262,7 +250,7 @@ dissect_tapa_discover_unknown_new_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_t
 
 		is_ascii = check_ascii(tvb, offset + 4, item_length);
 		if (is_ascii)
-			item_text = tvb_format_text(tvb, offset + 4, item_length);
+			item_text = tvb_format_text(pinfo->pool, tvb, offset + 4, item_length);
 		else
 			item_text = "BINARY-DATA";
 
@@ -272,7 +260,7 @@ dissect_tapa_discover_unknown_new_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_t
 
 		if (is_ascii)
 			proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_newtlv_valuetext,
-				tvb, offset, item_length, ENC_ASCII|ENC_NA);
+				tvb, offset, item_length, ENC_ASCII);
 		else
 			proto_tree_add_item(tapa_discover_item_tree, hf_tapa_discover_newtlv_valuehex,
 				tvb, offset, item_length, ENC_NA);
@@ -475,17 +463,17 @@ dissect_tapa_static(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *d
 }
 
 /* heuristic dissector */
-static gboolean
+static bool
 dissect_tapa_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *iph)
 {
 	/* The TAPA protocol also uses IP protocol number 4 but it isn't really IPIP */
 	if ((ws_ip_protocol(iph) == IP_PROTO_IPIP) && ((tvb_get_guint8(tvb, 0) & 0xF0) != 0x40) &&
 	    (tvb_get_ntohs(tvb, 2)) < 20) {
 		dissect_tapa_static(tvb, pinfo, tree, iph);
-		return TRUE;
+		return true;
 	}
 
-	return FALSE;
+	return false;
 }
 
 void
@@ -648,7 +636,7 @@ proto_reg_handoff_tapa(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
