@@ -18,13 +18,13 @@
 void proto_register_teap(void);
 void proto_reg_handoff_teap(void);
 
-static int proto_teap = -1;
+static int proto_teap;
 
-static gint ett_teap = -1;
-static gint ett_teap_tlv = -1;
-static gint ett_pac_attr_tlv = -1;
+static gint ett_teap;
+static gint ett_teap_tlv;
+static gint ett_pac_attr_tlv;
 
-static expert_field ei_teap_bad_length = EI_INIT;
+static expert_field ei_teap_bad_length;
 
 static dissector_handle_t teap_handle;
 
@@ -210,49 +210,53 @@ static const value_string pac_type_vals[] = {
    { 0, NULL }
  };
 
-static int hf_teap_tlv_mandatory = -1;
-static int hf_teap_tlv_reserved = -1;
-static int hf_teap_tlv_type = -1;
-static int hf_teap_tlv_len = -1;
-static int hf_teap_tlv_val = -1;
-static int hf_teap_auth_id = -1;
-static int hf_teap_identity = -1;
-static int hf_teap_status = -1;
-static int hf_teap_vendor_id = -1;
-static int hf_teap_request_action_status = -1;
-static int hf_teap_request_action_action = -1;
-static int hf_teap_crypto_reserved = -1;
-static int hf_teap_crypto_version = -1;
-static int hf_teap_crypto_rcv_version = -1;
-static int hf_teap_crypto_flags = -1;
-static int hf_teap_crypto_subtype = -1;
-static int hf_teap_crypto_nonce = -1;
-static int hf_teap_crypto_emsk = -1;
-static int hf_teap_crypto_msk = -1;
-static int hf_teap_nak_type = -1;
-static int hf_teap_error_code = -1;
-static int hf_teap_prompt = -1;
-static int hf_teap_user_len = -1;
-static int hf_teap_username = -1;
-static int hf_teap_pass_len = -1;
-static int hf_teap_password = -1;
+static int hf_teap_tlv_mandatory;
+static int hf_teap_tlv_reserved;
+static int hf_teap_tlv_type;
+static int hf_teap_tlv_len;
+static int hf_teap_tlv_val;
+static int hf_teap_auth_id;
+static int hf_teap_identity;
+static int hf_teap_status;
+static int hf_teap_vendor_id;
+static int hf_teap_request_action_status;
+static int hf_teap_request_action_action;
+static int hf_teap_crypto_reserved;
+static int hf_teap_crypto_version;
+static int hf_teap_crypto_rcv_version;
+static int hf_teap_crypto_flags;
+static int hf_teap_crypto_subtype;
+static int hf_teap_crypto_nonce;
+static int hf_teap_crypto_emsk;
+static int hf_teap_crypto_msk;
+static int hf_teap_nak_type;
+static int hf_teap_error_code;
+static int hf_teap_prompt;
+static int hf_teap_user_len;
+static int hf_teap_username;
+static int hf_teap_pass_len;
+static int hf_teap_password;
 
-static int hf_pac_attr_type = -1;
-static int hf_pac_attr_pac_key = -1;
-static int hf_pac_attr_pac_opaque = -1;
-static int hf_pac_attr_pac_lifetime = -1;
-static int hf_pac_attr_pac_a_id = -1;
-static int hf_pac_attr_pac_i_id = -1;
-static int hf_pac_attr_pac_reserved = -1;
-static int hf_pac_attr_pac_a_id_info = -1;
-static int hf_pac_attr_pac_result = -1;
-static int hf_pac_attr_pac_type = -1;
-static int hf_pac_attr_val = -1;
+static int hf_pac_attr_type;
+static int hf_pac_attr_pac_key;
+static int hf_pac_attr_pac_opaque;
+static int hf_pac_attr_pac_lifetime;
+static int hf_pac_attr_pac_a_id;
+static int hf_pac_attr_pac_i_id;
+static int hf_pac_attr_pac_reserved;
+static int hf_pac_attr_pac_a_id_info;
+static int hf_pac_attr_pac_result;
+static int hf_pac_attr_pac_type;
+static int hf_pac_attr_val;
+
+static int
+dissect_teap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_);
 
 static int
 dissect_teap_tlv_pac(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, guint16 len);
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_pac_attr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 {
   guint16 type;
@@ -327,17 +331,21 @@ dissect_pac_attr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset
 }
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_teap_tlv_pac(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, guint16 len)
 {
   int start_offset = offset;
 
+  increment_dissection_depth(pinfo);
   while (offset - start_offset < len) {
     offset += dissect_pac_attr(tvb, pinfo, tree, offset);
   }
+  decrement_dissection_depth(pinfo);
   return offset - start_offset;
 }
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_teap_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset, gboolean top)
 {
   int start_offset = offset;
@@ -387,6 +395,14 @@ dissect_teap_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset
       offset += 4;
       proto_tree_add_item(tlv_tree, hf_teap_nak_type, tvb, offset, 2, ENC_BIG_ENDIAN);
       offset += 2;
+
+      if (len > 6) {
+        next_tvb = tvb_new_subset_length(tvb, offset, len - 6);
+        increment_dissection_depth(pinfo);
+        offset += dissect_teap(next_tvb, pinfo, tlv_tree, NULL);
+        decrement_dissection_depth(pinfo);
+      }
+
       break;
 
     case TEAP_ERROR:
@@ -404,17 +420,38 @@ dissect_teap_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset
       offset += 1;
       proto_tree_add_item(tlv_tree, hf_teap_request_action_action, tvb, offset, 1, ENC_BIG_ENDIAN);
       offset += 1;
+
+      if (len > 2) {
+        next_tvb = tvb_new_subset_length(tvb, offset, len - 2);
+        offset += dissect_teap(next_tvb, pinfo, tlv_tree, NULL);
+      }
+
       break;
 
     case TEAP_EAP_PAYLOAD:
-      next_tvb = tvb_new_subset_length(tvb, offset, len);
+    {
+      guint16 eaplen = tvb_get_guint16(tvb, offset + 2, ENC_BIG_ENDIAN);
+
+      next_tvb = tvb_new_subset_length(tvb, offset, eaplen);
       call_dissector(eap_handle, next_tvb, pinfo, tlv_tree);
-      offset += len;
-      break;
+      offset += eaplen;
+
+      if (len > eaplen) {
+        next_tvb = tvb_new_subset_length(tvb, offset, len - eaplen);
+        offset += dissect_teap(next_tvb, pinfo, tlv_tree, NULL);
+      }
+    }
+    break;
 
     case TEAP_INTERMEDIATE_RESULT:
       proto_tree_add_item(tlv_tree, hf_teap_status, tvb, offset, 2, ENC_BIG_ENDIAN);
-      offset += len;
+      offset += 2;
+
+      if (len > 2) {
+        next_tvb = tvb_new_subset_length(tvb, offset, len - 2);
+        offset += dissect_teap(next_tvb, pinfo, tlv_tree, NULL);
+      }
+
       break;
 
     case TEAP_PAC:
@@ -488,6 +525,7 @@ dissect_teap_tlv(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset
 }
 
 static int
+// NOLINTNEXTLINE(misc-no-recursion)
 dissect_teap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
   proto_tree *ti;
