@@ -22,7 +22,7 @@
 
 #include <epan/packet.h>
 
-#include "packet-http.h"
+#include "packet-media-type.h"
 
 /*
  * Media dissector for line-based text media like text/plain, message/http.
@@ -33,10 +33,10 @@ void proto_register_text_lines(void);
 void proto_reg_handoff_text_lines(void);
 
 /* Filterable header fields */
-static gint proto_text_lines = -1;
+static gint proto_text_lines;
 
 /* Subtrees */
-static gint ett_text_lines = -1;
+static gint ett_text_lines;
 
 /* Dissector handles */
 static dissector_handle_t xml_handle;
@@ -48,7 +48,7 @@ dissect_text_lines(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* da
 	proto_item	*ti;
 	gint		offset = 0, next_offset;
 	gint		len;
-	http_message_info_t *message_info;
+	media_content_info_t *content_info;
 	const char	*data_name;
 	int length = tvb_captured_length(tvb);
 
@@ -68,14 +68,14 @@ dissect_text_lines(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* da
 		/*
 		 * No information from "match_string"
 		 */
-		message_info = (http_message_info_t *)data;
-		if (message_info == NULL) {
+		content_info = (media_content_info_t *)data;
+		if (content_info == NULL) {
 			/*
 			 * No information from dissector data
 			 */
 			data_name = NULL;
 		} else {
-			data_name = message_info->media_str;
+			data_name = content_info->media_str;
 			if (! (data_name && data_name[0])) {
 				/*
 				 * No information from dissector data
@@ -134,10 +134,7 @@ proto_register_text_lines(void)
 
 	proto_register_subtree_array(ett, array_length(ett));
 
-	proto_text_lines = proto_register_protocol(
-			"Line-based text data",	/* Long name */
-			"Line-based text data",	/* Short name */
-			"data-text-lines");		/* Filter name */
+	proto_text_lines = proto_register_protocol("Line-based text data", "Line-based text data", "data-text-lines");
 	register_dissector("data-text-lines", dissect_text_lines, proto_text_lines);
 }
 
