@@ -81,46 +81,46 @@ typedef struct _tftp_conv_info_t {
 } tftp_conv_info_t;
 
 
-static int proto_tftp = -1;
-static int hf_tftp_opcode = -1;
-static int hf_tftp_source_file = -1;
-static int hf_tftp_destination_file = -1;
-static int hf_tftp_request_frame = -1;
-static int hf_tftp_transfer_type = -1;
-static int hf_tftp_blocknum = -1;
-static int hf_tftp_full_blocknum = -1;
-static int hf_tftp_nextwindowsize = -1;
-static int hf_tftp_error_code = -1;
-static int hf_tftp_error_string = -1;
-static int hf_tftp_option_name = -1;
-static int hf_tftp_option_value = -1;
-static int hf_tftp_data = -1;
+static int proto_tftp;
+static int hf_tftp_opcode;
+static int hf_tftp_source_file;
+static int hf_tftp_destination_file;
+static int hf_tftp_request_frame;
+static int hf_tftp_transfer_type;
+static int hf_tftp_blocknum;
+static int hf_tftp_full_blocknum;
+static int hf_tftp_nextwindowsize;
+static int hf_tftp_error_code;
+static int hf_tftp_error_string;
+static int hf_tftp_option_name;
+static int hf_tftp_option_value;
+static int hf_tftp_data;
 
-static int hf_tftp_fragments = -1;
-static int hf_tftp_fragment = -1;
-static int hf_tftp_fragment_overlap = -1;
-static int hf_tftp_fragment_overlap_conflicts = -1;
-static int hf_tftp_fragment_multiple_tails = -1;
-static int hf_tftp_fragment_too_long_fragment = -1;
-static int hf_tftp_fragment_error = -1;
-static int hf_tftp_fragment_count = -1;
-static int hf_tftp_reassembled_in = -1;
-static int hf_tftp_reassembled_length = -1;
-static int hf_tftp_reassembled_data = -1;
+static int hf_tftp_fragments;
+static int hf_tftp_fragment;
+static int hf_tftp_fragment_overlap;
+static int hf_tftp_fragment_overlap_conflicts;
+static int hf_tftp_fragment_multiple_tails;
+static int hf_tftp_fragment_too_long_fragment;
+static int hf_tftp_fragment_error;
+static int hf_tftp_fragment_count;
+static int hf_tftp_reassembled_in;
+static int hf_tftp_reassembled_length;
+static int hf_tftp_reassembled_data;
 
-static gint ett_tftp = -1;
-static gint ett_tftp_option = -1;
+static gint ett_tftp;
+static gint ett_tftp_option;
 
-static gint ett_tftp_fragment = -1;
-static gint ett_tftp_fragments = -1;
+static gint ett_tftp_fragment;
+static gint ett_tftp_fragments;
 
-static expert_field ei_tftp_error = EI_INIT;
-static expert_field ei_tftp_likely_tsize_probe = EI_INIT;
-static expert_field ei_tftp_blocksize_range = EI_INIT;
-static expert_field ei_tftp_blocknum_will_wrap = EI_INIT;
-static expert_field ei_tftp_windowsize_range = EI_INIT;
-static expert_field ei_tftp_msftwindow_unrecognized = EI_INIT;
-static expert_field ei_tftp_windowsize_change = EI_INIT;
+static expert_field ei_tftp_error;
+static expert_field ei_tftp_likely_tsize_probe;
+static expert_field ei_tftp_blocksize_range;
+static expert_field ei_tftp_blocknum_will_wrap;
+static expert_field ei_tftp_windowsize_range;
+static expert_field ei_tftp_msftwindow_unrecognized;
+static expert_field ei_tftp_windowsize_change;
 
 #define LIKELY_TSIZE_PROBE_KEY 0
 #define FULL_BLOCKNUM_KEY 1
@@ -154,7 +154,7 @@ static const fragment_items tftp_frag_items = {
 void proto_reg_handoff_tftp (void);
 
 /* User definable values */
-static range_t *global_tftp_port_range = NULL;
+static range_t *global_tftp_port_range;
 
 /* minimum length is an ACK message of 4 bytes */
 #define MIN_HDR_LEN  4
@@ -205,10 +205,10 @@ static const value_string tftp_error_code_vals[] = {
   { 0, NULL }
 };
 
-static int tftp_eo_tap = -1;
+static int tftp_eo_tap;
 
 /* Preference setting - defragment fragmented TFTP files */
-static gboolean tftp_defragment = FALSE;
+static bool tftp_defragment;
 
 /* Used for TFTP Export Object feature */
 typedef struct _tftp_eo_t {
@@ -588,11 +588,22 @@ static void dissect_tftp_message(tftp_conv_info_t *tftp_info,
         tftp_info->is_simple_file            /* This is a simple file */
         && filename != NULL                  /* There is a file name */
         && !tftp_info->blocks_missing        /* No missing blocks */
-        && tftp_info->last_package_available /* Last package known */
+        && (tftp_info->last_package_available || !PINFO_FD_VISITED(pinfo))
+          /* If this is the first pass (i.e., this is tshark one-pass
+           * mode and we're tapping), then we can't know if the last
+           * block is present in the file yet. */
     ) {
 
-      if (blocknum == 1 && !tftp_info->payload_data) {
+      if (PINFO_FD_VISITED(pinfo)) {
+        if (blocknum == 1 && !tftp_info->payload_data) {
           tftp_info->payload_data = (guint8 *)g_try_malloc((gsize)tftp_info->file_length);
+        }
+      } else {
+        /* We allocate this in file scope so that it doesn't leak if it
+         * turns out we don't have all the blocks so we never send this
+         * to the tap.
+         */
+        tftp_info->payload_data = (guint8 *)wmem_realloc(wmem_file_scope(), tftp_info->payload_data, (gsize)tftp_info->file_length);
       }
 
       if (tftp_info->payload_data == NULL ||
@@ -759,7 +770,7 @@ tftp_info_for_conversation(conversation_t *conversation)
 }
 
 static gboolean
-is_valid_request_body(tvbuff_t *tvb)
+is_valid_request_body(tvbuff_t *tvb, packet_info *pinfo)
 {
   gint offset = 2;
   guint zeros_counter = 0;
@@ -777,7 +788,7 @@ is_valid_request_body(tvbuff_t *tvb)
 
   offset += tvb_strsize(tvb, offset);
   guint len = tvb_strsize(tvb, offset);
-  const gchar* mode = tvb_format_stringzpad(wmem_packet_scope(), tvb, offset, len);
+  const gchar* mode = tvb_format_stringzpad(pinfo->pool, tvb, offset, len);
 
   const gchar* modes[] = {"netascii", "octet", "mail"};
   for(guint i = 0; i < array_length(modes); ++i) {
@@ -788,14 +799,14 @@ is_valid_request_body(tvbuff_t *tvb)
 }
 
 static gboolean
-is_valid_request(tvbuff_t *tvb)
+is_valid_request(tvbuff_t *tvb, packet_info *pinfo)
 {
   if (tvb_captured_length(tvb) < MIN_HDR_LEN)
     return FALSE;
   guint16 opcode = tvb_get_ntohs(tvb, 0);
   if ((opcode != TFTP_RRQ) && (opcode != TFTP_WRQ))
     return FALSE;
-  return is_valid_request_body(tvb);
+  return is_valid_request_body(tvb, pinfo);
 }
 
 static conversation_t* create_tftp_conversation(packet_info *pinfo)
@@ -817,18 +828,18 @@ static conversation_t* create_tftp_conversation(packet_info *pinfo)
   return conversation;
 }
 
-static gboolean
+static bool
 dissect_tftp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
-  if (is_valid_request_body(tvb)) {
+  if (is_valid_request_body(tvb, pinfo)) {
     conversation_t* conversation = create_tftp_conversation(pinfo);
     dissect_tftp_message(tftp_info_for_conversation(conversation), tvb, pinfo, tree);
-    return TRUE;
+    return true;
   }
-  return FALSE;
+  return false;
 }
 
-static gboolean
+static bool
 dissect_embeddedtftp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
   /* Used to dissect TFTP packets where one can not assume
@@ -842,7 +853,7 @@ dissect_embeddedtftp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, v
    */
 
   if (tvb_captured_length(tvb) < MIN_HDR_LEN)
-    return FALSE;
+    return false;
 
   opcode = tvb_get_ntohs(tvb, 0);
 
@@ -850,8 +861,8 @@ dissect_embeddedtftp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, v
     case TFTP_RRQ:
     case TFTP_WRQ:
       /* These 2 opcodes have a NULL-terminated source file name after opcode. Verify */
-      if (!is_valid_request_body(tvb))
-        return FALSE;
+      if (!is_valid_request_body(tvb, pinfo))
+        return false;
      /* Intentionally dropping through here... */
     case TFTP_DATA:
     case TFTP_ACK:
@@ -872,16 +883,16 @@ dissect_embeddedtftp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, v
         case TFTP_ERR_OPT_FAIL:
           break;
         default:
-          return FALSE;
+          return false;
       }
       break;
     default:
-      return FALSE;
+      return false;
   }
 
   conversation = find_or_create_conversation(pinfo);
   dissect_tftp_message(tftp_info_for_conversation(conversation), tvb, pinfo, tree);
-  return TRUE;
+  return true;
 }
 
 static int
@@ -910,7 +921,7 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
    */
   if ((value_is_in_range(global_tftp_port_range, pinfo->destport) ||
        (pinfo->match_uint == pinfo->destport)) &&
-      is_valid_request(tvb))
+      is_valid_request(tvb, pinfo))
   {
     conversation = create_tftp_conversation(pinfo);
   }
@@ -1044,23 +1055,23 @@ proto_register_tftp(void)
 
     { &hf_tftp_fragment_overlap,
       { "Fragment overlap",        "tftp.fragment.overlap",
-        FT_BOOLEAN, 0, NULL, 0x00,
+        FT_BOOLEAN, BASE_NONE, NULL, 0x00,
         "Fragment overlaps with other fragments", HFILL }},
 
     { &hf_tftp_fragment_overlap_conflicts,
       { "Conflicting data in fragment overlap",
         "tftp.fragment.overlap.conflicts",
-        FT_BOOLEAN, 0, NULL, 0x00,
+        FT_BOOLEAN, BASE_NONE, NULL, 0x00,
         "Overlapping fragments contained conflicting data", HFILL }},
 
     { &hf_tftp_fragment_multiple_tails,
       { "Multiple tail fragments found",        "tftp.fragment.multipletails",
-        FT_BOOLEAN, 0, NULL, 0x00,
+        FT_BOOLEAN, BASE_NONE, NULL, 0x00,
         "Several tails were found when defragmenting the packet", HFILL }},
 
     { &hf_tftp_fragment_too_long_fragment,
       { "Fragment too long",        "tftp.fragment.toolongfragment",
-        FT_BOOLEAN, 0, NULL, 0x00,
+        FT_BOOLEAN, BASE_NONE, NULL, 0x00,
         "Fragment contained data past end of packet", HFILL }},
 
     { &hf_tftp_fragment_error,
@@ -1114,7 +1125,7 @@ proto_register_tftp(void)
   expert_tftp = expert_register_protocol(proto_tftp);
   expert_register_field_array(expert_tftp, ei, array_length(ei));
 
-  heur_subdissector_list = register_heur_dissector_list("tftp", proto_tftp);
+  heur_subdissector_list = register_heur_dissector_list_with_description("tftp", "TFTP payload", proto_tftp);
   reassembly_table_register(&tftp_reassembly_table, &addresses_ports_reassembly_table_functions);
 
   tftp_handle = register_dissector("tftp", dissect_tftp, proto_tftp);
