@@ -30,20 +30,20 @@ void proto_reg_handoff_tpkt(void);
 static heur_dissector_list_t tpkt_heur_subdissector_list;
 
 /* TPKT header fields             */
-static int proto_tpkt                = -1;
-static int proto_tpkt_heur           = -1;
+static int proto_tpkt;
+static int proto_tpkt_heur;
 static protocol_t *proto_tpkt_ptr;
-static int hf_tpkt_version           = -1;
-static int hf_tpkt_reserved          = -1;
-static int hf_tpkt_length            = -1;
-static int hf_tpkt_continuation_data = -1;
+static int hf_tpkt_version;
+static int hf_tpkt_reserved;
+static int hf_tpkt_length;
+static int hf_tpkt_continuation_data;
 
 
 /* TPKT fields defining a sub tree */
-static gint ett_tpkt           = -1;
+static gint ett_tpkt;
 
 /* desegmentation of OSI over TPKT over TCP */
-static gboolean tpkt_desegment = TRUE;
+static bool tpkt_desegment = true;
 
 #define TCP_PORT_TPKT_RANGE       "102"
 
@@ -592,7 +592,7 @@ dissect_ascii_tpkt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* da
  * or may not be present depending on the RDP security settings.
  */
 static int
-dissect_tpkt_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+dissect_tpkt_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     if (is_tpkt(tvb, 0) == -1) {
         /* Doesn't look like TPKT directly. Might be over TLS, so reject
@@ -604,6 +604,12 @@ dissect_tpkt_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *dat
     return dissect_tpkt(tvb, pinfo, tree, data);
 }
 
+static bool
+dissect_tpkt_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+{
+    return dissect_tpkt_tcp(tvb, pinfo, tree, data) > 0;
+}
+
 void
 proto_register_tpkt(void)
 {
@@ -613,7 +619,7 @@ proto_register_tpkt(void)
             {
                 "Version",
                 "tpkt.version",
-                FT_UINT8,
+                FT_UINT16,
                 BASE_DEC,
                 NULL,
                 0x0,
@@ -677,8 +683,8 @@ proto_register_tpkt(void)
         "To use this option, you must also enable \"Allow subdissectors to reassemble TCP streams\" in the TCP protocol settings.",
         &tpkt_desegment);
 
-    /* heuristic dissectors for premable CredSSP before RDP and Fast-Path RDP packets */
-    tpkt_heur_subdissector_list = register_heur_dissector_list("tpkt", proto_tpkt);
+    /* heuristic dissectors for preamble CredSSP before RDP and Fast-Path RDP packets */
+    tpkt_heur_subdissector_list = register_heur_dissector_list_with_description("tpkt", "TPKT fragment", proto_tpkt);
 
     proto_tpkt_heur = proto_register_protocol_in_name_only("TPKT Heuristic (for RDP)", "TPKT Heuristic (for RDP)", "tpkt", proto_tpkt, FT_PROTOCOL);
 }
@@ -697,7 +703,7 @@ proto_reg_handoff_tpkt(void)
      * if rejected the TLS heuristic dissector will be tried.
      */
     dissector_add_uint("tls.port", TCP_PORT_RDP, tpkt_handle);
-    dissector_add_uint("tcp.port", TCP_PORT_RDP, create_dissector_handle(dissect_tpkt_heur, proto_tpkt_heur));
+    dissector_add_uint("tcp.port", TCP_PORT_RDP, create_dissector_handle(dissect_tpkt_tcp, proto_tpkt_heur));
     heur_dissector_add("tcp", dissect_tpkt_heur, "TPKT over TCP", "tpkt_tcp", proto_tpkt, HEURISTIC_DISABLE);
 
     /*
