@@ -87,63 +87,63 @@ static dissector_handle_t twamp_test_handle;
 static dissector_handle_t twamp_control_handle;
 
 /* Protocol enabled flags */
-static int proto_owamp_test = -1;
-static int proto_twamp_test = -1;
-static int proto_twamp_control = -1;
-static gint ett_owamp_test = -1;
-static gint ett_twamp_test = -1;
-static gint ett_twamp_control = -1;
-static gint ett_twamp_error_estimate = -1;
+static int proto_owamp_test;
+static int proto_twamp_test;
+static int proto_twamp_control;
+static gint ett_owamp_test;
+static gint ett_twamp_test;
+static gint ett_twamp_control;
+static gint ett_twamp_error_estimate;
 
 /* Twamp test fields */
-static int hf_twamp_seq_number = -1;
-static int hf_twamp_sender_timestamp = -1;
-static int hf_twamp_error_estimate = -1;
-static int hf_twamp_mbz1 = -1;
-static int hf_twamp_receive_timestamp = -1;
-static int hf_twamp_sender_seq_number = -1;
-static int hf_twamp_timestamp = -1;
-static int hf_twamp_sender_error_estimate = -1;
-static int hf_twamp_mbz2 = -1;
-static int hf_twamp_sender_ttl = -1;
-static int hf_twamp_padding = -1;
-static int hf_twamp_error_estimate_multiplier = -1;
-static int hf_twamp_error_estimate_scale = -1;
-static int hf_twamp_error_estimate_b14 = -1;
-static int hf_twamp_error_estimate_b15 = -1;
+static int hf_twamp_seq_number;
+static int hf_twamp_sender_timestamp;
+static int hf_twamp_error_estimate;
+static int hf_twamp_mbz1;
+static int hf_twamp_receive_timestamp;
+static int hf_twamp_sender_seq_number;
+static int hf_twamp_timestamp;
+static int hf_twamp_sender_error_estimate;
+static int hf_twamp_mbz2;
+static int hf_twamp_sender_ttl;
+static int hf_twamp_padding;
+static int hf_twamp_error_estimate_multiplier;
+static int hf_twamp_error_estimate_scale;
+static int hf_twamp_error_estimate_b14;
+static int hf_twamp_error_estimate_b15;
 
 /* Twamp control fields */
-static int hf_twamp_control_unused = -1;
-static int hf_twamp_control_command = -1;
-static int hf_twamp_control_modes = -1;
-static int hf_twamp_control_mode = -1;
-static int hf_twamp_control_challenge = -1;
-static int hf_twamp_control_salt   = -1;
-static int hf_twamp_control_count  = -1;
-static int hf_twamp_control_keyid  = -1;
-static int hf_twamp_control_sessionid  = -1;
-static int hf_twamp_control_iv = -1;
-static int hf_twamp_control_ipvn = -1;
-static int hf_twamp_control_conf_sender = -1;
-static int hf_twamp_control_conf_receiver = -1;
-static int hf_twamp_control_number_of_schedule_slots = -1;
-static int hf_twamp_control_number_of_packets = -1;
-static int hf_twamp_control_start_time = -1;
-static int hf_twamp_control_accept = -1;
-static int hf_twamp_control_timeout = -1;
-static int hf_twamp_control_type_p = -1;
-static int hf_twamp_control_mbz1   = -1;
-static int hf_twamp_control_mbz2   = -1;
-static int hf_twamp_control_hmac   = -1;
-static int hf_twamp_control_num_sessions   = -1;
-static int hf_twamp_control_sender_port    = -1;
-static int hf_twamp_control_server_uptime  = -1;
-static int hf_twamp_control_receiver_port  = -1;
-static int hf_twamp_control_padding_length = -1;
-static int hf_twamp_control_sender_ipv4 = -1;
-static int hf_twamp_control_sender_ipv6 = -1;
-static int hf_twamp_control_receiver_ipv4 = -1;
-static int hf_twamp_control_receiver_ipv6 = -1;
+static int hf_twamp_control_unused;
+static int hf_twamp_control_command;
+static int hf_twamp_control_modes;
+static int hf_twamp_control_mode;
+static int hf_twamp_control_challenge;
+static int hf_twamp_control_salt;
+static int hf_twamp_control_count;
+static int hf_twamp_control_keyid;
+static int hf_twamp_control_sessionid;
+static int hf_twamp_control_iv;
+static int hf_twamp_control_ipvn;
+static int hf_twamp_control_conf_sender;
+static int hf_twamp_control_conf_receiver;
+static int hf_twamp_control_number_of_schedule_slots;
+static int hf_twamp_control_number_of_packets;
+static int hf_twamp_control_start_time;
+static int hf_twamp_control_accept;
+static int hf_twamp_control_timeout;
+static int hf_twamp_control_type_p;
+static int hf_twamp_control_mbz1;
+static int hf_twamp_control_mbz2;
+static int hf_twamp_control_hmac;
+static int hf_twamp_control_num_sessions;
+static int hf_twamp_control_sender_port;
+static int hf_twamp_control_server_uptime;
+static int hf_twamp_control_receiver_port;
+static int hf_twamp_control_padding_length;
+static int hf_twamp_control_sender_ipv4;
+static int hf_twamp_control_sender_ipv6;
+static int hf_twamp_control_receiver_ipv4;
+static int hf_twamp_control_receiver_ipv6;
 
 static const value_string twamp_control_accept_vals[] = {
     { 0, "OK" },
@@ -632,7 +632,7 @@ dissect_twamp_test(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *da
         proto_tree_add_item (twamp_tree, hf_twamp_sender_seq_number, tvb, offset, 4, ENC_BIG_ENDIAN);
         offset += 4;
 
-        if (tvb_get_ntohs(tvb, offset) & TWAMP_ERROR_ESTIMATE_ZBIT)
+        if (tvb_get_ntohs(tvb, offset + 8) & TWAMP_ERROR_ESTIMATE_ZBIT)
             proto_tree_add_item(twamp_tree, hf_twamp_sender_timestamp, tvb, offset, 8, ENC_TIME_NTP | ENC_BIG_ENDIAN);
         else
             proto_tree_add_item(twamp_tree, hf_twamp_sender_timestamp, tvb, offset, 8, ENC_TIME_SECS_NSECS | ENC_BIG_ENDIAN);
@@ -818,10 +818,7 @@ void proto_register_twamp(void)
 
 
     /* Register the protocol */
-    proto_twamp_test = proto_register_protocol(
-        "TwoWay Active Measurement Test Protocol",
-        "TWAMP-Test",
-        "twamp.test");
+    proto_twamp_test = proto_register_protocol("TwoWay Active Measurement Test Protocol", "TWAMP-Test", "twamp.test");
 
     /* Register the field array */
     proto_register_field_array (proto_twamp_test, hf_twamp_test,
@@ -831,11 +828,11 @@ void proto_register_twamp(void)
     proto_register_subtree_array (ett_twamp_test_arr,
                       array_length(ett_twamp_test_arr));
 
+    /* Register the dissector handle */
+    twamp_test_handle = register_dissector("twamp.test", dissect_twamp_test, proto_twamp_test);
+
     /* Register the protocol */
-    proto_twamp_control = proto_register_protocol(
-        "TwoWay Active Measurement Control Protocol",
-        "TWAMP-Control",
-        "twamp.control");
+    proto_twamp_control = proto_register_protocol("TwoWay Active Measurement Control Protocol", "TWAMP-Control", "twamp.control");
 
     /* Register the field array */
     proto_register_field_array (proto_twamp_control, hf_twamp_control,
@@ -845,20 +842,18 @@ void proto_register_twamp(void)
     proto_register_subtree_array (ett_twamp_control_arr,
                       array_length(ett_twamp_control_arr));
 
-    proto_owamp_test = proto_register_protocol(
-        "One-way Active Measurement Protocol",
-        "OWAMP-Test",
-        "owamp.test");
+    /* Register the dissector handle */
+    twamp_control_handle = register_dissector("twamp.control", dissect_twamp_server_greeting, proto_twamp_control);
 
+    /* Register the protocol */
+    proto_owamp_test = proto_register_protocol("One-way Active Measurement Protocol", "OWAMP-Test", "owamp.test");
+
+    /* Register the dissector handle */
+    owamp_test_handle = register_dissector("owamp.test", dissect_owamp_test, proto_owamp_test);
 }
 
 void proto_reg_handoff_twamp(void)
 {
-    twamp_test_handle = create_dissector_handle(dissect_twamp_test, proto_twamp_test);
-
-    owamp_test_handle = create_dissector_handle(dissect_owamp_test, proto_owamp_test);
-
-    twamp_control_handle = create_dissector_handle(dissect_twamp_server_greeting, proto_twamp_control);
     dissector_add_uint("tcp.port", TWAMP_CONTROL_PORT, twamp_control_handle);
 
     dissector_add_for_decode_as("udp.port", twamp_test_handle);
