@@ -27,36 +27,35 @@ void proto_reg_handoff_uasip(void);
 
 static tap_struct_uaudp ua_tap_info;
 #if 0
-static int uasip_tap                = -1;
+static int uasip_tap;
 #endif
 
-static int proto_uasip              = -1;
-static int hf_uasip_opcode          = -1;
-static int hf_uasip_version         = -1;
-static int hf_uasip_window_size     = -1;
-static int hf_uasip_mtu             = -1;
-static int hf_uasip_udp_lost        = -1;
-static int hf_uasip_udp_lost_reinit = -1;
-static int hf_uasip_keepalive       = -1;
-static int hf_uasip_qos_ip_tos      = -1;
-static int hf_uasip_qos_8021_vlid   = -1;
-static int hf_uasip_qos_8021_pri    = -1;
-static int hf_uasip_expseq          = -1;
-static int hf_uasip_sntseq          = -1;
-static int hf_uasip_type            = -1;
-static int hf_uasip_length          = -1;
+static int proto_uasip;
+static int hf_uasip_opcode;
+static int hf_uasip_version;
+static int hf_uasip_window_size;
+static int hf_uasip_mtu;
+static int hf_uasip_udp_lost;
+static int hf_uasip_udp_lost_reinit;
+static int hf_uasip_keepalive;
+static int hf_uasip_qos_ip_tos;
+static int hf_uasip_qos_8021_vlid;
+static int hf_uasip_qos_8021_pri;
+static int hf_uasip_expseq;
+static int hf_uasip_sntseq;
+static int hf_uasip_type;
+static int hf_uasip_length;
 
-static gint ett_uasip               = -1;
-static gint ett_uasip_tlv           = -1;
+static gint ett_uasip;
+static gint ett_uasip_tlv;
 
-static expert_field ei_uasip_tlv_length = EI_INIT;
+static expert_field ei_uasip_tlv_length;
 
 static guint8      proxy_ipaddr[4];
-static const char *pref_proxy_ipaddr_s = NULL;
+static const char *pref_proxy_ipaddr_s;
 
-static gboolean uasip_enabled = FALSE;
-static gboolean use_proxy_ipaddr = FALSE;
-static gboolean noesip_enabled   = FALSE;
+static gboolean use_proxy_ipaddr;
+static bool noesip_enabled;
 
 static dissector_handle_t uasip_handle;
 
@@ -87,7 +86,7 @@ static void _dissect_uasip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     ua_tap_info.expseq = 0;
     ua_tap_info.sntseq = 0;
 
-    col_add_fstr(pinfo->cinfo, COL_INFO, "%s", val_to_str_ext(opcode, &uaudp_opcode_str_ext, "unknown (0x%02x)"));
+    col_add_str(pinfo->cinfo, COL_INFO, val_to_str_ext(opcode, &uaudp_opcode_str_ext, "unknown (0x%02x)"));
 
     uasip_item = proto_tree_add_protocol_format(tree, proto_uasip, tvb, 0, 5,
                                                 "SIP/NOE Protocol, %s",
@@ -519,7 +518,7 @@ void proto_register_uasip(void)
     expert_register_field_array(expert_uasip, ei, array_length(ei));
 
     uasip_module = prefs_register_protocol(proto_uasip, proto_reg_handoff_uasip);
-    prefs_register_bool_preference(uasip_module, "aplication_octet_stream", "Try to decode application/octet-stream as UASIP", "UA SIP Protocol enabled", &uasip_enabled);
+    prefs_register_obsolete_preference(uasip_module, "application_octet_stream");
     prefs_register_bool_preference(uasip_module, "noesip", "Try to decode SIP NOE", "NOE SIP Protocol", &noesip_enabled);
     prefs_register_string_preference(uasip_module, "proxy_ipaddr", "Proxy IP Address",
                                      "IPv4 address of the proxy (Invalid values will be ignored)",
@@ -537,18 +536,16 @@ void proto_reg_handoff_uasip(void)
     {
         ua_sys_to_term_handle = find_dissector_add_dependency("ua_sys_to_term", proto_uasip);
         ua_term_to_sys_handle = find_dissector_add_dependency("ua_term_to_sys", proto_uasip);
+
+        /* Enable decoding "Internet media type" as UASIP */
+        dissector_add_for_decode_as("media_type", uasip_handle);
+
         prefs_initialized = TRUE;
     }
 
     use_proxy_ipaddr = FALSE;
     memset(proxy_ipaddr, 0, sizeof(proxy_ipaddr));
 
-    if(uasip_enabled){
-        dissector_add_string("media_type", "application/octet-stream", uasip_handle);
-    }else{
-        dissector_delete_string("media_type", "application/octet-stream", uasip_handle);
-    }
-
     if (strcmp(pref_proxy_ipaddr_s, "") != 0) {
         if (str_to_ip(pref_proxy_ipaddr_s, proxy_ipaddr)) {
             use_proxy_ipaddr = TRUE;
@@ -559,7 +556,7 @@ void proto_reg_handoff_uasip(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
