@@ -16,6 +16,7 @@
 #include <epan/prefs.h>
 #include <epan/expert.h>
 #include <wsutil/report_message.h>
+#include <wsutil/inet_addr.h>
 
 #include "packet-uaudp.h"
 
@@ -26,40 +27,40 @@ void proto_reg_handoff_uaudp(void);
 
 static dissector_handle_t uaudp_handle;
 
-static int proto_uaudp              = -1;
+static int proto_uaudp;
 
-static int hf_uaudp_opcode          = -1;
-static int hf_uaudp_version         = -1;
-static int hf_uaudp_window_size     = -1;
-static int hf_uaudp_mtu             = -1;
-static int hf_uaudp_udp_lost        = -1;
-static int hf_uaudp_udp_lost_reinit = -1;
-static int hf_uaudp_keepalive       = -1;
-static int hf_uaudp_qos_ip_tos      = -1;
-static int hf_uaudp_qos_8021_vlid   = -1;
-static int hf_uaudp_qos_8021_pri    = -1;
-static int hf_uaudp_superfast_connect = -1;
-static int hf_uaudp_expseq          = -1;
-static int hf_uaudp_sntseq          = -1;
-static int hf_uaudp_type            = -1;
-static int hf_uaudp_length          = -1;
-static int hf_uaudp_startsig_reserved = -1;
-static int hf_uaudp_startsig_filename = -1;
+static int hf_uaudp_opcode;
+static int hf_uaudp_version;
+static int hf_uaudp_window_size;
+static int hf_uaudp_mtu;
+static int hf_uaudp_udp_lost;
+static int hf_uaudp_udp_lost_reinit;
+static int hf_uaudp_keepalive;
+static int hf_uaudp_qos_ip_tos;
+static int hf_uaudp_qos_8021_vlid;
+static int hf_uaudp_qos_8021_pri;
+static int hf_uaudp_superfast_connect;
+static int hf_uaudp_expseq;
+static int hf_uaudp_sntseq;
+static int hf_uaudp_type;
+static int hf_uaudp_length;
+static int hf_uaudp_startsig_reserved;
+static int hf_uaudp_startsig_filename;
 
-static gint ett_uaudp               = -1;
-static gint ett_uaudp_tlv           = -1;
+static gint ett_uaudp;
+static gint ett_uaudp_tlv;
 
-static expert_field ei_uaudp_tlv_length = EI_INIT;
+static expert_field ei_uaudp_tlv_length;
 
 /* pref */
 #define UAUDP_PORT_RANGE "32000,32512" /* Not IANA registered */
-static range_t *ua_udp_range = NULL;
+static range_t *ua_udp_range;
 static address cs_address = ADDRESS_INIT_NONE;
 static ws_in4_addr cs_ipv4;
 static ws_in6_addr cs_ipv6;
 static const char* pref_sys_ip_s = "";
 
-static gboolean use_sys_ip = FALSE;
+static gboolean use_sys_ip;
 
 static const value_string uaudp_opcode_str[] =
 {
@@ -252,7 +253,7 @@ static void _dissect_uaudp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     {
         proto_tree_add_item(uaudp_tree, hf_uaudp_startsig_reserved, tvb, offset, 6, ENC_NA);
         offset += 6;
-        proto_tree_add_item(uaudp_tree, hf_uaudp_startsig_filename, tvb, offset, tvb_strsize(tvb, offset)-1, ENC_ASCII|ENC_NA);
+        proto_tree_add_item(uaudp_tree, hf_uaudp_startsig_filename, tvb, offset, tvb_strsize(tvb, offset)-1, ENC_ASCII);
         break;
     }
 
@@ -588,7 +589,7 @@ void proto_reg_handoff_uaudp(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
