@@ -52,50 +52,52 @@ struct uavcan_proto_data
 void proto_register_uavcan(void);
 void proto_reg_handoff_uavcan(void);
 
-static int proto_uavcan = -1;
+static dissector_handle_t uavcan_handle;
 
-static int hf_uavcan_can_id = -1;
-static int hf_uavcan_priority = -1;
-static int hf_uavcan_anonymous = -1;
-static int hf_uavcan_req_not_rsp = -1;
-static int hf_uavcan_serv_not_msg = -1;
-static int hf_uavcan_subject_id = -1;
-static int hf_uavcan_service_id = -1;
-static int hf_uavcan_dst_addr = -1;
-static int hf_uavcan_src_addr = -1;
-static int hf_uavcan_data = -1;
-static int hf_uavcan_start_of_transfer = -1;
-static int hf_uavcan_end_of_transfer = -1;
-static int hf_uavcan_toggle = -1;
-static int hf_uavcan_transfer_id = -1;
+static int proto_uavcan;
+
+static int hf_uavcan_can_id;
+static int hf_uavcan_priority;
+static int hf_uavcan_anonymous;
+static int hf_uavcan_req_not_rsp;
+static int hf_uavcan_serv_not_msg;
+static int hf_uavcan_subject_id;
+static int hf_uavcan_service_id;
+static int hf_uavcan_dst_addr;
+static int hf_uavcan_src_addr;
+static int hf_uavcan_data;
+static int hf_uavcan_start_of_transfer;
+static int hf_uavcan_end_of_transfer;
+static int hf_uavcan_toggle;
+static int hf_uavcan_transfer_id;
 
 static int uavcan_address_type = -1;
 
-static wmem_tree_t *fragment_info_table = NULL;
+static wmem_tree_t *fragment_info_table;
 
 static reassembly_table uavcan_reassembly_table;
 
-static int hf_uavcan_packet_crc = -1;
+static int hf_uavcan_packet_crc;
 
-static gint ett_uavcan = -1;
-static gint ett_uavcan_can = -1;
-static gint ett_uavcan_message = -1;
+static gint ett_uavcan;
+static gint ett_uavcan_can;
+static gint ett_uavcan_message;
 
-static expert_field ei_uavcan_toggle_bit_error = EI_INIT;
-static expert_field ei_uavcan_transfer_crc_error = EI_INIT;
+static expert_field ei_uavcan_toggle_bit_error;
+static expert_field ei_uavcan_transfer_crc_error;
 
-static gint ett_uavcan_fragment = -1;
-static gint ett_uavcan_fragments = -1;
-static int hf_uavcan_fragments = -1;
-static int hf_uavcan_fragment = -1;
-static int hf_uavcan_fragment_overlap = -1;
-static int hf_uavcan_fragment_overlap_conflicts = -1;
-static int hf_uavcan_fragment_multiple_tails = -1;
-static int hf_uavcan_fragment_too_long_fragment = -1;
-static int hf_uavcan_fragment_error = -1;
-static int hf_uavcan_fragment_count = -1;
-static int hf_uavcan_reassembled_in = -1;
-static int hf_uavcan_reassembled_length = -1;
+static gint ett_uavcan_fragment;
+static gint ett_uavcan_fragments;
+static int hf_uavcan_fragments;
+static int hf_uavcan_fragment;
+static int hf_uavcan_fragment_overlap;
+static int hf_uavcan_fragment_overlap_conflicts;
+static int hf_uavcan_fragment_multiple_tails;
+static int hf_uavcan_fragment_too_long_fragment;
+static int hf_uavcan_fragment_error;
+static int hf_uavcan_fragment_count;
+static int hf_uavcan_reassembled_in;
+static int hf_uavcan_reassembled_length;
 
 /* fragment struct to store packet assembly data */
 typedef struct _fragment_info_t
@@ -105,7 +107,7 @@ typedef struct _fragment_info_t
     guint32 seq_id;
 } fragment_info_t;
 
-guint32 uavcan_seq_id = 0;
+guint32 uavcan_seq_id;
 
 static const fragment_items uavcan_frag_items = {
     /* Fragment subtrees */
@@ -460,9 +462,9 @@ UAVCAN_addr_to_str(const address *addr, gchar *buf, int buf_len)
     const guint16 *addrdata = (const guint16 *) addr->data;
 
     if ((*addrdata & ANONYMOUS_FLAG) != 0) {
-        return (int) g_snprintf(buf, buf_len, "Anonymous");
+        return (int) snprintf(buf, buf_len, "Anonymous");
     } else if ((*addrdata & BROADCAST_FLAG) != 0) {
-        return (int) g_snprintf(buf, buf_len, "Broadcast");
+        return (int) snprintf(buf, buf_len, "Broadcast");
     } else {
         guint8 real_addr = (guint8) (*addrdata & ADDR_MASK);
         guint32_to_str_buf(real_addr, buf, buf_len);
@@ -477,7 +479,7 @@ UAVCAN_addr_str_len(const address *addr _U_)
 }
 
 static const char *
-UAVCAN_col_filter_str(const address *addr _U_, gboolean is_src)
+UAVCAN_col_filter_str(const address *addr _U_, bool is_src)
 {
     if (is_src)
         return "uavcan_can.src_addr";
@@ -622,6 +624,8 @@ proto_register_uavcan(void)
     proto_register_field_array(proto_uavcan, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
 
+    uavcan_handle = register_dissector("uavcan_can", dissect_uavcan, proto_uavcan);
+
     expert_uavcan = expert_register_protocol(proto_uavcan);
     expert_register_field_array(expert_uavcan, ei, array_length(ei));
 
@@ -634,10 +638,6 @@ proto_register_uavcan(void)
 void
 proto_reg_handoff_uavcan(void)
 {
-    dissector_handle_t uavcan_handle;
-
-    uavcan_handle = create_dissector_handle(dissect_uavcan, proto_uavcan);
-
     dsdl_message_handle = find_dissector_add_dependency("uavcan_dsdl.message", proto_uavcan);
     dsdl_request_handle = find_dissector_add_dependency("uavcan_dsdl.request", proto_uavcan);
     dsdl_response_handle = find_dissector_add_dependency("uavcan_dsdl.response", proto_uavcan);
