@@ -180,85 +180,85 @@ void proto_register_uci(void);
 #define UCI_APP_CONFIG_NB_OF_AZIMUTH_MEASUREMENTS 0xE4
 #define UCI_APP_CONFIG_NB_OF_ELEVATION_MEASUREMENTS 0xE5
 
-static gboolean gPREF_TCP_DESEGMENT = TRUE;
+static bool gPREF_TCP_DESEGMENT = true;
 static guint gPREF_TCP_PORT = 7000;
 
-static int proto_uci = -1;
-static dissector_handle_t handle_uci = NULL;
+static int proto_uci;
+static dissector_handle_t handle_uci;
 
-static int hf_uci_message_type = -1;
-static int hf_uci_packet_boundary_flag = -1;
-static int hf_uci_group_id = -1;
-static int hf_uci_opcode_id = -1;
-static int hf_uci_payload_length = -1;
-static int hf_uci_status = -1;
-static int hf_uci_reset_config = -1;
-static int hf_uci_device_state = -1;
-static int hf_uci_generic_version = -1;
-static int hf_uci_version_major = -1;
-static int hf_uci_version_minor = -1;
-static int hf_uci_maintenance_number = -1;
-static int hf_uci_mac_version = -1;
-static int hf_uci_phy_version = -1;
-static int hf_uci_test_version = -1;
-static int hf_uci_vendor_specific_information_length = -1;
-static int hf_uci_vendor_specific_information = -1;
-static int hf_uci_capability_parameters_count = -1;
-static int hf_uci_capability_parameter_type = -1;
-static int hf_uci_capability_parameter_len = -1;
-static int hf_uci_capability_parameter_value = -1;
-static int hf_uci_parameters_count = -1;
-static int hf_uci_parameter_type = -1;
-static int hf_uci_parameter_len = -1;
-static int hf_uci_parameter_value = -1;
-static int hf_uci_parameter_status = -1;
-static int hf_uci_session_id = -1;
-static int hf_uci_session_type = -1;
-static int hf_uci_session_state = -1;
-static int hf_uci_session_count = -1;
-static int hf_uci_app_config_parameters_count = -1;
-static int hf_uci_app_config_parameter_type = -1;
-static int hf_uci_app_config_parameter_len = -1;
-static int hf_uci_app_config_parameter_value = -1;
-static int hf_uci_app_config_parameter_status = -1;
-static int hf_uci_update_controller_multicast_list_action = -1;
-static int hf_uci_controlees_count = -1;
-static int hf_uci_controlee_short_address = -1;
-static int hf_uci_controlee_subsession_id = -1;
-static int hf_uci_controlee_status = -1;
-static int hf_uci_remaining_multicast_list_size = -1;
-static int hf_uci_ranging_count = -1;
-static int hf_uci_sequence_number = -1;
-static int hf_uci_current_ranging_interval = -1;
-static int hf_uci_ranging_measurement_type = -1;
-static int hf_uci_mac_addressing_mode_indicator = -1;
-static int hf_uci_ranging_measurement_count = -1;
-static int hf_uci_mac_address = -1;
-static int hf_uci_nlos = -1;
-static int hf_uci_distance = -1;
-static int hf_uci_aoa_azimuth = -1;
-static int hf_uci_aoa_azimuth_fom = -1;
-static int hf_uci_aoa_elevation = -1;
-static int hf_uci_aoa_elevation_fom = -1;
-static int hf_uci_aoa_destination_azimuth = -1;
-static int hf_uci_aoa_destination_azimuth_fom = -1;
-static int hf_uci_aoa_destination_elevation = -1;
-static int hf_uci_aoa_destination_elevation_fom = -1;
-static int hf_uci_slot_index = -1;
+static int hf_uci_message_type;
+static int hf_uci_packet_boundary_flag;
+static int hf_uci_group_id;
+static int hf_uci_opcode_id;
+static int hf_uci_payload_length;
+static int hf_uci_status;
+static int hf_uci_reset_config;
+static int hf_uci_device_state;
+static int hf_uci_generic_version;
+static int hf_uci_version_major;
+static int hf_uci_version_minor;
+static int hf_uci_maintenance_number;
+static int hf_uci_mac_version;
+static int hf_uci_phy_version;
+static int hf_uci_test_version;
+static int hf_uci_vendor_specific_information_length;
+static int hf_uci_vendor_specific_information;
+static int hf_uci_capability_parameters_count;
+static int hf_uci_capability_parameter_type;
+static int hf_uci_capability_parameter_len;
+static int hf_uci_capability_parameter_value;
+static int hf_uci_parameters_count;
+static int hf_uci_parameter_type;
+static int hf_uci_parameter_len;
+static int hf_uci_parameter_value;
+static int hf_uci_parameter_status;
+static int hf_uci_session_id;
+static int hf_uci_session_type;
+static int hf_uci_session_state;
+static int hf_uci_session_count;
+static int hf_uci_app_config_parameters_count;
+static int hf_uci_app_config_parameter_type;
+static int hf_uci_app_config_parameter_len;
+static int hf_uci_app_config_parameter_value;
+static int hf_uci_app_config_parameter_status;
+static int hf_uci_update_controller_multicast_list_action;
+static int hf_uci_controlees_count;
+static int hf_uci_controlee_short_address;
+static int hf_uci_controlee_subsession_id;
+static int hf_uci_controlee_status;
+static int hf_uci_remaining_multicast_list_size;
+static int hf_uci_ranging_count;
+static int hf_uci_sequence_number;
+static int hf_uci_current_ranging_interval;
+static int hf_uci_ranging_measurement_type;
+static int hf_uci_mac_addressing_mode_indicator;
+static int hf_uci_ranging_measurement_count;
+static int hf_uci_mac_address;
+static int hf_uci_nlos;
+static int hf_uci_distance;
+static int hf_uci_aoa_azimuth;
+static int hf_uci_aoa_azimuth_fom;
+static int hf_uci_aoa_elevation;
+static int hf_uci_aoa_elevation_fom;
+static int hf_uci_aoa_destination_azimuth;
+static int hf_uci_aoa_destination_azimuth_fom;
+static int hf_uci_aoa_destination_elevation;
+static int hf_uci_aoa_destination_elevation_fom;
+static int hf_uci_slot_index;
 
-static gint ett_uci = -1;
-static gint ett_uci_header = -1;
-static gint ett_uci_payload = -1;
-static gint ett_uci_capability_parameters = -1;
-static gint ett_uci_capability_parameter = -1;
-static gint ett_uci_parameters = -1;
-static gint ett_uci_parameter = -1;
-static gint ett_uci_app_config_parameters = -1;
-static gint ett_uci_app_config_parameter = -1;
-static gint ett_uci_controlee_list = -1;
-static gint ett_uci_controlee = -1;
-static gint ett_uci_ranging_measurements = -1;
-static gint ett_uci_ranging_measurement = -1;
+static gint ett_uci;
+static gint ett_uci_header;
+static gint ett_uci_payload;
+static gint ett_uci_capability_parameters;
+static gint ett_uci_capability_parameter;
+static gint ett_uci_parameters;
+static gint ett_uci_parameter;
+static gint ett_uci_app_config_parameters;
+static gint ett_uci_app_config_parameter;
+static gint ett_uci_controlee_list;
+static gint ett_uci_controlee;
+static gint ett_uci_ranging_measurements;
+static gint ett_uci_ranging_measurement;
 
 static const value_string message_type_vals[] = {
     { UCI_MT_COMMAND, "Command" },
@@ -1112,7 +1112,7 @@ static void dissect_uci_session_config_pdu(tvbuff_t *tvb, int offset, packet_inf
         opcode_id == UCI_OID_SESSION_UPDATE_CONTROLLER_MULTICAST_LIST) {
         dissect_session_update_controller_multicast_list_rsp(tvb, offset, pinfo, payload_tree);
     }
-    else if (message_type == UCI_MT_RESPONSE &&
+    else if (message_type == UCI_MT_NOTIFICATION &&
         opcode_id == UCI_OID_SESSION_UPDATE_CONTROLLER_MULTICAST_LIST) {
         dissect_session_update_controller_multicast_list_ntf(tvb, offset, pinfo, payload_tree);
     }
