@@ -20,7 +20,7 @@
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/expert.h>
-#include <epan/wmem/wmem.h>
+#include <epan/wmem_scopes.h>
 
 /*
  * Per-conversation information
@@ -76,37 +76,37 @@ static const value_string udt_types[] = {
 	{0, NULL},
 };
 
-static int proto_udt = -1;
-static int hf_udt_iscontrol = -1;
-static int hf_udt_type = -1;
-static int hf_udt_seqno = -1;
-static int hf_udt_ack_seqno = -1;
-static int hf_udt_ackno = -1;
-static int hf_udt_msgno = -1;
-static int hf_udt_msgno_first = -1;
-static int hf_udt_msgno_last = -1;
-static int hf_udt_msgno_inorder = -1;
-static int hf_udt_timestamp = -1;
-static int hf_udt_id = -1;
-static int hf_udt_addinfo = -1;
-static int hf_udt_rtt = -1;
-static int hf_udt_rttvar = -1;
-static int hf_udt_bufavail = -1;
-static int hf_udt_rate = -1;
-static int hf_udt_linkcap = -1;
-static int hf_udt_handshake_version = -1;
-static int hf_udt_handshake_type = -1;
-static int hf_udt_handshake_isn = -1;
-static int hf_udt_handshake_mtu = -1;
-static int hf_udt_handshake_flow_window = -1;
-static int hf_udt_handshake_reqtype = -1;
-static int hf_udt_handshake_id = -1;
-static int hf_udt_handshake_cookie = -1;
-static int hf_udt_handshake_peerip = -1;
+static int proto_udt;
+static int hf_udt_iscontrol;
+static int hf_udt_type;
+static int hf_udt_seqno;
+static int hf_udt_ack_seqno;
+static int hf_udt_ackno;
+static int hf_udt_msgno;
+static int hf_udt_msgno_first;
+static int hf_udt_msgno_last;
+static int hf_udt_msgno_inorder;
+static int hf_udt_timestamp;
+static int hf_udt_id;
+static int hf_udt_addinfo;
+static int hf_udt_rtt;
+static int hf_udt_rttvar;
+static int hf_udt_bufavail;
+static int hf_udt_rate;
+static int hf_udt_linkcap;
+static int hf_udt_handshake_version;
+static int hf_udt_handshake_type;
+static int hf_udt_handshake_isn;
+static int hf_udt_handshake_mtu;
+static int hf_udt_handshake_flow_window;
+static int hf_udt_handshake_reqtype;
+static int hf_udt_handshake_id;
+static int hf_udt_handshake_cookie;
+static int hf_udt_handshake_peerip;
 
-static gint ett_udt = -1;
+static gint ett_udt;
 
-static expert_field ei_udt_nak_seqno = EI_INIT;
+static expert_field ei_udt_nak_seqno;
 
 static dissector_handle_t udt_handle;
 
@@ -153,7 +153,7 @@ dissect_udt(tvbuff_t *tvb, packet_info* pinfo, proto_tree *parent_tree,
 			col_add_fstr(pinfo->cinfo, COL_INFO, "UDT type: ack2");
 			break;
 		case UDT_PACKET_TYPE_NAK: {
-			wmem_strbuf_t *nakstr = wmem_strbuf_new(wmem_packet_scope(), "");
+			wmem_strbuf_t *nakstr = wmem_strbuf_new(pinfo->pool, "");
 			guint max = tvb_reported_length(tvb);
 			if (max > UDT_MAX_NAK_LENGTH)
 			    max = UDT_MAX_NAK_LENGTH;
@@ -370,7 +370,7 @@ dissect_udt(tvbuff_t *tvb, packet_info* pinfo, proto_tree *parent_tree,
 	return tvb_reported_length(tvb);
 }
 
-static gboolean
+static bool
 dissect_udt_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data, gboolean is_dtls)
 {
 	conversation_t *conv;
@@ -383,27 +383,27 @@ dissect_udt_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data
 		// Already identified conversation as UDT - BUT we might have been called from
 		// the other dissector.
 		if (is_dtls != udt_conv->is_dtls)
-			return FALSE;
+			return false;
 		dissect_udt(tvb, pinfo, tree, data);
 	} else {
 		// Check if this is UDT...
 
 		/* Must have at least 24 captured bytes for heuristic check */
 		if (tvb_captured_length(tvb) < 24)
-			return FALSE;
+			return false;
 
 		/* detect handshake control packet */
 		if (tvb_get_ntohl(tvb, 0) != (0x80000000 | UDT_PACKET_TYPE_HANDSHAKE))
-			return FALSE;
+			return false;
 
 		/* must be version 4 */
 		if ((tvb_get_ntohl(tvb, 16) != 4))
-			return FALSE;
+			return false;
 
 		/* must be datagram or stream */
 		if ((tvb_get_ntohl(tvb, 20) != UDT_HANDSHAKE_TYPE_DGRAM)
 		    && (tvb_get_ntohl(tvb, 20) != UDT_HANDSHAKE_TYPE_STREAM))
-			return FALSE;
+			return false;
 
 		/* This looks like UDT! */
 		udt_conv = wmem_new0(wmem_file_scope(), udt_conversation);
@@ -418,16 +418,16 @@ dissect_udt_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data
 
 		dissect_udt(tvb, pinfo, tree, data);
 	}
-	return TRUE;
+	return true;
 }
 
-static gboolean
+static bool
 dissect_udt_heur_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
 	return dissect_udt_heur(tvb, pinfo, tree, data, FALSE /* Not DTLS */);
 }
 
-static gboolean
+static bool
 dissect_udt_heur_dtls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
 	return dissect_udt_heur(tvb, pinfo, tree, data, TRUE /* Is DTLS */);
@@ -587,15 +587,13 @@ void proto_register_udt(void)
 	expert_udt = expert_register_protocol(proto_udt);
 	expert_register_field_array(expert_udt, ei, array_length(ei));
 
-	register_dissector("udt", dissect_udt, proto_udt);
+	udt_handle = register_dissector("udt", dissect_udt, proto_udt);
 
-	heur_subdissector_list = register_heur_dissector_list("udt", proto_udt);
+	heur_subdissector_list = register_heur_dissector_list_with_description("udt", "UDT data", proto_udt);
 }
 
 void proto_reg_handoff_udt(void)
 {
-	udt_handle  = create_dissector_handle(dissect_udt, proto_udt);
-
 	heur_dissector_add("udp", dissect_udt_heur_udp, "UDT over UDP", "udt_udp", proto_udt, HEURISTIC_ENABLE);
 	heur_dissector_add("dtls", dissect_udt_heur_dtls, "UDT over DTLS", "udt_dtls", proto_udt, HEURISTIC_ENABLE);
 	dissector_add_for_decode_as_with_preference("udp.port", udt_handle);
