@@ -58,7 +58,7 @@ void proto_reg_handoff_uma(void);
 
 /* Length field is 2 bytes and comes first */
 #define UMA_HEADER_SIZE 2
-static gboolean uma_desegment = TRUE;
+static bool uma_desegment = true;
 
 static dissector_handle_t uma_tcp_handle;
 static dissector_handle_t uma_udp_handle;
@@ -67,120 +67,120 @@ static dissector_handle_t rtcp_handle;
 static dissector_handle_t llc_handle;
 
 /* Initialize the protocol and registered fields */
-static int proto_uma					= -1;
-static int hf_uma_length_indicator			= -1;
-static int hf_uma_pd					= -1;
-static int hf_uma_skip_ind				= -1;
-static int hf_uma_urr_msg_type				= -1;
-static int hf_uma_urlc_msg_type				= -1;
-static int hf_uma_urlc_TLLI				= -1;
-static int hf_uma_urlc_seq_nr				= -1;
-static int hf_uma_urr_IE				= -1;
-static int hf_uma_urr_IE_len				= -1;
-static int hf_uma_urr_uri				= -1;
-static int hf_uma_urr_radio_type_of_id			= -1;
-static int hf_uma_urr_radio_id				= -1;
-static int hf_uma_urr_cell_id				= -1;
-static int hf_uma_urr_lac				= -1;
-static int hf_uma_urr_gci				= -1;
-static int hf_uma_urr_tura				= -1;
-static int hf_uma_urr_gc				= -1;
-static int hf_uma_urr_uc				= -1;
-static int hf_uma_urr_rrs				= -1;
-static int hf_uma_urr_gmsi				= -1;
-static int hf_uma_urr_psho				= -1;
-static int hf_uma_urr_IP_Address_type			= -1;
-static int hf_uma_urr_FQDN				= -1;
-static int hf_uma_urr_sgw_ipv4				= -1;
-static int hf_uma_urr_redirection_counter		= -1;
-static int hf_uma_urr_dis_rej_cau			= -1;
-static int hf_uma_urr_MSCR				= -1;
-static int hf_uma_urr_ATT				= -1;
-static int hf_uma_urr_DTM				= -1;
-static int hf_uma_urr_GPRS				= -1;
-static int hf_uma_urr_NMO				= -1;
-static int hf_uma_urr_ECMC				= -1;
-static int hf_uma_urr_T3212_timer			= -1;
-static int hf_uma_urr_RAC				= -1;
-static int hf_uma_urr_ap_location			= -1;
-static int hf_uma_urr_SGSNR				= -1;
-static int hf_uma_urr_ECMP				= -1;
-static int hf_uma_urr_RE				= -1;
-static int hf_uma_urr_PFCFM				= -1;
-static int hf_uma_urr_3GECS				= -1;
-static int hf_uma_urr_TU3907_timer			= -1;
-static int hf_uma_urr_GSM_RR_state			= -1;
-static int hf_uma_urr_gan_band				= -1;
-static int hf_uma_urr_URR_state				= -1;
-static int hf_uma_urr_register_reject_cause 		= -1;
-static int hf_uma_urr_TU3906_timer			= -1;
-static int hf_uma_urr_TU3910_timer			= -1;
-static int hf_uma_urr_TU3902_timer			= -1;
-static int hf_uma_urr_communication_port 		= -1;
-static int hf_uma_urr_L3_Message			= -1;
-static int hf_uma_urr_L3_protocol_discriminator 	= -1;
-static int hf_uma_urr_GPRS_resumption			= -1;
-static int hf_uma_urr_ULQI				= -1;
-static int hf_uma_urr_TU3920_timer			= -1;
-static int hf_uma_urr_peak_tpt_cls			= -1;
-static int hf_uma_urr_radio_pri				= -1;
-static int hf_uma_urr_rlc_mode				= -1;
-static int hf_uma_urr_ga_psr_cause			= -1;
-static int hf_uma_urr_udr				= -1;
-static int hf_uma_urr_TU4001_timer			= -1;
-static int hf_uma_urr_LS				= -1;
-static int hf_uma_urr_cipher_res			= -1;
-static int hf_uma_urr_rand_val				= -1;
-static int hf_uma_urr_ciphering_command_mac 		= -1;
-static int hf_uma_urr_ciphering_key_seq_num 		= -1;
-static int hf_uma_urr_sapi_id				= -1;
-static int hf_uma_urr_establishment_cause 		= -1;
-static int hf_uma_urr_channel				= -1;
-static int hf_uma_urr_PDU_in_error			= -1;
-static int hf_uma_urr_sample_size			= -1;
-static int hf_uma_urr_payload_type			= -1;
-static int hf_uma_urr_LLC_PDU				= -1;
-static int hf_uma_urr_LBLI				= -1;
-static int hf_uma_urr_RI				= -1;
-static int hf_uma_urr_TU4003_timer			= -1;
-static int hf_uma_urr_ap_service_name_type 		= -1;
-static int hf_uma_urr_ap_Service_name_value 		= -1;
-static int hf_uma_urr_uma_service_zone_icon_ind 	= -1;
-static int hf_uma_urr_uma_service_zone_str_len 		= -1;
-static int hf_uma_urr_window_size			= -1;
-static int hf_uma_urr_uma_codec_mode			= -1;
-static int hf_uma_urr_UTRAN_cell_id_disc 		= -1;
-static int hf_uma_urr_ms_radio_id			= -1;
-static int hf_uma_urr_uma_service_zone_str 		= -1;
-static int hf_uma_urr_suti				= -1;
-static int hf_uma_urr_uma_mps				= -1;
-static int hf_uma_urr_num_of_plms			= -1;
-static int hf_uma_urr_cbs				= -1;
-static int hf_uma_urr_num_of_cbs_frms			= -1;
-static int hf_uma_urr_unc_ipv4				= -1;
-static int hf_uma_unc_FQDN				= -1;
-static int hf_uma_urr_GPRS_user_data_transport_ipv4 	= -1;
-static int hf_uma_urr_GPRS_port				= -1;
-static int hf_uma_urr_UNC_tcp_port			= -1;
-static int hf_uma_urr_RTP_port				= -1;
-static int hf_uma_urr_RTCP_port				= -1;
-static int hf_uma_urr_RXLEV_NCELL			= -1;
+static int proto_uma;
+static int hf_uma_length_indicator;
+static int hf_uma_pd;
+static int hf_uma_skip_ind;
+static int hf_uma_urr_msg_type;
+static int hf_uma_urlc_msg_type;
+static int hf_uma_urlc_TLLI;
+static int hf_uma_urlc_seq_nr;
+static int hf_uma_urr_IE;
+static int hf_uma_urr_IE_len;
+static int hf_uma_urr_uri;
+static int hf_uma_urr_radio_type_of_id;
+static int hf_uma_urr_radio_id;
+static int hf_uma_urr_cell_id;
+static int hf_uma_urr_lac;
+static int hf_uma_urr_gci;
+static int hf_uma_urr_tura;
+static int hf_uma_urr_gc;
+static int hf_uma_urr_uc;
+static int hf_uma_urr_rrs;
+static int hf_uma_urr_gmsi;
+static int hf_uma_urr_psho;
+static int hf_uma_urr_IP_Address_type;
+static int hf_uma_urr_FQDN;
+static int hf_uma_urr_sgw_ipv4;
+static int hf_uma_urr_redirection_counter;
+static int hf_uma_urr_dis_rej_cau;
+static int hf_uma_urr_MSCR;
+static int hf_uma_urr_ATT;
+static int hf_uma_urr_DTM;
+static int hf_uma_urr_GPRS;
+static int hf_uma_urr_NMO;
+static int hf_uma_urr_ECMC;
+static int hf_uma_urr_T3212_timer;
+static int hf_uma_urr_RAC;
+static int hf_uma_urr_ap_location;
+static int hf_uma_urr_SGSNR;
+static int hf_uma_urr_ECMP;
+static int hf_uma_urr_RE;
+static int hf_uma_urr_PFCFM;
+static int hf_uma_urr_3GECS;
+static int hf_uma_urr_TU3907_timer;
+static int hf_uma_urr_GSM_RR_state;
+static int hf_uma_urr_gan_band;
+static int hf_uma_urr_URR_state;
+static int hf_uma_urr_register_reject_cause;
+static int hf_uma_urr_TU3906_timer;
+static int hf_uma_urr_TU3910_timer;
+static int hf_uma_urr_TU3902_timer;
+static int hf_uma_urr_communication_port;
+static int hf_uma_urr_L3_Message;
+static int hf_uma_urr_L3_protocol_discriminator;
+static int hf_uma_urr_GPRS_resumption;
+static int hf_uma_urr_ULQI;
+static int hf_uma_urr_TU3920_timer;
+static int hf_uma_urr_peak_tpt_cls;
+static int hf_uma_urr_radio_pri;
+static int hf_uma_urr_rlc_mode;
+static int hf_uma_urr_ga_psr_cause;
+static int hf_uma_urr_udr;
+static int hf_uma_urr_TU4001_timer;
+static int hf_uma_urr_LS;
+static int hf_uma_urr_cipher_res;
+static int hf_uma_urr_rand_val;
+static int hf_uma_urr_ciphering_command_mac;
+static int hf_uma_urr_ciphering_key_seq_num;
+static int hf_uma_urr_sapi_id;
+static int hf_uma_urr_establishment_cause;
+static int hf_uma_urr_channel;
+static int hf_uma_urr_PDU_in_error;
+static int hf_uma_urr_sample_size;
+static int hf_uma_urr_payload_type;
+static int hf_uma_urr_LLC_PDU;
+static int hf_uma_urr_LBLI;
+static int hf_uma_urr_RI;
+static int hf_uma_urr_TU4003_timer;
+static int hf_uma_urr_ap_service_name_type;
+static int hf_uma_urr_ap_Service_name_value;
+static int hf_uma_urr_uma_service_zone_icon_ind;
+static int hf_uma_urr_uma_service_zone_str_len;
+static int hf_uma_urr_window_size;
+static int hf_uma_urr_uma_codec_mode;
+static int hf_uma_urr_UTRAN_cell_id_disc;
+static int hf_uma_urr_ms_radio_id;
+static int hf_uma_urr_uma_service_zone_str;
+static int hf_uma_urr_suti;
+static int hf_uma_urr_uma_mps;
+static int hf_uma_urr_num_of_plms;
+static int hf_uma_urr_cbs;
+static int hf_uma_urr_num_of_cbs_frms;
+static int hf_uma_urr_unc_ipv4;
+static int hf_uma_unc_FQDN;
+static int hf_uma_urr_GPRS_user_data_transport_ipv4;
+static int hf_uma_urr_GPRS_port;
+static int hf_uma_urr_UNC_tcp_port;
+static int hf_uma_urr_RTP_port;
+static int hf_uma_urr_RTCP_port;
+static int hf_uma_urr_RXLEV_NCELL;
 /* Generated from convert_proto_tree_add_text.pl */
-static int hf_uma_access_control_class_n = -1;
-static int hf_uma_data = -1;
+static int hf_uma_access_control_class_n;
+static int hf_uma_data;
 
 /* Initialize the subtree pointers */
-static int ett_uma     = -1;
-static int ett_uma_toc = -1;
-static int ett_urr_ie  = -1;
+static int ett_uma;
+static int ett_uma_toc;
+static int ett_urr_ie;
 
 /* Generated from convert_proto_tree_add_text.pl */
-static expert_field ei_uma_fqdn_not_present = EI_INIT;
-static expert_field ei_uma_wrong_message_type = EI_INIT;
-static expert_field ei_uma_unknown_protocol = EI_INIT;
-static expert_field ei_uma_skip_this_message = EI_INIT;
-static expert_field ei_uma_cbs_frames = EI_INIT;
-static expert_field ei_uma_unknown_format = EI_INIT;
+static expert_field ei_uma_fqdn_not_present;
+static expert_field ei_uma_wrong_message_type;
+static expert_field ei_uma_unknown_protocol;
+static expert_field ei_uma_skip_this_message;
+static expert_field ei_uma_cbs_frames;
+static expert_field ei_uma_unknown_format;
 
 /* The dynamic payload type which will be dissected as uma */
 #define DEFAULT_UMA_PORT_RANGE "14001" /* Not IANA registered */
@@ -1464,13 +1464,13 @@ dissect_uma_IE(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 		set_address(&dst_addr, AT_IPv4, 4, &GPRS_user_data_ipv4_address);
 
 		conversation = find_conversation(pinfo->num, &dst_addr,
-			&null_addr, ENDPOINT_UDP, GPRS_user_data_transport_UDP_port,
+			&null_addr, CONVERSATION_UDP, GPRS_user_data_transport_UDP_port,
 			0, NO_ADDR_B|NO_PORT_B);
 
 		if (conversation == NULL) {
 			/* It's not part of any conversation - create a new one. */
 			conversation = conversation_new(pinfo->num, &dst_addr,
-			    &null_addr, ENDPOINT_UDP, GPRS_user_data_transport_UDP_port ,
+			    &null_addr, CONVERSATION_UDP, GPRS_user_data_transport_UDP_port ,
 			    0, NO_ADDR2|NO_PORT2);
 
 		/* Set dissector */
@@ -1496,13 +1496,13 @@ dissect_uma_IE(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 		set_address(&dst_addr, AT_IPv4, 4, &unc_ipv4_address);
 
 		conversation = find_conversation(pinfo->num, &dst_addr,
-			&null_addr, ENDPOINT_TCP, UNC_tcp_port,
+			&null_addr, CONVERSATION_TCP, UNC_tcp_port,
 			0, NO_ADDR_B|NO_PORT_B);
 
 		if (conversation == NULL) {
 			/* It's not part of any conversation - create a new one. */
 			conversation = conversation_new(pinfo->num, &dst_addr,
-			    &null_addr, ENDPOINT_TCP, UNC_tcp_port,
+			    &null_addr, CONVERSATION_TCP, UNC_tcp_port,
 			    0, NO_ADDR2|NO_PORT2);
 			/* Set dissector */
 			conversation_set_dissector(conversation, uma_tcp_handle);
@@ -1858,7 +1858,7 @@ proto_register_uma(void)
 		{ &hf_uma_urr_gmsi,
 			{ "GMSI, GAN Mode Support Indicator","uma.urr.gmsi",
 			FT_UINT8,BASE_DEC, VALS(uma_gmsi_vals), 0x06,
-			"GMSI, GAN Mode Support Indicator", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_uma_urr_psho,
 			{ "PS HO, PS Handover Capable","uma.urr.psho",
@@ -1986,14 +1986,14 @@ proto_register_uma(void)
 			NULL, HFILL }
 		},
 		{ &hf_uma_urr_TU3906_timer,
-			{ "TU3907 Timer value(seconds)","uma.urr.tu3906",
+			{ "TU3906 Timer value(seconds)","uma.urr.tu3906",
 			FT_UINT16,BASE_DEC,  NULL, 0x0,
-			"TU3906 Timer value(seconds)", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_uma_urr_TU3910_timer,
-			{ "TU3907 Timer value(seconds)","uma.urr.tu3910",
+			{ "TU3910 Timer value(seconds)","uma.urr.tu3910",
 			FT_UINT16,BASE_DEC,  NULL, 0x0,
-			"TU3910 Timer value(seconds)", HFILL }
+			NULL, HFILL }
 		},
 		{ &hf_uma_urr_TU3902_timer,
 			{ "TU3902 Timer value(seconds)","uma.urr.tu3902",
