@@ -13,121 +13,133 @@
 
 #include <epan/packet.h>
 #include <epan/expert.h>
+#include <epan/follow.h>
 #include "packet-usb.h"
 
-/* protocols and header fields */
-static int proto_usb_com = -1;
-static int hf_usb_com_descriptor_subtype = -1;
-static int hf_usb_com_descriptor_cdc = -1;
-static int hf_usb_com_descriptor_payload = -1;
-static int hf_usb_com_control_subclass = -1;
-static int hf_usb_com_control_request_code = -1;
-static int hf_usb_com_control_value = -1;
-static int hf_usb_com_control_index = -1;
-static int hf_usb_com_control_length = -1;
-static int hf_usb_com_control_response_code = -1;
-static int hf_usb_com_control_payload = -1;
-static int hf_usb_com_get_ntb_params_length = -1;
-static int hf_usb_com_get_ntb_params_ntb_formats_supported = -1;
-static int hf_usb_com_get_ntb_params_ntb_formats_supported_16bit = -1;
-static int hf_usb_com_get_ntb_params_ntb_formats_supported_32bit = -1;
-static int hf_usb_com_get_ntb_params_ntb_in_max_size = -1;
-static int hf_usb_com_get_ntb_params_ndp_in_divisor = -1;
-static int hf_usb_com_get_ntb_params_ndp_in_payload_remainder = -1;
-static int hf_usb_com_get_ntb_params_ndp_in_alignment = -1;
-static int hf_usb_com_get_ntb_params_reserved = -1;
-static int hf_usb_com_get_ntb_params_ntb_out_max_size = -1;
-static int hf_usb_com_get_ntb_params_ndp_out_divisor = -1;
-static int hf_usb_com_get_ntb_params_ndp_out_payload_remainder = -1;
-static int hf_usb_com_get_ntb_params_ndp_out_alignment = -1;
-static int hf_usb_com_get_ntb_params_ntb_out_max_datagrams = -1;
-static int hf_usb_com_get_net_address_eui48 = -1;
-static int hf_usb_com_set_net_address_eui48 = -1;
-static int hf_usb_com_get_ntb_format_ntb_format = -1;
-static int hf_usb_com_set_ntb_format_ntb_format = -1;
-static int hf_usb_com_get_ntb_input_size_ntb_in_max_size = -1;
-static int hf_usb_com_get_ntb_input_size_ntb_in_max_datagrams = -1;
-static int hf_usb_com_get_ntb_input_size_reserved = -1;
-static int hf_usb_com_set_ntb_input_size_ntb_in_max_size = -1;
-static int hf_usb_com_set_ntb_input_size_ntb_in_max_datagrams = -1;
-static int hf_usb_com_set_ntb_input_size_reserved = -1;
-static int hf_usb_com_get_max_datagram_size_size = -1;
-static int hf_usb_com_set_max_datagram_size_size = -1;
-static int hf_usb_com_get_crc_mode_crc_mode = -1;
-static int hf_usb_com_set_crc_mode_crc_mode = -1;
-static int hf_usb_com_capabilities = -1;
-static int hf_usb_com_descriptor_acm_capabilities_reserved = -1;
-static int hf_usb_com_descriptor_acm_capabilities_network_connection = -1;
-static int hf_usb_com_descriptor_acm_capabilities_send_break = -1;
-static int hf_usb_com_descriptor_acm_capabilities_line_and_state = -1;
-static int hf_usb_com_descriptor_acm_capabilities_comm_features = -1;
-static int hf_usb_com_descriptor_control_interface = -1;
-static int hf_usb_com_descriptor_subordinate_interface = -1;
-static int hf_usb_com_descriptor_cm_capabilities_reserved = -1;
-static int hf_usb_com_descriptor_cm_capabilities_call_management_over_data_class_interface = -1;
-static int hf_usb_com_descriptor_cm_capabilities_call_management = -1;
-static int hf_usb_com_descriptor_cm_data_interface = -1;
-static int hf_usb_com_descriptor_ecm_mac_address = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_reserved = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_late_collisions = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_times_crs_lost = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_heartbeat_failure = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_underrun = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_rcv_overrun = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_max_collisions = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_deferred = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_more_collisions = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_one_collision = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_rcv_error_alignment = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_transmit_queue_length = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_rcv_crc_error = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_broadcast_frames_rcv = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_broadcast_bytes_rcv = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_multicast_frames_rcv = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_multicast_bytes_rcv = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_directed_frames_rcv = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_directed_bytes_rcv = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_broadcast_frames_xmit = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_broadcast_bytes_xmit = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_multicast_frames_xmit = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_multicast_bytes_xmit = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_directed_frames_xmit = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_directed_bytes_xmit = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_rcv_no_buffer = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_rcv_error = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_error = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_rvc_ok = -1;
-static int hf_usb_com_descriptor_ecm_eth_stats_xmit_ok = -1;
-static int hf_usb_com_descriptor_ecm_max_segment_size = -1;
-static int hf_usb_com_descriptor_ecm_nb_mc_filters = -1;
-static int hf_usb_com_descriptor_ecm_nb_mc_filters_mc_address_filtering = -1;
-static int hf_usb_com_descriptor_ecm_nb_mc_filters_nb_filters_supported = -1;
-static int hf_usb_com_descriptor_ecm_nb_power_filters = -1;
-static int hf_usb_com_interrupt_request_type = -1;
-static int hf_usb_com_interrupt_notif_code = -1;
-static int hf_usb_com_interrupt_value = -1;
-static int hf_usb_com_interrupt_value_nw_conn = -1;
-static int hf_usb_com_interrupt_index = -1;
-static int hf_usb_com_interrupt_length = -1;
-static int hf_usb_com_interrupt_dl_bitrate = -1;
-static int hf_usb_com_interrupt_ul_bitrate = -1;
-static int hf_usb_com_interrupt_payload = -1;
+static int cdc_data_follow_tap;
+static int proto_usb;
 
-static gint ett_usb_com = -1;
-static gint ett_usb_com_capabilities = -1;
-static gint ett_usb_com_bitmap = -1;
-static gint ett_usb_com_descriptor_ecm_eth_stats = -1;
-static gint ett_usb_com_descriptor_ecm_nb_mc_filters = -1;
+/* protocols and header fields */
+static int proto_usb_com;
+static int hf_usb_com_descriptor_subtype;
+static int hf_usb_com_descriptor_cdc;
+static int hf_usb_com_descriptor_payload;
+static int hf_usb_com_control_subclass;
+static int hf_usb_com_control_request_code;
+static int hf_usb_com_control_value;
+static int hf_usb_com_control_index;
+static int hf_usb_com_control_length;
+static int hf_usb_com_control_response_code;
+static int hf_usb_com_control_payload;
+static int hf_usb_com_get_ntb_params_length;
+static int hf_usb_com_get_ntb_params_ntb_formats_supported;
+static int hf_usb_com_get_ntb_params_ntb_formats_supported_16bit;
+static int hf_usb_com_get_ntb_params_ntb_formats_supported_32bit;
+static int hf_usb_com_get_ntb_params_ntb_in_max_size;
+static int hf_usb_com_get_ntb_params_ndp_in_divisor;
+static int hf_usb_com_get_ntb_params_ndp_in_payload_remainder;
+static int hf_usb_com_get_ntb_params_ndp_in_alignment;
+static int hf_usb_com_get_ntb_params_reserved;
+static int hf_usb_com_get_ntb_params_ntb_out_max_size;
+static int hf_usb_com_get_ntb_params_ndp_out_divisor;
+static int hf_usb_com_get_ntb_params_ndp_out_payload_remainder;
+static int hf_usb_com_get_ntb_params_ndp_out_alignment;
+static int hf_usb_com_get_ntb_params_ntb_out_max_datagrams;
+static int hf_usb_com_get_net_address_eui48;
+static int hf_usb_com_set_net_address_eui48;
+static int hf_usb_com_get_ntb_format_ntb_format;
+static int hf_usb_com_set_ntb_format_ntb_format;
+static int hf_usb_com_get_ntb_input_size_ntb_in_max_size;
+static int hf_usb_com_get_ntb_input_size_ntb_in_max_datagrams;
+static int hf_usb_com_get_ntb_input_size_reserved;
+static int hf_usb_com_set_ntb_input_size_ntb_in_max_size;
+static int hf_usb_com_set_ntb_input_size_ntb_in_max_datagrams;
+static int hf_usb_com_set_ntb_input_size_reserved;
+static int hf_usb_com_get_max_datagram_size_size;
+static int hf_usb_com_set_max_datagram_size_size;
+static int hf_usb_com_get_crc_mode_crc_mode;
+static int hf_usb_com_set_crc_mode_crc_mode;
+static int hf_usb_com_capabilities;
+static int hf_usb_com_descriptor_acm_capabilities_reserved;
+static int hf_usb_com_descriptor_acm_capabilities_network_connection;
+static int hf_usb_com_descriptor_acm_capabilities_send_break;
+static int hf_usb_com_descriptor_acm_capabilities_line_and_state;
+static int hf_usb_com_descriptor_acm_capabilities_comm_features;
+static int hf_usb_com_descriptor_control_interface;
+static int hf_usb_com_descriptor_subordinate_interface;
+static int hf_usb_com_descriptor_cm_capabilities_reserved;
+static int hf_usb_com_descriptor_cm_capabilities_call_management_over_data_class_interface;
+static int hf_usb_com_descriptor_cm_capabilities_call_management;
+static int hf_usb_com_descriptor_cm_data_interface;
+static int hf_usb_com_descriptor_ecm_mac_address;
+static int hf_usb_com_descriptor_ecm_eth_stats;
+static int hf_usb_com_descriptor_ecm_eth_stats_reserved;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_late_collisions;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_times_crs_lost;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_heartbeat_failure;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_underrun;
+static int hf_usb_com_descriptor_ecm_eth_stats_rcv_overrun;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_max_collisions;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_deferred;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_more_collisions;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_one_collision;
+static int hf_usb_com_descriptor_ecm_eth_stats_rcv_error_alignment;
+static int hf_usb_com_descriptor_ecm_eth_stats_transmit_queue_length;
+static int hf_usb_com_descriptor_ecm_eth_stats_rcv_crc_error;
+static int hf_usb_com_descriptor_ecm_eth_stats_broadcast_frames_rcv;
+static int hf_usb_com_descriptor_ecm_eth_stats_broadcast_bytes_rcv;
+static int hf_usb_com_descriptor_ecm_eth_stats_multicast_frames_rcv;
+static int hf_usb_com_descriptor_ecm_eth_stats_multicast_bytes_rcv;
+static int hf_usb_com_descriptor_ecm_eth_stats_directed_frames_rcv;
+static int hf_usb_com_descriptor_ecm_eth_stats_directed_bytes_rcv;
+static int hf_usb_com_descriptor_ecm_eth_stats_broadcast_frames_xmit;
+static int hf_usb_com_descriptor_ecm_eth_stats_broadcast_bytes_xmit;
+static int hf_usb_com_descriptor_ecm_eth_stats_multicast_frames_xmit;
+static int hf_usb_com_descriptor_ecm_eth_stats_multicast_bytes_xmit;
+static int hf_usb_com_descriptor_ecm_eth_stats_directed_frames_xmit;
+static int hf_usb_com_descriptor_ecm_eth_stats_directed_bytes_xmit;
+static int hf_usb_com_descriptor_ecm_eth_stats_rcv_no_buffer;
+static int hf_usb_com_descriptor_ecm_eth_stats_rcv_error;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_error;
+static int hf_usb_com_descriptor_ecm_eth_stats_rvc_ok;
+static int hf_usb_com_descriptor_ecm_eth_stats_xmit_ok;
+static int hf_usb_com_descriptor_ecm_max_segment_size;
+static int hf_usb_com_descriptor_ecm_nb_mc_filters;
+static int hf_usb_com_descriptor_ecm_nb_mc_filters_mc_address_filtering;
+static int hf_usb_com_descriptor_ecm_nb_mc_filters_nb_filters_supported;
+static int hf_usb_com_descriptor_ecm_nb_power_filters;
+static int hf_usb_com_interrupt_request_type;
+static int hf_usb_com_interrupt_notif_code;
+static int hf_usb_com_interrupt_value;
+static int hf_usb_com_interrupt_value_nw_conn;
+static int hf_usb_com_interrupt_index;
+static int hf_usb_com_interrupt_length;
+static int hf_usb_com_interrupt_dl_bitrate;
+static int hf_usb_com_interrupt_ul_bitrate;
+static int hf_usb_com_interrupt_payload;
+static int hf_usb_com_data_stream;
+static int hf_usb_com_data_in_payload;
+static int hf_usb_com_data_out_payload;
+
+static gint ett_usb_com;
+static gint ett_usb_com_capabilities;
+static gint ett_usb_com_bitmap;
+static gint ett_usb_com_descriptor_ecm_eth_stats;
+static gint ett_usb_com_descriptor_ecm_nb_mc_filters;
+
+static dissector_handle_t usb_com_descriptor_handle;
+static dissector_handle_t usb_com_control_handle;
+static dissector_handle_t usb_com_bulk_handle;
+static dissector_handle_t usb_com_interrupt_handle;
 
 static dissector_handle_t mbim_control_handle;
 static dissector_handle_t mbim_descriptor_handle;
 static dissector_handle_t mbim_bulk_handle;
 static dissector_handle_t eth_withoutfcs_handle;
 
-static expert_field ei_unexpected_controlling_iface = EI_INIT;
+static expert_field ei_unexpected_controlling_iface;
 
-static wmem_tree_t* controlling_ifaces = NULL;
+static wmem_tree_t* controlling_ifaces;
 
 typedef struct _controlling_iface {
     guint16 interfaceClass;
@@ -135,6 +147,12 @@ typedef struct _controlling_iface {
     guint16 interfaceProtocol;
 } controlling_iface_t;
 
+static guint32 cdc_data_stream_count;
+
+typedef struct _cdc_data_conv {
+    guint32 stream;
+} cdc_data_conv_t;
+
 #define CS_INTERFACE 0x24
 #define CS_ENDPOINT  0x25
 
@@ -412,7 +430,8 @@ static int
 dissect_usb_com_descriptor(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     usb_conv_info_t *usb_conv_info = (usb_conv_info_t *)data;
-    guint8 offset = 0, type, subtype;
+    gint offset = 0;
+    guint8 type, subtype;
     proto_tree *subtree;
     proto_tree *subtree_capabilities;
     proto_item *subitem_capabilities;
@@ -725,6 +744,7 @@ static int
 dissect_usb_com_bulk(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     usb_conv_info_t *usb_conv_info = (usb_conv_info_t *)data;
+    cdc_data_conv_t *cdc_data_info;
     guint32 k_bus_id;
     guint32 k_device_address;
     guint32 k_subordinate_id;
@@ -736,6 +756,8 @@ dissect_usb_com_bulk(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *
     };
     wmem_tree_t *wmem_tree;
     controlling_iface_t *master_iface = NULL;
+    proto_tree *subtree;
+    proto_item *item;
 
     if (!usb_conv_info) {
         return 0;
@@ -748,6 +770,38 @@ dissect_usb_com_bulk(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *
         return 0;
     }
 
+    /* Generic handling to allow follow stream functionality regardless if data
+     * is passed to higher layer dissector or not.
+     */
+    cdc_data_info = (cdc_data_conv_t *)usb_conv_info->class_data;
+    if (!cdc_data_info) {
+        cdc_data_info = wmem_new(wmem_file_scope(), cdc_data_conv_t);
+        cdc_data_info->stream = cdc_data_stream_count++;
+        usb_conv_info->class_data = cdc_data_info;
+        usb_conv_info->class_data_type = USB_CONV_CDC_DATA;
+    } else if (usb_conv_info->class_data_type != USB_CONV_CDC_DATA) {
+        /* Don't dissect if another USB type is in the conversation */
+        return 0;
+    }
+
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "USBCOM");
+
+    item = proto_tree_add_item(tree, proto_usb_com, tvb, 0, -1, ENC_NA);
+    subtree = proto_item_add_subtree(item, ett_usb_com);
+
+    item = proto_tree_add_uint(subtree, hf_usb_com_data_stream, tvb, 0, 0, cdc_data_info->stream);
+    proto_item_set_generated(item);
+
+    if (pinfo->p2p_dir == P2P_DIR_RECV) {
+        proto_tree_add_item(subtree, hf_usb_com_data_in_payload, tvb, 0, -1, ENC_NA);
+    } else {
+        proto_tree_add_item(subtree, hf_usb_com_data_out_payload, tvb, 0, -1, ENC_NA);
+    }
+
+    if (have_tap_listener(cdc_data_follow_tap)) {
+        tap_queue_packet(cdc_data_follow_tap, pinfo, tvb);
+    }
+
     k_bus_id = usb_conv_info->bus_id;
     k_device_address = usb_conv_info->device_address;
     k_subordinate_id = usb_conv_info->interfaceNum;
@@ -777,8 +831,8 @@ dissect_usb_com_bulk(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *
             break;
     }
 
-    /* Unknown (class, subclass, protocol) tuple. Do not attempt dissection. */
-    return 0;
+    /* Unknown (class, subclass, protocol) tuple. No further dissection. */
+    return tvb_captured_length(tvb);
 }
 
 static int
@@ -838,6 +892,115 @@ dissect_usb_com_interrupt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, v
     return tvb_captured_length(tvb);
 }
 
+static cdc_data_conv_t *get_cdc_data_conv(packet_info *pinfo)
+{
+    conversation_t *conversation;
+    usb_conv_info_t *usb_conv_info;
+
+    if (pinfo->ptype != PT_USB) {
+        return NULL;
+    }
+
+    conversation = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst, CONVERSATION_USB,
+                                     pinfo->srcport, pinfo->destport, 0);
+    if (!conversation) {
+        return NULL;
+    }
+
+    usb_conv_info = (usb_conv_info_t *)conversation_get_proto_data(conversation, proto_usb);
+    if (!usb_conv_info || (usb_conv_info->class_data_type != USB_CONV_CDC_DATA)) {
+        return NULL;
+    }
+
+    return (cdc_data_conv_t *)usb_conv_info->class_data;
+}
+
+static gchar *cdc_data_follow_conv_filter(epan_dissect_t *edt _U_, packet_info *pinfo, guint *stream, guint *sub_stream _U_)
+{
+    cdc_data_conv_t *cdc_data_info;
+
+    cdc_data_info = get_cdc_data_conv(pinfo);
+    if (cdc_data_info) {
+        *stream = cdc_data_info->stream;
+        return ws_strdup_printf("usbcom.data.stream eq %u", cdc_data_info->stream);
+    }
+
+    return NULL;
+}
+
+static gchar *cdc_data_follow_index_filter(guint stream, guint sub_stream _U_)
+{
+    return ws_strdup_printf("usbcom.data.stream eq %u", stream);
+}
+
+static gchar *cdc_data_follow_address_filter(address *src_addr _U_, address *dst_addr _U_, int src_port _U_, int dst_port _U_)
+{
+    /* We always just filter stream based on an arbitrarily generated index. */
+    return NULL;
+}
+
+static gchar *cdc_data_port_to_display(wmem_allocator_t *allocator, guint port)
+{
+    return wmem_strdup(allocator, port == NO_ENDPOINT ? "host" : "device");
+}
+
+static tap_packet_status
+follow_cdc_data_tap_listener(void *tapdata, packet_info *pinfo, epan_dissect_t *edt _U_,
+                             const void *data, tap_flags_t flags _U_)
+{
+    follow_record_t *follow_record;
+    follow_info_t *follow_info = (follow_info_t *)tapdata;
+    tvbuff_t *tvb = (tvbuff_t *)data;
+    guint32 data_length = tvb_captured_length(tvb);
+    gboolean is_server;
+
+    if (follow_info->client_port == 0) {
+        /* XXX: Client/Server does not quite match how USB works. Simply assume
+         * that host is "server" but it is important to note that client port
+         * will be set to either IN or OUT endpoint (whichever transmits data
+         * first). Client "receive" is OUT endpoint while client "transmit" is
+         * IN endpoint. The "other end" is always host.
+         */
+        if (pinfo->srcport == NO_ENDPOINT) {
+            follow_info->client_port = pinfo->destport;
+            copy_address(&follow_info->client_ip, &pinfo->dst);
+            follow_info->server_port = pinfo->srcport;
+            copy_address(&follow_info->server_ip, &pinfo->src);
+        } else {
+            follow_info->client_port = pinfo->srcport;
+            copy_address(&follow_info->client_ip, &pinfo->src);
+            follow_info->server_port = pinfo->destport;
+            copy_address(&follow_info->server_ip, &pinfo->dst);
+        }
+    }
+
+    is_server = pinfo->srcport == NO_ENDPOINT;
+
+    follow_record = g_new0(follow_record_t, 1);
+    follow_record->is_server = is_server;
+    follow_record->packet_num = pinfo->fd->num;
+    follow_record->abs_ts = pinfo->fd->abs_ts;
+    follow_record->data = g_byte_array_append(g_byte_array_new(),
+                                              tvb_get_ptr(tvb, 0, data_length),
+                                              data_length);
+
+    follow_info->bytes_written[is_server] += follow_record->data->len;
+    follow_info->payload = g_list_prepend(follow_info->payload, follow_record);
+
+    return TAP_PACKET_DONT_REDRAW;
+}
+
+static guint32 get_cdc_data_stream_count(void)
+{
+    return cdc_data_stream_count;
+}
+
+static void
+usb_com_cleanup_data(void)
+{
+    cdc_data_stream_count = 0;
+}
+
 void
 proto_register_usb_com(void)
 {
@@ -1129,7 +1292,16 @@ proto_register_usb_com(void)
               &units_bit_sec, 0, NULL, HFILL }},
         { &hf_usb_com_interrupt_payload,
             { "Payload", "usbcom.interrupt.payload", FT_BYTES, BASE_NONE,
-              NULL, 0, NULL, HFILL }}
+              NULL, 0, NULL, HFILL }},
+        { &hf_usb_com_data_stream,
+            { "Stream index", "usbcom.data.stream", FT_UINT32, BASE_DEC,
+              NULL, 0, NULL, HFILL }},
+        { &hf_usb_com_data_in_payload,
+            { "IN payload", "usbcom.data.in_payload", FT_BYTES, BASE_NONE,
+              NULL, 0, NULL, HFILL }},
+        { &hf_usb_com_data_out_payload,
+            { "OUT payload", "usbcom.data.out_payload", FT_BYTES, BASE_NONE,
+              NULL, 0, NULL, HFILL }},
     };
 
     static gint *usb_com_subtrees[] = {
@@ -1152,28 +1324,35 @@ proto_register_usb_com(void)
     proto_register_field_array(proto_usb_com, hf, array_length(hf));
     proto_register_subtree_array(usb_com_subtrees, array_length(usb_com_subtrees));
 
+    usb_com_descriptor_handle = register_dissector("usbcom.descriptor", dissect_usb_com_descriptor, proto_usb_com);
+    usb_com_control_handle = register_dissector("usbcom.control", dissect_usb_com_control, proto_usb_com);
+    usb_com_bulk_handle = register_dissector("usbcom.bulk", dissect_usb_com_bulk, proto_usb_com);
+    usb_com_interrupt_handle = register_dissector("usbcom.interrupt", dissect_usb_com_interrupt, proto_usb_com);
+
     expert_usb_com = expert_register_protocol(proto_usb_com);
     expert_register_field_array(expert_usb_com, ei, array_length(ei));
+
+    register_cleanup_routine(usb_com_cleanup_data);
+
+    cdc_data_follow_tap = register_tap("cdc_data_follow");
+    register_follow_stream(proto_usb_com, "cdc_data_follow", cdc_data_follow_conv_filter, cdc_data_follow_index_filter,
+                           cdc_data_follow_address_filter, cdc_data_port_to_display, follow_cdc_data_tap_listener,
+                           get_cdc_data_stream_count, NULL);
 }
 
 void
 proto_reg_handoff_usb_com(void)
 {
-    dissector_handle_t usb_com_descriptor_handle, usb_com_control_handle,
-                       usb_com_bulk_handle, usb_com_interrupt_handle;
-
-    usb_com_descriptor_handle = create_dissector_handle(dissect_usb_com_descriptor, proto_usb_com);
     dissector_add_uint("usb.descriptor", IF_CLASS_COMMUNICATIONS, usb_com_descriptor_handle);
-    usb_com_control_handle = create_dissector_handle(dissect_usb_com_control, proto_usb_com);
     dissector_add_uint("usb.control", IF_CLASS_COMMUNICATIONS, usb_com_control_handle);
-    usb_com_bulk_handle = create_dissector_handle(dissect_usb_com_bulk, proto_usb_com);
     dissector_add_uint("usb.bulk", IF_CLASS_CDC_DATA, usb_com_bulk_handle);
-    usb_com_interrupt_handle = create_dissector_handle(dissect_usb_com_interrupt, proto_usb_com);
     dissector_add_uint("usb.interrupt", IF_CLASS_COMMUNICATIONS, usb_com_interrupt_handle);
     mbim_control_handle = find_dissector_add_dependency("mbim.control", proto_usb_com);
     mbim_descriptor_handle = find_dissector_add_dependency("mbim.descriptor", proto_usb_com);
     mbim_bulk_handle = find_dissector_add_dependency("mbim.bulk", proto_usb_com);
     eth_withoutfcs_handle = find_dissector_add_dependency("eth_withoutfcs", proto_usb_com);
+
+    proto_usb = proto_get_id_by_filter_name("usb");
 }
 
 /*
