@@ -17,44 +17,46 @@
 #include <epan/expert.h>
 #include "packet-usb.h"
 
-static int proto_usb_dfu = -1;
+static int proto_usb_dfu;
 
-static gint hf_setup_command = -1;
-static gint hf_setup_unused = -1;
-static gint hf_setup_interface = -1;
-static gint hf_setup_length = -1;
-static gint hf_setup_timeout = -1;
-static gint hf_setup_block_number = -1;
-static gint hf_response = -1;
-static gint hf_command_in_frame = -1;
-static gint hf_state = -1;
-static gint hf_status = -1;
-static gint hf_poll_timeout = -1;
-static gint hf_iString = -1;
-static gint hf_data = -1;
-static gint hf_usb_dfu_descriptor = -1;
-static gint hf_usb_dfu_descriptor_bmAttributes_reserved = -1;
-static gint hf_usb_dfu_descriptor_bmAttributes_WillDetach = -1;
-static gint hf_usb_dfu_descriptor_bmAttributes_ManifestationTolerant = -1;
-static gint hf_usb_dfu_descriptor_bmAttributes_CanUpload = -1;
-static gint hf_usb_dfu_descriptor_bmAttributes_CanDownload = -1;
-static gint hf_usb_dfu_descriptor_wDetachTimeOut = -1;
-static gint hf_usb_dfu_descriptor_wTransferSize = -1;
-static gint hf_usb_dfu_descriptor_bcdDFUVersion = -1;
+static gint hf_setup_command;
+static gint hf_setup_unused;
+static gint hf_setup_interface;
+static gint hf_setup_length;
+static gint hf_setup_timeout;
+static gint hf_setup_block_number;
+static gint hf_response;
+static gint hf_command_in_frame;
+static gint hf_state;
+static gint hf_status;
+static gint hf_poll_timeout;
+static gint hf_iString;
+static gint hf_data;
+static gint hf_usb_dfu_descriptor;
+static gint hf_usb_dfu_descriptor_bmAttributes_reserved;
+static gint hf_usb_dfu_descriptor_bmAttributes_WillDetach;
+static gint hf_usb_dfu_descriptor_bmAttributes_ManifestationTolerant;
+static gint hf_usb_dfu_descriptor_bmAttributes_CanUpload;
+static gint hf_usb_dfu_descriptor_bmAttributes_CanDownload;
+static gint hf_usb_dfu_descriptor_wDetachTimeOut;
+static gint hf_usb_dfu_descriptor_wTransferSize;
+static gint hf_usb_dfu_descriptor_bcdDFUVersion;
 
-static gint ett_usb_dfu = -1;
-static gint ett_usb_dfu_descriptor = -1;
-static gint ett_command = -1;
+static gint ett_usb_dfu;
+static gint ett_usb_dfu_descriptor;
+static gint ett_command;
 
-static expert_field ei_unexpected_response = EI_INIT;
-static expert_field ei_unknown_data = EI_INIT;
-static expert_field ei_unexpected_data = EI_INIT;
-static expert_field ei_descriptor_invalid_length = EI_INIT;
-static expert_field ei_invalid_command_for_request_type = EI_INIT;
+static expert_field ei_unexpected_response;
+static expert_field ei_unknown_data;
+static expert_field ei_unexpected_data;
+static expert_field ei_descriptor_invalid_length;
+static expert_field ei_invalid_command_for_request_type;
 
 static dissector_handle_t usb_dfu_handle;
+static dissector_handle_t usf_dfu_descriptor_handle;
 
-static wmem_tree_t *command_info = NULL;
+
+static wmem_tree_t *command_info;
 
 typedef struct _command_data {
     guint32  bus_id;
@@ -541,6 +543,7 @@ proto_register_usb_dfu(void)
     proto_register_field_array(proto_usb_dfu, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
     usb_dfu_handle = register_dissector("usb_dfu", dissect_usb_dfu, proto_usb_dfu);
+    usf_dfu_descriptor_handle = register_dissector("usb_dfu.descriptor", dissect_usb_dfu_descriptor, proto_usb_dfu);
 
     expert_module = expert_register_protocol(proto_usb_dfu);
     expert_register_field_array(expert_module, ei, array_length(ei));
@@ -557,9 +560,6 @@ proto_register_usb_dfu(void)
 void
 proto_reg_handoff_usb_dfu(void)
 {
-    dissector_handle_t  usf_dfu_descriptor_handle;
-
-    usf_dfu_descriptor_handle = create_dissector_handle(dissect_usb_dfu_descriptor, proto_usb_dfu);
     dissector_add_uint("usb.descriptor", IF_CLASS_APPLICATION_SPECIFIC, usf_dfu_descriptor_handle);
 
     dissector_add_uint("usb.control", RUNTIME_KEY, usb_dfu_handle);
