@@ -103,156 +103,176 @@ void proto_reg_handoff_vines_icp(void);
 
 #define UDP_PORT_VINES	573
 
-static int proto_vines_frp = -1;
-static int hf_vines_frp_flags = -1;
-static int hf_vines_frp_flags_first_fragment = -1;
-static int hf_vines_frp_flags_last_fragment = -1;
-static int hf_vines_frp_sequence_number = -1;
+static int proto_vines_frp;
+static int hf_vines_frp_flags;
+static int hf_vines_frp_flags_first_fragment;
+static int hf_vines_frp_flags_last_fragment;
+static int hf_vines_frp_sequence_number;
 
-static gint ett_vines_frp = -1;
-static gint ett_vines_frp_flags = -1;
+static gint ett_vines_frp;
+static gint ett_vines_frp_flags;
 
-static int proto_vines_llc = -1;
-static int hf_vines_llc_packet_type = -1;
+static dissector_handle_t vines_frp_handle, vines_frp_new_handle;
 
-static gint ett_vines_llc = -1;
+static int proto_vines_llc;
+static int hf_vines_llc_packet_type;
 
-static int proto_vines_ip = -1;
-static int hf_vines_ip_protocol = -1;
-static int hf_vines_ip_checksum = -1;
-static int hf_vines_ip_length = -1;
-static int hf_vines_ip_source = -1;
-static int hf_vines_ip_destination = -1;
-static int hf_vines_tctl = -1;
-static int hf_vines_tctl_node = -1;
-static int hf_vines_tctl_class = -1;
-static int hf_vines_tctl_forward_router = -1;
-static int hf_vines_tctl_metric = -1;
-static int hf_vines_tctl_notif_packet = -1;
-static int hf_vines_tctl_hop_count = -1;
+static gint ett_vines_llc;
 
-static gint ett_vines_ip = -1;
-static gint ett_vines_ip_tctl = -1;
+static dissector_handle_t vines_llc_handle;
 
-static int proto_vines_echo = -1;
+static int proto_vines_ip;
+static int hf_vines_ip_protocol;
+static int hf_vines_ip_checksum;
+static int hf_vines_ip_length;
+static int hf_vines_ip_source;
+static int hf_vines_ip_destination;
+static int hf_vines_tctl;
+static int hf_vines_tctl_node;
+static int hf_vines_tctl_class;
+static int hf_vines_tctl_forward_router;
+static int hf_vines_tctl_metric;
+static int hf_vines_tctl_notif_packet;
+static int hf_vines_tctl_hop_count;
 
-static gint hf_vines_echo_data = -1;
+static gint ett_vines_ip;
+static gint ett_vines_ip_tctl;
 
-static gint ett_vines_echo = -1;
+static dissector_handle_t vines_ip_handle;
 
-static int proto_vines_ipc = -1;
-static int hf_vines_ipc_src_port = -1;
-static int hf_vines_ipc_dest_port = -1;
-static int hf_vines_ipc_packet_type = -1;
-static int hf_vines_ipc_control = -1;
-static int hf_vines_ipc_control_ack = -1;
-static int hf_vines_ipc_control_end_msg = -1;
-static int hf_vines_ipc_control_beg_msg = -1;
-static int hf_vines_ipc_control_abort_msg = -1;
-static int hf_vines_ipc_local_connection_id = -1;
-static int hf_vines_ipc_sequence_number = -1;
-static int hf_vines_ipc_length = -1;
-static int hf_vines_ipc_remote_connection_id = -1;
-static int hf_vines_ipc_ack_number = -1;
-static int hf_vines_ipc_error = -1;
+static int proto_vines_echo;
 
-static gint ett_vines_ipc = -1;
-static gint ett_vines_ipc_control = -1;
+static gint hf_vines_echo_data;
 
-static int proto_vines_spp = -1;
-static int hf_vines_spp_src_port = -1;
-static int hf_vines_spp_dest_port = -1;
-static int hf_vines_spp_packet_type = -1;
-static int hf_vines_spp_control = -1;
-static int hf_vines_spp_control_ack = -1;
-static int hf_vines_spp_control_end_msg = -1;
-static int hf_vines_spp_control_beg_msg = -1;
-static int hf_vines_spp_control_abort_msg = -1;
-static int hf_vines_spp_local_id = -1;
-static int hf_vines_spp_remote_id = -1;
-static int hf_vines_spp_seq_num = -1;
-static int hf_vines_spp_ack_num = -1;
-static int hf_vines_spp_window = -1;
+static gint ett_vines_echo;
 
-static gint ett_vines_spp = -1;
-static gint ett_vines_spp_control = -1;
+static dissector_handle_t vines_echo_handle;
 
-static int proto_vines_arp = -1;
-static int hf_vines_arp_address = -1;
-static int hf_vines_arp_version = -1;
-static int hf_vines_arp_packet_type = -1;
-static int hf_vines_arp_interface_metric = -1;
-static int hf_vines_arp_sequence_number = -1;
+static int proto_vines_ipc;
+static int hf_vines_ipc_src_port;
+static int hf_vines_ipc_dest_port;
+static int hf_vines_ipc_packet_type;
+static int hf_vines_ipc_control;
+static int hf_vines_ipc_control_ack;
+static int hf_vines_ipc_control_end_msg;
+static int hf_vines_ipc_control_beg_msg;
+static int hf_vines_ipc_control_abort_msg;
+static int hf_vines_ipc_local_connection_id;
+static int hf_vines_ipc_sequence_number;
+static int hf_vines_ipc_length;
+static int hf_vines_ipc_remote_connection_id;
+static int hf_vines_ipc_ack_number;
+static int hf_vines_ipc_error;
 
-static gint ett_vines_arp = -1;
+static gint ett_vines_ipc;
+static gint ett_vines_ipc_control;
 
-static int proto_vines_rtp = -1;
-static int hf_vines_rtp_comp_flag = -1;
-static int hf_vines_rtp_comp_flag_neighbor_router = -1;
-static int hf_vines_rtp_comp_flag_sequence_rtp = -1;
-static int hf_vines_rtp_comp_flag_sequence_rtp_version = -1;
-static int hf_vines_rtp_control = -1;
-static int hf_vines_rtp_control_sync_broadcast = -1;
-static int hf_vines_rtp_control_topology_update = -1;
-static int hf_vines_rtp_control_specific_request = -1;
-static int hf_vines_rtp_control_end_msg = -1;
-static int hf_vines_rtp_control_beg_msg = -1;
-static int hf_vines_rtp_machine_rtp = -1;
-static int hf_vines_rtp_machine_tcpip = -1;
-static int hf_vines_rtp_machine_bus = -1;
-static int hf_vines_rtp_flag_sequence_rtp = -1;
-static int hf_vines_rtp_flag_network_p2p = -1;
-static int hf_vines_rtp_flag_data_link_p2p = -1;
-static int hf_vines_rtp_flag_broadcast_medium = -1;
-static int hf_vines_rtp_metric_to_preferred_gateway = -1;
-static int hf_vines_rtp_requested_info = -1;
-static int hf_vines_rtp_metric_to_destination = -1;
-static int hf_vines_rtp_source_route_length = -1;
-static int hf_vines_rtp_router_sequence_number = -1;
-static int hf_vines_rtp_sequence_number = -1;
-static int hf_vines_rtp_data_offset = -1;
-static int hf_vines_rtp_preferred_gateway_sequence_number = -1;
-static int hf_vines_rtp_preferred_gateway_node_type = -1;
-static int hf_vines_rtp_metric = -1;
-static int hf_vines_rtp_destination_sequence_number = -1;
-static int hf_vines_rtp_link_address_length = -1;
-static int hf_vines_rtp_controller_type = -1;
-static int hf_vines_rtp_destination_node_type = -1;
-static int hf_vines_rtp_information_type = -1;
-static int hf_vines_rtp_version = -1;
-static int hf_vines_rtp_preferred_gateway = -1;
-static int hf_vines_rtp_neighbor_metric = -1;
-static int hf_vines_rtp_destination = -1;
-static int hf_vines_rtp_node_type = -1;
-static int hf_vines_rtp_operation_type = -1;
-static int hf_vines_rtp_packet_id = -1;
-static int hf_vines_rtp_network_number = -1;
-static int hf_vines_rtp_machine_type = -1;
-static int hf_vines_rtp_destination_controller_type = -1;
-static int hf_vines_rtp_destination_machine = -1;
-static int hf_vines_rtp_pref_gateway_controller_type = -1;
-static int hf_vines_rtp_pref_gateway_machine = -1;
-static int hf_vines_rtp_network_flags = -1;
-static int hf_vines_rtp_destination_flags = -1;
-static int hf_vines_rtp_preferred_gateway_flags = -1;
-static int hf_vines_rtp_preferred_gateway_data_link_address_ether = -1;
-static int hf_vines_rtp_preferred_gateway_data_link_address_bytes = -1;
-static int hf_vines_rtp_preferred_gateway_source_route = -1;
+static dissector_handle_t vines_ipc_handle;
 
-static gint ett_vines_rtp = -1;
-static gint ett_vines_rtp_compatibility_flags = -1;
-static gint ett_vines_rtp_req_info = -1;
-static gint ett_vines_rtp_control_flags = -1;
-static gint ett_vines_rtp_mtype = -1;
-static gint ett_vines_rtp_flags = -1;
+static int proto_vines_spp;
+static int hf_vines_spp_src_port;
+static int hf_vines_spp_dest_port;
+static int hf_vines_spp_packet_type;
+static int hf_vines_spp_control;
+static int hf_vines_spp_control_ack;
+static int hf_vines_spp_control_end_msg;
+static int hf_vines_spp_control_beg_msg;
+static int hf_vines_spp_control_abort_msg;
+static int hf_vines_spp_local_id;
+static int hf_vines_spp_remote_id;
+static int hf_vines_spp_seq_num;
+static int hf_vines_spp_ack_num;
+static int hf_vines_spp_window;
 
-static int proto_vines = -1;
-static int proto_vines_icp = -1;
-static int hf_vines_icp_exception_code = -1;
-static int hf_vines_icp_metric = -1;
-static int hf_vines_icp_packet_type = -1;
+static gint ett_vines_spp;
+static gint ett_vines_spp_control;
 
-static gint ett_vines_icp = -1;
+static dissector_handle_t vines_spp_handle;
+
+static int proto_vines_arp;
+static int hf_vines_arp_address;
+static int hf_vines_arp_version;
+static int hf_vines_arp_packet_type;
+static int hf_vines_arp_interface_metric;
+static int hf_vines_arp_sequence_number;
+
+static gint ett_vines_arp;
+
+static dissector_handle_t vines_arp_handle;
+
+static int proto_vines_rtp;
+static int hf_vines_rtp_comp_flag;
+static int hf_vines_rtp_comp_flag_neighbor_router;
+static int hf_vines_rtp_comp_flag_sequence_rtp;
+static int hf_vines_rtp_comp_flag_sequence_rtp_version;
+static int hf_vines_rtp_control;
+static int hf_vines_rtp_control_sync_broadcast;
+static int hf_vines_rtp_control_topology_update;
+static int hf_vines_rtp_control_specific_request;
+static int hf_vines_rtp_control_end_msg;
+static int hf_vines_rtp_control_beg_msg;
+static int hf_vines_rtp_machine_rtp;
+static int hf_vines_rtp_machine_tcpip;
+static int hf_vines_rtp_machine_bus;
+static int hf_vines_rtp_flag_sequence_rtp;
+static int hf_vines_rtp_flag_network_p2p;
+static int hf_vines_rtp_flag_data_link_p2p;
+static int hf_vines_rtp_flag_broadcast_medium;
+static int hf_vines_rtp_metric_to_preferred_gateway;
+static int hf_vines_rtp_requested_info;
+static int hf_vines_rtp_metric_to_destination;
+static int hf_vines_rtp_source_route_length;
+static int hf_vines_rtp_router_sequence_number;
+static int hf_vines_rtp_sequence_number;
+static int hf_vines_rtp_data_offset;
+static int hf_vines_rtp_preferred_gateway_sequence_number;
+static int hf_vines_rtp_preferred_gateway_node_type;
+static int hf_vines_rtp_metric;
+static int hf_vines_rtp_destination_sequence_number;
+static int hf_vines_rtp_link_address_length;
+static int hf_vines_rtp_controller_type;
+static int hf_vines_rtp_destination_node_type;
+static int hf_vines_rtp_information_type;
+static int hf_vines_rtp_version;
+static int hf_vines_rtp_preferred_gateway;
+static int hf_vines_rtp_neighbor_metric;
+static int hf_vines_rtp_destination;
+static int hf_vines_rtp_node_type;
+static int hf_vines_rtp_operation_type;
+static int hf_vines_rtp_packet_id;
+static int hf_vines_rtp_network_number;
+static int hf_vines_rtp_machine_type;
+static int hf_vines_rtp_destination_controller_type;
+static int hf_vines_rtp_destination_machine;
+static int hf_vines_rtp_pref_gateway_controller_type;
+static int hf_vines_rtp_pref_gateway_machine;
+static int hf_vines_rtp_network_flags;
+static int hf_vines_rtp_destination_flags;
+static int hf_vines_rtp_preferred_gateway_flags;
+static int hf_vines_rtp_preferred_gateway_data_link_address_ether;
+static int hf_vines_rtp_preferred_gateway_data_link_address_bytes;
+static int hf_vines_rtp_preferred_gateway_source_route;
+
+static gint ett_vines_rtp;
+static gint ett_vines_rtp_compatibility_flags;
+static gint ett_vines_rtp_req_info;
+static gint ett_vines_rtp_control_flags;
+static gint ett_vines_rtp_mtype;
+static gint ett_vines_rtp_flags;
+
+static dissector_handle_t vines_rtp_handle;
+
+static int proto_vines;
+static int proto_vines_icp;
+static int hf_vines_icp_exception_code;
+static int hf_vines_icp_metric;
+static int hf_vines_icp_packet_type;
+
+static gint ett_vines_icp;
+
+static dissector_handle_t vines_icp_handle;
+static capture_dissector_handle_t vines_echo_cap_handle;
+static capture_dissector_handle_t vines_ip_cap_handle;
 
 /* VINES IP structs and definitions */
 
@@ -299,15 +319,13 @@ typedef struct _e_vipc {
 	guint16 vipc_err_len;
 } e_vipc;
 
-static gboolean
+static bool
 capture_vines(const guchar *pd _U_, int offset _U_, int len _U_, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header _U_)
 {
 	capture_dissector_increment_count(cpinfo, proto_vines);
 	return TRUE;
 }
 
-static dissector_handle_t vines_ip_handle;
-
 /* Control flags */
 #define VINES_FRP_FIRST_FRAGMENT	0x01
 #define VINES_FRP_LAST_FRAGMENT		0x02
@@ -398,23 +416,17 @@ proto_register_vines_frp(void)
 		&ett_vines_frp_flags
 	};
 
-	proto_vines_frp = proto_register_protocol(
-	    "Banyan Vines Fragmentation Protocol", "Vines FRP", "vines_frp");
+	proto_vines_frp = proto_register_protocol("Banyan Vines Fragmentation Protocol", "Vines FRP", "vines_frp");
 	proto_register_field_array(proto_vines_frp, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	vines_frp_handle = register_dissector("vines_frp", dissect_vines_frp, proto_vines_frp);
+	vines_frp_new_handle = register_dissector("vines_frp.udp", dissect_vines_frp_new, proto_vines_frp);
 }
 
 void
 proto_reg_handoff_vines_frp(void)
 {
-	dissector_handle_t vines_frp_handle, vines_frp_new_handle;
-
-	vines_frp_handle = create_dissector_handle(dissect_vines_frp,
-	    proto_vines_frp);
 	dissector_add_uint("ip.proto", IP_PROTO_VINES, vines_frp_handle);
-
-	vines_frp_new_handle = create_dissector_handle(dissect_vines_frp_new,
-	    proto_vines_frp);
 	dissector_add_uint_with_preference("udp.port", UDP_PORT_VINES, vines_frp_new_handle);
 }
 
@@ -473,10 +485,10 @@ proto_register_vines_llc(void)
 		&ett_vines_llc,
 	};
 
-	proto_vines_llc = proto_register_protocol(
-	    "Banyan Vines LLC", "Vines LLC", "vines_llc");
+	proto_vines_llc = proto_register_protocol("Banyan Vines LLC", "Vines LLC", "vines_llc");
 	proto_register_field_array(proto_vines_llc, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	vines_llc_handle = register_dissector("vines_llc", dissect_vines_llc, proto_vines_llc);
 
 	/* subdissector code */
 	vines_llc_dissector_table = register_dissector_table("vines_llc.ptype",
@@ -486,10 +498,6 @@ proto_register_vines_llc(void)
 void
 proto_reg_handoff_vines_llc(void)
 {
-	dissector_handle_t vines_llc_handle;
-
-	vines_llc_handle = create_dissector_handle(dissect_vines_llc,
-	    proto_vines_llc);
 	dissector_add_uint("llc.dsap", SAP_VINES2, vines_llc_handle);
 }
 
@@ -686,7 +694,7 @@ proto_register_vines_ip(void)
 	vines_ip_dissector_table = register_dissector_table("vines_ip.protocol",
 	    "Vines protocol", proto_vines_ip, FT_UINT8, BASE_HEX);
 
-	vines_ip_handle = create_dissector_handle(dissect_vines_ip,
+	vines_ip_handle = register_dissector("vines_ip", dissect_vines_ip,
 	    proto_vines_ip);
 }
 
@@ -731,19 +739,16 @@ proto_register_vines_echo(void)
 		&ett_vines_echo,
 	};
 
-	proto_vines_echo = proto_register_protocol(
-	    "Banyan Vines Echo", "Vines Echo", "vines_echo");
+	proto_vines_echo = proto_register_protocol("Banyan Vines Echo", "Vines Echo", "vines_echo");
 	proto_register_field_array(proto_vines_echo, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	vines_echo_handle = register_dissector("vines_echo", dissect_vines_echo,
+	    proto_vines_echo);
 }
 
 void
 proto_reg_handoff_vines_echo(void)
 {
-	dissector_handle_t vines_echo_handle;
-
-	vines_echo_handle = create_dissector_handle(dissect_vines_echo,
-	    proto_vines_echo);
 	dissector_add_uint("vines_llc.ptype", VINES_LLC_ECHO, vines_echo_handle);
 	dissector_add_uint("ethertype", ETHERTYPE_VINES_ECHO, vines_echo_handle);
 }
@@ -982,17 +987,15 @@ proto_register_vines_ipc(void)
 	    "Vines IPC", "vines_ipc");
 	proto_register_field_array(proto_vines_ipc, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	vines_ipc_handle = register_dissector("vines_ipc", dissect_vines_ipc,
+	    proto_vines_ipc);
 
-	vines_ipc_heur_subdissector_list = register_heur_dissector_list("vines_ipc", proto_vines_ipc);
+	vines_ipc_heur_subdissector_list = register_heur_dissector_list_with_description("vines_ipc", "Vines IPC Data payload", proto_vines_ipc);
 }
 
 void
 proto_reg_handoff_vines_ipc(void)
 {
-	dissector_handle_t vines_ipc_handle;
-
-	vines_ipc_handle = create_dissector_handle(dissect_vines_ipc,
-	    proto_vines_ipc);
 	dissector_add_uint("vines_ip.protocol", VIP_PROTO_IPC, vines_ipc_handle);
 }
 
@@ -1150,17 +1153,15 @@ proto_register_vines_spp(void)
 	    "Vines SPP", "vines_spp");
 	proto_register_field_array(proto_vines_spp, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	vines_spp_handle = register_dissector("vines_spp", dissect_vines_spp,
+	    proto_vines_spp);
 
-	vines_spp_heur_subdissector_list = register_heur_dissector_list("vines_spp", proto_vines_spp);
+	vines_spp_heur_subdissector_list = register_heur_dissector_list_with_description("vines_spp", "Vines SPP Data payload", proto_vines_spp);
 }
 
 void
 proto_reg_handoff_vines_spp(void)
 {
-	dissector_handle_t vines_spp_handle;
-
-	vines_spp_handle = create_dissector_handle(dissect_vines_spp,
-	    proto_vines_spp);
 	dissector_add_uint("vines_ip.protocol", VIP_PROTO_SPP, vines_spp_handle);
 }
 
@@ -1283,19 +1284,16 @@ proto_register_vines_arp(void)
 		&ett_vines_arp,
 	};
 
-	proto_vines_arp = proto_register_protocol(
-	    "Banyan Vines ARP", "Vines ARP", "vines_arp");
+	proto_vines_arp = proto_register_protocol("Banyan Vines ARP", "Vines ARP", "vines_arp");
 	proto_register_field_array(proto_vines_arp, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	vines_arp_handle = register_dissector("vines_arp", dissect_vines_arp,
+	    proto_vines_arp);
 }
 
 void
 proto_reg_handoff_vines_arp(void)
 {
-	dissector_handle_t vines_arp_handle;
-
-	vines_arp_handle = create_dissector_handle(dissect_vines_arp,
-	    proto_vines_arp);
 	dissector_add_uint("vines_ip.protocol", VIP_PROTO_ARP, vines_arp_handle);
 }
 
@@ -1879,19 +1877,16 @@ proto_register_vines_rtp(void)
 		&ett_vines_rtp_flags,
 	};
 
-	proto_vines_rtp = proto_register_protocol(
-	    "Banyan Vines RTP", "Vines RTP", "vines_rtp");
+	proto_vines_rtp = proto_register_protocol("Banyan Vines RTP", "Vines RTP", "vines_rtp");
 	proto_register_field_array(proto_vines_rtp, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	vines_rtp_handle = register_dissector("vines_rtp", dissect_vines_rtp,
+	    proto_vines_rtp);
 }
 
 void
 proto_reg_handoff_vines_rtp(void)
 {
-	dissector_handle_t vines_rtp_handle;
-
-	vines_rtp_handle = create_dissector_handle(dissect_vines_rtp,
-	    proto_vines_rtp);
 	dissector_add_uint("vines_ip.protocol", VIP_PROTO_RTP, vines_rtp_handle);
 }
 
@@ -1990,27 +1985,23 @@ proto_register_vines_icp(void)
 		&ett_vines_icp,
 	};
 
-	proto_vines_icp = proto_register_protocol(
-	    "Banyan Vines ICP", "Vines ICP", "vines_icp");
+	proto_vines_icp = proto_register_protocol("Banyan Vines ICP", "Vines ICP", "vines_icp");
 	/* Placeholder for capture statistics */
 	proto_vines = proto_register_protocol("VINES", "VINES", "vines");
 	proto_register_field_array(proto_vines_icp, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+
+	vines_icp_handle = register_dissector("vines_icp", dissect_vines_icp, proto_vines_icp);
+	vines_ip_cap_handle = register_capture_dissector("vines.ip", capture_vines, proto_vines_ip);
+	vines_echo_cap_handle = register_capture_dissector("vines.echo", capture_vines, proto_vines_echo);
 }
 
 void
 proto_reg_handoff_vines_icp(void)
 {
-	dissector_handle_t vines_icp_handle;
-	capture_dissector_handle_t vines_echo_cap_handle;
-	capture_dissector_handle_t vines_ip_cap_handle;
-
-	vines_icp_handle = create_dissector_handle(dissect_vines_icp, proto_vines_icp);
 	dissector_add_uint("vines_ip.protocol", VIP_PROTO_ICP, vines_icp_handle);
 
-	vines_ip_cap_handle = create_capture_dissector_handle(capture_vines, proto_vines_ip);
 	capture_dissector_add_uint("ethertype", ETHERTYPE_VINES_IP, vines_ip_cap_handle);
-	vines_echo_cap_handle = create_capture_dissector_handle(capture_vines, proto_vines_echo);
 	capture_dissector_add_uint("ethertype", ETHERTYPE_VINES_ECHO, vines_echo_cap_handle);
 	capture_dissector_add_uint("ppp_hdlc", PPP_VINES, vines_echo_cap_handle);
 	capture_dissector_add_uint("ip.proto", PPP_VINES, vines_echo_cap_handle);
