@@ -21,13 +21,15 @@
 #include <epan/to_str.h>
 #include <epan/addr_resolv.h>
 #include <epan/proto_data.h>
+#include <epan/conversation_table.h>
+#include <epan/conversation_filter.h>
 
 void proto_register_vlan(void);
 void proto_reg_handoff_vlan(void);
 
 static unsigned int q_in_q_ethertype = ETHERTYPE_QINQ_OLD;
 
-static gboolean vlan_summary_in_tree = TRUE;
+static bool vlan_summary_in_tree = true;
 
 enum version_value {
   IEEE_8021Q_1998,
@@ -54,23 +56,23 @@ static capture_dissector_handle_t ipx_cap_handle;
 
 static int proto_vlan;
 
-static int hf_vlan_cfi = -1;
-static int hf_vlan_dei = -1;
-static int hf_vlan_etype = -1;
-static int hf_vlan_id = -1;
-static int hf_vlan_id_name = -1;
-static int hf_vlan_len = -1;
-static int hf_vlan_priority = -1;
-static int hf_vlan_priority_5 = -1;
-static int hf_vlan_priority_6 = -1;
-static int hf_vlan_priority_7 = -1;
-static int hf_vlan_priority_old = -1;
-static int hf_vlan_trailer = -1;
+static int hf_vlan_cfi;
+static int hf_vlan_dei;
+static int hf_vlan_etype;
+static int hf_vlan_id;
+static int hf_vlan_id_name;
+static int hf_vlan_len;
+static int hf_vlan_priority;
+static int hf_vlan_priority_5;
+static int hf_vlan_priority_6;
+static int hf_vlan_priority_7;
+static int hf_vlan_priority_old;
+static int hf_vlan_trailer;
 
-static gint ett_vlan = -1;
+static gint ett_vlan;
 
-static expert_field ei_vlan_len = EI_INIT;
-static expert_field ei_vlan_too_many_tags = EI_INIT;
+static expert_field ei_vlan_len;
+static expert_field ei_vlan_too_many_tags;
 
 /* From Table G-2 of IEEE standard 802.1D-2004 */
 /* Note that 0 is the default priority, but is above 1 and 2.
@@ -148,7 +150,7 @@ static const true_false_string tfs_eligible_ineligible = { "Eligible", "Ineligib
 
 #define VLAN_MAX_NESTED_TAGS 20
 
-static gboolean
+static bool
 capture_vlan(const guchar *pd, int offset, int len, capture_packet_info_t *cpinfo, const union wtap_pseudo_header *pseudo_header _U_ ) {
   guint16 encap_proto;
   if ( !BYTES_ARE_IN_FRAME(offset,len,5) )
@@ -182,7 +184,6 @@ columns_set_vlan(column_info *cinfo, guint16 tci)
                  "PRI: %d  DEI: %d  ID: %s",
                  (tci >> 13), ((tci >> 12) & 1), id_str);
   }
-  col_add_str(cinfo, COL_8021Q_VLAN_ID, id_str);
 }
 
 static int
@@ -315,6 +316,56 @@ dissect_vlan(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
     ethertype_data.trailer_id = hf_vlan_trailer;
     ethertype_data.fcs_len = 0;
 
+    /* deinterlacing requested */
+    if(prefs.conversation_deinterlacing_key>0) {
+      conversation_t *conv;
+      guint conv_type;
+      guint32 dtlc_iface = 0;
+      guint32 dtlc_vlan = 0;
+
+      if(prefs.conversation_deinterlacing_key&CONV_DEINT_KEY_INTERFACE &&
+         pinfo->rec->presence_flags & WTAP_HAS_INTERFACE_ID) {
+
+        if(prefs.conversation_deinterlacing_key&CONV_DEINT_KEY_VLAN &&
+           pinfo->vlan_id>0) {
+
+          conv_type = CONVERSATION_ETH_IV;
+          dtlc_iface = pinfo->rec->rec_header.packet_header.interface_id;
+          dtlc_vlan = pinfo->vlan_id;
+
+          /* look for existing conv, create one if none found */
+          conv = find_conversation_deinterlacer(pinfo->num, &pinfo->src, &pinfo->dst, conv_type,
+                                 dtlc_iface, dtlc_vlan, 0);
+
+          if(!conv) {
+            /* ETH _IN moulting into _IV */
+            conversation_new_deinterlacer(pinfo->num, &pinfo->src, &pinfo->dst,
+                                conv_type, dtlc_iface, pinfo->vlan_id, 0);
+          }
+        }
+        // else : vlan id == 0, such thing is not expected
+      }
+      else {
+        if(prefs.conversation_deinterlacing_key&CONV_DEINT_KEY_VLAN &&
+           pinfo->vlan_id>0) {
+
+          conv_type = CONVERSATION_ETH_NV;
+
+          /* look for existing conv, create one if none found */
+          conv = find_conversation_deinterlacer(pinfo->num, &pinfo->src, &pinfo->dst, conv_type,
+                                 dtlc_iface, pinfo->vlan_id, 0);
+
+          if(!conv) {
+            /* ETH _NN moulting into _NV */
+            conversation_new_deinterlacer(pinfo->num, &pinfo->src, &pinfo->dst,
+                                conv_type, dtlc_iface, pinfo->vlan_id, 0);
+          }
+        }
+        // else : vlan id == 0, such thing is not expected
+      }
+
+    }
+
     call_dissector_with_data(ethertype_handle, tvb, pinfo, tree, &ethertype_data);
   }
   return tvb_captured_length(tvb);
@@ -436,7 +487,7 @@ proto_register_vlan(void)
         "Priorities and drop eligibility",
         "Number of priorities supported, and number of those drop eligible (not used for 802.1Q-1998)",
         &vlan_priority_drop, priority_drop_vals, FALSE);
-  vlan_handle = create_dissector_handle(dissect_vlan, proto_vlan);
+  vlan_handle = register_dissector("vlan", dissect_vlan, proto_vlan);
 }
 
 void
