@@ -6,21 +6,15 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
+/*
+ * RFC 6386 - VP8 Data Format and Decoding Guide
+ * RFC 7741 - RTP Payload Format for VP8 Video
+ */
+
+
 #include "config.h"
 
 #include <epan/packet.h>
@@ -44,61 +38,59 @@ void proto_register_vp8(void);
 #define BIT_567_MASK            0x0E
 #define BIT_45678_MASK          0x1F
 #define BIT_12_MASK             0xC0
-#define BIT_NO_MASK             0xFF
+#define BIT_NO_MASK             0x0
 
-#define BIT_2BYTE_NO_MASK       0xFFFF
-#define BIT_3BYTE_NO_MASK       0xFFFFFF
+#define BIT_2BYTE_NO_MASK       0x0
+#define BIT_3BYTE_NO_MASK       0x0
 #define BIT_EXT_PICTURE_MASK    0x7FFF
-#define BIT_PARTITION_SIZE_MASK 0xE0FFFF
-
-static range_t *temp_dynamic_payload_type_range = NULL;
+#define BIT_PARTITION_SIZE_MASK 0xFFFFE0
 
 static dissector_handle_t vp8_handle;
 
 /* Initialize the protocol and registered fields */
-static int proto_vp8 = -1;
-static int hf_vp8_pld_x_bit = -1;
-static int hf_vp8_pld_r_bit = -1;
-static int hf_vp8_pld_n_bit = -1;
-static int hf_vp8_pld_s_bit = -1;
-static int hf_vp8_pld_part_id = -1;
-static int hf_vp8_pld_i_bit = -1;
-static int hf_vp8_pld_l_bit = -1;
-static int hf_vp8_pld_t_bit = -1;
-static int hf_vp8_pld_k_bit = -1;
-static int hf_vp8_pld_rsv_a = -1;
-static int hf_vp8_pld_picture_id = -1;
-static int hf_vp8_pld_extended_picture_id = -1;
-static int hf_vp8_pld_tl0picidx = -1;
-static int hf_vp8_pld_tid = -1;
-static int hf_vp8_pld_y_bit = -1;
-static int hf_vp8_pld_keyidx = -1;
+static int proto_vp8;
+static int hf_vp8_pld_x_bit;
+static int hf_vp8_pld_r_bit;
+static int hf_vp8_pld_n_bit;
+static int hf_vp8_pld_s_bit;
+static int hf_vp8_pld_part_id;
+static int hf_vp8_pld_i_bit;
+static int hf_vp8_pld_l_bit;
+static int hf_vp8_pld_t_bit;
+static int hf_vp8_pld_k_bit;
+static int hf_vp8_pld_rsv_a;
+static int hf_vp8_pld_picture_id;
+static int hf_vp8_pld_extended_picture_id;
+static int hf_vp8_pld_tl0picidx;
+static int hf_vp8_pld_tid;
+static int hf_vp8_pld_y_bit;
+static int hf_vp8_pld_keyidx;
 
 /* payload header fields */
-static int hf_vp8_hdr_frametype = -1;
-static int hf_vp8_hdr_version = -1;
-static int hf_vp8_hdr_show_bit = -1;
-static int hf_vp8_hdr_first_partition_size = -1;
+static int hf_vp8_hdr_frametype;
+static int hf_vp8_hdr_version;
+static int hf_vp8_hdr_show_bit;
+static int hf_vp8_hdr_first_partition_size;
 
 /* keyframe fields */
-static int hf_vp8_keyframe_start_code = -1;
-static int hf_vp8_keyframe_width = -1;
-static int hf_vp8_keyframe_horizontal_scale = -1;
-static int hf_vp8_keyframe_height = -1;
-static int hf_vp8_keyframe_vertical_scale = -1;
+static int hf_vp8_keyframe_start_code;
+static int hf_vp8_keyframe_width;
+static int hf_vp8_keyframe_horizontal_scale;
+static int hf_vp8_keyframe_height;
+static int hf_vp8_keyframe_vertical_scale;
 
 /* Initialize the subtree pointers */
-static int ett_vp8 = -1;
-static int ett_vp8_payload_descriptor = -1;
-static int ett_vp8_payload_header = -1;
-static int ett_vp8_payload = -1;
-static int ett_vp8_keyframe = -1;
+static int ett_vp8;
+static int ett_vp8_payload_descriptor;
+static int ett_vp8_payload_header;
+static int ett_vp8_payload;
+static int ett_vp8_keyframe;
 
-static expert_field ei_vp8_startcode = EI_INIT;
-static expert_field ei_vp8_undecoded = EI_INIT;
-static expert_field ei_vp8_continuation = EI_INIT;
-static expert_field ei_vp8_first_partition_split = EI_INIT;
-static expert_field ei_vp8_first_partition_plus = EI_INIT;
+static expert_field ei_vp8_startcode;
+static expert_field ei_vp8_undecoded;
+static expert_field ei_vp8_continuation;
+static expert_field ei_vp8_first_partition_split;
+static expert_field ei_vp8_first_partition_plus;
 
 static void
 dissect_vp8_payload_descriptor(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *vp8_tree, gint *offset, gboolean *hasHeader);
@@ -124,18 +116,27 @@ static const value_string vp8_type_values[] = {
     {  0, NULL }
 };
 
+static const range_string vp8_hdr_version_vals[] = {
+    {  0, 0,   "Bicubic  (Loop Filter=Normal)" },
+    {  1, 1,   "Bilinear (Loop Filter=Simple)" },
+    {  2, 2,   "Bilinear (Loop Filter=None)" },
+    {  3, 3,   "No filters" },
+    {  4, 7,   "Reserved for future use" },
+    {  0, 0,  NULL }
+};
+
 static const true_false_string vp8_x_bit_vals = {
     "Extended control bits present (I L T K)",
     "Extended control bits not present"
 };
 
 static const true_false_string vp8_r_bit_vals = {
-    "Reserved for future use (Error should be zero)",
+    "Reserved for future use (error: should be zero)",
     "Reserved for future use"
 };
 
 static const true_false_string vp8_n_bit_vals = {
-    "Non referenced frame",
+    "Non-reference frame",
     "Reference frame"
 };
 
@@ -155,13 +156,13 @@ static const true_false_string vp8_l_bit_vals = {
 };
 
 static const true_false_string vp8_t_bit_vals = {
-    "TID (temporal layer index) byte present",
-    "TID (temporal layer index) byte not present"
+    "TID (temporal layer index) present",
+    "TID (temporal layer index) not present"
 };
 
 static const true_false_string vp8_k_bit_vals = {
-    "TID/KEYIDX byte present",
-    "TID/KEYIDX byte not present"
+    "KEYIDX present",
+    "KEYIDX not present"
 };
 
 static const true_false_string vp8_hdr_frametype_vals = {
@@ -212,11 +213,11 @@ The first octets after the RTP header are the VP8 payload descriptor,
 
          0 1 2 3 4 5 6 7
         +-+-+-+-+-+-+-+-+
-        |X|R|N|S|PartID | (REQUIRED)
+        |X|R|N|S|R| PID | (REQUIRED), second R bit is parsed as part of PID
         +-+-+-+-+-+-+-+-+
    X:   |I|L|T|K| RSV   | (OPTIONAL)
         +-+-+-+-+-+-+-+-+
-   I:   |   PictureID   | (OPTIONAL)
+   I:   |M|  PictureID  | (OPTIONAL)
         +-+-+-+-+-+-+-+-+
    L:   |   TL0PICIDX   | (OPTIONAL)
         +-+-+-+-+-+-+-+-+
@@ -338,10 +339,7 @@ The first three octets of an encoded VP8 frame are referred to as an
     size2 = tvb_get_guint8(tvb, *offset + 2);
     (*partition1_size) = size0 + (size1*8) + (size2*2048);
     proto_tree_add_uint(vp8_payload_header_tree, hf_vp8_hdr_first_partition_size, tvb, *offset, 3, *partition1_size);
-    (*offset)++;
-    (*offset)++;
-    (*offset)++;
-
+    (*offset) += 3;
 }
 
 static void
@@ -444,7 +442,7 @@ proto_register_vp8(void)
             NULL, HFILL }
         },
         { &hf_vp8_pld_part_id,
-            { "Part Id",           "vp8.pld.partid",
+            { "2nd R bit and Part Id",           "vp8.pld.partid",
             FT_UINT8, BASE_DEC, NULL, BIT_5678_MASK,
             NULL, HFILL }
         },
@@ -474,13 +472,13 @@ proto_register_vp8(void)
             NULL, HFILL }
         },
         { &hf_vp8_pld_picture_id,
-            { "Picture Id",           "vp8.pld.pictureid",
+            { "Picture ID",           "vp8.pld.pictureid",
             FT_UINT8, BASE_DEC, NULL, BIT_NO_MASK,
             NULL, HFILL }
         },
         { &hf_vp8_pld_extended_picture_id,
-            { "Extended Picture Id",           "vp8.pld.pictureid",
-            FT_UINT8, BASE_DEC, NULL, BIT_EXT_PICTURE_MASK,
+            { "Extended Picture ID",           "vp8.pld.pictureid",
+            FT_UINT16, BASE_DEC, NULL, BIT_EXT_PICTURE_MASK,
             NULL, HFILL }
         },
         { &hf_vp8_pld_tl0picidx,
@@ -494,7 +492,7 @@ proto_register_vp8(void)
             NULL, HFILL }
         },
         { &hf_vp8_pld_y_bit,
-            { "1 Lay Sync Bit (Y)",           "vp8.pld.y",
+            { "1 layer sync bit (Y)",           "vp8.pld.y",
             FT_BOOLEAN, 8, NULL, BIT_3_MASK,
             NULL, HFILL }
         },
@@ -510,17 +508,17 @@ proto_register_vp8(void)
         },
         { &hf_vp8_hdr_version,
             { "version",           "vp8.hdr.version",
-            FT_UINT8, BASE_DEC, NULL, BIT_567_MASK,
+            FT_UINT8, BASE_DEC | BASE_RANGE_STRING, RVALS(vp8_hdr_version_vals), BIT_567_MASK,
             NULL, HFILL }
         },
         { &hf_vp8_hdr_show_bit,
             { "Show bit",           "vp8.hdr.show",
-            FT_BOOLEAN, 8, NULL, BIT_5_MASK,
-            NULL, HFILL }
+            FT_BOOLEAN, 8, NULL, BIT_4_MASK,
+            "Set when current frame is for display", HFILL }
         },
         { &hf_vp8_hdr_first_partition_size,
             { "First partition size",           "vp8.hdr.partition_size",
-            FT_UINT8, BASE_DEC, NULL, BIT_PARTITION_SIZE_MASK,
+            FT_UINT24, BASE_DEC, NULL, BIT_PARTITION_SIZE_MASK,
             NULL, HFILL }
         },
         { &hf_vp8_keyframe_start_code,
@@ -568,52 +566,26 @@ proto_register_vp8(void)
     proto_register_field_array(proto_vp8, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
 
-    vp8_module = prefs_register_protocol(proto_vp8, proto_reg_handoff_vp8);
+    vp8_module = prefs_register_protocol(proto_vp8, NULL);
 
     expert_vp8 = expert_register_protocol(proto_vp8);
     expert_register_field_array(expert_vp8, ei, array_length(ei));
 
-    prefs_register_range_preference(vp8_module, "dynamic.payload.type",
-                            "vp8 dynamic payload types",
-                            "Dynamic payload types which will be interpreted as vp8"
-                            "; Values must be in the range 96 - 127",
-                            &temp_dynamic_payload_type_range, 127);
+    prefs_register_obsolete_preference(vp8_module, "dynamic.payload.type");
 
     vp8_handle = register_dissector("vp8", dissect_vp8, proto_vp8);
 }
 
-static void
-range_delete_vp8_rtp_pt_callback(guint32 rtp_pt, gpointer ptr _U_) {
-    if ((rtp_pt >= 96) && (rtp_pt <= 127))
-        dissector_delete_uint("rtp.pt", rtp_pt, vp8_handle);
-}
-
-static void
-range_add_vp8_rtp_pt_callback(guint32 rtp_pt, gpointer ptr _U_) {
-    if ((rtp_pt >= 96) && (rtp_pt <= 127))
-        dissector_add_uint("rtp.pt", rtp_pt, vp8_handle);
-}
-
 void
 proto_reg_handoff_vp8(void)
 {
-    static range_t  *dynamic_payload_type_range = NULL;
-    static gboolean  vp8_prefs_initialized      = FALSE;
+    dissector_add_string("rtp_dyn_payload_type" , "VP8", vp8_handle);
 
-    if (!vp8_prefs_initialized) {
-        dissector_add_string("rtp_dyn_payload_type" , "VP8", vp8_handle);
-        vp8_prefs_initialized = TRUE;
-    } else {
-        range_foreach(dynamic_payload_type_range, range_delete_vp8_rtp_pt_callback, NULL);
-        wmem_free(wmem_epan_scope(), dynamic_payload_type_range);
-    }
-
-    dynamic_payload_type_range = range_copy(wmem_epan_scope(), temp_dynamic_payload_type_range);
-    range_foreach(dynamic_payload_type_range, range_add_vp8_rtp_pt_callback, NULL);
+    dissector_add_uint_range_with_preference("rtp.pt", "", vp8_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
