@@ -10,19 +10,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -36,30 +24,32 @@
 void proto_register_vrrp(void);
 void proto_reg_handoff_vrrp(void);
 
-static gint proto_vrrp = -1;
-static gint ett_vrrp = -1;
-static gint ett_vrrp_ver_type = -1;
+static dissector_handle_t vrrp_handle;
 
-static gint hf_vrrp_ver_type = -1;
-static gint hf_vrrp_version = -1;
-static gint hf_vrrp_type = -1;
-static gint hf_vrrp_virt_rtr_id = -1;
-static gint hf_vrrp_prio = -1;
-static gint hf_vrrp_addr_count = -1;
-static gint hf_vrrp_checksum = -1;
-static gint hf_vrrp_checksum_status = -1;
-static gint hf_vrrp_auth_type = -1;
-static gint hf_vrrp_adver_int = -1;
-static gint hf_vrrp_reserved_mbz = -1;
-static gint hf_vrrp_short_adver_int = -1;
-static gint hf_vrrp_ip = -1;
-static gint hf_vrrp_ip6 = -1;
-static gint hf_vrrp_auth_string = -1;
-static gint hf_vrrp_md5_auth_data = -1;
+static gint proto_vrrp;
+static gint ett_vrrp;
+static gint ett_vrrp_ver_type;
 
-static gboolean g_vrrp_v3_checksum_as_in_v2 = FALSE;
+static gint hf_vrrp_ver_type;
+static gint hf_vrrp_version;
+static gint hf_vrrp_type;
+static gint hf_vrrp_virt_rtr_id;
+static gint hf_vrrp_prio;
+static gint hf_vrrp_addr_count;
+static gint hf_vrrp_checksum;
+static gint hf_vrrp_checksum_status;
+static gint hf_vrrp_auth_type;
+static gint hf_vrrp_adver_int;
+static gint hf_vrrp_reserved_mbz;
+static gint hf_vrrp_short_adver_int;
+static gint hf_vrrp_ip;
+static gint hf_vrrp_ip6;
+static gint hf_vrrp_auth_string;
+static gint hf_vrrp_md5_auth_data;
 
-static expert_field ei_vrrp_checksum = EI_INIT;
+static bool g_vrrp_v3_checksum_as_in_v2 = true;
+
+static expert_field ei_vrrp_checksum;
 
 #define VRRP_VERSION_MASK  0xf0
 #define VRRP_TYPE_MASK     0x0f
@@ -216,7 +206,7 @@ dissect_vrrp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_
     }
 
     if (auth_type == VRRP_AUTH_TYPE_SIMPLE_TEXT) {
-        proto_tree_add_item(vrrp_tree, hf_vrrp_auth_string, tvb, offset, VRRP_AUTH_DATA_LEN, ENC_ASCII|ENC_NA);
+        proto_tree_add_item(vrrp_tree, hf_vrrp_auth_string, tvb, offset, VRRP_AUTH_DATA_LEN, ENC_ASCII);
         offset += VRRP_AUTH_DATA_LEN;
     } else if (auth_type == VRRP_AUTH_TYPE_IP_MD5) {
         if (vrrp_len - offset >= 16) {
@@ -234,17 +224,17 @@ void proto_register_vrrp(void)
         { &hf_vrrp_ver_type,
             {"VRRP message version and type", "vrrp.typever",
                 FT_UINT8, BASE_DEC, NULL, 0x0,
-                "VRRP version and type", HFILL }},
+                NULL, HFILL }},
 
         { &hf_vrrp_version,
             {"VRRP protocol version", "vrrp.version",
                 FT_UINT8, BASE_DEC, NULL, VRRP_VERSION_MASK,
-                "VRRP version", HFILL }},
+                NULL, HFILL }},
 
         { &hf_vrrp_type,
             {"VRRP packet type", "vrrp.type",
                 FT_UINT8, BASE_DEC, VALS(vrrp_type_vals), VRRP_TYPE_MASK,
-                "VRRP type", HFILL }},
+                NULL, HFILL }},
 
         { &hf_vrrp_virt_rtr_id,
             {"Virtual Rtr ID", "vrrp.virt_rtr_id",
@@ -324,11 +314,12 @@ void proto_register_vrrp(void)
     expert_module_t* expert_vrrp;
     module_t *vrrp_module;
 
-    proto_vrrp = proto_register_protocol("Virtual Router Redundancy Protocol",
-            "VRRP", "vrrp");
+    proto_vrrp = proto_register_protocol("Virtual Router Redundancy Protocol", "VRRP", "vrrp");
     proto_register_field_array(proto_vrrp, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
 
+    vrrp_handle = register_dissector("vrrp", dissect_vrrp, proto_vrrp);
+
     expert_vrrp = expert_register_protocol(proto_vrrp);
     expert_register_field_array(expert_vrrp, ei, array_length(ei));
 
@@ -336,24 +327,20 @@ void proto_register_vrrp(void)
 
     prefs_register_bool_preference(vrrp_module, "v3_checksum_as_in_v2",
         "Calculate V3 checksum as in V2 for IPv4 packets",
-        "There is some ambiguity on how to calculate V3 checksums"
-        "As in V3 will use a pseudo header(which may only be implemented for IPv6 by some manufacturers)",
+        "There was some ambiguity on how to calculate IPv4 V3 checksums. "
+        "As in v2 will not use a pseudo header (some manufacturers add a pseudo header for IPv4 checksum "
+        "since RFC5798 was ambiguous). RFC9568 specifies that there is no pseudo header for IPv4.",
         &g_vrrp_v3_checksum_as_in_v2);
-
-
 }
 
 void
 proto_reg_handoff_vrrp(void)
 {
-    dissector_handle_t vrrp_handle;
-
-    vrrp_handle = create_dissector_handle(dissect_vrrp, proto_vrrp);
     dissector_add_uint("ip.proto", IP_PROTO_VRRP, vrrp_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
