@@ -9,19 +9,7 @@
  * By Jens Kilian <jens.kilian@verigy.com>
  * Copyright 2009 Verigy Deutschland GmbH
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -104,43 +92,43 @@ void proto_reg_handoff_vxi11_async(void);
 void proto_register_vxi11_intr(void);
 void proto_reg_handoff_vxi11_intr(void);
 
-static int proto_vxi11_core = -1;
+static int proto_vxi11_core;
 
-static gint ett_vxi11_core = -1;
-static gint ett_vxi11_core_flags = -1;
-static gint ett_vxi11_core_reason = -1;
+static gint ett_vxi11_core;
+static gint ett_vxi11_core_flags;
+static gint ett_vxi11_core_reason;
 
-static int hf_vxi11_core_procedure_v1 = -1;
-static int hf_vxi11_core_abort_port = -1;
-static int hf_vxi11_core_client_id = -1;
-static int hf_vxi11_core_cmd = -1;
-static int hf_vxi11_core_data = -1;
-static int hf_vxi11_core_device = -1;
-static int hf_vxi11_core_enable = -1;
-static int hf_vxi11_core_error = -1;
-static int hf_vxi11_core_flags = -1;
-static int hf_vxi11_core_flag_wait_lock = -1;
-static int hf_vxi11_core_flag_end = -1;
-static int hf_vxi11_core_flag_term_chr_set = -1;
-static int hf_vxi11_core_handle = -1;
-static int hf_vxi11_core_host_addr = -1;
-static int hf_vxi11_core_host_port = -1;
-static int hf_vxi11_core_io_timeout = -1;
-static int hf_vxi11_core_lid = -1;
-static int hf_vxi11_core_lock_device = -1;
-static int hf_vxi11_core_lock_timeout = -1;
-static int hf_vxi11_core_max_recv_size = -1;
-static int hf_vxi11_core_network_order = -1;
-static int hf_vxi11_core_prog_family = -1;
-static int hf_vxi11_core_prog_num = -1;
-static int hf_vxi11_core_prog_vers = -1;
-static int hf_vxi11_core_reason = -1;
-static int hf_vxi11_core_reason_req_cnt = -1;
-static int hf_vxi11_core_reason_chr = -1;
-static int hf_vxi11_core_reason_end = -1;
-static int hf_vxi11_core_size = -1;
-static int hf_vxi11_core_stb = -1;
-static int hf_vxi11_core_term_char = -1;
+static int hf_vxi11_core_procedure_v1;
+static int hf_vxi11_core_abort_port;
+static int hf_vxi11_core_client_id;
+static int hf_vxi11_core_cmd;
+static int hf_vxi11_core_data;
+static int hf_vxi11_core_device;
+static int hf_vxi11_core_enable;
+static int hf_vxi11_core_error;
+static int hf_vxi11_core_flags;
+static int hf_vxi11_core_flag_wait_lock;
+static int hf_vxi11_core_flag_end;
+static int hf_vxi11_core_flag_term_chr_set;
+static int hf_vxi11_core_handle;
+static int hf_vxi11_core_host_addr;
+static int hf_vxi11_core_host_port;
+static int hf_vxi11_core_io_timeout;
+static int hf_vxi11_core_lid;
+static int hf_vxi11_core_lock_device;
+static int hf_vxi11_core_lock_timeout;
+static int hf_vxi11_core_max_recv_size;
+static int hf_vxi11_core_network_order;
+static int hf_vxi11_core_prog_family;
+static int hf_vxi11_core_prog_num;
+static int hf_vxi11_core_prog_vers;
+static int hf_vxi11_core_reason;
+static int hf_vxi11_core_reason_req_cnt;
+static int hf_vxi11_core_reason_chr;
+static int hf_vxi11_core_reason_end;
+static int hf_vxi11_core_size;
+static int hf_vxi11_core_stb;
+static int hf_vxi11_core_term_char;
 
 static const value_string vxi11_core_error_vals[] = {
     { VXI11_CORE_ERROR_NO_ERROR, "No Error" },
@@ -181,11 +169,11 @@ static const value_string vxi11_core_cmd_vals[] = {
 #define VXI11_ASYNC_PROGRAM 0x0607B0
 #define VXI11_ASYNC_VERSION 1
 
-static int proto_vxi11_async = -1;
+static int proto_vxi11_async;
 
-static gint ett_vxi11_async = -1;
+static gint ett_vxi11_async;
 
-static int hf_vxi11_async_procedure_v1 = -1;
+static int hf_vxi11_async_procedure_v1;
 
 
 /* Interrupt protocol. */
@@ -196,12 +184,12 @@ static int hf_vxi11_async_procedure_v1 = -1;
 #define VXI11_INTR_PROGRAM 0x0607B1
 #define VXI11_INTR_VERSION 1
 
-static int proto_vxi11_intr = -1;
+static int proto_vxi11_intr;
 
-static gint ett_vxi11_intr = -1;
+static gint ett_vxi11_intr;
 
-static int hf_vxi11_intr_procedure_v1 = -1;
-static int hf_vxi11_intr_handle = -1;
+static int hf_vxi11_intr_procedure_v1;
+static int hf_vxi11_intr_handle;
 
 
 /* Helper routines for dissecting common fields. */
@@ -248,7 +236,7 @@ dissect_flags(tvbuff_t *tvb, int offset, proto_tree *tree)
 
             if (flags != 0)
             {
-                wmem_strbuf_t *strbuf = wmem_strbuf_new_label(wmem_packet_scope());
+                wmem_strbuf_t *strbuf = wmem_strbuf_create(wmem_packet_scope());
 
                 if (flags & VXI11_CORE_FLAG_WAITLOCK)
                 {
@@ -293,7 +281,7 @@ dissect_reason(tvbuff_t *tvb, int offset, proto_tree *tree)
 
             if (reason != 0)
             {
-                wmem_strbuf_t *strbuf = wmem_strbuf_new_label(wmem_packet_scope());
+                wmem_strbuf_t *strbuf = wmem_strbuf_create(wmem_packet_scope());
 
                 if (reason & VXI11_CORE_REASON_REQCNT)
                 {
@@ -536,7 +524,7 @@ dissect_device_read_resp(tvbuff_t *tvb,
     datalength = tvb_get_ntohl( tvb, offset);
     if(MAX_DATA_SHOW_SIZE <=datalength)
         datalength = MAX_DATA_SHOW_SIZE;
-    col_append_fstr( pinfo->cinfo, COL_INFO," %s",tvb_format_text(tvb, offset+4,(guint32) datalength));
+    col_append_fstr( pinfo->cinfo, COL_INFO," %s",tvb_format_text(pinfo->pool, tvb, offset+4,(guint32) datalength));
 
     offset = dissect_rpc_opaque_data(tvb, offset, tree, NULL, hf_vxi11_core_data, FALSE, 0, FALSE, NULL, NULL);
 
@@ -574,7 +562,7 @@ dissect_device_remote_func(tvbuff_t *tvb,
     const gchar *addrstr;
     int offset = 0;
 
-    addrstr = tvb_ip_to_str(tvb, offset);
+    addrstr = tvb_ip_to_str(pinfo->pool, tvb, offset);
     offset = dissect_rpc_uint32(tvb, tree, hf_vxi11_core_host_addr, offset);
 
     port   = tvb_get_ntohl(tvb, offset);
@@ -608,7 +596,7 @@ dissect_device_write_parms(tvbuff_t *tvb,
     datalength = tvb_get_ntohl( tvb, offset);
     if(MAX_DATA_SHOW_SIZE <=datalength)
         datalength = MAX_DATA_SHOW_SIZE;
-    col_append_fstr( pinfo->cinfo, COL_INFO," %s",tvb_format_text(tvb, offset+4,(guint32) datalength));
+    col_append_fstr( pinfo->cinfo, COL_INFO," %s",tvb_format_text(pinfo->pool, tvb, offset+4,(guint32) datalength));
 
     offset = dissect_rpc_opaque_data(tvb, offset, tree, NULL, hf_vxi11_core_data, FALSE, 0, FALSE, NULL, NULL);
     proto_item_append_text(tree, " (Device_WriteParms) LID=%d", lid);
@@ -1011,7 +999,7 @@ proto_reg_handoff_vxi11_intr(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 4
