@@ -54,98 +54,98 @@ static reassembly_table wai_reassembly_table;
 
 static dissector_handle_t wai_handle;
 
-static int proto_wai = -1;
+static int proto_wai;
 
-static gint hf_wai_version = -1;
-static gint hf_wai_type = -1;
-static gint hf_wai_subtype = -1;
-static gint hf_wai_reserved = -1;
-static gint hf_wai_length = -1;
-static gint hf_wai_seq = -1;
-static gint hf_wai_fragm_seq = -1;
-static gint hf_wai_flag = -1;
-static gint hf_wai_data = -1;
-static gint hf_wai_bk_rekeying_flag = -1;
-static gint hf_wai_preauthentication_flag = -1;
-static gint hf_wai_certificate_flag = -1;
-static gint hf_wai_optional_flag = -1;
-static gint hf_wai_usk_rekeying_flag = -1;
-static gint hf_wai_negotiation_flag = -1;
-static gint hf_wai_revoking_flag = -1;
-static gint hf_wai_reserved_flag = -1;
-static gint hf_wai_attr_type = -1;
-static gint hf_wai_cert = -1;
-static gint hf_wai_cert_id = -1;
-static gint hf_wai_cert_data = -1;
-static gint hf_wai_cert_len = -1;
-static gint hf_wai_addid = -1;
-static gint hf_wai_ae_mac = -1;
-static gint hf_wai_asue_mac = -1;
-static gint hf_wai_bkid = -1;
-static gint hf_wai_uskid = -1;
-static gint hf_wai_wie = -1;
-static gint hf_wai_message_auth_code = -1;
-static gint hf_wai_mskid = -1;
-static gint hf_wai_data_pack_num = -1;
-static gint hf_wai_key_data = -1;
-static gint hf_wai_key_data_len = -1;
-static gint hf_wai_key_data_content = -1;
-static gint hf_wai_key_ann_id = -1;
-static gint hf_wai_auth_id = -1;
-static gint hf_wai_identity = -1;
-static gint hf_wai_identity_id = -1;
-static gint hf_wai_identity_len = -1;
-static gint hf_wai_identity_data = -1;
-static gint hf_wai_ecdh = -1;
-static gint hf_wai_ecdh_id = -1;
-static gint hf_wai_ecdh_len = -1;
-static gint hf_wai_ecdh_content = -1;
-static gint hf_wai_counter = -1;
-static gint hf_wai_sta_key_id = -1;
-static gint hf_wai_challenge = -1;
-static gint hf_wai_cert_ver = -1;
-static gint hf_wai_nonce = -1;
-static gint hf_wai_ver_res = -1;
-static gint hf_wai_sign_alg = -1;
-static gint hf_wai_hash_alg_id = -1;
-static gint hf_wai_sign_alg_id = -1;
-static gint hf_wai_param = -1;
-static gint hf_wai_param_id = -1;
-static gint hf_wai_param_content = -1;
-static gint hf_wai_sign_val = -1;
-static gint hf_wai_sign_content = -1;
-static gint hf_wai_sign = -1;
-static gint hf_wai_identity_list = -1;
-static gint hf_wai_reserved_byte = -1;
-static gint hf_wai_no_of_ids = -1;
-static gint hf_wai_access_res = -1;
-static gint hf_wai_fragments = -1;
-static gint hf_wai_fragment = -1;
-static gint hf_wai_fragment_overlap = -1;
-static gint hf_wai_fragment_overlap_conflicts = -1;
-static gint hf_wai_fragment_multiple_tails = -1;
-static gint hf_wai_fragment_too_long_fragment = -1;
-static gint hf_wai_fragment_error = -1;
-static gint hf_wai_fragment_count = -1;
-static gint hf_wai_reassembled_in = -1;
-static gint hf_wai_reassembled_length = -1;
+static gint hf_wai_version;
+static gint hf_wai_type;
+static gint hf_wai_subtype;
+static gint hf_wai_reserved;
+static gint hf_wai_length;
+static gint hf_wai_seq;
+static gint hf_wai_fragm_seq;
+static gint hf_wai_flag;
+static gint hf_wai_data;
+static gint hf_wai_bk_rekeying_flag;
+static gint hf_wai_preauthentication_flag;
+static gint hf_wai_certificate_flag;
+static gint hf_wai_optional_flag;
+static gint hf_wai_usk_rekeying_flag;
+static gint hf_wai_negotiation_flag;
+static gint hf_wai_revoking_flag;
+static gint hf_wai_reserved_flag;
+static gint hf_wai_attr_type;
+static gint hf_wai_cert;
+static gint hf_wai_cert_id;
+static gint hf_wai_cert_data;
+static gint hf_wai_cert_len;
+static gint hf_wai_addid;
+static gint hf_wai_ae_mac;
+static gint hf_wai_asue_mac;
+static gint hf_wai_bkid;
+static gint hf_wai_uskid;
+static gint hf_wai_wie;
+static gint hf_wai_message_auth_code;
+static gint hf_wai_mskid;
+static gint hf_wai_data_pack_num;
+static gint hf_wai_key_data;
+static gint hf_wai_key_data_len;
+static gint hf_wai_key_data_content;
+static gint hf_wai_key_ann_id;
+static gint hf_wai_auth_id;
+static gint hf_wai_identity;
+static gint hf_wai_identity_id;
+static gint hf_wai_identity_len;
+static gint hf_wai_identity_data;
+static gint hf_wai_ecdh;
+static gint hf_wai_ecdh_id;
+static gint hf_wai_ecdh_len;
+static gint hf_wai_ecdh_content;
+static gint hf_wai_counter;
+static gint hf_wai_sta_key_id;
+static gint hf_wai_challenge;
+static gint hf_wai_cert_ver;
+static gint hf_wai_nonce;
+static gint hf_wai_ver_res;
+static gint hf_wai_sign_alg;
+static gint hf_wai_hash_alg_id;
+static gint hf_wai_sign_alg_id;
+static gint hf_wai_param;
+static gint hf_wai_param_id;
+static gint hf_wai_param_content;
+static gint hf_wai_sign_val;
+static gint hf_wai_sign_content;
+static gint hf_wai_sign;
+static gint hf_wai_identity_list;
+static gint hf_wai_reserved_byte;
+static gint hf_wai_no_of_ids;
+static gint hf_wai_access_res;
+static gint hf_wai_fragments;
+static gint hf_wai_fragment;
+static gint hf_wai_fragment_overlap;
+static gint hf_wai_fragment_overlap_conflicts;
+static gint hf_wai_fragment_multiple_tails;
+static gint hf_wai_fragment_too_long_fragment;
+static gint hf_wai_fragment_error;
+static gint hf_wai_fragment_count;
+static gint hf_wai_reassembled_in;
+static gint hf_wai_reassembled_length;
 
-static gint ett_wai = -1;
-static gint ett_wai_data = -1;
-static gint ett_wai_flags = -1;
-static gint ett_wai_certificate = -1;
-static gint ett_wai_mac = -1;
-static gint ett_wai_identity = -1;
-static gint ett_wai_key_data = -1;
-static gint ett_wai_ecdh_param = -1;
-static gint ett_wai_certificate_verification = -1;
-static gint ett_wai_identity_list = -1;
-static gint ett_wai_sign = -1;
-static gint ett_wai_sign_alg = -1;
-static gint ett_wai_sign_val = -1;
-static gint ett_wai_parameter = -1;
-static gint ett_wai_fragment = -1;
-static gint ett_wai_fragments = -1;
+static gint ett_wai;
+static gint ett_wai_data;
+static gint ett_wai_flags;
+static gint ett_wai_certificate;
+static gint ett_wai_mac;
+static gint ett_wai_identity;
+static gint ett_wai_key_data;
+static gint ett_wai_ecdh_param;
+static gint ett_wai_certificate_verification;
+static gint ett_wai_identity_list;
+static gint ett_wai_sign;
+static gint ett_wai_sign_alg;
+static gint ett_wai_sign_val;
+static gint ett_wai_parameter;
+static gint ett_wai_fragment;
+static gint ett_wai_fragments;
 
 static const value_string wai_type_names [] = {
     { 1, "WAI protocol package"},
