@@ -29,140 +29,140 @@ void proto_register_waveagent(void);
 void proto_reg_handoff_waveagent(void);
 
 /* Initialize the protocol and registered fields */
-static int proto_waveagent = -1;
-static int hf_waveagent_controlword = -1;
-static int hf_waveagent_payloadlen = -1;
-static int hf_waveagent_transnum = -1;
-static int hf_waveagent_rtoken = -1;
-static int hf_waveagent_flowid = -1;
-static int hf_waveagent_capstatus = -1;
-static int hf_waveagent_protocolversion = -1;
-static int hf_waveagent_capimpl = -1;
-static int hf_waveagent_id = -1;
-static int hf_waveagent_bindtag = -1;
-static int hf_waveagent_version = -1;
-static int hf_waveagent_brokerip = -1;
-static int hf_waveagent_brokerport = -1;
-static int hf_waveagent_bindlevel = -1;
-static int hf_waveagent_bindport = -1;
-static int hf_waveagent_numinterfaces = -1;
-static int hf_waveagent_capabilities2 = -1;
-static int hf_waveagent_ifmask = -1;
-static int hf_waveagent_commandstatus = -1;
-static int hf_waveagent_syserrno = -1;
-static int hf_waveagent_statusstring = -1;
-static int hf_waveagent_rxdatapckts = -1;
-static int hf_waveagent_rxdatabytes = -1;
-static int hf_waveagent_rxpcktrate = -1;
-static int hf_waveagent_rxbyterate = -1;
-static int hf_waveagent_txdatapckts = -1;
-static int hf_waveagent_txdatabytes = -1;
-static int hf_waveagent_txpcktrate = -1;
-static int hf_waveagent_txbyterate = -1;
-static int hf_waveagent_looppckts = -1;
-static int hf_waveagent_loopbytes = -1;
-static int hf_waveagent_rxctlpckts = -1;
-static int hf_waveagent_rxctlbytes = -1;
-static int hf_waveagent_txctlpckts = -1;
-static int hf_waveagent_txctlbytes = -1;
-static int hf_waveagent_unknowncmds = -1;
-static int hf_waveagent_snap = -1;
-static int hf_waveagent_state = -1;
-static int hf_waveagent_appstate = -1;
-static int hf_waveagent_rx1pl = -1;
-static int hf_waveagent_rx2pl = -1;
-static int hf_waveagent_rx3pl = -1;
-static int hf_waveagent_rx4pl = -1;
-static int hf_waveagent_rx5pl = -1;
-static int hf_waveagent_rxoospkts = -1;
-/* static int hf_waveagent_rxmeanlatency = -1; */
-/* static int hf_waveagent_rxminlatency = -1; */
-/* static int hf_waveagent_rxmaxlatency = -1; */
-static int hf_waveagent_latencysum = -1;
-static int hf_waveagent_latencycount = -1;
-static int hf_waveagent_txflowstop = -1;
-static int hf_waveagent_jitter = -1;
-static int hf_waveagent_remoteport = -1;
-static int hf_waveagent_remoteaddr = -1;
-static int hf_waveagent_dscp = -1;
-static int hf_waveagent_fsflags = -1;
-static int hf_waveagent_fscbrflag = -1;
-static int hf_waveagent_fscombinedsetupflag = -1;
-/* static int hf_waveagent_totalbytes = -1; */
-static int hf_waveagent_payfill = -1;
-static int hf_waveagent_paysize = -1;
-static int hf_waveagent_avgrate = -1;
-static int hf_waveagent_rxflownum = -1;
-static int hf_waveagent_mode = -1;
-static int hf_waveagent_endpointtype = -1;
-static int hf_waveagent_totalframes = -1;
-static int hf_waveagent_bssidstartindex = -1;
-static int hf_waveagent_bssidstopindex = -1;
-static int hf_waveagent_ifindex = -1;
-static int hf_waveagent_iftype = -1;
-static int hf_waveagent_ifdescription = -1;
-static int hf_waveagent_ifmacaddr = -1;
-static int hf_waveagent_iflinkspeed = -1;
-static int hf_waveagent_ifdhcp = -1;
-static int hf_waveagent_ifwlanbssid = -1;
-static int hf_waveagent_ifwlanssid = -1;
-static int hf_waveagent_ifiptype = -1;
-static int hf_waveagent_ifipv4 = -1;
-static int hf_waveagent_ifipv6 = -1;
-static int hf_waveagent_ifdhcpserver = -1;
-static int hf_waveagent_ifgateway = -1;
-static int hf_waveagent_ifdnsserver = -1;
-static int hf_waveagent_ifethl2status = -1;
-static int hf_waveagent_ifwlanl2status = -1;
-static int hf_waveagent_ifl3status = -1;
-static int hf_waveagent_totalbssid = -1;
-static int hf_waveagent_returnedbssid = -1;
-static int hf_waveagent_scanbssid = -1;
-static int hf_waveagent_scanssid = -1;
-static int hf_waveagent_ifwlanrssi = -1;
-static int hf_waveagent_ifwlansupprates = -1;
-static int hf_waveagent_ifwlancapabilities = -1;
-static int hf_waveagent_ifwlanchannel = -1;
-static int hf_waveagent_ifwlanprivacy = -1;
-static int hf_waveagent_ifwlanbssmode = -1;
-static int hf_waveagent_ifwlannoise = -1;
-static int hf_waveagent_ifphytypes = -1;
-static int hf_waveagent_ifphytypebit0 = -1;
-static int hf_waveagent_ifphytypebit1 = -1;
-static int hf_waveagent_ifphytypebit2 = -1;
-static int hf_waveagent_ifphytypebit3 = -1;
-/* static int hf_waveagent_ifphytypebit4 = -1; */
-static int hf_waveagent_ifwlanauthentication = -1;
-static int hf_waveagent_ifwlancipher = -1;
-static int hf_waveagent_delayfactor = -1;
-static int hf_waveagent_medialossrate = -1;
-static int hf_waveagent_txstartts = -1;
-static int hf_waveagent_txendts = -1;
-static int hf_waveagent_rxstartts = -1;
-static int hf_waveagent_rxendts = -1;
-static int hf_waveagent_oidcode = -1;
-static int hf_waveagent_oidvalue = -1;
-static int hf_waveagent_destip = -1;
-static int hf_waveagent_destport = -1;
-static int hf_waveagent_connectflags = -1;
-static int hf_waveagent_connecttype = -1;
-static int hf_waveagent_minrssi = -1;
-static int hf_waveagent_connecttimeout = -1;
-static int hf_waveagent_connectattempts = -1;
-static int hf_waveagent_reason = -1;
-static int hf_waveagent_sigsequencenum = -1;
-static int hf_waveagent_relaydestid = -1;
-static int hf_waveagent_relaysrcid = -1;
-static int hf_waveagent_relaymessagest = -1;
+static int proto_waveagent;
+static int hf_waveagent_controlword;
+static int hf_waveagent_payloadlen;
+static int hf_waveagent_transnum;
+static int hf_waveagent_rtoken;
+static int hf_waveagent_flowid;
+static int hf_waveagent_capstatus;
+static int hf_waveagent_protocolversion;
+static int hf_waveagent_capimpl;
+static int hf_waveagent_id;
+static int hf_waveagent_bindtag;
+static int hf_waveagent_version;
+static int hf_waveagent_brokerip;
+static int hf_waveagent_brokerport;
+static int hf_waveagent_bindlevel;
+static int hf_waveagent_bindport;
+static int hf_waveagent_numinterfaces;
+static int hf_waveagent_capabilities2;
+static int hf_waveagent_ifmask;
+static int hf_waveagent_commandstatus;
+static int hf_waveagent_syserrno;
+static int hf_waveagent_statusstring;
+static int hf_waveagent_rxdatapckts;
+static int hf_waveagent_rxdatabytes;
+static int hf_waveagent_rxpcktrate;
+static int hf_waveagent_rxbyterate;
+static int hf_waveagent_txdatapckts;
+static int hf_waveagent_txdatabytes;
+static int hf_waveagent_txpcktrate;
+static int hf_waveagent_txbyterate;
+static int hf_waveagent_looppckts;
+static int hf_waveagent_loopbytes;
+static int hf_waveagent_rxctlpckts;
+static int hf_waveagent_rxctlbytes;
+static int hf_waveagent_txctlpckts;
+static int hf_waveagent_txctlbytes;
+static int hf_waveagent_unknowncmds;
+static int hf_waveagent_snap;
+static int hf_waveagent_state;
+static int hf_waveagent_appstate;
+static int hf_waveagent_rx1pl;
+static int hf_waveagent_rx2pl;
+static int hf_waveagent_rx3pl;
+static int hf_waveagent_rx4pl;
+static int hf_waveagent_rx5pl;
+static int hf_waveagent_rxoospkts;
+/* static int hf_waveagent_rxmeanlatency; */
+/* static int hf_waveagent_rxminlatency; */
+/* static int hf_waveagent_rxmaxlatency; */
+static int hf_waveagent_latencysum;
+static int hf_waveagent_latencycount;
+static int hf_waveagent_txflowstop;
+static int hf_waveagent_jitter;
+static int hf_waveagent_remoteport;
+static int hf_waveagent_remoteaddr;
+static int hf_waveagent_dscp;
+static int hf_waveagent_fsflags;
+static int hf_waveagent_fscbrflag;
+static int hf_waveagent_fscombinedsetupflag;
+/* static int hf_waveagent_totalbytes; */
+static int hf_waveagent_payfill;
+static int hf_waveagent_paysize;
+static int hf_waveagent_avgrate;
+static int hf_waveagent_rxflownum;
+static int hf_waveagent_mode;
+static int hf_waveagent_endpointtype;
+static int hf_waveagent_totalframes;
+static int hf_waveagent_bssidstartindex;
+static int hf_waveagent_bssidstopindex;
+static int hf_waveagent_ifindex;
+static int hf_waveagent_iftype;
+static int hf_waveagent_ifdescription;
+static int hf_waveagent_ifmacaddr;
+static int hf_waveagent_iflinkspeed;
+static int hf_waveagent_ifdhcp;
+static int hf_waveagent_ifwlanbssid;
+static int hf_waveagent_ifwlanssid;
+static int hf_waveagent_ifiptype;
+static int hf_waveagent_ifipv4;
+static int hf_waveagent_ifipv6;
+static int hf_waveagent_ifdhcpserver;
+static int hf_waveagent_ifgateway;
+static int hf_waveagent_ifdnsserver;
+static int hf_waveagent_ifethl2status;
+static int hf_waveagent_ifwlanl2status;
+static int hf_waveagent_ifl3status;
+static int hf_waveagent_totalbssid;
+static int hf_waveagent_returnedbssid;
+static int hf_waveagent_scanbssid;
+static int hf_waveagent_scanssid;
+static int hf_waveagent_ifwlanrssi;
+static int hf_waveagent_ifwlansupprates;
+static int hf_waveagent_ifwlancapabilities;
+static int hf_waveagent_ifwlanchannel;
+static int hf_waveagent_ifwlanprivacy;
+static int hf_waveagent_ifwlanbssmode;
+static int hf_waveagent_ifwlannoise;
+static int hf_waveagent_ifphytypes;
+static int hf_waveagent_ifphytypebit0;
+static int hf_waveagent_ifphytypebit1;
+static int hf_waveagent_ifphytypebit2;
+static int hf_waveagent_ifphytypebit3;
+/* static int hf_waveagent_ifphytypebit4; */
+static int hf_waveagent_ifwlanauthentication;
+static int hf_waveagent_ifwlancipher;
+static int hf_waveagent_delayfactor;
+static int hf_waveagent_medialossrate;
+static int hf_waveagent_txstartts;
+static int hf_waveagent_txendts;
+static int hf_waveagent_rxstartts;
+static int hf_waveagent_rxendts;
+static int hf_waveagent_oidcode;
+static int hf_waveagent_oidvalue;
+static int hf_waveagent_destip;
+static int hf_waveagent_destport;
+static int hf_waveagent_connectflags;
+static int hf_waveagent_connecttype;
+static int hf_waveagent_minrssi;
+static int hf_waveagent_connecttimeout;
+static int hf_waveagent_connectattempts;
+static int hf_waveagent_reason;
+static int hf_waveagent_sigsequencenum;
+static int hf_waveagent_relaydestid;
+static int hf_waveagent_relaysrcid;
+static int hf_waveagent_relaymessagest;
 
 /* Initialize the subtree pointers */
-static gint ett_waveagent = -1;
-static gint ett_statechange = -1;
-static gint ett_phytypes = -1;
-static gint ett_fsflags = -1;
-static gint ett_scindex[8] = { -1, -1, -1, -1, -1, -1, -1, -1 };  /* NUM_STATE_CHANGES */
-static gint ett_bss[8]     = { -1, -1, -1, -1, -1, -1, -1, -1 };  /* NUM_BSS           */
-static gint ett_relaymessage = -1;
+static gint ett_waveagent;
+static gint ett_statechange;
+static gint ett_phytypes;
+static gint ett_fsflags;
+static gint ett_scindex[8];  /* NUM_STATE_CHANGES */
+static gint ett_bss[8];  /* NUM_BSS           */
+static gint ett_relaymessage;
 
 
 static const value_string control_words[] = {
@@ -1062,9 +1062,9 @@ static int dissect_waveagent(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
     return tvb_captured_length(tvb);
 }
 
-static gboolean dissect_waveagent_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool dissect_waveagent_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
 {
-    return (dissect_waveagent(tvb, pinfo, tree) > 0) ? TRUE : FALSE;
+    return dissect_waveagent(tvb, pinfo, tree) > 0;
 }
 
 
@@ -1261,17 +1261,17 @@ void proto_register_waveagent(void)
 
         { &hf_waveagent_id,
         { "ID", "waveagent.id",
-        FT_STRING, 0, NULL, 0x0,
+        FT_STRING, BASE_NONE, NULL, 0x0,
         NULL, HFILL } },
 
         { &hf_waveagent_bindtag,
         { "Binding Tag", "waveagent.bindtag",
-        FT_STRING, 0, NULL, 0x0,
+        FT_STRING, BASE_NONE, NULL, 0x0,
         NULL, HFILL } },
 
         { &hf_waveagent_version,
         { "Version", "waveagent.version",
-        FT_STRING, 0, NULL, 0x0,
+        FT_STRING, BASE_NONE, NULL, 0x0,
         NULL, HFILL } },
 
         { &hf_waveagent_brokerip,
@@ -1330,7 +1330,7 @@ void proto_register_waveagent(void)
 
         { &hf_waveagent_statusstring,
         { "Status Message", "waveagent.statmsg",
-        FT_STRING, 0, NULL, 0x0,
+        FT_STRING, BASE_NONE, NULL, 0x0,
         NULL, HFILL } },
     /* END: Command response message fields */
 
@@ -1617,7 +1617,7 @@ void proto_register_waveagent(void)
 
         { &hf_waveagent_ifwlanssid,
         { "WLAN Interface Connected to SSID", "waveagent.ifwlanssid",
-        FT_STRING, 0, NULL, 0x0,
+        FT_STRING, BASE_NONE, NULL, 0x0,
         NULL, HFILL } },
 
         { &hf_waveagent_ifwlanrssi,
@@ -1670,7 +1670,7 @@ void proto_register_waveagent(void)
 
         { &hf_waveagent_ifdescription,
         { "Name/Description of the adapter", "waveagent.ifdescription",
-        FT_STRING, 0, NULL, 0x0,
+        FT_STRING, BASE_NONE, NULL, 0x0,
         NULL, HFILL } },
 
         { &hf_waveagent_ifmacaddr,
@@ -1753,7 +1753,7 @@ void proto_register_waveagent(void)
 
         { &hf_waveagent_scanssid,
         { "SSID", "waveagent.scanssid",
-        FT_STRING, 0, NULL, 0x0,
+        FT_STRING, BASE_NONE, NULL, 0x0,
         NULL, HFILL } },
 
         { &hf_waveagent_ifwlansupprates,
@@ -1790,7 +1790,7 @@ void proto_register_waveagent(void)
 
         { &hf_waveagent_oidvalue,
         { "OID Value", "waveagent.oidvalue",
-        FT_STRING, 0, NULL, 0x0,
+        FT_STRING, BASE_NONE, NULL, 0x0,
         NULL, HFILL } },
     /* END: OID fields */
 
@@ -1883,8 +1883,7 @@ void proto_register_waveagent(void)
         &ett_relaymessage,
     };
 
-    proto_waveagent = proto_register_protocol(
-        "WaveAgent", "waveagent", "waveagent");
+    proto_waveagent = proto_register_protocol("WaveAgent", "waveagent", "waveagent");
 
     proto_register_field_array(proto_waveagent, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
