@@ -26,9 +26,16 @@
 #include "packet-http.h"
 #include "packet-tcp.h"
 
+#ifdef HAVE_ZLIBNG
+#define ZLIB_PREFIX(x) zng_ ## x
+#include <zlib-ng.h>
+typedef zng_stream zlib_stream;
+#else
 #ifdef HAVE_ZLIB
-#define ZLIB_CONST
+#define ZLIB_PREFIX(x) x
 #include <zlib.h>
+typedef z_stream zlib_stream;
+#endif /* HAVE_ZLIB */
 #endif
 
 /*
@@ -50,80 +57,92 @@ static dissector_handle_t sip_handle;
 #define WEBSOCKET_JSON 2
 #define WEBSOCKET_SIP 3
 
-/* Use key values counting down from UINT32_MAX to avoid clash with pkt_info proto_data key */
-#define FRAG_DATA_KEY (UINT32_MAX - 0)
+/* Use key values counting down from G_MAXUINT32 to avoid clash with pkt_info proto_data key */
+#define OPCODE_KEY (G_MAXUINT32 - 0)
 
 static gint  pref_text_type             = WEBSOCKET_NONE;
-static gboolean pref_decompress         = TRUE;
+static bool pref_decompress         = true;
+
+#define DEFAULT_MAX_UNMASKED_LEN        (1024 * 256)
+static guint pref_max_unmasked_len      = DEFAULT_MAX_UNMASKED_LEN;
 
 typedef struct {
   const char   *subprotocol;
   guint16       server_port;
   gboolean      permessage_deflate;
+#ifdef HAVE_ZLIBNG
+  gboolean      permessage_deflate_ok;
+  gint8         server_wbits;
+  gint8         client_wbits;
+  zng_streamp     server_take_over_context;
+  zng_streamp     client_take_over_context;
+#else
 #ifdef HAVE_ZLIB
   gboolean      permessage_deflate_ok;
   gint8         server_wbits;
   gint8         client_wbits;
   z_streamp     server_take_over_context;
   z_streamp     client_take_over_context;
+#endif
 #endif
   guint32       frag_id;
-  /* The following two parameters are only valid on the first linear pass. */
+  gboolean      first_frag;
   guint8        first_frag_opcode;
   gboolean      first_frag_pmc;
 } websocket_conv_t;
 
-#ifdef HAVE_ZLIB
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
 typedef struct {
   guint8 *decompr_payload;
   guint decompr_len;
 } websocket_packet_t;
 #endif
 
-static int websocket_follow_tap = -1;
+static int websocket_follow_tap;
 
 /* Initialize the protocol and registered fields */
-static int proto_websocket = -1;
-static int proto_http = -1;
+static int proto_websocket;
+static int proto_http;
 
-static int hf_ws_fin = -1;
-static int hf_ws_reserved = -1;
-static int hf_ws_pmc = -1;
-static int hf_ws_opcode = -1;
-static int hf_ws_mask = -1;
-static int hf_ws_payload_length = -1;
-static int hf_ws_payload_length_ext_16 = -1;
-static int hf_ws_payload_length_ext_64 = -1;
-static int hf_ws_masking_key = -1;
-static int hf_ws_payload = -1;
-static int hf_ws_masked_payload = -1;
-static int hf_ws_payload_continue = -1;
-static int hf_ws_payload_text = -1;
-static int hf_ws_payload_close = -1;
-static int hf_ws_payload_close_status_code = -1;
-static int hf_ws_payload_close_reason = -1;
-static int hf_ws_payload_ping = -1;
-static int hf_ws_payload_pong = -1;
-static int hf_ws_payload_unknown = -1;
-static int hf_ws_fragments = -1;
-static int hf_ws_fragment = -1;
-static int hf_ws_fragment_overlap = -1;
-static int hf_ws_fragment_overlap_conflict = -1;
-static int hf_ws_fragment_multiple_tails = -1;
-static int hf_ws_fragment_too_long_fragment = -1;
-static int hf_ws_fragment_error = -1;
-static int hf_ws_fragment_count = -1;
-static int hf_ws_reassembled_length = -1;
+static int hf_ws_fin;
+static int hf_ws_reserved;
+static int hf_ws_pmc;
+static int hf_ws_opcode;
+static int hf_ws_mask;
+static int hf_ws_payload_length;
+static int hf_ws_payload_length_ext_16;
+static int hf_ws_payload_length_ext_64;
+static int hf_ws_masking_key;
+static int hf_ws_payload;
+static int hf_ws_masked_payload;
+static int hf_ws_payload_continue;
+static int hf_ws_payload_text;
+static int hf_ws_payload_close;
+static int hf_ws_payload_close_status_code;
+static int hf_ws_payload_close_reason;
+static int hf_ws_payload_ping;
+static int hf_ws_payload_pong;
+static int hf_ws_payload_unknown;
+static int hf_ws_fragments;
+static int hf_ws_fragment;
+static int hf_ws_fragment_overlap;
+static int hf_ws_fragment_overlap_conflict;
+static int hf_ws_fragment_multiple_tails;
+static int hf_ws_fragment_too_long_fragment;
+static int hf_ws_fragment_error;
+static int hf_ws_fragment_count;
+static int hf_ws_reassembled_length;
 
-static gint ett_ws = -1;
-static gint ett_ws_pl = -1;
-static gint ett_ws_mask = -1;
-static gint ett_ws_control_close = -1;
-static gint ett_ws_fragments = -1;
-static gint ett_ws_fragment = -1;
+static gint ett_ws;
+static gint ett_ws_pl;
+static gint ett_ws_mask;
+static gint ett_ws_control_close;
+static gint ett_ws_fragments;
+static gint ett_ws_fragment;
 
-static expert_field ei_ws_payload_unknown = EI_INIT;
-static expert_field ei_ws_decompression_failed = EI_INIT;
+static expert_field ei_ws_payload_unknown;
+static expert_field ei_ws_decompression_failed;
+static expert_field ei_ws_not_fully_unmasked;
 
 #define WS_CONTINUE 0x0
 #define WS_TEXT     0x1
@@ -185,18 +204,12 @@ static const fragment_items ws_frag_items = {
     "websocket fragments"
 };
 
-typedef struct {
-  guint8 opcode;
-  gboolean pmc;
-} websocket_frag_t;
-
 static dissector_table_t port_subdissector_table;
 static dissector_table_t protocol_subdissector_table;
 static heur_dissector_list_t heur_subdissector_list;
 
 static reassembly_table ws_reassembly_table;
 
-#define MAX_UNMASKED_LEN (1024 * 256)
 static tvbuff_t *
 tvb_unmasked(tvbuff_t *tvb, packet_info *pinfo, const guint offset, guint payload_length, const guint8 *masking_key)
 {
@@ -204,7 +217,7 @@ tvb_unmasked(tvbuff_t *tvb, packet_info *pinfo, const guint offset, guint payloa
   gchar        *data_unmask;
   guint         i;
   const guint8 *data_mask;
-  guint         unmasked_length = payload_length > MAX_UNMASKED_LEN ? MAX_UNMASKED_LEN : payload_length;
+  guint         unmasked_length = payload_length > pref_max_unmasked_len ? pref_max_unmasked_len : payload_length;
 
   data_unmask = (gchar *)wmem_alloc(pinfo->pool, unmasked_length);
   data_mask   = tvb_get_ptr(tvb, offset, unmasked_length);
@@ -216,7 +229,7 @@ tvb_unmasked(tvbuff_t *tvb, packet_info *pinfo, const guint offset, guint payloa
   return tvb_new_child_real_data(tvb, data_unmask, unmasked_length, payload_length);
 }
 
-#ifdef HAVE_ZLIB
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
 static gint8
 websocket_extract_wbits(const gchar *str)
 {
@@ -247,17 +260,22 @@ websocket_zfree(void *opaque _U_, void *addr)
 {
   wmem_free(wmem_file_scope(), addr);
 }
-
+#ifdef HAVE_ZLIBNG
+static zng_streamp
+websocket_init_z_stream_context(gint8 wbits)
+{
+  zng_streamp z_strm = wmem_new0(wmem_file_scope(), zlib_stream);
+#else
 static z_streamp
 websocket_init_z_stream_context(gint8 wbits)
 {
-  z_streamp z_strm = wmem_new0(wmem_file_scope(), z_stream);
-
+  z_streamp z_strm = wmem_new0(wmem_file_scope(), zlib_stream);
+#endif
   z_strm->zalloc = websocket_zalloc;
   z_strm->zfree = websocket_zfree;
 
-  if (inflateInit2(z_strm, wbits) != Z_OK) {
-    inflateEnd(z_strm);
+  if (ZLIB_PREFIX(inflateInit2)(z_strm, wbits) != Z_OK) {
+    ZLIB_PREFIX(inflateEnd)(z_strm);
     wmem_free(wmem_file_scope(), z_strm);
     return NULL;
   }
@@ -270,7 +288,11 @@ websocket_init_z_stream_context(gint8 wbits)
  * Otherwise FALSE is returned.
  */
 static gboolean
+#ifdef HAVE_ZLIBNG
+websocket_uncompress(tvbuff_t* tvb, packet_info* pinfo, zng_streamp z_strm, tvbuff_t** uncompressed_tvb, guint32 key)
+#else
 websocket_uncompress(tvbuff_t *tvb, packet_info *pinfo, z_streamp z_strm, tvbuff_t **uncompressed_tvb, guint32 key)
+#endif
 {
   /*
    * Decompression a message: append "0x00 0x00 0xff 0xff" to the end of
@@ -298,7 +320,7 @@ websocket_uncompress(tvbuff_t *tvb, packet_info *pinfo, z_streamp z_strm, tvbuff
     z_strm->next_out = decompr_buf;
     z_strm->avail_out = decompr_buf_len;
 
-    err = inflate(z_strm, Z_SYNC_FLUSH);
+    err = ZLIB_PREFIX(inflate)(z_strm, Z_SYNC_FLUSH);
 
     if (err == Z_OK || err == Z_STREAM_END || err == Z_BUF_ERROR) {
       guint avail_bytes = decompr_buf_len - z_strm->avail_out;
@@ -366,7 +388,7 @@ dissect_websocket_control_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *t
 }
 
 static void
-dissect_websocket_data_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_tree *pl_tree, guint8 opcode, websocket_conv_t *websocket_conv, gboolean pmc _U_, gint raw_offset _U_)
+dissect_websocket_data_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_tree *pl_tree, guint8 opcode, websocket_conv_t *websocket_conv, gint raw_offset _U_)
 {
   proto_item         *ti;
   dissector_handle_t  handle = NULL;
@@ -384,16 +406,20 @@ dissect_websocket_data_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
     handle = dissector_get_uint_handle(port_subdissector_table, websocket_conv->server_port);
   }
 
-#ifdef HAVE_ZLIB
-  if (websocket_conv->permessage_deflate_ok && pmc) {
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
+  if (websocket_conv->permessage_deflate_ok && websocket_conv->first_frag_pmc) {
     tvbuff_t   *uncompressed = NULL;
     gboolean    uncompress_ok = FALSE;
 
     if (!PINFO_FD_VISITED(pinfo)) {
+#ifdef HAVE_ZLIBNG
+      zng_streamp z_strm;
+#else
       z_streamp z_strm;
+#endif
       gint8 wbits;
 
-      if (pinfo->srcport == websocket_conv->server_port) {
+      if (pinfo->destport == websocket_conv->server_port) {
         z_strm = websocket_conv->server_take_over_context;
         wbits = websocket_conv->server_wbits;
       } else {
@@ -405,11 +431,11 @@ dissect_websocket_data_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
         uncompress_ok = websocket_uncompress(tvb, pinfo, z_strm, &uncompressed, raw_offset);
       } else {
         /* no context take over, initialize a new context */
-        z_strm = wmem_new0(pinfo->pool, z_stream);
-        if (inflateInit2(z_strm, wbits) == Z_OK) {
+        z_strm = wmem_new0(pinfo->pool, zlib_stream);
+        if (ZLIB_PREFIX(inflateInit2)(z_strm, wbits) == Z_OK) {
           uncompress_ok = websocket_uncompress(tvb, pinfo, z_strm, &uncompressed, raw_offset);
         }
-        inflateEnd(z_strm);
+        ZLIB_PREFIX(inflateEnd)(z_strm);
       }
     } else {
       websocket_packet_t *pkt_info =
@@ -504,7 +530,7 @@ websocket_parse_extensions(websocket_conv_t *websocket_conv, const char *str)
 
   websocket_conv->permessage_deflate = !!strstr(str, "permessage-deflate")
       || !!strstr(str, "x-webkit-deflate-frame");
-#ifdef HAVE_ZLIB
+#if defined (HAVE_ZLIB) || defined (HAVE_ZLIBNG)
   websocket_conv->permessage_deflate_ok = pref_decompress &&
        websocket_conv->permessage_deflate;
   if (websocket_conv->permessage_deflate_ok) {
@@ -525,9 +551,10 @@ websocket_parse_extensions(websocket_conv_t *websocket_conv, const char *str)
 }
 
 static void
-dissect_websocket_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_tree *ws_tree, gboolean fin, guint8 opcode, websocket_conv_t *websocket_conv, gboolean pmc, gint raw_offset)
+dissect_websocket_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, proto_tree *ws_tree, guint8 fin, guint8 opcode, websocket_conv_t *websocket_conv, gint raw_offset, guint masked_payload_length)
 {
   const guint         offset = 0, length = tvb_reported_length(tvb);
+  const guint         capture_length = tvb_captured_length(tvb);
   proto_item         *ti;
   proto_tree         *pl_tree;
   tvbuff_t           *tvb_appdata;
@@ -537,6 +564,12 @@ dissect_websocket_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, p
   ti = proto_tree_add_item(ws_tree, hf_ws_payload, tvb, offset, length, ENC_NA);
   pl_tree = proto_item_add_subtree(ti, ett_ws_pl);
 
+  if (masked_payload_length > capture_length) {
+    expert_add_info_format(pinfo, ti, &ei_ws_not_fully_unmasked, "Payload not fully unmasked. "
+      "%u bytes not yet unmasked due to the preference of max unmasked length limit (%u bytes).",
+      masked_payload_length - capture_length, pref_max_unmasked_len);
+  }
+
   /* Extension Data */
   /* TODO: Add dissector of Extension (not extension available for the moment...) */
 
@@ -545,21 +578,6 @@ dissect_websocket_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, p
     return;
   }
 
-  /* According to RFC 6455 5.5, control frames can be interjected in the
-   * middle of a fragmented message, can have a payload, and MUST NOT be
-   * fragmented. So we do not save the first frag opcode and pmc until now.
-   */
-
-  if (!PINFO_FD_VISITED(pinfo) && opcode != WS_CONTINUE && !fin) {
-    /* This is a first frame of a multifragment message. The first time
-     * we see this frame, store information needed for later fragments
-     * of the same message.
-     */
-
-    websocket_conv->first_frag_opcode = opcode;
-    websocket_conv->first_frag_pmc = pmc;
-  }
-
   bool save_fragmented = pinfo->fragmented;
 
   if (!fin || opcode == WS_CONTINUE) {
@@ -568,12 +586,6 @@ dissect_websocket_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, p
 
     pinfo->fragmented = TRUE;
 
-    /* XXX - The same fragment ID is used for all reassemblies on this
-     * conversation. Note this doesn't work properly if more than one
-     * reassembly for the same conversation completes in the same frame
-     * in the capture file. That should be rare in practice, though.
-     * (This is a common issue with fragment_add_seq_next.)
-     */
     frag_msg = fragment_add_seq_next(&ws_reassembly_table, tvb, offset,
               pinfo, websocket_conv->frag_id,
               NULL, tvb_captured_length_remaining(tvb, offset),
@@ -583,25 +595,20 @@ dissect_websocket_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, p
       NULL, tree);
   }
 
+  if (!PINFO_FD_VISITED(pinfo) && frag_tvb) {
+    /* First time fragments fully reassembled, store opcode from first fragment */
+    p_add_proto_data(wmem_file_scope(), pinfo, proto_websocket, OPCODE_KEY,
+        GUINT_TO_POINTER(websocket_conv->first_frag_opcode));
+  }
+
   if (frag_tvb) {
     /* Fragments were fully reassembled. */
     tvb_appdata = frag_tvb;
 
-    websocket_frag_t *frag_data;
-
-    if (!PINFO_FD_VISITED(pinfo)) {
-      /* First time fragments fully reassembled, store opcode from first fragment */
-      frag_data = wmem_new(wmem_file_scope(), websocket_frag_t);
-      frag_data->opcode = websocket_conv->first_frag_opcode;
-      frag_data->pmc = websocket_conv->first_frag_pmc;
-      p_add_proto_data(wmem_file_scope(), pinfo, proto_websocket, FRAG_DATA_KEY, frag_data);
-    } else {
-      /* Lookup opcode and pmc from first fragment */
-      frag_data = p_get_proto_data(wmem_file_scope(), pinfo, proto_websocket, FRAG_DATA_KEY);
-      DISSECTOR_ASSERT(frag_data);
-    }
-    opcode = frag_data->opcode;
-    pmc = frag_data->pmc;
+    /* Lookup opcode from first fragment */
+    guint first_frag_opcode = GPOINTER_TO_UINT(
+        p_get_proto_data(wmem_file_scope(),pinfo, proto_websocket, OPCODE_KEY));
+    opcode = (guint8)first_frag_opcode;
   } else {
     /* Right now this is exactly the same, this may change when exts. are added.
     tvb_appdata = tvb_new_subset_length(tvb, offset, length);
@@ -617,7 +624,7 @@ dissect_websocket_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, p
     return;
   }
 
-  dissect_websocket_data_frame(tvb_appdata, pinfo, tree, pl_tree, opcode, websocket_conv, pmc, raw_offset);
+  dissect_websocket_data_frame(tvb_appdata, pinfo, tree, pl_tree, opcode, websocket_conv, raw_offset);
   pinfo->fragmented = save_fragmented;
 }
 
@@ -626,8 +633,8 @@ dissect_websocket_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
 {
   static guint32 frag_id_counter = 0;
   proto_item   *ti, *ti_len;
-  guint8        opcode;
-  gboolean      mask, fin, pmc = FALSE;
+  guint8        fin, opcode;
+  gboolean      mask;
   guint         short_length, payload_length;
   guint         payload_offset, mask_offset;
   proto_tree   *ws_tree;
@@ -644,6 +651,7 @@ dissect_websocket_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
   websocket_conv = (websocket_conv_t *)conversation_get_proto_data(conv, proto_websocket);
   if (!websocket_conv) {
     websocket_conv = wmem_new0(wmem_file_scope(), websocket_conv_t);
+    websocket_conv->first_frag = TRUE;
     websocket_conv->frag_id = ++frag_id_counter;
 
     http_conv_t *http_conv = (http_conv_t *)conversation_get_proto_data(conv, proto_http);
@@ -653,9 +661,31 @@ dissect_websocket_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
       if ( http_conv->websocket_extensions) {
         websocket_parse_extensions(websocket_conv, http_conv->websocket_extensions);
       }
+    } else if (pinfo->match_uint == pinfo->srcport || pinfo->match_uint == pinfo->destport) {
+      /* The session was not set up by HTTP upgrade, but by Decode As.
+       * Assume the matched port is the server port. */
+      websocket_conv->server_port = (uint16_t)pinfo->match_uint;
+    } else {
+      /* match_uint is not one of the ports, which means the session was
+       * set up by the heuristic Websocket dissector. */
+      uint32_t low_port, high_port;
+      if (pinfo->srcport > pinfo->destport) {
+        low_port = pinfo->destport;
+        high_port = pinfo->srcport;
+      } else {
+        low_port = pinfo->srcport;
+        high_port = pinfo->destport;
+      }
+      if (dissector_get_uint_handle(port_subdissector_table, low_port)) {
+        websocket_conv->server_port = (uint16_t)low_port;
+      } else if (dissector_get_uint_handle(port_subdissector_table, high_port)) {
+        websocket_conv->server_port = (uint16_t)high_port;
+      }
     }
 
     conversation_add_proto_data(conv, proto_websocket, websocket_conv);
+  } else {
+    websocket_conv->first_frag = FALSE;
   }
 
   short_length = tvb_get_guint8(tvb, 1) & MASK_WS_PAYLOAD_LEN;
@@ -682,16 +712,25 @@ dissect_websocket_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
   ws_tree = proto_item_add_subtree(ti, ett_ws);
 
   /* Flags */
-  proto_tree_add_item_ret_boolean(ws_tree, hf_ws_fin, tvb, 0, 1, ENC_NA, &fin);
+  proto_tree_add_item(ws_tree, hf_ws_fin, tvb, 0, 1, ENC_NA);
+  fin = (tvb_get_guint8(tvb, 0) & MASK_WS_FIN) >> 4;
   proto_tree_add_item(ws_tree, hf_ws_reserved, tvb, 0, 1, ENC_BIG_ENDIAN);
   if (websocket_conv->permessage_deflate) {
     /* RSV1 is Per-Message Compressed bit (RFC 7692). */
-    proto_tree_add_item_ret_boolean(ws_tree, hf_ws_pmc, tvb, 0, 1, ENC_BIG_ENDIAN, &pmc);
+    if (websocket_conv->first_frag) {
+      /* First fragment, save pmc flag needed for decompressing continuation fragments */
+      websocket_conv->first_frag_pmc = !!(tvb_get_guint8(tvb, 0) & MASK_WS_RSV1);
+    }
+    proto_tree_add_item(ws_tree, hf_ws_pmc, tvb, 0, 1, ENC_BIG_ENDIAN);
   }
 
   /* Opcode */
   proto_tree_add_item(ws_tree, hf_ws_opcode, tvb, 0, 1, ENC_BIG_ENDIAN);
   opcode = tvb_get_guint8(tvb, 0) & MASK_WS_OPCODE;
+  if (websocket_conv->first_frag) {
+    /* First fragment, save opcode needed when dissecting the reassembled frame */
+    websocket_conv->first_frag_opcode = opcode;
+  }
   col_append_fstr(pinfo->cinfo, COL_INFO, " %s", val_to_str_const(opcode, ws_opcode_vals, "Unknown Opcode"));
   col_append_str(pinfo->cinfo, COL_INFO, fin ? " [FIN]" : "[FRAGMENT] ");
 
@@ -725,7 +764,7 @@ dissect_websocket_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, voi
     } else {
       tvb_payload = tvb_new_subset_length(tvb, payload_offset, payload_length);
     }
-    dissect_websocket_payload(tvb_payload, pinfo, tree, ws_tree, fin, opcode, websocket_conv, pmc, tvb_raw_offset(tvb));
+    dissect_websocket_payload(tvb_payload, pinfo, tree, ws_tree, fin, opcode, websocket_conv, tvb_raw_offset(tvb), (mask ? payload_length : 0));
   }
 
   return tvb_captured_length(tvb);
@@ -812,18 +851,18 @@ test_websocket(packet_info* pinfo _U_, tvbuff_t* tvb, int offset _U_, void* data
   return TRUE;
 }
 
-static gboolean
+static bool
 dissect_websocket_heur_tcp(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, void* data)
 {
   if (!test_websocket(pinfo, tvb, 0, data))
   {
-    return FALSE;
+    return false;
   }
   conversation_t* conversation = find_or_create_conversation(pinfo);
   conversation_set_dissector(conversation, websocket_handle);
 
   tcp_dissect_pdus(tvb, pinfo, tree, TRUE, 2, get_websocket_frame_length, dissect_websocket_frame, data);
-  return TRUE;
+  return true;
 }
 
 void
@@ -930,7 +969,7 @@ proto_register_websocket(void)
     { &hf_ws_fragments,
       { "Reassembled websocket Fragments", "websocket.fragments",
       FT_NONE, BASE_NONE, NULL, 0x0,
-      "Fragments", HFILL }
+      NULL, HFILL }
     },
     { &hf_ws_fragment,
       { "Websocket Fragment", "websocket.fragment",
@@ -987,6 +1026,7 @@ proto_register_websocket(void)
   static ei_register_info ei[] = {
     { &ei_ws_payload_unknown, { "websocket.payload.unknown.expert", PI_UNDECODED, PI_NOTE, "Dissector for Websocket Opcode", EXPFILL }},
     { &ei_ws_decompression_failed, { "websocket.decompression.failed.expert", PI_PROTOCOL, PI_WARN, "Decompression failed", EXPFILL }},
+    { &ei_ws_not_fully_unmasked, { "websocket.payload.not.fully.unmasked", PI_UNDECODED, PI_NOTE, "Payload not fully unmasked", EXPFILL }},
   };
 
   static const enum_val_t text_types[] = {
@@ -1007,7 +1047,7 @@ proto_register_websocket(void)
    * this table using the standard heur_dissector_add()
    * function.
    */
-  heur_subdissector_list = register_heur_dissector_list("ws", proto_websocket);
+  heur_subdissector_list = register_heur_dissector_list_with_description("ws", "WebSocket data frame", proto_websocket);
 
   port_subdissector_table = register_dissector_table("ws.port",
       "TCP port for protocols using WebSocket", proto_websocket, FT_UINT16, BASE_DEC);
@@ -1038,6 +1078,10 @@ proto_register_websocket(void)
 
   prefs_register_bool_preference(websocket_module, "decompress",
         "Try to decompress permessage-deflate payload", NULL, &pref_decompress);
+
+  prefs_register_uint_preference(websocket_module, "max_unmasked_len", "Max unmasked payload length",
+    "The default value is 256KB (1024x256) bytes. If the preference is too large, it may affect the parsing speed.",
+    10, &pref_max_unmasked_len);
 }
 
 void
