@@ -36,49 +36,51 @@
 void proto_reg_handoff_wg(void);
 void proto_register_wg(void);
 
-static int proto_wg = -1;
-static int hf_wg_type = -1;
-static int hf_wg_reserved = -1;
-static int hf_wg_sender = -1;
-static int hf_wg_ephemeral = -1;
-static int hf_wg_encrypted_static = -1;
-static int hf_wg_static = -1;
-static int hf_wg_encrypted_timestamp = -1;
-static int hf_wg_timestamp_tai64_label = -1;
-static int hf_wg_timestamp_nanoseconds = -1;
-static int hf_wg_timestamp_value = -1;
-static int hf_wg_mac1 = -1;
-static int hf_wg_mac2 = -1;
-static int hf_wg_receiver = -1;
-static int hf_wg_encrypted_empty = -1;
-static int hf_wg_handshake_ok = -1;
-static int hf_wg_nonce = -1;
-static int hf_wg_encrypted_cookie = -1;
-static int hf_wg_counter = -1;
-static int hf_wg_encrypted_packet = -1;
-static int hf_wg_stream = -1;
-static int hf_wg_response_in = -1;
-static int hf_wg_response_to = -1;
-static int hf_wg_receiver_pubkey = -1;
-static int hf_wg_receiver_pubkey_known_privkey = -1;
-static int hf_wg_ephemeral_known_privkey = -1;
-static int hf_wg_static_known_pubkey = -1;
-static int hf_wg_static_known_privkey = -1;
+static int proto_wg;
+static int hf_wg_type;
+static int hf_wg_reserved;
+static int hf_wg_sender;
+static int hf_wg_ephemeral;
+static int hf_wg_encrypted_static;
+static int hf_wg_static;
+static int hf_wg_encrypted_timestamp;
+static int hf_wg_timestamp_tai64_label;
+static int hf_wg_timestamp_nanoseconds;
+static int hf_wg_timestamp_value;
+static int hf_wg_mac1;
+static int hf_wg_mac2;
+static int hf_wg_receiver;
+static int hf_wg_encrypted_empty;
+static int hf_wg_handshake_ok;
+static int hf_wg_nonce;
+static int hf_wg_encrypted_cookie;
+static int hf_wg_counter;
+static int hf_wg_encrypted_packet;
+static int hf_wg_stream;
+static int hf_wg_response_in;
+static int hf_wg_response_to;
+static int hf_wg_receiver_pubkey;
+static int hf_wg_receiver_pubkey_known_privkey;
+static int hf_wg_ephemeral_known_privkey;
+static int hf_wg_static_known_pubkey;
+static int hf_wg_static_known_privkey;
 
-static gint ett_wg = -1;
-static gint ett_timestamp = -1;
-static gint ett_key_info = -1;
+static gint ett_wg;
+static gint ett_timestamp;
+static gint ett_key_info;
 
-static expert_field ei_wg_bad_packet_length = EI_INIT;
-static expert_field ei_wg_keepalive  = EI_INIT;
-static expert_field ei_wg_decryption_error = EI_INIT;
+static expert_field ei_wg_bad_packet_length;
+static expert_field ei_wg_keepalive;
+static expert_field ei_wg_decryption_error;
+static expert_field ei_wg_decryption_unsupported;
 
-static gboolean     pref_dissect_packet = TRUE;
+static bool     pref_dissect_packet = true;
 static const char  *pref_keylog_file;
 
 static dissector_handle_t ip_handle;
 static dissector_handle_t wg_handle;
 
+static bool wg_decryption_supported;
 
 // Length of AEAD authentication tag
 #define AUTH_TAG_LENGTH 16
@@ -144,7 +146,7 @@ typedef struct wg_ekey {
  * Maps the public key to the "wg_skey_t" structure.
  * Keys are populated from the UAT and key log file.
  */
-static GHashTable *wg_static_keys = NULL;
+static GHashTable *wg_static_keys;
 
 /*
  * Set of ephemeral keys (for decryption). Maps the public key to the
@@ -358,7 +360,7 @@ wg_mac1_key(const wg_qqword *static_public, wg_qqword *mac_key_out)
 {
     gcry_md_hd_t hd;
     if (gcry_md_open(&hd, GCRY_MD_BLAKE2S_256, 0) == 0) {
-        const char wg_label_mac1[] = "mac1----";
+        static const char wg_label_mac1[] = "mac1----";
         gcry_md_write(hd, wg_label_mac1, strlen(wg_label_mac1));
         gcry_md_write(hd, static_public->data, sizeof(wg_qqword));
         memcpy(mac_key_out->data, gcry_md_read(hd, 0), sizeof(wg_qqword));
@@ -518,6 +520,10 @@ aead_decrypt(const wg_qqword *key, guint64 counter, const guchar *ctext, guint c
 static void
 wg_add_static_key(const wg_qqword *tmp_key, gboolean is_private)
 {
+    if (!wg_decryption_supported) {
+        return;
+    }
+
     wg_skey_t *key = g_new0(wg_skey_t, 1);
     if (is_private) {
         set_private_key(&key->priv_key, tmp_key);
@@ -549,6 +555,10 @@ wg_add_static_key(const wg_qqword *tmp_key, gboolean is_private)
 static wg_ekey_t *
 wg_add_ephemeral_privkey(const wg_qqword *priv_key)
 {
+    if (!wg_decryption_supported) {
+        return NULL;
+    }
+
     wg_qqword pub_key;
     priv_to_pub(&pub_key, priv_key);
     wg_ekey_t *key = (wg_ekey_t *)wmem_map_lookup(wg_ephemeral_keys, &pub_key);
@@ -626,6 +636,10 @@ static void wg_keylog_process_lines(const void *data, guint datalen);
 static void
 wg_keylog_read(void)
 {
+    if (!wg_decryption_supported) {
+        return;
+    }
+
     if (!pref_keylog_file || !*pref_keylog_file) {
         return;
     }
@@ -765,7 +779,7 @@ wg_key_uat_record_copy_cb(void *dest, const void *source, size_t len _U_)
     return dest;
 }
 
-static gboolean
+static bool
 wg_key_uat_record_update_cb(void *r, char **error)
 {
     wg_key_uat_record_t *rec = (wg_key_uat_record_t *)r;
@@ -790,6 +804,10 @@ wg_key_uat_record_free_cb(void *r)
 static void
 wg_key_uat_apply(void)
 {
+    if (!wg_decryption_supported) {
+        return;
+    }
+
     if (!wg_static_keys) {
         // The first field of "wg_skey_t" is the pubkey (and the table key),
         // its initial four bytes should be good enough as key hash.
@@ -928,7 +946,7 @@ wg_process_response(tvbuff_t *tvb, wg_handshake_state_t *hs)
     // XXX when multiple responses are linkable to a single handshake state,
     // they should probably fork into a new state or be discarded when equal.
     if (hs->initiator_recv_cipher || hs->responder_recv_cipher) {
-        ws_warning("%s FIXME multiple responses linked to a single session", G_STRFUNC);
+        ws_warning("FIXME multiple responses linked to a single session");
         return;
     }
     DISSECTOR_ASSERT(!hs->initiator_recv_cipher);
@@ -1044,7 +1062,7 @@ wg_session_update_address(wg_session_t *session, packet_info *pinfo, gboolean se
 
 /* Finds an initiation message based on the given Receiver ID that was not
  * previously associated with a responder message. Returns the session if a
- * matching initation message can be found or NULL otherwise.
+ * matching initiation message can be found or NULL otherwise.
  */
 static wg_session_t *
 wg_sessions_lookup_initiation(packet_info *pinfo, guint32 receiver_id)
@@ -1127,7 +1145,7 @@ wg_mac1_key_probe(tvbuff_t *tvb, gboolean is_initiation)
     const int mac1_offset = is_initiation ? 116 : 60;
 
     // Shortcut: skip MAC1 validation if no pubkeys are configured.
-    if (g_hash_table_size(wg_static_keys) == 0) {
+    if (!wg_static_keys || g_hash_table_size(wg_static_keys) == 0) {
         return NULL;
     }
 
@@ -1246,8 +1264,12 @@ wg_dissect_pubkey(proto_tree *tree, tvbuff_t *tvb, int offset, gboolean is_ephem
 
     int hf_id = is_ephemeral ? hf_wg_ephemeral : hf_wg_static;
     proto_item *ti = proto_tree_add_string(tree, hf_id, tvb, offset, 32, key_str);
-    proto_tree *key_tree = proto_item_add_subtree(ti, ett_key_info);
-    wg_dissect_key_extra(key_tree, tvb, (const wg_qqword *)pubkey, is_ephemeral);
+    if (wg_decryption_supported) {
+        proto_tree *key_tree = proto_item_add_subtree(ti, ett_key_info);
+        wg_dissect_key_extra(key_tree, tvb, (const wg_qqword *)pubkey, is_ephemeral);
+    } else {
+        expert_add_info(NULL, ti, &ei_wg_decryption_unsupported);
+    }
 }
 
 static void
@@ -1611,8 +1633,8 @@ dissect_wg(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
     DISSECTOR_ASSERT_NOT_REACHED();
 }
 
-static gboolean
-dissect_wg_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
+static bool
+dissect_wg_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     /*
      * Heuristics to detect the WireGuard protocol:
@@ -1628,20 +1650,20 @@ dissect_wg_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data
     gboolean    reserved_is_zeroes;
 
     if (tvb_reported_length(tvb) < 4)
-        return FALSE;
+        return false;
 
     message_type = tvb_get_guint8(tvb, 0);
     reserved_is_zeroes = tvb_get_ntoh24(tvb, 1) == 0;
 
     if (!wg_is_valid_message_length(message_type, tvb_reported_length(tvb))) {
-        return FALSE;
+        return false;
     }
 
     switch (message_type) {
         case WG_TYPE_COOKIE_REPLY:
         case WG_TYPE_TRANSPORT_DATA:
             if (!reserved_is_zeroes)
-                return FALSE;
+                return false;
             break;
     }
 
@@ -1658,8 +1680,8 @@ dissect_wg_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data
         conversation_set_dissector(conversation, wg_handle);
     }
 
-    dissect_wg(tvb, pinfo, tree, NULL);
-    return TRUE;
+    dissect_wg(tvb, pinfo, tree, data);
+    return true;
 }
 
 static void
@@ -1843,6 +1865,10 @@ proto_register_wg(void)
           { "wg.decryption_error", PI_DECRYPTION, PI_WARN,
             "Packet data decryption failed", EXPFILL }
         },
+        { &ei_wg_decryption_unsupported,
+          { "wg.decryption_unsupported", PI_DECRYPTION, PI_WARN,
+            "Decryption unsupported (disable FIPS mode or upgrade Libgcrypt to 1.10.0 or higher)", EXPFILL }
+        },
     };
 
     /* UAT for header fields */
@@ -1896,11 +1922,16 @@ proto_register_wg(void)
             "LOCAL_EPHEMERAL_PRIVATE_KEY or PRESHARED_KEY.",
             &pref_keylog_file, FALSE);
 
-    if (!wg_decrypt_init()) {
-        ws_warning("%s: decryption will not be possible due to lack of algorithms support", G_STRFUNC);
-    }
+    wg_decryption_supported = wg_decrypt_init();
+    /* We require libgcrypt 1.8.0, so if the algorithms aren't supported
+     * that's almost surely because FIPS mode is on. For libgcrypt 1.10.0
+     * and higher we turn it off in epan_init() when initializing gcrypt.
+     * We could verify that's the reason by calling gcry_fips_mode_active()
+     */
 
-    secrets_register_type(SECRETS_TYPE_WIREGUARD, wg_keylog_process_lines);
+    if (wg_decryption_supported) {
+        secrets_register_type(SECRETS_TYPE_WIREGUARD, wg_keylog_process_lines);
+    }
 
     wg_ephemeral_keys = wmem_map_new_autoreset(wmem_epan_scope(), wmem_file_scope(), g_int_hash, wg_pubkey_equal);
 
