@@ -27,87 +27,89 @@
 void proto_register_wtls(void);
 void proto_reg_handoff_wtls(void);
 
+static dissector_handle_t wtls_handle;
+
 /* File scoped variables for the protocol and registered fields */
-static int proto_wtls = -1;
+static int proto_wtls;
 
 /* These fields used by fixed part of header */
-static int hf_wtls_record = -1;
-static int hf_wtls_record_type = -1;
-static int hf_wtls_record_length = -1;
-static int hf_wtls_record_sequence = -1;
-static int hf_wtls_record_ciphered = -1;
-static int hf_wtls_hands = -1;
-static int hf_wtls_hands_type = -1;
-static int hf_wtls_hands_length = -1;
-static int hf_wtls_hands_cli_hello = -1;
-static int hf_wtls_hands_cli_hello_version = -1;
-static int hf_wtls_hands_cli_hello_gmt = -1;
-static int hf_wtls_hands_cli_hello_random = -1;
-static int hf_wtls_hands_cli_hello_session = -1;
-static int hf_wtls_hands_cli_hello_session_str = -1;
-static int hf_wtls_hands_cli_hello_cli_key_id = -1;
-static int hf_wtls_hands_cli_hello_cli_key_len = -1;
-static int hf_wtls_hands_cli_hello_trust_key_id = -1;
-static int hf_wtls_hands_cli_hello_key_exchange = -1;
-static int hf_wtls_hands_cli_hello_key_exchange_suite = -1;
-static int hf_wtls_hands_cli_hello_key_parameter_index = -1;
-static int hf_wtls_hands_cli_hello_key_parameter_set = -1;
-static int hf_wtls_hands_cli_hello_key_identifier_type = -1;
-static int hf_wtls_hands_cli_hello_key_identifier_charset = -1;
-static int hf_wtls_hands_cli_hello_key_identifier_size = -1;
-static int hf_wtls_hands_cli_hello_key_identifier = -1;
-static int hf_wtls_hands_cli_hello_key_identifier_str = -1;
-static int hf_wtls_hands_cli_hello_cipher_suite = -1;
-static int hf_wtls_hands_cli_hello_cipher_suite_item = -1;
-static int hf_wtls_hands_cli_hello_compression_methods = -1;
-static int hf_wtls_hands_cli_hello_compression = -1;
-static int hf_wtls_hands_cli_hello_sequence_mode = -1;
-static int hf_wtls_hands_cli_hello_key_refresh = -1;
-static int hf_wtls_hands_serv_hello = -1;
-static int hf_wtls_hands_serv_hello_version = -1;
-static int hf_wtls_hands_serv_hello_gmt = -1;
-static int hf_wtls_hands_serv_hello_random = -1;
-static int hf_wtls_hands_serv_hello_session = -1;
-static int hf_wtls_hands_serv_hello_session_str = -1;
-static int hf_wtls_hands_serv_hello_cli_key_id = -1;
-static int hf_wtls_hands_serv_hello_cipher_suite_item = -1;
-static int hf_wtls_hands_serv_hello_cipher_bulk = -1;
-static int hf_wtls_hands_serv_hello_cipher_mac = -1;
-static int hf_wtls_hands_serv_hello_compression = -1;
-static int hf_wtls_hands_serv_hello_sequence_mode = -1;
-static int hf_wtls_hands_serv_hello_key_refresh = -1;
-static int hf_wtls_hands_certificates = -1;
-static int hf_wtls_hands_certificate = -1;
-static int hf_wtls_hands_certificate_type = -1;
-static int hf_wtls_hands_certificate_wtls_version = -1;
-static int hf_wtls_hands_certificate_wtls_signature_type = -1;
-static int hf_wtls_hands_certificate_wtls_issuer_type = -1;
-static int hf_wtls_hands_certificate_wtls_issuer_charset = -1;
-static int hf_wtls_hands_certificate_wtls_issuer_size = -1;
-static int hf_wtls_hands_certificate_wtls_issuer_name = -1;
-static int hf_wtls_hands_certificate_wtls_valid_not_before = -1;
-static int hf_wtls_hands_certificate_wtls_valid_not_after = -1;
-static int hf_wtls_hands_certificate_wtls_subject_type = -1;
-static int hf_wtls_hands_certificate_wtls_subject_charset = -1;
-static int hf_wtls_hands_certificate_wtls_subject_size = -1;
-static int hf_wtls_hands_certificate_wtls_subject_name = -1;
-static int hf_wtls_hands_certificate_wtls_public_key_type = -1;
-static int hf_wtls_hands_certificate_wtls_key_parameter_index = -1;
-static int hf_wtls_hands_certificate_wtls_key_parameter_set = -1;
-static int hf_wtls_hands_certificate_wtls_rsa_exponent = -1;
-static int hf_wtls_hands_certificate_wtls_rsa_modules = -1;
-static int hf_wtls_hands_certificate_wtls_signature = -1;
-static int hf_wtls_alert = -1;
-static int hf_wtls_alert_level = -1;
-static int hf_wtls_alert_description = -1;
+static int hf_wtls_record;
+static int hf_wtls_record_type;
+static int hf_wtls_record_length;
+static int hf_wtls_record_sequence;
+static int hf_wtls_record_ciphered;
+static int hf_wtls_hands;
+static int hf_wtls_hands_type;
+static int hf_wtls_hands_length;
+static int hf_wtls_hands_cli_hello;
+static int hf_wtls_hands_cli_hello_version;
+static int hf_wtls_hands_cli_hello_gmt;
+static int hf_wtls_hands_cli_hello_random;
+static int hf_wtls_hands_cli_hello_session;
+static int hf_wtls_hands_cli_hello_session_str;
+static int hf_wtls_hands_cli_hello_cli_key_id;
+static int hf_wtls_hands_cli_hello_cli_key_len;
+static int hf_wtls_hands_cli_hello_trust_key_id;
+static int hf_wtls_hands_cli_hello_key_exchange;
+static int hf_wtls_hands_cli_hello_key_exchange_suite;
+static int hf_wtls_hands_cli_hello_key_parameter_index;
+static int hf_wtls_hands_cli_hello_key_parameter_set;
+static int hf_wtls_hands_cli_hello_key_identifier_type;
+static int hf_wtls_hands_cli_hello_key_identifier_charset;
+static int hf_wtls_hands_cli_hello_key_identifier_size;
+static int hf_wtls_hands_cli_hello_key_identifier;
+static int hf_wtls_hands_cli_hello_key_identifier_str;
+static int hf_wtls_hands_cli_hello_cipher_suite;
+static int hf_wtls_hands_cli_hello_cipher_suite_item;
+static int hf_wtls_hands_cli_hello_compression_methods;
+static int hf_wtls_hands_cli_hello_compression;
+static int hf_wtls_hands_cli_hello_sequence_mode;
+static int hf_wtls_hands_cli_hello_key_refresh;
+static int hf_wtls_hands_serv_hello;
+static int hf_wtls_hands_serv_hello_version;
+static int hf_wtls_hands_serv_hello_gmt;
+static int hf_wtls_hands_serv_hello_random;
+static int hf_wtls_hands_serv_hello_session;
+static int hf_wtls_hands_serv_hello_session_str;
+static int hf_wtls_hands_serv_hello_cli_key_id;
+static int hf_wtls_hands_serv_hello_cipher_suite_item;
+static int hf_wtls_hands_serv_hello_cipher_bulk;
+static int hf_wtls_hands_serv_hello_cipher_mac;
+static int hf_wtls_hands_serv_hello_compression;
+static int hf_wtls_hands_serv_hello_sequence_mode;
+static int hf_wtls_hands_serv_hello_key_refresh;
+static int hf_wtls_hands_certificates;
+static int hf_wtls_hands_certificate;
+static int hf_wtls_hands_certificate_type;
+static int hf_wtls_hands_certificate_wtls_version;
+static int hf_wtls_hands_certificate_wtls_signature_type;
+static int hf_wtls_hands_certificate_wtls_issuer_type;
+static int hf_wtls_hands_certificate_wtls_issuer_charset;
+static int hf_wtls_hands_certificate_wtls_issuer_size;
+static int hf_wtls_hands_certificate_wtls_issuer_name;
+static int hf_wtls_hands_certificate_wtls_valid_not_before;
+static int hf_wtls_hands_certificate_wtls_valid_not_after;
+static int hf_wtls_hands_certificate_wtls_subject_type;
+static int hf_wtls_hands_certificate_wtls_subject_charset;
+static int hf_wtls_hands_certificate_wtls_subject_size;
+static int hf_wtls_hands_certificate_wtls_subject_name;
+static int hf_wtls_hands_certificate_wtls_public_key_type;
+static int hf_wtls_hands_certificate_wtls_key_parameter_index;
+static int hf_wtls_hands_certificate_wtls_key_parameter_set;
+static int hf_wtls_hands_certificate_wtls_rsa_exponent;
+static int hf_wtls_hands_certificate_wtls_rsa_modules;
+static int hf_wtls_hands_certificate_wtls_signature;
+static int hf_wtls_alert;
+static int hf_wtls_alert_level;
+static int hf_wtls_alert_description;
 
 /* Initialize the subtree pointers */
-static gint ett_wtls = -1;
-static gint ett_wtls_rec = -1;
-static gint ett_wtls_msg_type = -1;
-static gint ett_wtls_msg_type_item = -1;
-static gint ett_wtls_msg_type_item_sub = -1;
-static gint ett_wtls_msg_type_item_sub_sub = -1;
+static int ett_wtls;
+static int ett_wtls_rec;
+static int ett_wtls_msg_type;
+static int ett_wtls_msg_type_item;
+static int ett_wtls_msg_type_item_sub;
+static int ett_wtls_msg_type_item_sub_sub;
 
 static const value_string wtls_vals_record_type[] = {
 	{ 1, "change_cipher_data" },
@@ -301,7 +303,7 @@ static value_string_ext wtls_vals_alert_description_ext = VALUE_STRING_EXT_INIT(
 #define PUBLIC_KEY_ECDH			 3
 #define PUBLIC_KEY_ECDSA		 4
 
-static void dissect_wtls_handshake (proto_tree *, tvbuff_t *, guint, guint);
+static void dissect_wtls_handshake (proto_tree *, tvbuff_t *, unsigned, unsigned);
 
 /* Code to actually dissect the packets */
 static int
@@ -310,8 +312,8 @@ dissect_wtls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
 	int offset = 0;
 
 	char pdut;
-	guint count = 0;
-	guint offset_wtls = 0;
+	unsigned count = 0;
+	unsigned offset_wtls = 0;
 
 /* Set up structures we will need to add the protocol subtree and manage it */
 	proto_item *ti;
@@ -418,7 +420,7 @@ static int
 add_text_identifier(tvbuff_t *tvb, int offset, int hf_charset,
 		    int hf_size, int hf_str, proto_tree *tree)
 {
-	guint8 size;
+	uint8_t size;
 	int client_size = 0;
 
 	proto_tree_add_item(tree, hf_charset, tvb, offset, 2, ENC_BIG_ENDIAN);
@@ -439,9 +441,9 @@ add_text_identifier(tvbuff_t *tvb, int offset, int hf_charset,
 static int
 add_session_id(proto_tree *tree, int hf, int hf_str, tvbuff_t *tvb, int offset)
 {
-	guint count;
-	guint i;
-	guint64 session_id;
+	unsigned count;
+	unsigned i;
+	uint64_t session_id;
 
 	count = tvb_get_guint8(tvb, offset);
 	if (count == 0)
@@ -458,13 +460,13 @@ add_session_id(proto_tree *tree, int hf, int hf_str, tvbuff_t *tvb, int offset)
 }
 
 static void
-dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint count)
+dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, unsigned offset, unsigned count)
 {
 	char pdu_msg_type;
 	int client_size = 0;
-	guint value = 0;
+	unsigned value = 0;
 	int size = 0;
-	guint public_key = 0;
+	unsigned public_key = 0;
 	char valStr[1024];
 	const char *valBulk = NULL;
 	const char *valMac = NULL;
@@ -553,7 +555,7 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 					size = tvb_get_ntohs (tvb, offset);
 					proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
 						hf_wtls_hands_cli_hello_key_parameter_set,
-						tvb,offset,size+2,ENC_ASCII|ENC_NA);
+						tvb,offset,size+2,ENC_ASCII);
 					offset+=size+2;
 					client_size+=size+2;
 				}
@@ -682,7 +684,7 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 					size = tvb_get_ntohs (tvb, offset);
 					proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
 						hf_wtls_hands_cli_hello_key_parameter_set,
-						tvb,offset,size+2,ENC_ASCII|ENC_NA);
+						tvb,offset,size+2,ENC_ASCII);
 					offset+=size+2;
 					client_size+=size+2;
 				}
@@ -782,22 +784,22 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 			       {
 				       if (valMac != NULL)
 				       {
-					       g_snprintf(valStr,1024,"%s, %s",valBulk,valMac);
+					       snprintf(valStr,1024,"%s, %s",valBulk,valMac);
 				       }
 				       else
 				       {
-					       g_snprintf(valStr,1024,"%s, Unknown MAC (0x%02x)",valBulk,tvb_get_guint8 (tvb, offset));
+					       snprintf(valStr,1024,"%s, Unknown MAC (0x%02x)",valBulk,tvb_get_guint8 (tvb, offset));
 				       }
 			       }
 			       else
 			       {
 				       if (valMac != NULL)
 				       {
-					       g_snprintf(valStr,1024,"Unknown Bulk (0x%02x), %s",value,valMac);
+					       snprintf(valStr,1024,"Unknown Bulk (0x%02x), %s",value,valMac);
 				       }
 				       else
 				       {
-					       g_snprintf(valStr,1024,"Unknown Bulk (0x%02x), Unknown MAC (0x%02x)",value,
+					       snprintf(valStr,1024,"Unknown Bulk (0x%02x), Unknown MAC (0x%02x)",value,
 							       tvb_get_guint8 (tvb, offset));
 				       }
 				}
@@ -989,7 +991,7 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 							size = tvb_get_ntohs (tvb, offset);
 							proto_tree_add_item(wtls_msg_type_item_sub_tree,
 								hf_wtls_hands_certificate_wtls_key_parameter_set,
-								tvb,offset,size+2,ENC_ASCII|ENC_NA);
+								tvb,offset,size+2,ENC_ASCII);
 							offset+=size+2;
 							client_size+=size+2;
 						}
@@ -1538,7 +1540,7 @@ proto_register_wtls(void)
 	};
 
 /* Setup protocol subtree array */
-	static gint *ett[] = {
+	static int *ett[] = {
 		&ett_wtls,
 		&ett_wtls_rec,
 		&ett_wtls_msg_type,
@@ -1553,19 +1555,19 @@ proto_register_wtls(void)
 /* Required function calls to register the header fields and subtrees used  */
 	proto_register_field_array(proto_wtls, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+
+/* Register our dissector handle */
+	wtls_handle = register_dissector("wtls", dissect_wtls, proto_wtls);
 }
 
 void
 proto_reg_handoff_wtls(void)
 {
-	dissector_handle_t wtls_handle;
-
-	wtls_handle = create_dissector_handle(dissect_wtls, proto_wtls);
 	dissector_add_uint_range_with_preference("udp.port", UDP_PORT_WTLS_RANGE, wtls_handle);
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
