@@ -33,28 +33,28 @@ void proto_reg_handoff_xip(void);
 /* Next dissector handles. */
 static dissector_handle_t xip_serval_handle;
 
-static gint proto_xip			= -1;
+static gint proto_xip;
 
-static gint hf_xip_version		= -1;
-static gint hf_xip_next_hdr		= -1;
-static gint hf_xip_payload_len		= -1;
-static gint hf_xip_hop_limit		= -1;
-static gint hf_xip_num_dst		= -1;
-static gint hf_xip_num_src		= -1;
-static gint hf_xip_last_node		= -1;
-static gint hf_xip_dst_dag		= -1;
-static gint hf_xip_dst_dag_entry	= -1;
-static gint hf_xip_src_dag		= -1;
-static gint hf_xip_src_dag_entry	= -1;
+static gint hf_xip_version;
+static gint hf_xip_next_hdr;
+static gint hf_xip_payload_len;
+static gint hf_xip_hop_limit;
+static gint hf_xip_num_dst;
+static gint hf_xip_num_src;
+static gint hf_xip_last_node;
+static gint hf_xip_dst_dag;
+static gint hf_xip_dst_dag_entry;
+static gint hf_xip_src_dag;
+static gint hf_xip_src_dag_entry;
 
-static gint ett_xip_tree		= -1;
-static gint ett_xip_ddag		= -1;
-static gint ett_xip_sdag		= -1;
+static gint ett_xip_tree;
+static gint ett_xip_ddag;
+static gint ett_xip_sdag;
 
-static expert_field ei_xip_invalid_len = EI_INIT;
-static expert_field ei_xip_next_header = EI_INIT;
-static expert_field ei_xip_bad_num_dst = EI_INIT;
-static expert_field ei_xip_bad_num_src = EI_INIT;
+static expert_field ei_xip_invalid_len;
+static expert_field ei_xip_next_header;
+static expert_field ei_xip_bad_num_dst;
+static expert_field ei_xip_bad_num_src;
 
 static dissector_handle_t xip_handle;
 
@@ -397,9 +397,9 @@ xia_ntop(const struct xia_addr *src, wmem_strbuf_t *buf)
 #define XIPH_DSTD		8
 
 static void
-construct_dag(tvbuff_t *tvb, proto_tree *xip_tree,
+construct_dag(tvbuff_t *tvb, packet_info *pinfo, proto_tree *xip_tree,
 	const gint ett, const gint hf, const gint hf_entry,
-	const guint8 num_nodes, guint8 offset)
+	const guint8 num_nodes, gint offset)
 {
 	proto_tree *dag_tree;
 	proto_item *ti;
@@ -407,13 +407,12 @@ construct_dag(tvbuff_t *tvb, proto_tree *xip_tree,
 	wmem_strbuf_t *buf;
 	const gchar *dag_str;
 	guint i, j;
-	guint8 dag_offset = offset;
+	gint dag_offset = offset;
 
 	ti = proto_tree_add_item(xip_tree, hf, tvb, offset,
 		num_nodes * XIA_NODE_SIZE, ENC_BIG_ENDIAN);
 
-	buf = wmem_strbuf_sized_new(wmem_packet_scope(),
-		XIA_MAX_STRADDR_SIZE, XIA_MAX_STRADDR_SIZE);
+	buf = wmem_strbuf_new_sized(pinfo->pool, XIA_MAX_STRADDR_SIZE);
 
 	dag_tree = proto_item_add_subtree(ti, ett);
 
@@ -552,13 +551,13 @@ display_xip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	/* Construct Destination DAG subtree. */
 	if (num_dst_nodes > 0)
-		construct_dag(tvb, xip_tree, ett_xip_ddag,
+		construct_dag(tvb, pinfo, xip_tree, ett_xip_ddag,
 			hf_xip_dst_dag, hf_xip_dst_dag_entry,
 			num_dst_nodes, XIPH_DSTD);
 
 	/* Construct Source DAG subtree. */
 	if (num_src_nodes > 0)
-		construct_dag(tvb, xip_tree, ett_xip_sdag,
+		construct_dag(tvb, pinfo, xip_tree, ett_xip_sdag,
 			hf_xip_src_dag, hf_xip_src_dag_entry,
 			num_src_nodes,
 			XIPH_DSTD + num_dst_nodes * XIA_NODE_SIZE);
@@ -667,10 +666,7 @@ proto_register_xip(void)
 
 	expert_module_t* expert_xip;
 
-	proto_xip = proto_register_protocol(
-		"eXpressive Internet Protocol",
-		"XIP",
-		"xip");
+	proto_xip = proto_register_protocol("eXpressive Internet Protocol", "XIP", "xip");
 
 	xip_handle = register_dissector("xip", dissect_xip, proto_xip);
 	proto_register_field_array(proto_xip, hf, array_length(hf));
@@ -689,7 +685,7 @@ proto_reg_handoff_xip(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local variables:
  * c-basic-offset: 8
