@@ -41,23 +41,27 @@ struct _attr_reg_data {
 };
 
 
-static gint ett_dtd = -1;
-static gint ett_xmpli = -1;
+static gint ett_dtd;
+static gint ett_xmpli;
 
-static int hf_unknowwn_attrib = -1;
-static int hf_comment = -1;
-static int hf_xmlpi = -1;
-static int hf_dtd_tag = -1;
-static int hf_doctype = -1;
-static int hf_cdatasection = -1;
+static int hf_unknowwn_attrib;
+static int hf_comment;
+static int hf_xmlpi;
+static int hf_dtd_tag;
+static int hf_doctype;
+static int hf_cdatasection;
 
-static expert_field ei_xml_closing_unopened_tag = EI_INIT;
-static expert_field ei_xml_closing_unopened_xmpli_tag = EI_INIT;
-static expert_field ei_xml_unrecognized_text = EI_INIT;
+static expert_field ei_xml_closing_unopened_tag;
+static expert_field ei_xml_closing_unopened_xmpli_tag;
+static expert_field ei_xml_unrecognized_text;
 
 /* dissector handles */
 static dissector_handle_t xml_handle;
 
+/* Port 3702 is IANA-registered for Web Service Discovery, which uses
+ * SOAP-over-UDP to send XML */
+#define XML_UDP_PORT_RANGE "3702"
+
 /* parser definitions */
 static tvbparse_wanted_t *want;
 static tvbparse_wanted_t *want_ignore;
@@ -70,7 +74,7 @@ static xml_ns_t xml_ns     = {"xml",     "/", -1, -1, -1, NULL, NULL, NULL};
 static xml_ns_t unknown_ns = {"unknown", "?", -1, -1, -1, NULL, NULL, NULL};
 static xml_ns_t *root_ns;
 
-static gboolean pref_heuristic_unicode    = FALSE;
+static bool pref_heuristic_unicode;
 static gint pref_default_encoding = IANA_CS_UTF_8;
 
 
@@ -381,11 +385,11 @@ dissect_xml(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
     return tvb_captured_length(tvb);
 }
 
-static gboolean dissect_xml_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
+static bool dissect_xml_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data)
 {
     if (tvbparse_peek(tvbparse_init(pinfo->pool, tvb, 0, -1, NULL, want_ignore), want_heur)) {
         dissect_xml(tvb, pinfo, tree, data);
-        return TRUE;
+        return true;
     } else if (pref_heuristic_unicode) {
         const guint8 *data_str;
         tvbuff_t     *unicode_tvb;
@@ -408,10 +412,10 @@ static gboolean dissect_xml_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
         if (tvbparse_peek(tvbparse_init(pinfo->pool, unicode_tvb, 0, -1, NULL, want_ignore), want_heur)) {
             add_new_data_source(pinfo, unicode_tvb, "UTF8");
             dissect_xml(unicode_tvb, pinfo, tree, data);
-            return TRUE;
+            return true;
         }
     }
-    return FALSE;
+    return false;
 }
 
 xml_frame_t *xml_get_tag(xml_frame_t *frame, const gchar *name)
@@ -1115,7 +1119,7 @@ static gchar *fully_qualified_name(GPtrArray *hier, gchar *name, gchar *proto_na
 
     wmem_strbuf_append(s, name);
 
-    return wmem_strbuf_finalize(s);;
+    return wmem_strbuf_finalize(s);
 }
 
 
@@ -1137,7 +1141,7 @@ static xml_ns_t *make_xml_hier(gchar      *elem_name,
     guint     i;
     struct _attr_reg_data  d;
 
-    if ( !elem_name || g_str_equal(elem_name, root->name) ) {
+    if ( g_str_equal(elem_name, root->name) ) {
         return NULL;
     }
 
@@ -1275,7 +1279,7 @@ static void register_dtd(dtd_build_data_t *dtd_data, GString *errors)
         root_name = wmem_strdup(wmem_epan_scope(), dtd_data->proto_root);
     }
 
-    /* we use a stack with the names to avoid recurring infinitelly */
+    /* we use a stack with the names to avoid recurring infinitely */
     hier = g_ptr_array_new();
 
     /*
@@ -1645,6 +1649,7 @@ proto_reg_handoff_xml(void)
 {
     wmem_map_foreach(media_types, add_dissector_media, NULL);
     dissector_add_uint_range_with_preference("tcp.port", "", xml_handle);
+    dissector_add_uint_range_with_preference("udp.port", XML_UDP_PORT_RANGE, xml_handle);
 
     heur_dissector_add("http",  dissect_xml_heur, "XML in HTTP", "xml_http", xml_ns.hf_tag, HEURISTIC_DISABLE);
     heur_dissector_add("sip",   dissect_xml_heur, "XML in SIP", "xml_sip", xml_ns.hf_tag, HEURISTIC_DISABLE);
