@@ -77,12 +77,12 @@ xmpp_iq(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_element_t *pac
     xmpp_attr_t *attr_id, *attr_type;
 
     xmpp_attr_info attrs_info[] = {
-        {"xmlns", &hf_xmpp_xmlns, FALSE, FALSE, NULL, NULL},
-        {"id", &hf_xmpp_id, TRUE, TRUE, NULL, NULL},
-        {"type", &hf_xmpp_type, TRUE, TRUE, NULL, NULL},
-        {"from", &hf_xmpp_from, FALSE, TRUE, NULL, NULL},
-        {"to", &hf_xmpp_to, FALSE, TRUE, NULL, NULL},
-        {"xml:lang", NULL, FALSE, FALSE, NULL, NULL}
+        {"xmlns", &hf_xmpp_xmlns, false, false, NULL, NULL},
+        {"id", &hf_xmpp_id, true, true, NULL, NULL},
+        {"type", &hf_xmpp_type, true, true, NULL, NULL},
+        {"from", &hf_xmpp_from, false, true, NULL, NULL},
+        {"to", &hf_xmpp_to, false, true, NULL, NULL},
+        {"xml:lang", NULL, false, false, NULL, NULL}
     };
 
     conversation_t     *conversation;
@@ -200,9 +200,9 @@ xmpp_error(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_element_t *
     xmpp_element_t *text_element, *cond_element;
 
     xmpp_attr_info attrs_info[] = {
-        {"type", &hf_xmpp_error_type, TRUE, TRUE, NULL, NULL},
-        {"code", &hf_xmpp_error_code, FALSE, TRUE, NULL, NULL},
-        {"condition", &hf_xmpp_error_condition, TRUE, TRUE, NULL, NULL} /*TODO: validate list to the condition element*/
+        {"type", &hf_xmpp_error_type, true, true, NULL, NULL},
+        {"code", &hf_xmpp_error_code, false, true, NULL, NULL},
+        {"condition", &hf_xmpp_error_condition, true, true, NULL, NULL} /*TODO: validate list to the condition element*/
     };
 
     gchar *error_info;
@@ -259,13 +259,13 @@ xmpp_presence(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_element_
     xmpp_array_t *show_array = xmpp_ep_init_array_t(pinfo->pool, show_enums, array_length(show_enums));
 
     xmpp_attr_info attrs_info[] = {
-        {"from", &hf_xmpp_from, FALSE, FALSE, NULL, NULL},
-        {"id", &hf_xmpp_id, FALSE, TRUE, NULL, NULL},
-        {"to", &hf_xmpp_to, FALSE, FALSE, NULL, NULL},
-        {"type", &hf_xmpp_type, FALSE, TRUE, xmpp_val_enum_list, type_array},
-        {"xml:lang", NULL, FALSE, FALSE, NULL,NULL},
-        {"show", &hf_xmpp_presence_show, FALSE, TRUE, xmpp_val_enum_list, show_array},
-        {"priority", NULL, FALSE, FALSE, NULL, NULL}
+        {"from", &hf_xmpp_from, false, false, NULL, NULL},
+        {"id", &hf_xmpp_id, false, true, NULL, NULL},
+        {"to", &hf_xmpp_to, false, false, NULL, NULL},
+        {"type", &hf_xmpp_type, false, true, xmpp_val_enum_list, type_array},
+        {"xml:lang", NULL, false, false, NULL,NULL},
+        {"show", &hf_xmpp_presence_show, false, true, xmpp_val_enum_list, show_array},
+        {"priority", NULL, false, false, NULL, NULL}
     };
 
     xmpp_elem_info elems_info[] = {
@@ -311,8 +311,8 @@ xmpp_presence_status(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_e
     proto_tree *status_tree;
 
     xmpp_attr_info attrs_info[] = {
-        {"xml:lang", NULL, FALSE, TRUE, NULL, NULL},
-        {"value", NULL, TRUE, TRUE, NULL, NULL}
+        {"xml:lang", NULL, false, true, NULL, NULL},
+        {"value", NULL, true, true, NULL, NULL}
     };
 
     xmpp_attr_t *fake_value;
@@ -344,12 +344,12 @@ xmpp_message(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_element_t
     xmpp_array_t *type_array = xmpp_ep_init_array_t(pinfo->pool, type_enums, array_length(type_enums));
 
     xmpp_attr_info attrs_info[] = {
-        {"from", &hf_xmpp_from, FALSE, FALSE, NULL, NULL},
-        {"id", &hf_xmpp_id, FALSE, TRUE, NULL, NULL},
-        {"to", &hf_xmpp_to, FALSE, FALSE, NULL, NULL},
-        {"type", &hf_xmpp_type, FALSE, TRUE, xmpp_val_enum_list, type_array},
-        {"xml:lang", NULL, FALSE, FALSE, NULL,NULL},
-        {"chatstate", &hf_xmpp_message_chatstate, FALSE, TRUE, NULL, NULL}
+        {"from", &hf_xmpp_from, false, false, NULL, NULL},
+        {"id", &hf_xmpp_id, false, true, NULL, NULL},
+        {"to", &hf_xmpp_to, false, false, NULL, NULL},
+        {"type", &hf_xmpp_type, false, true, xmpp_val_enum_list, type_array},
+        {"xml:lang", NULL, false, false, NULL,NULL},
+        {"chatstate", &hf_xmpp_message_chatstate, false, true, NULL, NULL}
     };
 
     xmpp_elem_info elems_info [] = {
@@ -413,8 +413,8 @@ xmpp_message_body(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_elem
     proto_tree *body_tree;
 
     xmpp_attr_info attrs_info[] = {
-        {"xml:lang", NULL, FALSE, TRUE, NULL, NULL},
-        {"value", NULL, TRUE, TRUE, NULL, NULL}
+        {"xml:lang", NULL, false, true, NULL, NULL},
+        {"value", NULL, true, true, NULL, NULL}
     };
 
     xmpp_attr_t *fake_data_attr;
@@ -437,8 +437,8 @@ xmpp_message_subject(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_e
     proto_tree *subject_tree;
 
     xmpp_attr_info attrs_info[] = {
-        {"xml:lang", NULL, FALSE, TRUE, NULL, NULL},
-        {"value", NULL, TRUE, FALSE, NULL, NULL}
+        {"xml:lang", NULL, false, true, NULL, NULL},
+        {"value", NULL, true, false, NULL, NULL}
     };
 
     xmpp_attr_t *fake_data_attr;
@@ -462,8 +462,8 @@ xmpp_message_thread(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_el
     proto_tree *thread_tree;
 
     xmpp_attr_info attrs_info[] = {
-        {"parent", &hf_xmpp_message_thread_parent, FALSE, TRUE, NULL, NULL},
-        {"value", NULL, TRUE, TRUE, NULL, NULL}
+        {"parent", &hf_xmpp_message_thread_parent, false, true, NULL, NULL},
+        {"value", NULL, true, true, NULL, NULL}
     };
 
     xmpp_attr_t *fake_value;
@@ -487,10 +487,10 @@ xmpp_auth(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_element_t *p
     proto_tree *auth_tree;
 
     xmpp_attr_info_ext attrs_info[]={
-        {"urn:ietf:params:xml:ns:xmpp-sasl", {"xmlns", &hf_xmpp_xmlns, TRUE, TRUE, NULL, NULL}},
-        {"urn:ietf:params:xml:ns:xmpp-sasl", {"mechanism", NULL, TRUE, TRUE, NULL, NULL}},
-        {"http://www.google.com/talk/protocol/auth", {"xmlns", &hf_xmpp_xmlns, TRUE, TRUE, NULL, NULL}},
-        {"http://www.google.com/talk/protocol/auth", {"client-uses-full-bind-result", NULL, TRUE, TRUE, NULL, NULL}},
+        {"urn:ietf:params:xml:ns:xmpp-sasl", {"xmlns", &hf_xmpp_xmlns, true, true, NULL, NULL}},
+        {"urn:ietf:params:xml:ns:xmpp-sasl", {"mechanism", NULL, true, true, NULL, NULL}},
+        {"http://www.google.com/talk/protocol/auth", {"xmlns", &hf_xmpp_xmlns, true, true, NULL, NULL}},
+        {"http://www.google.com/talk/protocol/auth", {"client-uses-full-bind-result", NULL, true, true, NULL, NULL}},
     };
 
     col_set_str(pinfo->cinfo, COL_INFO, "AUTH");
@@ -513,7 +513,7 @@ xmpp_challenge_response_success(proto_tree *tree, tvbuff_t *tvb,
     proto_tree *subtree;
 
     xmpp_attr_info attrs_info[] = {
-        {"xmlns", &hf_xmpp_xmlns, TRUE, TRUE, NULL, NULL}
+        {"xmlns", &hf_xmpp_xmlns, true, true, NULL, NULL}
     };
 
     col_set_str(pinfo->cinfo, COL_INFO, col_info);
@@ -534,8 +534,8 @@ xmpp_failure(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_element_t
     proto_tree *fail_tree;
 
     xmpp_attr_info attrs_info[] = {
-        {"xmlns", &hf_xmpp_xmlns, TRUE, TRUE, NULL, NULL},
-        {"condition", NULL, FALSE, TRUE, NULL, NULL}
+        {"xmlns", &hf_xmpp_xmlns, true, true, NULL, NULL},
+        {"condition", NULL, false, true, NULL, NULL}
     };
 
     static const gchar *fail_names[] = {"aborted","account-disabled", "credentials-expired",
@@ -592,13 +592,13 @@ xmpp_stream(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xmpp_element_t
     proto_tree *stream_tree;
 
     xmpp_attr_info_ext attrs_info [] = {
-        {"http://etherx.jabber.org/streams",{"xmlns", &hf_xmpp_xmlns, FALSE, TRUE, NULL, NULL}},
-        {"http://etherx.jabber.org/streams",{"version", NULL, FALSE, TRUE, NULL, NULL}},
-        {"http://etherx.jabber.org/streams",{"from", NULL, FALSE, TRUE, NULL, NULL}},
-        {"http://etherx.jabber.org/streams",{"to", NULL, FALSE, TRUE, NULL, NULL}},
-        {"http://etherx.jabber.org/streams",{"id", NULL, FALSE, TRUE, NULL, NULL}},
-        {"http://etherx.jabber.org/streams",{"xml:lang", NULL, FALSE, TRUE, NULL, NULL}},
-        {"jabber:client",{"xmlns", &hf_xmpp_xmlns, FALSE, TRUE, NULL, NULL}},
+        {"http://etherx.jabber.org/streams",{"xmlns", &hf_xmpp_xmlns, false, true, NULL, NULL}},
+        {"http://etherx.jabber.org/streams",{"version", NULL, false, true, NULL, NULL}},
+        {"http://etherx.jabber.org/streams",{"from", NULL, false, true, NULL, NULL}},
+        {"http://etherx.jabber.org/streams",{"to", NULL, false, true, NULL, NULL}},
+        {"http://etherx.jabber.org/streams",{"id", NULL, false, true, NULL, NULL}},
+        {"http://etherx.jabber.org/streams",{"xml:lang", NULL, false, true, NULL, NULL}},
+        {"jabber:client",{"xmlns", &hf_xmpp_xmlns, false, true, NULL, NULL}},
 
     };
 
@@ -618,7 +618,7 @@ xmpp_stream_close(proto_tree *tree, tvbuff_t *tvb, packet_info* pinfo)
     tvbparse_t        *tt;
     tvbparse_elem_t   *elem;
 
-    tt = tvbparse_init(tvb,0,-1,NULL,want_ignore);
+    tt = tvbparse_init(pinfo->pool, tvb,0,-1,NULL,want_ignore);
 
     if((elem = tvbparse_get(tt,want_stream_end_tag))!=NULL)
     {
@@ -656,7 +656,7 @@ xmpp_features_mechanisms(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xm
     proto_tree *mechanisms_tree;
 
     xmpp_attr_info attrs_info [] = {
-        {"xmlns", &hf_xmpp_xmlns, TRUE, TRUE, NULL, NULL}
+        {"xmlns", &hf_xmpp_xmlns, true, true, NULL, NULL}
     };
 
     xmpp_elem_info elems_info [] = {
@@ -677,7 +677,7 @@ xmpp_starttls(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo,
     proto_tree *tls_tree;
 
     xmpp_attr_info attrs_info [] = {
-        {"xmlns", &hf_xmpp_xmlns, TRUE, TRUE, NULL, NULL},
+        {"xmlns", &hf_xmpp_xmlns, true, true, NULL, NULL},
     };
 
     col_add_fstr(pinfo->cinfo, COL_INFO, "STARTTLS ");
@@ -705,7 +705,7 @@ xmpp_proceed(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo,
     guint32 ssl_proceed;
 
     xmpp_attr_info attrs_info [] = {
-        {"xmlns", &hf_xmpp_xmlns, TRUE, TRUE, NULL, NULL},
+        {"xmlns", &hf_xmpp_xmlns, true, true, NULL, NULL},
     };
 
     col_add_fstr(pinfo->cinfo, COL_INFO, "PROCEED ");
