@@ -224,93 +224,93 @@ static const value_string diag_val_vals[] = {
 };
 
 /* Initialize the protocol and registered fields */
-static int proto_xtp = -1;
+static int proto_xtp;
 /* common header */
-static int hf_xtp_key = -1;
-static int hf_xtp_cmd = -1;
-static int hf_xtp_cmd_options = -1;
-static int hf_xtp_cmd_options_nocheck = -1;
-static int hf_xtp_cmd_options_edge = -1;
-static int hf_xtp_cmd_options_noerr = -1;
-static int hf_xtp_cmd_options_multi = -1;
-static int hf_xtp_cmd_options_res = -1;
-static int hf_xtp_cmd_options_sort = -1;
-static int hf_xtp_cmd_options_noflow = -1;
-static int hf_xtp_cmd_options_fastnak = -1;
-static int hf_xtp_cmd_options_sreq = -1;
-static int hf_xtp_cmd_options_dreq = -1;
-static int hf_xtp_cmd_options_rclose = -1;
-static int hf_xtp_cmd_options_wclose = -1;
-static int hf_xtp_cmd_options_eom = -1;
-static int hf_xtp_cmd_options_end = -1;
-static int hf_xtp_cmd_options_btag = -1;
-static int hf_xtp_cmd_ptype = -1;
-static int hf_xtp_cmd_ptype_ver = -1;
-static int hf_xtp_cmd_ptype_pformat = -1;
-static int hf_xtp_dlen = -1;
-static int hf_xtp_sort = -1;
-static int hf_xtp_sync = -1;
-static int hf_xtp_seq = -1;
+static int hf_xtp_key;
+static int hf_xtp_cmd;
+static int hf_xtp_cmd_options;
+static int hf_xtp_cmd_options_nocheck;
+static int hf_xtp_cmd_options_edge;
+static int hf_xtp_cmd_options_noerr;
+static int hf_xtp_cmd_options_multi;
+static int hf_xtp_cmd_options_res;
+static int hf_xtp_cmd_options_sort;
+static int hf_xtp_cmd_options_noflow;
+static int hf_xtp_cmd_options_fastnak;
+static int hf_xtp_cmd_options_sreq;
+static int hf_xtp_cmd_options_dreq;
+static int hf_xtp_cmd_options_rclose;
+static int hf_xtp_cmd_options_wclose;
+static int hf_xtp_cmd_options_eom;
+static int hf_xtp_cmd_options_end;
+static int hf_xtp_cmd_options_btag;
+static int hf_xtp_cmd_ptype;
+static int hf_xtp_cmd_ptype_ver;
+static int hf_xtp_cmd_ptype_pformat;
+static int hf_xtp_dlen;
+static int hf_xtp_sort;
+static int hf_xtp_sync;
+static int hf_xtp_seq;
 /* control segment */
-static int hf_xtp_cntl_rseq = -1;
-static int hf_xtp_cntl_alloc = -1;
-static int hf_xtp_cntl_echo = -1;
-static int hf_xtp_ecntl_rseq = -1;
-static int hf_xtp_ecntl_alloc = -1;
-static int hf_xtp_ecntl_echo = -1;
-static int hf_xtp_ecntl_nspan = -1;
-static int hf_xtp_ecntl_span_left = -1;
-static int hf_xtp_ecntl_span_right = -1;
-static int hf_xtp_tcntl_rseq = -1;
-static int hf_xtp_tcntl_alloc = -1;
-static int hf_xtp_tcntl_echo = -1;
-static int hf_xtp_tcntl_rsvd = -1;
-static int hf_xtp_tcntl_xkey = -1;
+static int hf_xtp_cntl_rseq;
+static int hf_xtp_cntl_alloc;
+static int hf_xtp_cntl_echo;
+static int hf_xtp_ecntl_rseq;
+static int hf_xtp_ecntl_alloc;
+static int hf_xtp_ecntl_echo;
+static int hf_xtp_ecntl_nspan;
+static int hf_xtp_ecntl_span_left;
+static int hf_xtp_ecntl_span_right;
+static int hf_xtp_tcntl_rseq;
+static int hf_xtp_tcntl_alloc;
+static int hf_xtp_tcntl_echo;
+static int hf_xtp_tcntl_rsvd;
+static int hf_xtp_tcntl_xkey;
 /* traffic specifier */
-static int hf_xtp_tspec_tlen = -1;
-static int hf_xtp_tspec_service = -1;
-static int hf_xtp_tspec_tformat = -1;
-static int hf_xtp_tspec_traffic = -1;
-static int hf_xtp_tspec_maxdata = -1;
-static int hf_xtp_tspec_inrate = -1;
-static int hf_xtp_tspec_outrate = -1;
-static int hf_xtp_tspec_inburst = -1;
-static int hf_xtp_tspec_outburst = -1;
+static int hf_xtp_tspec_tlen;
+static int hf_xtp_tspec_service;
+static int hf_xtp_tspec_tformat;
+static int hf_xtp_tspec_traffic;
+static int hf_xtp_tspec_maxdata;
+static int hf_xtp_tspec_inrate;
+static int hf_xtp_tspec_outrate;
+static int hf_xtp_tspec_inburst;
+static int hf_xtp_tspec_outburst;
 /* address segment */
-static int hf_xtp_aseg_alen = -1;
-static int hf_xtp_aseg_adomain = -1;
-static int hf_xtp_aseg_aformat = -1;
-static int hf_xtp_aseg_address = -1;
-static int hf_xtp_aseg_dsthost = -1;
-static int hf_xtp_aseg_srchost = -1;
-static int hf_xtp_aseg_dstport = -1;
-static int hf_xtp_aseg_srcport = -1;
+static int hf_xtp_aseg_alen;
+static int hf_xtp_aseg_adomain;
+static int hf_xtp_aseg_aformat;
+static int hf_xtp_aseg_address;
+static int hf_xtp_aseg_dsthost;
+static int hf_xtp_aseg_srchost;
+static int hf_xtp_aseg_dstport;
+static int hf_xtp_aseg_srcport;
 /* others */
-static int hf_xtp_btag = -1;
-static int hf_xtp_diag_code = -1;
-static int hf_xtp_diag_val = -1;
-static int hf_xtp_diag_msg = -1;
-static int hf_xtp_checksum = -1;
-static int hf_xtp_checksum_status = -1;
-static int hf_xtp_data = -1;
+static int hf_xtp_btag;
+static int hf_xtp_diag_code;
+static int hf_xtp_diag_val;
+static int hf_xtp_diag_msg;
+static int hf_xtp_checksum;
+static int hf_xtp_checksum_status;
+static int hf_xtp_data;
 
 /* Initialize the subtree pointers */
-static gint ett_xtp = -1;
-static gint ett_xtp_cmd = -1;
-static gint ett_xtp_cmd_options = -1;
-static gint ett_xtp_cmd_ptype = -1;
-static gint ett_xtp_cntl = -1;
-static gint ett_xtp_ecntl = -1;
-static gint ett_xtp_tcntl = -1;
-static gint ett_xtp_tspec = -1;
-static gint ett_xtp_jcntl = -1;
-static gint ett_xtp_first = -1;
-static gint ett_xtp_aseg = -1;
-static gint ett_xtp_data = -1;
-static gint ett_xtp_diag = -1;
+static gint ett_xtp;
+static gint ett_xtp_cmd;
+static gint ett_xtp_cmd_options;
+static gint ett_xtp_cmd_ptype;
+static gint ett_xtp_cntl;
+static gint ett_xtp_ecntl;
+static gint ett_xtp_tcntl;
+static gint ett_xtp_tspec;
+static gint ett_xtp_jcntl;
+static gint ett_xtp_first;
+static gint ett_xtp_aseg;
+static gint ett_xtp_data;
+static gint ett_xtp_diag;
 
-static expert_field ei_xtp_spans_bad = EI_INIT;
-static expert_field ei_xtp_checksum = EI_INIT;
+static expert_field ei_xtp_spans_bad;
+static expert_field ei_xtp_checksum;
 
 /* dissector of each payload */
 static int
