@@ -48,105 +48,107 @@
 void proto_reg_handoff_zebra(void);
 void proto_register_zebra(void);
 
-static int proto_zebra = -1;
-static int hf_zebra_len = -1;
-static int hf_zebra_command = -1;
-static int hf_zebra_request = -1;
-static int hf_zebra_interface = -1;
-static int hf_zebra_index = -1;
-static int hf_zebra_indexnum = -1;
-static int hf_zebra_type_v0 = -1;
-static int hf_zebra_type_v1 = -1;
-static int hf_zebra_intflags = -1;
-static int hf_zebra_rtflags = -1;
-static int hf_zebra_distance = -1;
-static int hf_zebra_metric = -1;
-static int hf_zebra_mtu = -1;
-static int hf_zebra_mtu6 = -1;
-static int hf_zebra_bandwidth = -1;
-static int hf_zebra_family = -1;
-static int hf_zebra_flags = -1;
-static int hf_zebra_message = -1;
-static int hf_zebra_route_safi = -1;
-static int hf_zebra_msg_nexthop = -1;
-static int hf_zebra_msg_index = -1;
-static int hf_zebra_msg_distance = -1;
-static int hf_zebra_msg_metric = -1;
-static int hf_zebra_nexthopnum = -1;
-static int hf_zebra_nexthop4 = -1;
-static int hf_zebra_nexthop6 = -1;
-static int hf_zebra_dest4 = -1;
-static int hf_zebra_dest6 = -1;
-static int hf_zebra_prefixlen = -1;
-static int hf_zebra_prefix4 = -1;
-static int hf_zebra_prefix6 = -1;
-static int hf_zebra_version = -1;
-static int hf_zebra_marker = -1;
-static int hf_zebra_intstatus = -1;
-static int hf_zebra_routeridaddress = -1;
-static int hf_zebra_routeridmask = -1;
-static int hf_zebra_mac = -1;
-static int hf_zebra_redist_default = -1;
-static int hf_zebra_vrfid = -1;
-static int hf_zebra_routeridfamily = -1;
-static int hf_zebra_nexthoptype = -1;
-static int hf_zebra_msg_mtu = -1;
-static int hf_zebra_msg_tag = -1;
-static int hf_zebra_tag = -1;
-static int hf_zebra_maclen = -1;
-static int hf_zebra_haslinkparam = -1;
-/* FRRouting, Zebra API v4, v5 and v6 */
-static int hf_zebra_command_v4 = -1;
-static int hf_zebra_command_v5 = -1;
-static int hf_zebra_command_v6 = -1;
-static int hf_zebra_type_v4 = -1;
-static int hf_zebra_type_v5 = -1;
-static int hf_zebra_ptmenable = -1;
-static int hf_zebra_ptmstatus = -1;
-static int hf_zebra_instance = -1;
-static int hf_zebra_rtflags_u32 = -1;
-static int hf_zebra_speed = -1;
-static int hf_zebra_lltype = -1;
-static int hf_zebra_message4 = -1;
-static int hf_zebra_message5 = -1;
-static int hf_zebra_route_safi_u8 = -1;
-static int hf_zebra_rmac = -1;
-static int hf_zebra_msg4_tag = -1;
-static int hf_zebra_msg4_mtu = -1;
-static int hf_zebra_msg4_srcpfx = -1;
-static int hf_zebra_msg5_distance = -1;
-static int hf_zebra_msg5_metric = -1;
-static int hf_zebra_msg5_tag = -1;
-static int hf_zebra_msg5_mtu = -1;
-static int hf_zebra_msg5_srcpfx = -1;
-static int hf_zebra_msg_label = -1;
-static int hf_zebra_msg_tableid = -1;
-static int hf_zebra_nexthopnum_u16 = -1;
-static int hf_zebra_nexthoptype_frr = -1;
-static int hf_zebra_bhtype = -1;
-static int hf_zebra_srcprefixlen = -1;
-static int hf_zebra_srcprefix4 = -1;
-static int hf_zebra_srcprefix6 = -1;
-static int hf_zebra_tableid = -1;
-static int hf_zebra_afi = -1;
-static int hf_zebra_pid = -1;
-static int hf_zebra_vrf_table_id = -1;
-static int hf_zebra_vrf_netns_name = -1;
-static int hf_zebra_vrf_name = -1;
-static int hf_zebra_proto = -1;
-static int hf_zebra_label_chunk_keep = -1;
-static int hf_zebra_label_chunk_size = -1;
-static int hf_zebra_label_chunk_start = -1;
-static int hf_zebra_label_chunk_end = -1;
-static int hf_zebra_mpls_enabled = -1;
-static int hf_zebra_multipath_num = -1;
-static int hf_zebra_labelnum = -1;
-static int hf_zebra_label = -1;
-static int hf_zebra_receive_notify = -1;
+static dissector_handle_t zebra_handle;
 
-static gint ett_zebra = -1;
-static gint ett_zebra_request = -1;
-static gint ett_message = -1;
+static int proto_zebra;
+static int hf_zebra_len;
+static int hf_zebra_command;
+static int hf_zebra_request;
+static int hf_zebra_interface;
+static int hf_zebra_index;
+static int hf_zebra_indexnum;
+static int hf_zebra_type_v0;
+static int hf_zebra_type_v1;
+static int hf_zebra_intflags;
+static int hf_zebra_rtflags;
+static int hf_zebra_distance;
+static int hf_zebra_metric;
+static int hf_zebra_mtu;
+static int hf_zebra_mtu6;
+static int hf_zebra_bandwidth;
+static int hf_zebra_family;
+static int hf_zebra_flags;
+static int hf_zebra_message;
+static int hf_zebra_route_safi;
+static int hf_zebra_msg_nexthop;
+static int hf_zebra_msg_index;
+static int hf_zebra_msg_distance;
+static int hf_zebra_msg_metric;
+static int hf_zebra_nexthopnum;
+static int hf_zebra_nexthop4;
+static int hf_zebra_nexthop6;
+static int hf_zebra_dest4;
+static int hf_zebra_dest6;
+static int hf_zebra_prefixlen;
+static int hf_zebra_prefix4;
+static int hf_zebra_prefix6;
+static int hf_zebra_version;
+static int hf_zebra_marker;
+static int hf_zebra_intstatus;
+static int hf_zebra_routeridaddress;
+static int hf_zebra_routeridmask;
+static int hf_zebra_mac;
+static int hf_zebra_redist_default;
+static int hf_zebra_vrfid;
+static int hf_zebra_routeridfamily;
+static int hf_zebra_nexthoptype;
+static int hf_zebra_msg_mtu;
+static int hf_zebra_msg_tag;
+static int hf_zebra_tag;
+static int hf_zebra_maclen;
+static int hf_zebra_haslinkparam;
+/* FRRouting, Zebra API v4, v5 and v6 */
+static int hf_zebra_command_v4;
+static int hf_zebra_command_v5;
+static int hf_zebra_command_v6;
+static int hf_zebra_type_v4;
+static int hf_zebra_type_v5;
+static int hf_zebra_ptmenable;
+static int hf_zebra_ptmstatus;
+static int hf_zebra_instance;
+static int hf_zebra_rtflags_u32;
+static int hf_zebra_speed;
+static int hf_zebra_lltype;
+static int hf_zebra_message4;
+static int hf_zebra_message5;
+static int hf_zebra_route_safi_u8;
+static int hf_zebra_rmac;
+static int hf_zebra_msg4_tag;
+static int hf_zebra_msg4_mtu;
+static int hf_zebra_msg4_srcpfx;
+static int hf_zebra_msg5_distance;
+static int hf_zebra_msg5_metric;
+static int hf_zebra_msg5_tag;
+static int hf_zebra_msg5_mtu;
+static int hf_zebra_msg5_srcpfx;
+static int hf_zebra_msg_label;
+static int hf_zebra_msg_tableid;
+static int hf_zebra_nexthopnum_u16;
+static int hf_zebra_nexthoptype_frr;
+static int hf_zebra_bhtype;
+static int hf_zebra_srcprefixlen;
+static int hf_zebra_srcprefix4;
+static int hf_zebra_srcprefix6;
+static int hf_zebra_tableid;
+static int hf_zebra_afi;
+static int hf_zebra_pid;
+static int hf_zebra_vrf_table_id;
+static int hf_zebra_vrf_netns_name;
+static int hf_zebra_vrf_name;
+static int hf_zebra_proto;
+static int hf_zebra_label_chunk_keep;
+static int hf_zebra_label_chunk_size;
+static int hf_zebra_label_chunk_start;
+static int hf_zebra_label_chunk_end;
+static int hf_zebra_mpls_enabled;
+static int hf_zebra_multipath_num;
+static int hf_zebra_labelnum;
+static int hf_zebra_label;
+static int hf_zebra_receive_notify;
+
+static gint ett_zebra;
+static gint ett_zebra_request;
+static gint ett_message;
 
 #define TCP_PORT_ZEBRA			2600 /* Not IANA registered */
 
@@ -2316,19 +2318,19 @@ dissect_zebra_request(proto_tree *tree, gboolean request, tvbuff_t *tvb,
  from version 0.
  */
 
-static gboolean
+static bool
 zebra_get_header(tvbuff_t *tvb, int offset, zebra_header_t *header)
 {
 	guint16 len, command;
 	guint8  version;
 
 	if (tvb_captured_length_remaining(tvb, offset) < 3) {
-		return FALSE;
+		return false;
 	}
 
 	len = tvb_get_ntohs(tvb, offset);
 	if (len < 3) {
-		return FALSE;
+		return false;
 	}
 
 	offset += 2;
@@ -2338,7 +2340,7 @@ zebra_get_header(tvbuff_t *tvb, int offset, zebra_header_t *header)
 	} else { // not version 0
 		offset++;
 		if (tvb_captured_length_remaining(tvb, offset) < 3) {
-			return FALSE;
+			return false;
 		}
 		version = tvb_get_guint8(tvb, offset);
 		if (version == 1 || version == 2) {
@@ -2350,10 +2352,10 @@ zebra_get_header(tvbuff_t *tvb, int offset, zebra_header_t *header)
 			 * to invent a few more. */
 			offset += 5;
 		} else {
-			return FALSE;
+			return false;
 		}
 		if (tvb_captured_length_remaining(tvb, offset) < 2) {
-			return FALSE;
+			return false;
 		}
 		command = tvb_get_ntohs(tvb, offset);
 	}
@@ -2362,44 +2364,44 @@ zebra_get_header(tvbuff_t *tvb, int offset, zebra_header_t *header)
 		header->command = command;
 		header->version = version;
 	}
-	return TRUE;
+	return true;
 }
 
-static gboolean
+static bool
 test_zebra(packet_info *pinfo _U_, tvbuff_t *tvb, int offset, void *data _U_)
 {
 	zebra_header_t header;
 
 	if (!zebra_get_header(tvb, offset, &header)) {
-		return FALSE;
+		return false;
 	}
 
 	if (header.len > 1024) {
 		/* There can be multiple PDUs in a segment, but PDUs themselves
 		 * are small. Even 1024 is a generous overestimate.
 		 */
-		return FALSE;
+		return false;
 	}
 
 	if (header.version < 4) {
 		if (!try_val_to_str(header.command, messages)) {
-			return FALSE;
+			return false;
 		}
 	} else if (header.version == 4) {
 		if (!try_val_to_str(header.command, frr_zapi4_messages)) {
-			return FALSE;
+			return false;
 		}
 	} else if (header.version == 5) {
 		if (!try_val_to_str(header.command, frr_zapi5_messages)) {
-			return FALSE;
+			return false;
 		}
 	} else {
 		if (!try_val_to_str(header.command, frr_zapi6_messages)) {
-			return FALSE;
+			return false;
 		}
 	}
 
-	return TRUE;
+	return true;
 }
 
 static int
@@ -2624,7 +2626,7 @@ proto_register_zebra(void)
 		{ &hf_zebra_routeridaddress,
 		  { "Router ID address",	"zebra.routerIDAddress",
 		    FT_IPv4, BASE_NONE, NULL, 0x0,
-		    "Router ID", HFILL }},
+		    NULL, HFILL }},
 		{ &hf_zebra_routeridmask,
 		  { "Router ID mask",	"zebra.routerIDMask",
 		    FT_UINT8, BASE_DEC, NULL, 0x0,
@@ -2871,14 +2873,12 @@ proto_register_zebra(void)
 	proto_zebra = proto_register_protocol("Zebra Protocol", "ZEBRA", "zebra");
 	proto_register_field_array(proto_zebra, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+	zebra_handle = register_dissector("zebra", dissect_zebra, proto_zebra);
 }
 
 void
 proto_reg_handoff_zebra(void)
 {
-	dissector_handle_t zebra_handle;
-
-	zebra_handle = create_dissector_handle(dissect_zebra, proto_zebra);
 	dissector_add_uint_with_preference("tcp.port", TCP_PORT_ZEBRA, zebra_handle);
 }
 
