@@ -39,24 +39,24 @@ void proto_register_ziop(void);
  * ------------------------------------------------------------------------------------------+
  */
 
-static int proto_ziop = -1;
+static int proto_ziop;
 
 /*
  * (sub)Tree declares
  */
 
-static gint hf_ziop_magic = -1;
-static gint hf_ziop_giop_version_major = -1;
-static gint hf_ziop_giop_version_minor = -1;
-static gint hf_ziop_flags = -1;
-static gint hf_ziop_message_type = -1;
-static gint hf_ziop_message_size = -1;
-static gint hf_ziop_compressor_id = -1;
-static gint hf_ziop_original_length = -1;
+static gint hf_ziop_magic;
+static gint hf_ziop_giop_version_major;
+static gint hf_ziop_giop_version_minor;
+static gint hf_ziop_flags;
+static gint hf_ziop_message_type;
+static gint hf_ziop_message_size;
+static gint hf_ziop_compressor_id;
+static gint hf_ziop_original_length;
 
-static gint ett_ziop = -1;
+static gint ett_ziop;
 
-static expert_field ei_ziop_version = EI_INIT;
+static expert_field ei_ziop_version;
 
 static dissector_handle_t ziop_tcp_handle;
 
@@ -115,7 +115,7 @@ dissect_ziop (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void* data
   ti = proto_tree_add_item (tree, proto_ziop, tvb, 0, -1, ENC_NA);
   ziop_tree = proto_item_add_subtree (ti, ett_ziop);
 
-  proto_tree_add_item(ziop_tree, hf_ziop_magic, tvb, offset, 4, ENC_ASCII|ENC_NA);
+  proto_tree_add_item(ziop_tree, hf_ziop_magic, tvb, offset, 4, ENC_ASCII);
   offset += 4;
   proto_tree_add_item(ziop_tree, hf_ziop_giop_version_major, tvb, offset, 1, ENC_BIG_ENDIAN);
   giop_version_major = tvb_get_guint8(tvb, offset);
@@ -210,7 +210,7 @@ dissect_ziop_tcp (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void*
 }
 
 
-gboolean
+bool
 dissect_ziop_heur (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void * data)
 {
   guint tot_len;
@@ -224,11 +224,11 @@ dissect_ziop_heur (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void
     {
       /* Not enough data captured to hold the ZIOP header; don't try
          to interpret it as GIOP. */
-      return FALSE;
+      return false;
     }
   if ( tvb_memeql(tvb, 0, (const guint8 *)ZIOP_MAGIC, 4) != 0)
     {
-      return FALSE;
+      return false;
     }
 
   if ( pinfo->ptype == PT_TCP )
@@ -253,7 +253,7 @@ dissect_ziop_heur (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree, void
     {
       dissect_ziop (tvb, pinfo, tree, data);
     }
-  return TRUE;
+  return true;
 }
 
 void
@@ -309,13 +309,13 @@ proto_register_ziop (void)
   expert_register_field_array(expert_ziop, ei, array_length(ei));
 
   register_dissector("ziop", dissect_ziop, proto_ziop);
+  ziop_tcp_handle = register_dissector("ziop.tcp", dissect_ziop_tcp, proto_ziop);
 }
 
 
 void
 proto_reg_handoff_ziop (void)
 {
-  ziop_tcp_handle = create_dissector_handle(dissect_ziop_tcp, proto_ziop);
   dissector_add_for_decode_as_with_preference("udp.port", ziop_tcp_handle);
 
   heur_dissector_add("tcp", dissect_ziop_heur, "ZIOP over TCP", "ziop_tcp", proto_ziop, HEURISTIC_ENABLE);
