@@ -28,100 +28,100 @@ void proto_register_zrtp(void);
 /*
   RTP header
 */
-static int proto_zrtp = -1;
-static int hf_zrtp_rtpversion = -1;
-static int hf_zrtp_rtppadding = -1;
-static int hf_zrtp_rtpextension = -1;
-/* static int hf_zrtp_id = -1; */
-static int hf_zrtp_sequence = -1;
-static int hf_zrtp_cookie = -1;
-static int hf_zrtp_source_id = -1;
+static int proto_zrtp;
+static int hf_zrtp_rtpversion;
+static int hf_zrtp_rtppadding;
+static int hf_zrtp_rtpextension;
+/* static int hf_zrtp_id; */
+static int hf_zrtp_sequence;
+static int hf_zrtp_cookie;
+static int hf_zrtp_source_id;
 
 /*
   ZRTP header
 */
-static int hf_zrtp_signature = -1;
-static int hf_zrtp_msg_length = -1;
-static int hf_zrtp_msg_type = -1;
-static int hf_zrtp_msg_version = -1;
+static int hf_zrtp_signature;
+static int hf_zrtp_msg_length;
+static int hf_zrtp_msg_type;
+static int hf_zrtp_msg_version;
 
 /*
   Hello Data
 */
-static int hf_zrtp_msg_client_id = -1;
-static int hf_zrtp_msg_zid = -1;
-static int hf_zrtp_msg_sigcap = -1;
-static int hf_zrtp_msg_mitm = -1;
-static int hf_zrtp_msg_passive = -1;
-static int hf_zrtp_msg_hash_count = -1;
-static int hf_zrtp_msg_cipher_count = -1;
-static int hf_zrtp_msg_authtag_count = -1;
-static int hf_zrtp_msg_key_count = -1;
-static int hf_zrtp_msg_sas_count = -1;
-static int hf_zrtp_msg_hash = -1;
-static int hf_zrtp_msg_cipher = -1;
-static int hf_zrtp_msg_at = -1;
-static int hf_zrtp_msg_keya = -1;
-static int hf_zrtp_msg_sas = -1;
-static int hf_zrtp_msg_hash_image = -1;
+static int hf_zrtp_msg_client_id;
+static int hf_zrtp_msg_zid;
+static int hf_zrtp_msg_sigcap;
+static int hf_zrtp_msg_mitm;
+static int hf_zrtp_msg_passive;
+static int hf_zrtp_msg_hash_count;
+static int hf_zrtp_msg_cipher_count;
+static int hf_zrtp_msg_authtag_count;
+static int hf_zrtp_msg_key_count;
+static int hf_zrtp_msg_sas_count;
+static int hf_zrtp_msg_hash;
+static int hf_zrtp_msg_cipher;
+static int hf_zrtp_msg_at;
+static int hf_zrtp_msg_keya;
+static int hf_zrtp_msg_sas;
+static int hf_zrtp_msg_hash_image;
 
 /*
   Commit Data
 */
-static int hf_zrtp_msg_hvi = -1;
-static int hf_zrtp_msg_nonce = -1;
-static int hf_zrtp_msg_key_id = -1;
+static int hf_zrtp_msg_hvi;
+static int hf_zrtp_msg_nonce;
+static int hf_zrtp_msg_key_id;
 
 /*
   DHParts Data
 */
-static int hf_zrtp_msg_rs1ID = -1;
-static int hf_zrtp_msg_rs2ID = -1;
-static int hf_zrtp_msg_auxs = -1;
-static int hf_zrtp_msg_pbxs = -1;
+static int hf_zrtp_msg_rs1ID;
+static int hf_zrtp_msg_rs2ID;
+static int hf_zrtp_msg_auxs;
+static int hf_zrtp_msg_pbxs;
 
 /*
   Confirm Data
 */
-static int hf_zrtp_msg_hmac = -1;
-static int hf_zrtp_msg_cfb = -1;
+static int hf_zrtp_msg_hmac;
+static int hf_zrtp_msg_cfb;
 
 /*
   Error Data
 */
-static int hf_zrtp_msg_error = -1;
+static int hf_zrtp_msg_error;
 
 /*
   Ping Data
 */
-static int hf_zrtp_msg_ping_version = -1;
-static int hf_zrtp_msg_ping_endpointhash = -1;
-static int hf_zrtp_msg_pingack_endpointhash = -1;
-static int hf_zrtp_msg_ping_ssrc = -1;
+static int hf_zrtp_msg_ping_version;
+static int hf_zrtp_msg_ping_endpointhash;
+static int hf_zrtp_msg_pingack_endpointhash;
+static int hf_zrtp_msg_ping_ssrc;
 
 /*
   Checksum Data
 */
-static int hf_zrtp_checksum = -1;
-static int hf_zrtp_checksum_status = -1;
+static int hf_zrtp_checksum;
+static int hf_zrtp_checksum_status;
 
 /*
   Sub-Tree
 */
-static gint ett_zrtp = -1;
-static gint ett_zrtp_msg = -1;
-static gint ett_zrtp_msg_data = -1;
+static gint ett_zrtp;
+static gint ett_zrtp_msg;
+static gint ett_zrtp_msg_data;
 
-static gint ett_zrtp_msg_hc = -1;
-static gint ett_zrtp_msg_kc = -1;
-static gint ett_zrtp_msg_ac = -1;
-static gint ett_zrtp_msg_cc = -1;
-static gint ett_zrtp_msg_sc = -1;
+static gint ett_zrtp_msg_hc;
+static gint ett_zrtp_msg_kc;
+static gint ett_zrtp_msg_ac;
+static gint ett_zrtp_msg_cc;
+static gint ett_zrtp_msg_sc;
 
-static gint ett_zrtp_checksum = -1;
+static gint ett_zrtp_checksum;
 
 
-static expert_field ei_zrtp_checksum = EI_INIT;
+static expert_field ei_zrtp_checksum;
 
 static dissector_handle_t zrtp_handle;
 
@@ -164,7 +164,7 @@ typedef struct _value_string_keyval {
 } value_string_keyval;
 
 
-const value_zrtp_versions valid_zrtp_versions[] =
+static const value_zrtp_versions valid_zrtp_versions[] =
   {
     {"1.1x"},
     {"1.0x"},
@@ -174,7 +174,7 @@ const value_zrtp_versions valid_zrtp_versions[] =
     {NULL}
   };
 
-const value_string_keyval zrtp_hash_type_vals[] =
+static const value_string_keyval zrtp_hash_type_vals[] =
   {
     { "S256",   "SHA-256 Hash"},
     { "S384",   "SHA-384 Hash"},
@@ -183,7 +183,7 @@ const value_string_keyval zrtp_hash_type_vals[] =
     { NULL,             NULL }
   };
 
-const value_string_keyval zrtp_cipher_type_vals[] =
+static const value_string_keyval zrtp_cipher_type_vals[] =
   {
     { "AES1",   "AES-CM with 128 bit keys"},
     { "AES2",   "AES-CM with 192 bit keys"},
@@ -197,7 +197,7 @@ const value_string_keyval zrtp_cipher_type_vals[] =
     { NULL,             NULL }
   };
 
-const value_string_keyval zrtp_auth_tag_vals[] =
+static const value_string_keyval zrtp_auth_tag_vals[] =
   {
     { "HS32",   "HMAC-SHA1 32 bit authentication tag"},
     { "HS80",   "HMAC-SHA1 80 bit authentication tag"},
@@ -206,14 +206,14 @@ const value_string_keyval zrtp_auth_tag_vals[] =
     { NULL,             NULL }
   };
 
-const value_string_keyval zrtp_sas_type_vals[] =
+static const value_string_keyval zrtp_sas_type_vals[] =
   {
     { "B32 ",   "Short authentication string using base 32"},
     { "B256",   "Short authentication string using base 256"},
     { NULL,             NULL }
   };
 
-const value_string_keyval zrtp_key_agreement_vals[] =
+static const value_string_keyval zrtp_key_agreement_vals[] =
   {
     { "DH2k",   "DH mode with p=2048 bit prime"},
     { "DH3k",   "DH mode with p=3072 bit prime"},
@@ -226,7 +226,7 @@ const value_string_keyval zrtp_key_agreement_vals[] =
     { NULL,             NULL }
   };
 
-const value_string zrtp_error_vals[] =
+static const value_string zrtp_error_vals[] =
   {
     { ZRTP_ERR_10, "Malformed Packet (CRC OK but wrong structure)"},
     { ZRTP_ERR_20, "Critical Software Error"},
@@ -286,7 +286,7 @@ key_to_val(const gchar *key, int keylen, const value_string_keyval *kv, const gc
   int i = 0;
   while (kv[i].key) {
     if (!strncmp(kv[i].key, key, keylen)) {
-      return(kv[i].val);
+      return kv[i].val;
     }
     i++;
   }
@@ -299,7 +299,7 @@ check_valid_version(const gchar *version) {
   int match_size = (version[0] == '0') ? 4 : 3;
   while (valid_zrtp_versions[i].version) {
     if (!strncmp(valid_zrtp_versions[i].version, version, match_size)) {
-      return(valid_zrtp_versions[i].version);
+      return valid_zrtp_versions[i].version;
     }
     i++;
   }
@@ -334,7 +334,7 @@ dissect_zrtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
 
   proto_tree_add_item(zrtp_tree, hf_zrtp_sequence, tvb, prime_offset+2, 2, ENC_BIG_ENDIAN);
 
-  proto_tree_add_item(zrtp_tree, hf_zrtp_cookie, tvb, prime_offset+4, 4, ENC_ASCII|ENC_NA);
+  proto_tree_add_item(zrtp_tree, hf_zrtp_cookie, tvb, prime_offset+4, 4, ENC_ASCII);
 
   proto_tree_add_item(zrtp_tree, hf_zrtp_source_id, tvb, prime_offset+8, 4, ENC_BIG_ENDIAN);
 
@@ -350,7 +350,7 @@ dissect_zrtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_
 
   tvb_memcpy(tvb, (void *)message_type, msg_offset+4, 8);
   message_type[8] = '\0';
-  proto_tree_add_item(zrtp_msg_tree, hf_zrtp_msg_type, tvb, msg_offset+4, 8, ENC_ASCII|ENC_NA);
+  proto_tree_add_item(zrtp_msg_tree, hf_zrtp_msg_type, tvb, msg_offset+4, 8, ENC_ASCII);
 
   linelen = tvb_reported_length_remaining(tvb, msg_offset+12);
 
@@ -469,7 +469,7 @@ dissect_Ping(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
 
   col_set_str(pinfo->cinfo, COL_INFO, "Ping Packet");
 
-  proto_tree_add_item(zrtp_tree, hf_zrtp_msg_ping_version,      tvb, data_offset,   4, ENC_ASCII|ENC_NA);
+  proto_tree_add_item(zrtp_tree, hf_zrtp_msg_ping_version,      tvb, data_offset,   4, ENC_ASCII);
   proto_tree_add_item(zrtp_tree, hf_zrtp_msg_ping_endpointhash, tvb, data_offset+4, 8, ENC_BIG_ENDIAN);
 }
 
@@ -479,7 +479,7 @@ dissect_PingACK(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
 
   col_set_str(pinfo->cinfo, COL_INFO, "PingACK Packet");
 
-  proto_tree_add_item(zrtp_tree, hf_zrtp_msg_ping_version,         tvb, data_offset,    4, ENC_ASCII|ENC_NA);
+  proto_tree_add_item(zrtp_tree, hf_zrtp_msg_ping_version,         tvb, data_offset,    4, ENC_ASCII);
   proto_tree_add_item(zrtp_tree, hf_zrtp_msg_pingack_endpointhash, tvb, data_offset+4,  8, ENC_BIG_ENDIAN);
   proto_tree_add_item(zrtp_tree, hf_zrtp_msg_ping_endpointhash,    tvb, data_offset+12, 8, ENC_BIG_ENDIAN);
   proto_tree_add_item(zrtp_tree, hf_zrtp_msg_ping_ssrc,            tvb, data_offset+20, 4, ENC_BIG_ENDIAN);
@@ -635,8 +635,8 @@ dissect_Hello(tvbuff_t *tvb, packet_info *pinfo, proto_tree *zrtp_tree) {
   if (check_valid_version(version_str) == NULL) {
     col_set_str(pinfo->cinfo, COL_INFO, "Unsupported version of ZRTP protocol");
   }
-  proto_tree_add_item(zrtp_tree, hf_zrtp_msg_version,    tvb, msg_offset+12,  4, ENC_ASCII|ENC_NA);
-  proto_tree_add_item(zrtp_tree, hf_zrtp_msg_client_id,  tvb, msg_offset+16, 16, ENC_ASCII|ENC_NA);
+  proto_tree_add_item(zrtp_tree, hf_zrtp_msg_version,    tvb, msg_offset+12,  4, ENC_ASCII);
+  proto_tree_add_item(zrtp_tree, hf_zrtp_msg_client_id,  tvb, msg_offset+16, 16, ENC_ASCII);
   proto_tree_add_item(zrtp_tree, hf_zrtp_msg_hash_image, tvb, msg_offset+32, 32, ENC_NA);
   proto_tree_add_item(zrtp_tree, hf_zrtp_msg_zid,        tvb, msg_offset+64, 12, ENC_NA);
   proto_tree_add_item(zrtp_tree, hf_zrtp_msg_sigcap,     tvb, data_offset+0,  1, ENC_BIG_ENDIAN);
@@ -1134,7 +1134,7 @@ proto_reg_handoff_zrtp(void)
 }
 
 /*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
+ * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
  * Local Variables:
  * c-basic-offset: 2
