@@ -47,9 +47,9 @@
 #define ZVT_APDU_MIN_LEN 3
 
 
-static GHashTable *apdu_table = NULL, *bitmap_table = NULL, *tlv_table = NULL;
+static GHashTable *apdu_table = NULL, *bitmap_table = NULL, *tlv_table;
 
-static wmem_tree_t *transactions = NULL;
+static wmem_tree_t *transactions;
 
 typedef struct _zvt_transaction_t {
     guint32 rqst_frame;
@@ -224,64 +224,66 @@ static const bitmap_info_t bitmap_info[] = {
 void proto_register_zvt(void);
 void proto_reg_handoff_zvt(void);
 
-static int proto_zvt = -1;
+static dissector_handle_t zvt_tcp_handle;
 
-static int ett_zvt = -1;
-static int ett_zvt_apdu = -1;
-static int ett_zvt_bitmap = -1;
-static int ett_zvt_tlv_dat_obj = -1;
-static int ett_zvt_tlv_subseq = -1;
-static int ett_zvt_tlv_tag = -1;
-static int ett_zvt_tlv_receipt = -1;
+static int proto_zvt;
 
-static int hf_zvt_resp_in = -1;
-static int hf_zvt_resp_to = -1;
-static int hf_zvt_serial_char = -1;
-static int hf_zvt_crc = -1;
-static int hf_zvt_ctrl = -1;
-static int hf_zvt_ccrc = -1;
-static int hf_zvt_aprc = -1;
-static int hf_zvt_len = -1;
-static int hf_zvt_data = -1;
-static int hf_zvt_int_status = -1;
-static int hf_zvt_pwd = -1;
-static int hf_zvt_reg_cfg = -1;
-static int hf_zvt_res_code = -1;
-static int hf_zvt_cc = -1;
-static int hf_zvt_amount = -1;
-static int hf_zvt_terminal_id = -1;
-static int hf_zvt_time = -1;
-static int hf_zvt_date = -1;
-static int hf_zvt_card_type = -1;
-static int hf_zvt_bmp = -1;
-static int hf_zvt_tlv_total_len = -1;
-static int hf_zvt_tlv_tag = -1;
-static int hf_zvt_tlv_tag_class = -1;
-static int hf_zvt_tlv_tag_type = -1;
-static int hf_zvt_tlv_len = -1;
-static int hf_zvt_text_lines_line = -1;
-static int hf_zvt_permitted_cmd = -1;
-static int hf_zvt_receipt_type = -1;
-static int hf_zvt_receipt_parameter_positive_customer = -1;
-static int hf_zvt_receipt_parameter_negative_customer = -1;
-static int hf_zvt_receipt_parameter_positive_merchant = -1;
-static int hf_zvt_receipt_parameter_negative_merchant = -1;
-static int hf_zvt_receipt_parameter_customer_before_merchant = -1;
-static int hf_zvt_receipt_parameter_print_short_receipt = -1;
-static int hf_zvt_receipt_parameter_no_product_data = -1;
-static int hf_zvt_receipt_parameter_ecr_as_printer = -1;
-static int hf_zvt_receipt_parameter = -1;
-static int hf_zvt_trace_number = -1;
-static int hf_zvt_expiry_date = -1;
-static int hf_zvt_card_number = -1;
-static int hf_zvt_card_name = -1;
-static int hf_zvt_additional_data = -1;
-static int hf_zvt_characters_per_line = -1;
-static int hf_zvt_receipt_info = -1;
-static int hf_zvt_receipt_info_positive = -1;
-static int hf_zvt_receipt_info_signature = -1;
-static int hf_zvt_receipt_info_negative = -1;
-static int hf_zvt_receipt_info_printing = -1;
+static int ett_zvt;
+static int ett_zvt_apdu;
+static int ett_zvt_bitmap;
+static int ett_zvt_tlv_dat_obj;
+static int ett_zvt_tlv_subseq;
+static int ett_zvt_tlv_tag;
+static int ett_zvt_tlv_receipt;
+
+static int hf_zvt_resp_in;
+static int hf_zvt_resp_to;
+static int hf_zvt_serial_char;
+static int hf_zvt_crc;
+static int hf_zvt_ctrl;
+static int hf_zvt_ccrc;
+static int hf_zvt_aprc;
+static int hf_zvt_len;
+static int hf_zvt_data;
+static int hf_zvt_int_status;
+static int hf_zvt_pwd;
+static int hf_zvt_reg_cfg;
+static int hf_zvt_res_code;
+static int hf_zvt_cc;
+static int hf_zvt_amount;
+static int hf_zvt_terminal_id;
+static int hf_zvt_time;
+static int hf_zvt_date;
+static int hf_zvt_card_type;
+static int hf_zvt_bmp;
+static int hf_zvt_tlv_total_len;
+static int hf_zvt_tlv_tag;
+static int hf_zvt_tlv_tag_class;
+static int hf_zvt_tlv_tag_type;
+static int hf_zvt_tlv_len;
+static int hf_zvt_text_lines_line;
+static int hf_zvt_permitted_cmd;
+static int hf_zvt_receipt_type;
+static int hf_zvt_receipt_parameter_positive_customer;
+static int hf_zvt_receipt_parameter_negative_customer;
+static int hf_zvt_receipt_parameter_positive_merchant;
+static int hf_zvt_receipt_parameter_negative_merchant;
+static int hf_zvt_receipt_parameter_customer_before_merchant;
+static int hf_zvt_receipt_parameter_print_short_receipt;
+static int hf_zvt_receipt_parameter_no_product_data;
+static int hf_zvt_receipt_parameter_ecr_as_printer;
+static int hf_zvt_receipt_parameter;
+static int hf_zvt_trace_number;
+static int hf_zvt_expiry_date;
+static int hf_zvt_card_number;
+static int hf_zvt_card_name;
+static int hf_zvt_additional_data;
+static int hf_zvt_characters_per_line;
+static int hf_zvt_receipt_info;
+static int hf_zvt_receipt_info_positive;
+static int hf_zvt_receipt_info_signature;
+static int hf_zvt_receipt_info_negative;
+static int hf_zvt_receipt_info_printing;
 
 static int * const receipt_parameter_flag_fields[] = {
     &hf_zvt_receipt_parameter_positive_customer,
@@ -303,7 +305,7 @@ static int * const receipt_info_fields[] = {
     NULL
 };
 
-static expert_field ei_invalid_apdu_len = EI_INIT;
+static expert_field ei_invalid_apdu_len;
 
 static const value_string serial_char[] = {
     { STX, "Start of text (STX)" },
@@ -556,10 +558,10 @@ static inline gint dissect_zvt_tlv_receipt_param(
 
 static inline gint dissect_zvt_tlv_characters_per_line(
         tvbuff_t *tvb, gint offset, gint len,
-        packet_info *pinfo, proto_tree *tree, tlv_seq_info_t *seq_info _U_)
+        packet_info *pinfo _U_, proto_tree *tree, tlv_seq_info_t *seq_info _U_)
 {
-    const gchar *str = tvb_bcd_dig_to_str_be(pinfo->pool, tvb, offset, 1, NULL, FALSE);
-    proto_tree_add_string(tree, hf_zvt_characters_per_line, tvb, offset, 1, str);
+    proto_tree_add_item(tree, hf_zvt_characters_per_line, tvb, offset, 1,
+            ENC_BCD_DIGITS_0_9 | ENC_BIG_ENDIAN);
     return len;
 }
 
@@ -763,10 +765,10 @@ static inline gint dissect_zvt_card_type(
 
 
 static inline gint dissect_zvt_terminal_id(
-        tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *tree)
+        tvbuff_t *tvb, gint offset, packet_info *pinfo _U_, proto_tree *tree)
 {
-    const gchar *str = tvb_bcd_dig_to_str_be(pinfo->pool, tvb, offset, 4, NULL, FALSE);
-    proto_tree_add_string(tree, hf_zvt_terminal_id, tvb, offset, 4, str);
+    proto_tree_add_item(tree, hf_zvt_terminal_id, tvb, offset, 4,
+            ENC_BCD_DIGITS_0_9 | ENC_BIG_ENDIAN);
     return 4;
 }
 
@@ -832,22 +834,23 @@ static inline gint dissect_zvt_expiry_date(
 
 
 static inline gint dissect_zvt_trace_number(
-        tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *tree)
+        tvbuff_t *tvb, gint offset, packet_info *pinfo _U_, proto_tree *tree)
 {
-    const gchar *str = tvb_bcd_dig_to_str_be(pinfo->pool, tvb, offset, 3, NULL, FALSE);
-    proto_tree_add_string(tree, hf_zvt_trace_number, tvb, offset, 3, str);
+    proto_tree_add_item(tree, hf_zvt_trace_number, tvb, offset, 3,
+            ENC_BCD_DIGITS_0_9 | ENC_BIG_ENDIAN);
     return 3;
 }
 
 
 static inline gint dissect_zvt_card_number(
-        tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *tree)
+        tvbuff_t *tvb, gint offset, packet_info *pinfo _U_, proto_tree *tree)
 {
     guint8 tens = tvb_get_guint8(tvb, offset) & 0x0f;
     guint8 ones = tvb_get_guint8(tvb, offset + 1) & 0x0f;
     guint8 length = tens * 10 + ones;
-    const gchar *str = tvb_bcd_dig_to_str_be(pinfo->pool, tvb, offset + 2, length, NULL, FALSE);
-    proto_tree_add_string(tree, hf_zvt_card_number, tvb, offset + 2, length, str);
+
+    proto_tree_add_item(tree, hf_zvt_card_number, tvb, offset + 2, length,
+            ENC_BCD_DIGITS_0_9 | ENC_BIG_ENDIAN);
     return 2 + length;
 }
 
@@ -1208,16 +1211,16 @@ dissect_zvt_serial(tvbuff_t *tvb, gint offset, packet_info *pinfo, proto_tree *t
 }
 
 
-static gboolean
+static bool
 valid_ctrl_field(tvbuff_t *tvb, gint offset)
 {
     if (tvb_get_guint8(tvb, offset) == 0x80 ||
         tvb_get_guint8(tvb, offset) == 0x84 ||
         try_val_to_str_ext(tvb_get_ntohs(tvb, offset), &ctrl_field_ext)) {
-            return TRUE;
+            return true;
     }
 
-    return FALSE;
+    return false;
 }
 
 
@@ -1227,21 +1230,21 @@ dissect_zvt(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void *data _U_)
     gint        zvt_len = 0;
     proto_item *zvt_ti;
     proto_tree *zvt_tree;
-    gboolean    is_serial; /* serial or TCP/IP protocol? */
+    bool        is_serial; /* serial or TCP/IP protocol? */
 
     if (tvb_captured_length(tvb) == 1 &&
             (tvb_get_guint8(tvb, 0) == ACK ||
              tvb_get_guint8(tvb, 0) == NAK)) {
-        is_serial = TRUE;
+        is_serial = true;
     }
     else if (tvb_captured_length(tvb) >= 2 &&
             tvb_get_guint8(tvb, 0) == DLE &&
             tvb_get_guint8(tvb, 1) == STX) {
-        is_serial = TRUE;
+        is_serial = true;
     }
     else if (tvb_captured_length(tvb) >= ZVT_APDU_MIN_LEN &&
             valid_ctrl_field(tvb, 0)) {
-        is_serial = FALSE;
+        is_serial = false;
     }
     else
         return 0;
@@ -1408,10 +1411,10 @@ proto_register_zvt(void)
             { "Negative customer receipt", "zvt.tlv.receipt_parameter.negative_customer", FT_BOOLEAN,
                 8, TFS(&tfs_required_not_required), 0x40, NULL, HFILL } },
         { &hf_zvt_receipt_parameter_positive_merchant,
-            { "Positive merchant receipt", "zvt.tlv.receipt_parameter.positive_customer", FT_BOOLEAN,
+            { "Positive merchant receipt", "zvt.tlv.receipt_parameter.positive_merchant", FT_BOOLEAN,
                 8, TFS(&tfs_required_not_required), 0x20, NULL, HFILL } },
         { &hf_zvt_receipt_parameter_negative_merchant,
-            { "Negative merchant receipt", "zvt.tlv.receipt_parameter.negative_customer", FT_BOOLEAN,
+            { "Negative merchant receipt", "zvt.tlv.receipt_parameter.negative_merchant", FT_BOOLEAN,
                 8, TFS(&tfs_required_not_required), 0x10, NULL, HFILL } },
         { &hf_zvt_receipt_parameter_customer_before_merchant,
             { "Customer receipt should be sent before the merchant receipt", "zvt.tlv.receipt_parameter.customer_first", FT_BOOLEAN,
@@ -1505,6 +1508,7 @@ proto_register_zvt(void)
 
     /* register by name to allow mapping to a user DLT */
     register_dissector("zvt", dissect_zvt, proto_zvt);
+    zvt_tcp_handle = register_dissector("zvt.tcp", dissect_zvt_tcp, proto_zvt);
 
     register_shutdown_routine(zvt_shutdown);
 }
@@ -1513,10 +1517,6 @@ proto_register_zvt(void)
 void
 proto_reg_handoff_zvt(void)
 {
-    dissector_handle_t  zvt_tcp_handle;
-
-    zvt_tcp_handle = create_dissector_handle(dissect_zvt_tcp, proto_zvt);
-
     dissector_add_for_decode_as_with_preference("tcp.port", zvt_tcp_handle);
 }
 
