@@ -27,6 +27,7 @@
 #include "epan/frame_data.h"
 
 #include "dfilter/dfilter.h"
+#include "dfilter/dfilter-translator.h"
 #include "epan_dissect.h"
 
 #include <wsutil/nstime.h>
@@ -106,26 +107,26 @@
 #include <signal.h>
 #endif
 
-static GSList *epan_plugin_register_all_procotols = NULL;
-static GSList *epan_plugin_register_all_handoffs = NULL;
+static GSList *epan_plugin_register_all_procotols;
+static GSList *epan_plugin_register_all_handoffs;
 
-static wmem_allocator_t *pinfo_pool_cache = NULL;
+static wmem_allocator_t *pinfo_pool_cache;
 
 /* Global variables holding the content of the corresponding environment variable
  * to save fetching it repeatedly.
  */
-gboolean wireshark_abort_on_dissector_bug = FALSE;
-gboolean wireshark_abort_on_too_many_items = FALSE;
+bool wireshark_abort_on_dissector_bug;
+bool wireshark_abort_on_too_many_items;
 
 #ifdef HAVE_PLUGINS
 /* Used for bookkeeping, includes all libwireshark plugin types (dissector, tap, epan). */
-static plugins_t *libwireshark_plugins = NULL;
+static plugins_t *libwireshark_plugins;
 #endif
 
 /* "epan_plugins" are a specific type of libwireshark plugin (the name isn't the best for clarity). */
-static GSList *epan_plugins = NULL;
+static GSList *epan_plugins;
 
-const gchar*
+const char*
 epan_get_version(void) {
 	return VERSION;
 }
@@ -175,31 +176,31 @@ quiet_gcrypt_logger (void *dummy _U_, int level, const char *format, va_list arg
 #endif // _WIN32
 
 static void
-epan_plugin_init(gpointer data, gpointer user_data _U_)
+epan_plugin_init(void *data, void *user_data _U_)
 {
 	((epan_plugin *)data)->init();
 }
 
 static void
-epan_plugin_post_init(gpointer data, gpointer user_data _U_)
+epan_plugin_post_init(void *data, void *user_data _U_)
 {
 	((epan_plugin *)data)->post_init();
 }
 
 static void
-epan_plugin_dissect_init(gpointer data, gpointer user_data)
+epan_plugin_dissect_init(void *data, void *user_data)
 {
 	((epan_plugin *)data)->dissect_init((epan_dissect_t *)user_data);
 }
 
 static void
-epan_plugin_dissect_cleanup(gpointer data, gpointer user_data)
+epan_plugin_dissect_cleanup(void *data, void *user_data)
 {
 	((epan_plugin *)data)->dissect_cleanup((epan_dissect_t *)user_data);
 }
 
 static void
-epan_plugin_cleanup(gpointer data, gpointer user_data _U_)
+epan_plugin_cleanup(void *data, void *user_data _U_)
 {
 	((epan_plugin *)data)->cleanup();
 }
@@ -229,32 +230,32 @@ int epan_plugins_supported(void)
 #endif
 }
 
-static void epan_plugin_register_all_tap_listeners(gpointer data, gpointer user_data _U_)
+static void epan_plugin_register_all_tap_listeners(void *data, void *user_data _U_)
 {
 	epan_plugin *plug = (epan_plugin *)data;
 	if (plug->register_all_tap_listeners)
 		plug->register_all_tap_listeners();
 }
 
-gboolean
-epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
+bool
+epan_init(register_cb cb, void *client_data, bool load_plugins)
 {
-	volatile gboolean status = TRUE;
+	volatile bool status = true;
 
 	/* Get the value of some environment variables and set corresponding globals for performance reasons*/
 	/* If the WIRESHARK_ABORT_ON_DISSECTOR_BUG environment variable is set,
 	 * it will call abort(), instead, to make it easier to get a stack trace.
 	*/
 	if (getenv("WIRESHARK_ABORT_ON_DISSECTOR_BUG") != NULL) {
-		wireshark_abort_on_dissector_bug = TRUE;
+		wireshark_abort_on_dissector_bug = true;
 	} else {
-		wireshark_abort_on_dissector_bug = FALSE;
+		wireshark_abort_on_dissector_bug = false;
 	}
 
 	if (getenv("WIRESHARK_ABORT_ON_TOO_MANY_ITEMS") != NULL) {
-		wireshark_abort_on_too_many_items = TRUE;
+		wireshark_abort_on_too_many_items = true;
 	} else {
-		wireshark_abort_on_too_many_items = FALSE;
+		wireshark_abort_on_too_many_items = false;
 	}
 
 	/*
@@ -275,6 +276,8 @@ epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
 
 	except_init();
 
+	dfilter_translator_init();
+
 	if (load_plugins) {
 #ifdef HAVE_PLUGINS
 		libwireshark_plugins = plugins_init(WS_PLUGIN_EPAN);
@@ -356,7 +359,7 @@ epan_init(register_cb cb, gpointer client_data, gboolean load_plugins)
 				 dissector_error_nomsg : exception_message);
 		if (getenv("WIRESHARK_ABORT_ON_DISSECTOR_BUG") != NULL)
 			abort();
-		status = FALSE;
+		status = false;
 	}
 	ENDTRY;
 	return status;
@@ -444,6 +447,8 @@ epan_cleanup(void)
 	except_deinit();
 	addr_resolv_cleanup();
 
+	dfilter_translator_cleanup();
+
 	if (pinfo_pool_cache != NULL) {
 		wmem_destroy_allocator(pinfo_pool_cache);
 		pinfo_pool_cache = NULL;
@@ -487,25 +492,25 @@ epan_get_modified_block(const epan_t *session, const frame_data *fd)
 }
 
 const char *
-epan_get_interface_name(const epan_t *session, guint32 interface_id)
+epan_get_interface_name(const epan_t *session, uint32_t interface_id, unsigned section_number)
 {
 	if (session->funcs.get_interface_name)
-		return session->funcs.get_interface_name(session->prov, interface_id);
+		return session->funcs.get_interface_name(session->prov, interface_id, section_number);
 
 	return NULL;
 }
 
 const char *
-epan_get_interface_description(const epan_t *session, guint32 interface_id)
+epan_get_interface_description(const epan_t *session, uint32_t interface_id, unsigned section_number)
 {
 	if (session->funcs.get_interface_description)
-		return session->funcs.get_interface_description(session->prov, interface_id);
+		return session->funcs.get_interface_description(session->prov, interface_id, section_number);
 
 	return NULL;
 }
 
 const nstime_t *
-epan_get_frame_ts(const epan_t *session, guint32 frame_num)
+epan_get_frame_ts(const epan_t *session, uint32_t frame_num)
 {
 	const nstime_t *abs_ts = NULL;
 
@@ -541,10 +546,10 @@ epan_conversation_init(void)
  * This is > 0 if a Lua script wanted to see all fields all the time.
  * This is ref-counted, so clearing it won't override other taps/scripts wanting it.
  */
-static gint always_visible_refcount = 0;
+static int always_visible_refcount;
 
 void
-epan_set_always_visible(gboolean force)
+epan_set_always_visible(bool force)
 {
 	if (force)
 		always_visible_refcount++;
@@ -553,7 +558,7 @@ epan_set_always_visible(gboolean force)
 }
 
 void
-epan_dissect_init(epan_dissect_t *edt, epan_t *session, const gboolean create_proto_tree, const gboolean proto_tree_visible)
+epan_dissect_init(epan_dissect_t *edt, epan_t *session, const bool create_proto_tree, const bool proto_tree_visible)
 {
 	ws_assert(edt);
 
@@ -570,7 +575,7 @@ epan_dissect_init(epan_dissect_t *edt, epan_t *session, const gboolean create_pr
 
 	if (create_proto_tree) {
 		edt->tree = proto_tree_create_root(&edt->pi);
-		proto_tree_set_visible(edt->tree, (always_visible_refcount > 0) ? TRUE : proto_tree_visible);
+		proto_tree_set_visible(edt->tree, (always_visible_refcount > 0) ? true : proto_tree_visible);
 	}
 	else {
 		edt->tree = NULL;
@@ -613,7 +618,7 @@ epan_dissect_reset(epan_dissect_t *edt)
 }
 
 epan_dissect_t*
-epan_dissect_new(epan_t *session, const gboolean create_proto_tree, const gboolean proto_tree_visible)
+epan_dissect_new(epan_t *session, const bool create_proto_tree, const bool proto_tree_visible)
 {
 	epan_dissect_t *edt;
 
@@ -624,7 +629,7 @@ epan_dissect_new(epan_t *session, const gboolean create_proto_tree, const gboole
 }
 
 void
-epan_dissect_fake_protocols(epan_dissect_t *edt, const gboolean fake_protocols)
+epan_dissect_fake_protocols(epan_dissect_t *edt, const bool fake_protocols)
 {
 	if (edt)
 		proto_tree_set_fake_protocols(edt->tree, fake_protocols);
@@ -746,7 +751,7 @@ epan_dissect_prime_with_hfid(epan_dissect_t *edt, int hfid)
 void
 epan_dissect_prime_with_hfid_array(epan_dissect_t *edt, GArray *hfids)
 {
-	guint i;
+	unsigned i;
 
 	for (i = 0; i < hfids->len; i++) {
 		proto_tree_prime_with_hfid(edt->tree,
@@ -755,38 +760,38 @@ epan_dissect_prime_with_hfid_array(epan_dissect_t *edt, GArray *hfids)
 }
 
 /* ----------------------- */
-const gchar *
+const char *
 epan_custom_set(epan_dissect_t *edt, GSList *field_ids,
-			     gint occurrence,
-			     gchar *result,
-			     gchar *expr, const int size )
+			     int occurrence,
+			     char *result,
+			     char *expr, const int size )
 {
 	return proto_custom_set(edt->tree, field_ids, occurrence, result, expr, size);
 }
 
 void
-epan_dissect_fill_in_columns(epan_dissect_t *edt, const gboolean fill_col_exprs, const gboolean fill_fd_colums)
+epan_dissect_fill_in_columns(epan_dissect_t *edt, const bool fill_col_exprs, const bool fill_fd_colums)
 {
 	col_custom_set_edt(edt, edt->pi.cinfo);
 	col_fill_in(&edt->pi, fill_col_exprs, fill_fd_colums);
 }
 
-gboolean
+bool
 epan_dissect_packet_contains_field(epan_dissect_t* edt,
 				   const char *field_name)
 {
 	GPtrArray* array;
 	int field_id;
-	gboolean contains_field;
+	bool contains_field;
 
 	if (!edt || !edt->tree)
-		return FALSE;
+		return false;
 	field_id = proto_get_id_by_filter_name(field_name);
 	if (field_id < 0)
-		return FALSE;
+		return false;
 	array = proto_find_finfo(edt->tree, field_id);
-	contains_field = (array->len > 0) ? TRUE : FALSE;
-	g_ptr_array_free(array, TRUE);
+	contains_field = (array->len > 0) ? true : false;
+	g_ptr_array_free(array, true);
 	return contains_field;
 }
 
@@ -797,6 +802,7 @@ void
 epan_gather_compile_info(feature_list l)
 {
 	gather_zlib_compile_info(l);
+	gather_zlib_ng_compile_info(l);
 	gather_pcre2_compile_info(l);
 
 	/* Lua */
