@@ -58,24 +58,24 @@ bytes_fvalue_get(fvalue_t *fv)
 static char *
 oid_to_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype _U_, int field_display _U_)
 {
-	return oid_encoded2string(scope, g_bytes_get_data(fv->value.bytes, NULL), (guint)g_bytes_get_size(fv->value.bytes));
+	return oid_encoded2string(scope, g_bytes_get_data(fv->value.bytes, NULL), (unsigned)g_bytes_get_size(fv->value.bytes));
 }
 
 static char *
 rel_oid_to_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype _U_, int field_display _U_)
 {
-	return rel_oid_encoded2string(scope,  g_bytes_get_data(fv->value.bytes, NULL), (guint)g_bytes_get_size(fv->value.bytes));
+	return rel_oid_encoded2string(scope,  g_bytes_get_data(fv->value.bytes, NULL), (unsigned)g_bytes_get_size(fv->value.bytes));
 }
 
 static char *
 system_id_to_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype _U_, int field_display _U_)
 {
-	return print_system_id(scope,  g_bytes_get_data(fv->value.bytes, NULL), (guint)g_bytes_get_size(fv->value.bytes));
+	return print_system_id(scope,  g_bytes_get_data(fv->value.bytes, NULL), (unsigned)g_bytes_get_size(fv->value.bytes));
 }
 
 char *
 bytes_to_dfilter_repr(wmem_allocator_t *scope,
-			const guint8 *src, size_t src_size)
+			const uint8_t *src, size_t src_size)
 {
 	char *buf;
 	size_t max_char_size;
@@ -97,7 +97,7 @@ bytes_to_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype, int f
 {
 	char separator;
 	const uint8_t *bytes;
-	gsize bytes_size;
+	size_t bytes_size;
 
 	bytes = g_bytes_get_data(fv->value.bytes, &bytes_size);
 
@@ -132,8 +132,8 @@ bytes_to_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype, int f
 	return wmem_strdup(scope, "");
 }
 
-static gboolean
-bytes_from_string(fvalue_t *fv, const char *s, size_t len, gchar **err_msg _U_)
+static bool
+bytes_from_string(fvalue_t *fv, const char *s, size_t len, char **err_msg _U_)
 {
 	GByteArray	*bytes;
 
@@ -142,20 +142,20 @@ bytes_from_string(fvalue_t *fv, const char *s, size_t len, gchar **err_msg _U_)
 	if (len == 0)
 		len = strlen(s);
 
-	g_byte_array_append(bytes, (const guint8 *)s, (guint)len);
+	g_byte_array_append(bytes, (const uint8_t *)s, (unsigned)len);
 
 	/* Free up the old value, if we have one */
 	bytes_fvalue_free(fv);
 	fv->value.bytes = g_byte_array_free_to_bytes(bytes);
 
-	return TRUE;
+	return true;
 }
 
 GByteArray *
-byte_array_from_literal(const char *s, gchar **err_msg)
+byte_array_from_literal(const char *s, char **err_msg)
 {
 	GByteArray	*bytes;
-	gboolean	res;
+	bool	res;
 
 	/* Skip leading colon if any. */
 	if (*s == ':')
@@ -182,43 +182,43 @@ byte_array_from_literal(const char *s, gchar **err_msg)
 		char *endptr;
 		long number = strtol(s + 2, &endptr, 2);
 		if (errno == 0 && *endptr == '\0' && number >= 0x0 && number <= 0xff) {
-			guint8 byte = (guint8)number;
+			uint8_t byte = (uint8_t)number;
 			g_byte_array_append(bytes, &byte, 1);
 			return bytes;
 		}
 	}
 
-	res = hex_str_to_bytes(s, bytes, FALSE);
+	res = hex_str_to_bytes(s, bytes, false);
 
 	if (!res) {
 		if (err_msg != NULL)
 			*err_msg = ws_strdup_printf("\"%s\" is not a valid byte string.", s);
-		g_byte_array_free(bytes, TRUE);
+		g_byte_array_free(bytes, true);
 		return NULL;
 	}
 
 	return bytes;
 }
 
-static gboolean
-bytes_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
+static bool
+bytes_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value _U_, char **err_msg)
 {
 	GByteArray	*bytes;
 
 	bytes = byte_array_from_literal(s, err_msg);
 	if (bytes == NULL)
-		return FALSE;
+		return false;
 
 	/* Free up the old value, if we have one */
 	bytes_fvalue_free(fv);
 
 	fv->value.bytes = g_byte_array_free_to_bytes(bytes);
 
-	return TRUE;
+	return true;
 }
 
 GByteArray *
-byte_array_from_charconst(unsigned long num, gchar **err_msg)
+byte_array_from_charconst(unsigned long num, char **err_msg)
 {
 	if (num > UINT8_MAX) {
 		if (err_msg) {
@@ -233,159 +233,121 @@ byte_array_from_charconst(unsigned long num, gchar **err_msg)
 	return bytes;
 }
 
-static gboolean
-bytes_from_charconst(fvalue_t *fv, unsigned long num, gchar **err_msg)
+static bool
+bytes_from_charconst(fvalue_t *fv, unsigned long num, char **err_msg)
 {
 	GByteArray	*bytes;
 
 	bytes = byte_array_from_charconst(num, err_msg);
 	if (bytes == NULL)
-		return FALSE;
+		return false;
 
 	/* Free up the old value, if we have one */
 	bytes_fvalue_free(fv);
 
 	fv->value.bytes = g_byte_array_free_to_bytes(bytes);
 
-	return TRUE;
+	return true;
 }
 
-static gboolean
-ax25_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value, gchar **err_msg)
+static bool
+bytes_from_uinteger64(fvalue_t *fv, const char *s _U_, uint64_t num, char **err_msg)
 {
-	/*
-	 * Don't request an error message if bytes_from_literal fails;
-	 * if it does, we'll report an error specific to this address
-	 * type.
-	 */
-	if (bytes_from_literal(fv, s, TRUE, NULL)) {
-		if (g_bytes_get_size(fv->value.bytes) > FT_AX25_ADDR_LEN) {
-			if (err_msg != NULL) {
-				*err_msg = ws_strdup_printf("\"%s\" contains too many bytes to be a valid AX.25 address.",
-				    s);
-			}
-			return FALSE;
+	if (num > UINT8_MAX) {
+		if (err_msg) {
+			*err_msg = ws_strdup_printf("%s is too large for a byte value", s);
 		}
-		else if (g_bytes_get_size(fv->value.bytes) < FT_AX25_ADDR_LEN && !allow_partial_value) {
-			if (err_msg != NULL) {
-				*err_msg = ws_strdup_printf("\"%s\" contains too few bytes to be a valid AX.25 address.",
-				    s);
-			}
-			return FALSE;
-		}
-
-		return TRUE;
+		return false;
 	}
 
-	/*
-	 * XXX - what needs to be done here is something such as:
-	 *
-	 * Look for a "-" in the string.
-	 *
-	 * If we find it, make sure that there are 1-6 alphanumeric
-	 * ASCII characters before it, and that there are 2 decimal
-	 * digits after it, from 00 to 15; if we don't find it, make
-	 * sure that there are 1-6 alphanumeric ASCII characters
-	 * in the string.
-	 *
-	 * If so, make the first 6 octets of the address the ASCII
-	 * characters, with lower-case letters mapped to upper-case
-	 * letters, shifted left by 1 bit, padded to 6 octets with
-	 * spaces, also shifted left by 1 bit, and, if we found a
-	 * "-", convert what's after it to a number and make the 7th
-	 * octet the number, shifted left by 1 bit, otherwise make the
-	 * 7th octet zero.
-	 *
-	 * We should also change all the comparison functions for
-	 * AX.25 addresses check the upper 7 bits of all but the last
-	 * octet of the address, ignoring the "end of address" bit,
-	 * and compare only the 4 bits above the low-order bit for
-	 * the last octet, ignoring the "end of address" bit and
-	 * various reserved bits and bits used for other purposes.
-	 *
-	 * See section 3.12 "Address-Field Encoding" of the AX.25
-	 * spec and
-	 *
-	 *	http://www.itu.int/ITU-R/terrestrial/docs/fixedmobile/fxm-art19-sec3.pdf
-	 */
-	if (err_msg != NULL)
-		*err_msg = ws_strdup_printf("\"%s\" is not a valid AX.25 address.", s);
-	return FALSE;
+	return bytes_from_charconst(fv, (unsigned long)num, err_msg);
 }
 
-static gboolean
-vines_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value, gchar **err_msg)
+static bool
+bytes_from_sinteger64(fvalue_t *fv, const char *s, int64_t num, char **err_msg)
+{
+	if (num < 0) {
+		if (err_msg) {
+			*err_msg = ws_strdup_printf("Byte values cannot be negative");
+		}
+		return false;
+	}
+	return bytes_from_uinteger64(fv, s, (uint64_t)num, err_msg);
+}
+
+static bool
+vines_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value, char **err_msg)
 {
 	/*
 	 * Don't request an error message if bytes_from_literal fails;
 	 * if it does, we'll report an error specific to this address
 	 * type.
 	 */
-	if (bytes_from_literal(fv, s, TRUE, NULL)) {
+	if (bytes_from_literal(fv, s, true, NULL)) {
 		if (g_bytes_get_size(fv->value.bytes) > FT_VINES_ADDR_LEN) {
 			if (err_msg != NULL) {
 				*err_msg = ws_strdup_printf("\"%s\" contains too many bytes to be a valid Vines address.",
 				    s);
 			}
-			return FALSE;
+			return false;
 		}
 		else if (g_bytes_get_size(fv->value.bytes) < FT_VINES_ADDR_LEN && !allow_partial_value) {
 			if (err_msg != NULL) {
 				*err_msg = ws_strdup_printf("\"%s\" contains too few bytes to be a valid Vines address.",
 				    s);
 			}
-			return FALSE;
+			return false;
 		}
 
-		return TRUE;
+		return true;
 	}
 
 	/* XXX - need better validation of Vines address */
 
 	if (err_msg != NULL)
 		*err_msg = ws_strdup_printf("\"%s\" is not a valid Vines address.", s);
-	return FALSE;
+	return false;
 }
 
-static gboolean
-ether_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value, gchar **err_msg)
+static bool
+ether_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value, char **err_msg)
 {
 	/*
 	 * Don't request an error message if bytes_from_literal fails;
 	 * if it does, we'll report an error specific to this address
 	 * type.
 	 */
-	if (bytes_from_literal(fv, s, TRUE, NULL)) {
+	if (bytes_from_literal(fv, s, true, NULL)) {
 		if (g_bytes_get_size(fv->value.bytes) > FT_ETHER_LEN) {
 			if (err_msg != NULL) {
 				*err_msg = ws_strdup_printf("\"%s\" contains too many bytes to be a valid Ethernet address.",
 				    s);
 			}
-			return FALSE;
+			return false;
 		}
 		else if (g_bytes_get_size(fv->value.bytes) < FT_ETHER_LEN && !allow_partial_value) {
 			if (err_msg != NULL) {
 				*err_msg = ws_strdup_printf("\"%s\" contains too few bytes to be a valid Ethernet address.",
 				    s);
 			}
-			return FALSE;
+			return false;
 		}
 
-		return TRUE;
+		return true;
 	}
 
 	/* XXX - Try resolving as an Ethernet host name and parse that? */
 
 	if (err_msg != NULL)
 		*err_msg = ws_strdup_printf("\"%s\" is not a valid Ethernet address.", s);
-	return FALSE;
+	return false;
 }
 
-static gboolean
-oid_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
+static bool
+oid_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value _U_, char **err_msg)
 {
 	GByteArray	*bytes;
-	gboolean	res;
+	bool	res;
 
 
 #if 0
@@ -395,8 +357,8 @@ oid_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_,
 	 * we'll log a message.
 	 */
 	/* do not try it as '.' is handled as valid separator for hexbytes :( */
-	if (bytes_from_literal(fv, s, TRUE, NULL)) {
-		return TRUE;
+	if (bytes_from_literal(fv, s, true, NULL)) {
+		return true;
 	}
 #endif
 
@@ -405,103 +367,103 @@ oid_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_,
 	if (!res) {
 		if (err_msg != NULL)
 			*err_msg = ws_strdup_printf("\"%s\" is not a valid OBJECT IDENTIFIER.", s);
-		g_byte_array_free(bytes, TRUE);
-		return FALSE;
+		g_byte_array_free(bytes, true);
+		return false;
 	}
 
 	/* Free up the old value, if we have one */
 	bytes_fvalue_free(fv);
 	fv->value.bytes = g_byte_array_free_to_bytes(bytes);
 
-	return TRUE;
+	return true;
 }
 
-static gboolean
-rel_oid_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
+static bool
+rel_oid_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value _U_, char **err_msg)
 {
 	GByteArray	*bytes;
-	gboolean	res;
+	bool	res;
 
 	bytes = g_byte_array_new();
-	res = rel_oid_str_to_bytes(s, bytes, FALSE);
+	res = rel_oid_str_to_bytes(s, bytes, false);
 	if (!res) {
 		if (err_msg != NULL)
 			*err_msg = ws_strdup_printf("\"%s\" is not a valid RELATIVE-OID.", s);
-		g_byte_array_free(bytes, TRUE);
-		return FALSE;
+		g_byte_array_free(bytes, true);
+		return false;
 	}
 
 	/* Free up the old value, if we have one */
 	bytes_fvalue_free(fv);
 	fv->value.bytes = g_byte_array_free_to_bytes(bytes);
 
-	return TRUE;
+	return true;
 }
 
-static gboolean
-system_id_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
+static bool
+system_id_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value _U_, char **err_msg)
 {
 	/*
 	 * Don't request an error message if bytes_from_literal fails;
 	 * if it does, we'll report an error specific to this address
 	 * type.
 	 */
-	if (bytes_from_literal(fv, s, TRUE, NULL)) {
+	if (bytes_from_literal(fv, s, true, NULL)) {
 		if (g_bytes_get_size(fv->value.bytes) > MAX_SYSTEMID_LEN) {
 			if (err_msg != NULL) {
 				*err_msg = ws_strdup_printf("\"%s\" contains too many bytes to be a valid OSI System-ID.",
 				    s);
 			}
-			return FALSE;
+			return false;
 		}
 
-		return TRUE;
+		return true;
 	}
 
 	/* XXX - need better validation of OSI System-ID address */
 
 	if (err_msg != NULL)
 		*err_msg = ws_strdup_printf("\"%s\" is not a valid OSI System-ID.", s);
-	return FALSE;
+	return false;
 }
 
-static gboolean
-fcwwn_from_literal(fvalue_t *fv, const char *s, gboolean allow_partial_value _U_, gchar **err_msg)
+static bool
+fcwwn_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value _U_, char **err_msg)
 {
 	/*
 	 * Don't request an error message if bytes_from_literal fails;
 	 * if it does, we'll report an error specific to this address
 	 * type.
 	 */
-	if (bytes_from_literal(fv, s, TRUE, NULL)) {
+	if (bytes_from_literal(fv, s, true, NULL)) {
 		if (g_bytes_get_size(fv->value.bytes) > FT_FCWWN_LEN) {
 			if (err_msg != NULL) {
 				*err_msg = ws_strdup_printf("\"%s\" contains too many bytes to be a valid FCWWN.",
 				    s);
 			}
-			return FALSE;
+			return false;
 		}
 
-		return TRUE;
+		return true;
 	}
 
 	/* XXX - need better validation of FCWWN address */
 
 	if (err_msg != NULL)
 		*err_msg = ws_strdup_printf("\"%s\" is not a valid FCWWN.", s);
-	return FALSE;
+	return false;
 }
 
-static guint
+static unsigned
 len(fvalue_t *fv)
 {
-	return (guint)g_bytes_get_size(fv->value.bytes);
+	return (unsigned)g_bytes_get_size(fv->value.bytes);
 }
 
 static void
-slice(fvalue_t *fv, GByteArray *bytes, guint offset, guint length)
+slice(fvalue_t *fv, GByteArray *bytes, unsigned offset, unsigned length)
 {
-	const guint8 *data = (const guint8 *)g_bytes_get_data(fv->value.bytes, NULL) + offset;
+	const uint8_t *data = (const uint8_t *)g_bytes_get_data(fv->value.bytes, NULL) + offset;
 	g_byte_array_append(bytes, data, length);
 }
 
@@ -516,21 +478,21 @@ static enum ft_result
 bytes_bitwise_and(fvalue_t *fv_dst, const fvalue_t *fv_a, const fvalue_t *fv_b, char **err_ptr _U_)
 {
 	GByteArray	*dst;
-	const guint8 *p_a, *p_b;
-	gsize size_a, size_b;
+	const uint8_t *p_a, *p_b;
+	size_t size_a, size_b;
 
 	p_a = g_bytes_get_data(fv_a->value.bytes, &size_a);
 	p_b = g_bytes_get_data(fv_b->value.bytes, &size_b);
 
-	gsize len = MIN(size_a, size_b);
+	size_t len = MIN(size_a, size_b);
 	if (len == 0) {
 		fv_dst->value.bytes = g_bytes_new(NULL, 0);
 		return FT_OK;
 	}
 
-	dst = g_byte_array_sized_new((guint)len);
-	for (gsize i = 0; i < len; i++) {
-		guint8 byte = p_a[i] & p_b[i];
+	dst = g_byte_array_sized_new((unsigned)len);
+	for (size_t i = 0; i < len; i++) {
+		uint8_t byte = p_a[i] & p_b[i];
 		g_byte_array_append(dst, &byte, 1);
 	}
 	fv_dst->value.bytes = g_byte_array_free_to_bytes(dst);
@@ -538,29 +500,29 @@ bytes_bitwise_and(fvalue_t *fv_dst, const fvalue_t *fv_a, const fvalue_t *fv_b,
 }
 
 static enum ft_result
-cmp_contains(const fvalue_t *fv_a, const fvalue_t *fv_b, gboolean *contains)
+cmp_contains(const fvalue_t *fv_a, const fvalue_t *fv_b, bool *contains)
 {
 	const void *data_a, *data_b;
-	gsize size_a, size_b;
+	size_t size_a, size_b;
 
 	data_a = g_bytes_get_data(fv_a->value.bytes, &size_a);
 	data_b = g_bytes_get_data(fv_b->value.bytes, &size_b);
 
 	if (ws_memmem(data_a, size_a, data_b, size_b)) {
-		*contains = TRUE;
+		*contains = true;
 	}
 	else {
-		*contains = FALSE;
+		*contains = false;
 	}
 
 	return FT_OK;
 }
 
 static enum ft_result
-cmp_matches(const fvalue_t *fv, const ws_regex_t *regex, gboolean *matches)
+cmp_matches(const fvalue_t *fv, const ws_regex_t *regex, bool *matches)
 {
 	const void *data;
-	gsize data_size;
+	size_t data_size;
 
 	data = g_bytes_get_data(fv->value.bytes, &data_size);
 
@@ -568,39 +530,37 @@ cmp_matches(const fvalue_t *fv, const ws_regex_t *regex, gboolean *matches)
 	return FT_OK;
 }
 
-static guint
+static unsigned
 bytes_hash(const fvalue_t *fv)
 {
 	return g_bytes_hash(fv->value.bytes);
 }
 
-static gboolean
+static bool
 bytes_is_zero(const fvalue_t *fv)
 {
 	const uint8_t *data;
-	gsize data_size;
+	size_t data_size;
 
 	data = g_bytes_get_data(fv->value.bytes, &data_size);
 
 	if (data_size == 0)
-		return TRUE;
+		return true;
 
-	for (gsize i = 0; i < data_size; i++) {
+	for (size_t i = 0; i < data_size; i++) {
 		if (data[i] != 0) {
-			return FALSE;
+			return false;
 		}
 	}
-	return TRUE;
+	return true;
 }
 
 void
 ftype_register_bytes(void)
 {
 
-	static ftype_t bytes_type = {
+	static const ftype_t bytes_type = {
 		FT_BYTES,			/* ftype */
-		"FT_BYTES",			/* name */
-		"Byte sequence",		/* pretty_name */
 		0,				/* wire_size */
 		bytes_fvalue_new,		/* new_value */
 		bytes_fvalue_copy,		/* copy_value */
@@ -608,10 +568,14 @@ ftype_register_bytes(void)
 		bytes_from_literal,		/* val_from_literal */
 		bytes_from_string,		/* val_from_string */
 		bytes_from_charconst,		/* val_from_charconst */
+		bytes_from_uinteger64,		/* val_from_uinteger64 */
+		bytes_from_sinteger64,		/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		bytes_to_repr,			/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ .set_value_bytes = bytes_fvalue_set },	/* union set_value */
 		{ .get_value_bytes = bytes_fvalue_get },	/* union get_value */
@@ -634,10 +598,8 @@ ftype_register_bytes(void)
 		NULL,				/* modulo */
 	};
 
-	static ftype_t uint_bytes_type = {
+	static const ftype_t uint_bytes_type = {
 		FT_UINT_BYTES,		/* ftype */
-		"FT_UINT_BYTES",		/* name */
-		"Byte sequence",		/* pretty_name */
 		0,				/* wire_size */
 		bytes_fvalue_new,		/* new_value */
 		bytes_fvalue_copy,		/* copy_value */
@@ -645,10 +607,14 @@ ftype_register_bytes(void)
 		bytes_from_literal,		/* val_from_literal */
 		NULL,				/* val_from_string */
 		NULL,				/* val_from_charconst */
+		NULL,				/* val_from_uinteger64 */
+		NULL,				/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		bytes_to_repr,			/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ .set_value_bytes = bytes_fvalue_set },	/* union set_value */
 		{ .get_value_bytes = bytes_fvalue_get },	/* union get_value */
@@ -671,47 +637,8 @@ ftype_register_bytes(void)
 		NULL,				/* modulo */
 	};
 
-	static ftype_t ax25_type = {
-		FT_AX25,			/* ftype */
-		"FT_AX25",			/* name */
-		"AX.25 address",		/* pretty_name */
-		FT_AX25_ADDR_LEN,		/* wire_size */
-		bytes_fvalue_new,		/* new_value */
-		bytes_fvalue_copy,		/* copy_value */
-		bytes_fvalue_free,		/* free_value */
-		ax25_from_literal,		/* val_from_literal */
-		NULL,				/* val_from_string */
-		NULL,				/* val_from_charconst */
-		bytes_to_repr,			/* val_to_string_repr */
-
-		NULL,				/* val_to_uinteger64 */
-		NULL,				/* val_to_sinteger64 */
-
-		{ .set_value_bytes = bytes_fvalue_set },	/* union set_value */
-		{ .get_value_bytes = bytes_fvalue_get },	/* union get_value */
-
-		cmp_order,
-		cmp_contains,
-		cmp_matches,
-
-		bytes_hash,			/* hash */
-		bytes_is_zero,			/* is_zero */
-		NULL,				/* is_negative */
-		len,
-		(FvalueSlice)slice,
-		bytes_bitwise_and,		/* bitwise_and */
-		NULL,				/* unary_minus */
-		NULL,				/* add */
-		NULL,				/* subtract */
-		NULL,				/* multiply */
-		NULL,				/* divide */
-		NULL,				/* modulo */
-	};
-
-	static ftype_t vines_type = {
+	static const ftype_t vines_type = {
 		FT_VINES,			/* ftype */
-		"FT_VINES",			/* name */
-		"VINES address",		/* pretty_name */
 		FT_VINES_ADDR_LEN,		/* wire_size */
 		bytes_fvalue_new,		/* new_value */
 		bytes_fvalue_copy,		/* copy_value */
@@ -719,10 +646,14 @@ ftype_register_bytes(void)
 		vines_from_literal,		/* val_from_literal */
 		NULL,				/* val_from_string */
 		NULL,				/* val_from_charconst */
+		NULL,				/* val_from_uinteger64 */
+		NULL,				/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		bytes_to_repr,			/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ .set_value_bytes = bytes_fvalue_set },	/* union set_value */
 		{ .get_value_bytes = bytes_fvalue_get },	/* union get_value */
@@ -745,10 +676,8 @@ ftype_register_bytes(void)
 		NULL,				/* modulo */
 	};
 
-	static ftype_t ether_type = {
+	static const ftype_t ether_type = {
 		FT_ETHER,			/* ftype */
-		"FT_ETHER",			/* name */
-		"Ethernet or other MAC address",/* pretty_name */
 		FT_ETHER_LEN,			/* wire_size */
 		bytes_fvalue_new,		/* new_value */
 		bytes_fvalue_copy,		/* copy_value */
@@ -756,10 +685,14 @@ ftype_register_bytes(void)
 		ether_from_literal,		/* val_from_literal */
 		NULL,				/* val_from_string */
 		NULL,				/* val_from_charconst */
+		NULL,				/* val_from_uinteger64 */
+		NULL,				/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		bytes_to_repr,			/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ .set_value_bytes = bytes_fvalue_set },	/* union set_value */
 		{ .get_value_bytes = bytes_fvalue_get },	/* union get_value */
@@ -782,10 +715,8 @@ ftype_register_bytes(void)
 		NULL,				/* modulo */
 	};
 
-	static ftype_t oid_type = {
+	static const ftype_t oid_type = {
 		FT_OID,			/* ftype */
-		"FT_OID",			/* name */
-		"ASN.1 object identifier",	/* pretty_name */
 		0,			/* wire_size */
 		bytes_fvalue_new,		/* new_value */
 		bytes_fvalue_copy,		/* copy_value */
@@ -793,10 +724,14 @@ ftype_register_bytes(void)
 		oid_from_literal,		/* val_from_literal */
 		NULL,				/* val_from_string */
 		NULL,				/* val_from_charconst */
+		NULL,				/* val_from_uinteger64 */
+		NULL,				/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		oid_to_repr,			/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ .set_value_bytes = bytes_fvalue_set },	/* union set_value */
 		{ .get_value_bytes = bytes_fvalue_get },	/* union get_value */
@@ -819,10 +754,8 @@ ftype_register_bytes(void)
 		NULL,				/* modulo */
 	};
 
-	static ftype_t rel_oid_type = {
+	static const ftype_t rel_oid_type = {
 		FT_REL_OID,			/* ftype */
-		"FT_REL_OID",			/* name */
-		"ASN.1 relative object identifier",	/* pretty_name */
 		0,			/* wire_size */
 		bytes_fvalue_new,		/* new_value */
 		bytes_fvalue_copy,		/* copy_value */
@@ -830,10 +763,14 @@ ftype_register_bytes(void)
 		rel_oid_from_literal,		/* val_from_literal */
 		NULL,				/* val_from_string */
 		NULL,				/* val_from_charconst */
+		NULL,				/* val_from_uinteger64 */
+		NULL,				/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		rel_oid_to_repr,		/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ .set_value_bytes = bytes_fvalue_set },	/* union set_value */
 		{ .get_value_bytes = bytes_fvalue_get },	/* union get_value */
@@ -856,10 +793,8 @@ ftype_register_bytes(void)
 		NULL,				/* modulo */
 	};
 
-	static ftype_t system_id_type = {
+	static const ftype_t system_id_type = {
 		FT_SYSTEM_ID,			/* ftype */
-		"FT_SYSTEM_ID",			/* name */
-		"OSI System-ID",		/* pretty_name */
 		0,			/* wire_size */
 		bytes_fvalue_new,		/* new_value */
 		bytes_fvalue_copy,		/* copy_value */
@@ -867,10 +802,14 @@ ftype_register_bytes(void)
 		system_id_from_literal,		/* val_from_literal */
 		NULL,				/* val_from_string */
 		NULL,				/* val_from_charconst */
+		NULL,				/* val_from_uinteger64 */
+		NULL,				/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		system_id_to_repr,		/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ .set_value_bytes = bytes_fvalue_set }, /* union set_value */
 		{ .get_value_bytes = bytes_fvalue_get },	/* union get_value */
@@ -893,10 +832,8 @@ ftype_register_bytes(void)
 		NULL,				/* modulo */
 	};
 
-	static ftype_t fcwwn_type = {
+	static const ftype_t fcwwn_type = {
 		FT_FCWWN,			/* ftype */
-		"FT_FCWWN",			/* name */
-		"Fibre Channel WWN",	/* pretty_name */
 		FT_FCWWN_LEN,			/* wire_size */
 		bytes_fvalue_new,		/* new_value */
 		bytes_fvalue_copy,		/* copy_value */
@@ -904,10 +841,14 @@ ftype_register_bytes(void)
 		fcwwn_from_literal,		/* val_from_literal */
 		NULL,				/* val_from_string */
 		NULL,				/* val_from_charconst */
+		NULL,				/* val_from_uinteger64 */
+		NULL,				/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		bytes_to_repr,			/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ .set_value_bytes = bytes_fvalue_set },	/* union set_value */
 		{ .get_value_bytes = bytes_fvalue_get },	/* union get_value */
@@ -932,7 +873,6 @@ ftype_register_bytes(void)
 
 	ftype_register(FT_BYTES, &bytes_type);
 	ftype_register(FT_UINT_BYTES, &uint_bytes_type);
-	ftype_register(FT_AX25, &ax25_type);
 	ftype_register(FT_VINES, &vines_type);
 	ftype_register(FT_ETHER, &ether_type);
 	ftype_register(FT_OID, &oid_type);
@@ -946,7 +886,6 @@ ftype_register_pseudofields_bytes(int proto)
 {
 	static int hf_ft_bytes;
 	static int hf_ft_uint_bytes;
-	static int hf_ft_ax25;
 	static int hf_ft_vines;
 	static int hf_ft_ether;
 	static int hf_ft_oid;
@@ -964,11 +903,6 @@ ftype_register_pseudofields_bytes(int proto)
 			FT_UINT_BYTES, BASE_NONE, NULL, 0x00,
 			NULL, HFILL }
 		},
-		{ &hf_ft_ax25,
-		    { "FT_AX25", "_ws.ftypes.ax25",
-			FT_AX25, BASE_NONE, NULL, 0x00,
-			NULL, HFILL }
-		},
 		{ &hf_ft_vines,
 		    { "FT_VINES", "_ws.ftypes.vines",
 			FT_VINES, BASE_NONE, NULL, 0x00,
