@@ -11,9 +11,10 @@
 #include <string.h>
 
 #include <ftypes-int.h>
-#include <epan/ipv6.h>
 #include <epan/addr_resolv.h>
 #include <epan/to_str.h>
+#include <wsutil/inet_cidr.h>
+#include <wsutil/strtoi.h>
 
 static bool
 ipv6_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value _U_, char **err_msg)
@@ -21,8 +22,8 @@ ipv6_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value _U_, cha
 	const char *slash;
 	const char *addr_str;
 	char *addr_str_to_free = NULL;
-	unsigned int nmask_bits;
-	fvalue_t *nmask_fvalue;
+	uint32_t nmask_bits;
+	const char *endptr;
 
 	/* Look for prefix: Is there a single slash in the string? */
 	slash = strchr(s, '/');
@@ -48,14 +49,12 @@ ipv6_from_literal(fvalue_t *fv, const char *s, bool allow_partial_value _U_, cha
 
 	/* If prefix */
 	if (slash) {
-		/* XXX - this is inefficient */
-		nmask_fvalue = fvalue_from_literal(FT_UINT32, slash+1, false, err_msg);
-		if (!nmask_fvalue) {
+		if(!ws_strtou32(slash+1, &endptr, &nmask_bits) || *endptr != '\0') {
+			if (err_msg != NULL) {
+				*err_msg = ws_strdup_printf("%s in not a valid mask", slash+1);
+			}
 			return false;
 		}
-		nmask_bits = fvalue_get_uinteger(nmask_fvalue);
-		fvalue_free(nmask_fvalue);
-
 		if (nmask_bits > 128) {
 			if (err_msg != NULL) {
 				*err_msg = ws_strdup_printf("Prefix in a IPv6 address should be <= 128, not %u",
@@ -89,17 +88,15 @@ ipv6_to_repr(wmem_allocator_t *scope, const fvalue_t *fv, ftrepr_t rtype _U_, in
 }
 
 static void
-ipv6_set(fvalue_t *fv, const ws_in6_addr *value)
+ipv6_set(fvalue_t *fv, const ipv6_addr_and_prefix *value)
 {
-	memcpy(&fv->value.ipv6.addr, value, FT_IPv6_LEN);
-	fv->value.ipv6.prefix = 128;
+	fv->value.ipv6 = *value;
 }
 
-
-static const ws_in6_addr *
+static const ipv6_addr_and_prefix *
 ipv6_get(fvalue_t *fv)
 {
-	return &fv->value.ipv6.addr;
+	return &fv->value.ipv6;
 }
 
 static const uint8_t bitmasks[9] =
@@ -205,10 +202,8 @@ is_zero(const fvalue_t *fv_a)
 void
 ftype_register_ipv6(void)
 {
-	static ftype_t ipv6_type = {
+	static const ftype_t ipv6_type = {
 		FT_IPv6,			/* ftype */
-		"FT_IPv6",			/* name */
-		"IPv6 address",			/* pretty_name */
 		FT_IPv6_LEN,			/* wire_size */
 		NULL,				/* new_value */
 		NULL,				/* copy_value */
@@ -216,10 +211,14 @@ ftype_register_ipv6(void)
 		ipv6_from_literal,		/* val_from_literal */
 		NULL,				/* val_from_string */
 		NULL,				/* val_from_charconst */
+		NULL,				/* val_from_uinteger64 */
+		NULL,				/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		ipv6_to_repr,			/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ .set_value_ipv6 = ipv6_set },	/* union set_value */
 		{ .get_value_ipv6 = ipv6_get },	/* union get_value */
