@@ -15,10 +15,8 @@ void
 ftype_register_none(void)
 {
 
-	static ftype_t none_type = {
+	static const ftype_t none_type = {
 		FT_NONE,			/* ftype */
-		"FT_NONE",			/* name */
-		"Label",			/* pretty_name */
 		0,				/* wire_size */
 		NULL,				/* new_value */
 		NULL,				/* copy_value */
@@ -26,10 +24,14 @@ ftype_register_none(void)
 		NULL,				/* val_from_literal */
 		NULL,				/* val_from_string */
 		NULL,				/* val_from_charconst */
+		NULL,				/* val_from_uinteger64 */
+		NULL,				/* val_from_sinteger64 */
+		NULL,				/* val_from_double */
 		NULL,				/* val_to_string_repr */
 
 		NULL,				/* val_to_uinteger64 */
 		NULL,				/* val_to_sinteger64 */
+		NULL,				/* val_to_double */
 
 		{ NULL },			/* union set_value */
 		{ NULL },			/* union get_value */
@@ -43,7 +45,7 @@ ftype_register_none(void)
 		NULL,				/* is_negative */
 		NULL,				/* len */
 		NULL,				/* slice */
-		NULL,				/* biwise_and */
+		NULL,				/* bitwise_and */
 		NULL,				/* unary_minus */
 		NULL,				/* add */
 		NULL,				/* subtract */
