@@ -5,19 +5,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "config.h"
@@ -177,7 +165,7 @@ static const value_string ipproto_val[] = {
     { IP_PROTO_SHIM6,   "Shim6 header" },           /* 140 Shim6 Shim6 Protocol [RFC5533] */
     { IP_PROTO_WESP,    "WESP" },                   /* 141 WESP Wrapped Encapsulating Security Payload [RFC5840] */
     { IP_PROTO_ROHC,    "ROHC" },                   /* 142 ROHC Robust Header Compression [RFC5858] */
-    { 143, "Unassigned" },                          /* 143 Unassigned */
+    { IP_PROTO_ETHERNET,"Ethernet" },               /* 143 Ethernet [RFC8986] */
     { 144, "Unassigned" },                          /* 144 Unassigned */
     { 145, "Unassigned" },                          /* 145 Unassigned */
     { 146, "Unassigned" },                          /* 146 Unassigned */
@@ -270,7 +258,7 @@ const char *ipprotostr(const int proto) {
 
 /* https://www.iana.org/assignments/ipv6-parameters/ipv6-parameters.xhtml#extension-header */
 
-static gboolean ipv6_exthdr_check(int proto)
+static bool ipv6_exthdr_check(int proto)
 {
     switch (proto) {
     /* fall through all cases */
@@ -283,12 +271,12 @@ static gboolean ipv6_exthdr_check(int proto)
     case IP_PROTO_MIPV6:        /* Mobility Header */
     case IP_PROTO_HIP:          /* Host Identity Protocol */
     case IP_PROTO_SHIM6:        /* Shim6 Protocol */
-        return TRUE;
+        return true;
         break;
     default:
         break;
     }
-    return FALSE;
+    return false;
 }
 
 const char *ipv6extprotostr(int proto)
