@@ -24,22 +24,41 @@
 /*
  * Optionally do reassembly of the request/response line, headers, and body.
  */
-gboolean
+bool
 req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
-    const gboolean desegment_headers, const gboolean desegment_body,
-    gboolean desegment_until_fin, int *last_chunk_offset)
+    const bool desegment_headers, const bool desegment_body,
+    bool desegment_until_fin, int *last_chunk_offset,
+	dissector_table_t streaming_subdissector_table, dissector_handle_t *streaming_chunk_handle)
 {
-	gint		next_offset = offset;
-	gint		next_offset_sav;
-	gint		length_remaining, reported_length_remaining;
+	int		next_offset = offset;
+	int		next_offset_sav;
+	int		length_remaining, reported_length_remaining;
 	int		linelen;
-	gchar		*header_val;
+	char		*header_val;
 	int		content_length;
-	gboolean	content_length_found = FALSE;
-	gboolean	content_type_found = FALSE;
-	gboolean	chunked_encoding = FALSE;
-	gchar		*line;
-	gchar		*content_type = NULL;
+	bool	content_length_found = false;
+	bool	content_type_found = false;
+	bool	chunked_encoding = false;
+	char		*line;
+	char		*content_type = NULL;
+	dissector_handle_t streaming_handle = NULL;
+	bool streaming_chunk_mode = false;
+
+	DISSECTOR_ASSERT_HINT((streaming_subdissector_table && streaming_chunk_handle)
+		|| (streaming_subdissector_table == NULL && streaming_chunk_handle == NULL),
+		"The streaming_subdissector_table and streaming_chunk_handle arguments must "
+		"be both given or both NULL.");
+
+	/* Check whether the first line is the beginning of a chunk.
+	 * If it is the beginning of a chunk, we assume we are working
+	 * in streaming chunk mode. The headers of HTTP request or response
+	 * and at least one chunk should have been dissected in the previous
+	 * packets and now we are processing subsequent chunks.
+	 */
+	if (desegment_body && streaming_subdissector_table
+		&& starts_with_chunk_size(tvb, offset, pinfo)) {
+		streaming_chunk_mode = true;
+	}
 
 	/*
 	 * Do header desegmentation if we've been told to.
@@ -77,8 +96,11 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 	 * marking end of headers) or request one more byte (we
 	 * don't know how many bytes we'll need, so we just ask
 	 * for one).
+	 *
+	 * If tvb starts with chunk size, then we just ignore headers parsing.
 	 */
-	if (desegment_headers && pinfo->can_desegment) {
+	if (!streaming_chunk_mode
+		&& desegment_headers && pinfo->can_desegment) {
 		for (;;) {
 			next_offset_sav = next_offset;
 
@@ -95,7 +117,7 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 			if (reported_length_remaining < 1) {
 				pinfo->desegment_offset = offset;
 				pinfo->desegment_len = DESEGMENT_ONE_MORE_SEGMENT;
-				return FALSE;
+				return false;
 			}
 
 			length_remaining = tvb_captured_length_remaining(tvb,
@@ -106,7 +128,7 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 			 * header (i.e. a line end).
 			 */
 			linelen = tvb_find_line_end(tvb, next_offset,
-			    length_remaining, &next_offset, TRUE);
+			    length_remaining, &next_offset, true);
 			if (linelen == -1 &&
 			    length_remaining >= reported_length_remaining) {
 				/*
@@ -115,7 +137,7 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 				 */
 				pinfo->desegment_offset = offset;
 				pinfo->desegment_len = DESEGMENT_ONE_MORE_SEGMENT;
-				return FALSE;
+				return false;
 			}
 
                         if (linelen == 0) {
@@ -138,7 +160,7 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 				 * line and doing expensive string comparisons if the first
 				 * character doesn't match. Shaves about 20% off the load time of
 				 * one of my sample files that's HTTP-alike. */
-				guchar first_byte = tvb_get_guint8(tvb, next_offset_sav);
+				unsigned char first_byte = tvb_get_guint8(tvb, next_offset_sav);
 				if (! (first_byte == 'c' || first_byte == 'C' ||
 				       first_byte == 't' || first_byte == 'T')) {
 					continue;
@@ -154,13 +176,17 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 					 * 2^31-1 bytes, ignore large values we cannot handle. */
 					header_val = g_strstrip(line + 15);
 					if (ws_strtoi32(header_val, NULL, &content_length) && content_length >= 0)
-						content_length_found = TRUE;
+						content_length_found = true;
 				} else if (g_ascii_strncasecmp(line, "Content-Type:", 13) == 0) {
-					content_type_found = TRUE;
+					content_type_found = true;
 					content_type = line+13;
 					while (*content_type == ' ') {
 						content_type++;
 					}
+					g_strchomp(content_type);
+					if (streaming_subdissector_table) {
+						streaming_handle = dissector_get_string_handle(streaming_subdissector_table, content_type);
+					}
 				} else if (g_ascii_strncasecmp( line, "Transfer-Encoding:", 18) == 0) {
 					/*
 					 * Find out if this Transfer-Encoding is
@@ -172,12 +198,12 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 					 * say the same for RTSP, but handle it
 					 * anyway.)
 					 */
-					gchar *p;
-					guint len;
+					char *p;
+					unsigned len;
 
 					header_val = line+18;
 					p = header_val;
-					len = (guint) strlen(header_val);
+					len = (unsigned) strlen(header_val);
 					/* Skip white space */
 					while (p < header_val + len &&
 					    (*p == ' ' || *p == '\t'))
@@ -193,7 +219,7 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 							 * they should be
 							 * ignored.
 							 */
-							chunked_encoding = TRUE;
+							chunked_encoding = true;
 						}
 					}
 				}
@@ -201,12 +227,20 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 		}
 	}
 
+	if (streaming_chunk_mode) {
+		/* the tvb starts with chunk size without HTTP headers */
+		chunked_encoding = true;
+	} else if (desegment_body && chunked_encoding && streaming_handle && streaming_chunk_handle) {
+		streaming_chunk_mode = true;
+		*streaming_chunk_handle = streaming_handle;
+	}
+
 	/*
 	 * The above loop ends when we reached the end of the headers, so
 	 * there should be content_length bytes after the 4 terminating bytes
 	 * and next_offset points to after the end of the headers.
 	 *
-	 * XXX: If desegment_headers is FALSE but desegment_body is TRUE,
+	 * XXX: If desegment_headers is false but desegment_body is true,
 	 * then for HTTP Responses we will always set to DESEGMENT_UNTIL_FIN,
 	 * which is probably not what we want.
 	 */
@@ -217,45 +251,55 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 			 * data until we reach the end of the stream, or a
 			 * zero sized chunk.
 			 *
+			 * But if streaming_chunk_mode is true,
+			 * we will just pull one more chunk if the end of
+			 * this tvb is in middle of a chunk. Because we want
+			 * to dissect chunks with subdissector as soon as
+			 * possible.
+			 *
 			 * XXX
 			 * This doesn't bother with trailing headers; I don't
 			 * think they are really used, and we'd have to use
 			 * is_http_request_or_reply() to determine if it was
 			 * a trailing header, or the start of a new response.
 			 */
-			gboolean done_chunking = FALSE;
+			bool done_chunking = false;
 			if (last_chunk_offset != NULL && *last_chunk_offset) {
 				next_offset = offset + *last_chunk_offset;
 			}
 
 			while (!done_chunking) {
-				guint chunk_size = 0;
-				gint  chunk_offset = 0;
-				gchar *chunk_string = NULL;
-				gchar *c = NULL;
+				unsigned chunk_size = 0;
+				int   chunk_offset = 0;
+				char *chunk_string = NULL;
+				char *c = NULL;
 
 				reported_length_remaining =
 				    tvb_reported_length_remaining(tvb,
 				    next_offset);
 
+				if (reported_length_remaining == 0 && streaming_chunk_mode) {
+					return true;
+				}
+
 				if (reported_length_remaining < 1) {
 					pinfo->desegment_offset = offset;
 					pinfo->desegment_len = DESEGMENT_ONE_MORE_SEGMENT;
-					return FALSE;
+					return false;
 				}
 
 				length_remaining = tvb_captured_length_remaining(tvb,
 				    next_offset);
 
 				linelen = tvb_find_line_end(tvb, next_offset,
-						length_remaining, &chunk_offset, TRUE);
+						length_remaining, &chunk_offset, true);
 
 				if (linelen == -1 &&
 				    length_remaining >=
 				    reported_length_remaining) {
 					 pinfo->desegment_offset = offset;
 					 pinfo->desegment_len = DESEGMENT_ONE_MORE_SEGMENT;
-					 return FALSE;
+					 return false;
 				}
 
 				/* We have a line with the chunk size in it.*/
@@ -273,22 +317,23 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 				c = chunk_string;
 
 				/*
-				 * We don't care about the extensions.
+				 * We don't care about the extensions (including optional
+				 * BWS, see RFC 9112 7.1.1)
 				 */
-				if ((c = strchr(c, ';'))) {
+				if ((c = strpbrk(c, "; \t"))) {
 					*c = '\0';
 				}
 
-				if (sscanf(chunk_string, "%x", &chunk_size) < 1) {
+				if (!ws_hexstrtou32(chunk_string, NULL, &chunk_size)) {
 					/* We couldn't get the chunk size,
 					 * so stop trying.
 					 */
-					return TRUE;
+					return true;
 				}
 				if (chunk_size > 1U<<31) {
 					/* Chunk size is unreasonable. */
 					/* XXX What /is/ reasonable? */
-					return TRUE;
+					return true;
 				}
 
 				if (chunk_size == 0) {
@@ -297,26 +342,26 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 					 * trailing CRLF.
 					 */
 					linelen = tvb_find_line_end(tvb,
-					    chunk_offset, length_remaining, &chunk_offset, TRUE);
+					    chunk_offset, length_remaining, &chunk_offset, true);
 
 					if (linelen == -1 &&
 					    length_remaining >=
 					    reported_length_remaining) {
 						pinfo->desegment_offset = offset;
 						pinfo->desegment_len = DESEGMENT_ONE_MORE_SEGMENT;
-						return FALSE;
+						return false;
 					}
 
 					pinfo->desegment_offset = chunk_offset;
 					pinfo->desegment_len = 0;
-					done_chunking = TRUE;
+					done_chunking = true;
 				} else {
 					/*
 					 * Skip to the next chunk if we
 					 * already have it
 					 */
 					if (reported_length_remaining >
-					        (gint) chunk_size) {
+					        (int) chunk_size) {
 
 						next_offset = chunk_offset
 						    + chunk_size + 2;
@@ -325,28 +370,39 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 						 * Fetch this chunk, plus the
 						 * trailing CRLF.
 						 */
-						pinfo->desegment_offset = offset;
-						pinfo->desegment_len = DESEGMENT_ONE_MORE_SEGMENT;
-						return FALSE;
+						if (streaming_chunk_mode) {
+							int size_remaining = chunk_size + linelen + 4 - reported_length_remaining;
+							if (size_remaining == 0) {
+								return true;
+							} else {
+								pinfo->desegment_offset = offset;
+								pinfo->desegment_len = size_remaining;
+								return false;
+							}
+						} else {
+							pinfo->desegment_offset = offset;
+							pinfo->desegment_len = DESEGMENT_ONE_MORE_SEGMENT;
+							return false;
+						}
 					}
 				}
 
 			}
 		} else if (content_length_found) {
 			if (content_length >= 128*1024) { /* MS-RPCH stipulate that the content-length must be between 128K and 2G */
-				gchar *tmp;
+				char *tmp;
 				if (content_type_found &&
 				strncmp(content_type, "application/rpc", 15) == 0) {
 					/* It looks like a RPC_IN_DATA request or a RPC_OUT_DATA response
 					 * in which the content-length is meaningless
 					 */
-					return TRUE;
+					return true;
 				}
 				/* Following sizeof will return the length of the string + \0 we need to not count it*/
 				tmp = tvb_get_string_enc(pinfo->pool, tvb, 0, sizeof("RPC_OUT_DATA") - 1, ENC_ASCII);
 				if ((strncmp(tmp, "RPC_IN_DATA", sizeof("RPC_IN_DATA") - 1) == 0) ||
 				    (strncmp(tmp, "RPC_OUT_DATA", sizeof("RPC_OUT_DATA") - 1) == 0)) {
-					return TRUE;
+					return true;
 				}
 			}
 			/* next_offset has been set to the end of the headers */
@@ -360,14 +416,14 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 					 * It's a waste of time asking for more
 					 * data, because that data wasn't captured.
 					 */
-					return TRUE;
+					return true;
 				}
 				if (length_remaining == -1)
 					length_remaining = 0;
 				pinfo->desegment_offset = offset;
 				pinfo->desegment_len =
 				    content_length - length_remaining;
-				return FALSE;
+				return false;
 			}
 		} else if (desegment_until_fin && pinfo->can_desegment) {
 			/*
@@ -387,13 +443,13 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 				 * It's a waste of time asking for more
 				 * data, because that data wasn't captured.
 				 */
-				return TRUE;
+				return true;
 			}
 
 			pinfo->desegment_offset = offset;
 			pinfo->desegment_len = DESEGMENT_UNTIL_FIN;
 
-			return FALSE;
+			return false;
 		}
 
 	}
@@ -401,7 +457,7 @@ req_resp_hdrs_do_reassembly(tvbuff_t *tvb, const int offset, packet_info *pinfo,
 	/*
 	 * No further desegmentation needed.
 	 */
-	return TRUE;
+	return true;
 }
 
 /*
