@@ -32,12 +32,11 @@ Examples:
 
 
 ALLOWED_LICENSES = [
-    'BSD',
+    'BSD (1 clause)',
     'BSD (2 clause)',
     'BSD (2 clause) GPL (v2 or later)',
     'BSD (3 clause)',
     'GPL (v2 or later)',
-    'GPL (v3 or later) (with Bison parser exception)',
     'ISC',
     'ISC GPL (v2 or later)',
     'LGPL (v2 or later)',
@@ -61,16 +60,13 @@ PATH_SPECIFIC_ALLOWED_LICENSES = {
     'wsutil/strnatcmp.h': [
         'Zlib',
     ],
-    'dtds': [
+    'resources/protocols/dtds': [
         'UNKNOWN',
     ],
-    'diameter/dictionary.dtd': [
+    'resources/protocols/diameter/dictionary.dtd': [
         'UNKNOWN',
     ],
-    'wimaxasncp/dictionary.dtd': [
-        'UNKNOWN',
-    ],
-    'CONTRIBUTING.md': [
+    'resources/protocols/wimaxasncp/dictionary.dtd': [
         'UNKNOWN',
     ],
     'doc/': [
@@ -82,9 +78,6 @@ PATH_SPECIFIC_ALLOWED_LICENSES = {
     'docbook/custom_layer_single_html.xsl': [
         'UNKNOWN',
     ],
-    'docbook/ws.css' : [
-        'UNKNOWN'
-    ],
     'fix': [
         'UNKNOWN',
     ],
@@ -129,18 +122,6 @@ PATH_SPECIFIC_ALLOWED_LICENSES = {
     'epan/dissectors/pidl/idl_types.h': [
         'UNKNOWN',
     ],
-    # Written by Ronnie Sahlberg and correctly licensed, but cannot include
-    # a license header despite the file extension as they need to be
-    # parsed by the pidl tool
-    'epan/dissectors/pidl/mapi/request.cnf.c': [
-        'UNKNOWN',
-    ],
-    'epan/dissectors/pidl/mapi/response.cnf.c': [
-        'UNKNOWN',
-    ],
-    'tools/abi-dumps': [
-        'UNKNOWN',
-    ],
     # The following tools are under incompatible licenses (mostly GPLv3 or
     # GPLv3+), but this is OK since they are not actually linked into Wireshark
     'tools/pidl': [
@@ -155,6 +136,9 @@ PATH_SPECIFIC_ALLOWED_LICENSES = {
     '.gitlab/': [
         'UNKNOWN',
     ],
+    'wsutil/safe-math.h': [ # Public domain (CC0)
+        'UNKNOWN',
+    ],
 }
 
 def check_licenses(options, args):
@@ -184,7 +168,7 @@ def check_licenses(options, args):
                                                     'licensecheck.pl'))
 
   licensecheck = subprocess.Popen([licensecheck_path,
-                                   '-l', '150',
+                                   '-l', '160',
                                    '-r', start_dir],
                                   stdout=subprocess.PIPE,
                                   stderr=subprocess.PIPE)
@@ -210,7 +194,7 @@ def check_licenses(options, args):
 
     # All files in the build output directory are generated one way or another.
     # There's no need to check them.
-    if filename.startswith('out/') or filename.startswith('sconsbuild/'):
+    if os.path.dirname(filename).startswith('build'):
       continue
 
     # For now we're just interested in the license.
