@@ -9,6 +9,14 @@
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
+import sys
+import getopt
+import csv
+import re
+import collections
+import urllib.request, urllib.error, urllib.parse
+import codecs
+
 iana_svc_url = 'https://www.iana.org/assignments/service-names-port-numbers/service-names-port-numbers.csv'
 
 __doc__ = '''\
@@ -18,15 +26,8 @@ url defaults to
     %s
 ''' % (iana_svc_url)
 
-import sys
-import getopt
-import csv
-import re
-import collections
-import urllib.request, urllib.error, urllib.parse
-import codecs
 
-services_file = 'services'
+services_file = 'epan/services-data.c'
 
 exclude_services = [
     '^spr-itunes',
@@ -43,7 +44,7 @@ def parse_port(port_str):
         if len(p) == 1:
             return tuple([int(p[0])])
         if len(p) == 2:
-            return tuple([int(p[0]), int(p[1])])
+            return tuple(range(int(p[0]), int(p[1]) + 1))
     except ValueError:
         pass
     return ()
@@ -105,7 +106,7 @@ def parse_rows(svc_fd):
         if description == service or description == service.replace("-", " "):
             description = None
 
-        if not port in services_map:
+        if port not in services_map:
             services_map[port] = collections.OrderedDict()
 
         # Remove some duplicates (first entry wins)
@@ -117,7 +118,7 @@ def parse_rows(svc_fd):
         if proto_exists:
             continue
 
-        if not service in services_map[port]:
+        if service not in services_map[port]:
             services_map[port][service] = [description]
         services_map[port][service].append(proto)
 
@@ -126,23 +127,58 @@ def parse_rows(svc_fd):
 
     return services_map
 
-def write_body(d, f):
+def compile_body(d):
     keys = list(d.keys())
     keys.sort()
+    body = []
 
     for port in keys:
         for serv in d[port].keys():
-            sep = "\t" * (1 + abs((15 - len(serv)) // 8))
-            port_str = port_to_str(port) + "/" + "/".join(d[port][serv][1:])
-            line = serv + sep + port_str
+            line = [port, d[port][serv][1:], serv]
             description = d[port][serv][0]
             if description:
-                sep = "\t"
-                if len(port_str) < 8:
-                    sep *= 2
-                line += sep + "# " + description
-            line += "\n"
-            f.write(line)
+                line.append(description)
+            body.append(line)
+
+    return body
+
+def add_entry(table, port, service_name, description):
+    table.append([int(port), service_name, description])
+
+
+ # body = [(port-range,), [proto-list], service-name, optional-description]
+ # table = [port-number, service-name, optional-description]
+def compile_tables(body):
+
+    body.sort()
+    tcp_udp_table = []
+    tcp_table = []
+    udp_table = []
+    sctp_table = []
+    dccp_table = []
+
+    for entry in body:
+        if len(entry) == 4:
+            port_range, proto_list, service_name, description = entry
+        else:
+            port_range, proto_list, service_name = entry
+            description = None
+
+        for port in port_range:
+            if 'tcp' in proto_list and 'udp' in proto_list:
+                add_entry(tcp_udp_table, port, service_name, description)
+            else:
+                if 'tcp' in proto_list:
+                    add_entry(tcp_table, port, service_name, description)
+                if 'udp' in proto_list:
+                    add_entry(udp_table, port, service_name, description)
+            if 'sctp' in proto_list:
+                add_entry(sctp_table, port, service_name, description)
+            if 'dccp' in proto_list:
+                add_entry(dccp_table, port, service_name, description)
+
+    return tcp_udp_table, tcp_table, udp_table, sctp_table, dccp_table
+
 
 def exit_msg(msg=None, status=1):
     if msg is not None:
@@ -181,28 +217,77 @@ def main(argv):
 
     out = open(services_file, 'w')
     out.write('''\
-# This is a local copy of the IANA port-numbers file.
-#
-# Wireshark uses it to resolve port numbers into human readable
-# service names, e.g. TCP port 80 -> http.
-#
-# It is subject to copyright and being used with IANA's permission:
-# https://www.wireshark.org/lists/wireshark-dev/200708/msg00160.html
-#
-# The original file can be found at:
-# %s
-#
-# The format is the same as that used for services(5). It is allowed to merge
-# identical protocols, for example:
-#   foo 64/tcp
-#   foo 64/udp
-# becomes
-#   foo 64/tcp/udp
-#
+/*
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
+ * Copyright 1998 Gerald Combs
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
+ * This is a local copy of the IANA port-numbers file.
+ *
+ * Wireshark uses it to resolve port numbers into human readable
+ * service names, e.g. TCP port 80 -> http.
+ *
+ * It is subject to copyright and being used with IANA's permission:
+ * https://www.wireshark.org/lists/wireshark-dev/200708/msg00160.html
+ *
+ * The original file can be found at:
+ * %s
+ *
+ * Generated by tools/make-services.py
+ */
 
 ''' % (iana_svc_url))
 
-    write_body(body, out)
+    body = compile_body(body)
+    # body = [(port-range,), [proto-list], service-name, optional-description]
+
+    max_port = 0
+
+    tcp_udp, tcp, udp, sctp, dccp = compile_tables(body)
+
+    def write_entry(f, e, max_port):
+        line = "    {{ {}, \"{}\", ".format(*e)
+        sep_len = 32 - len(line)
+        if sep_len <= 0:
+            sep_len = 1
+        line += ' ' * sep_len
+        if len(e) == 3 and e[2]:
+            line += "\"{}\" }},\n".format(e[2].replace('"', '\\"'))
+        else:
+            line += "\"\" },\n"
+        f.write(line)
+        if int(e[0]) > int(max_port):
+            return e[0]
+        return max_port
+
+    out.write("static const ws_services_entry_t global_tcp_udp_services_table[] = {\n")
+    for e in tcp_udp:
+        max_port = write_entry(out, e, max_port)
+    out.write("};\n\n")
+
+    out.write("static const ws_services_entry_t global_tcp_services_table[] = {\n")
+    for e in tcp:
+        max_port = write_entry(out, e, max_port)
+    out.write("};\n\n")
+
+    out.write("static const ws_services_entry_t global_udp_services_table[] = {\n")
+    for e in udp:
+        max_port = write_entry(out, e, max_port)
+    out.write("};\n\n")
+
+    out.write("static const ws_services_entry_t global_sctp_services_table[] = {\n")
+    for e in sctp:
+        max_port = write_entry(out, e, max_port)
+    out.write("};\n\n")
+
+    out.write("static const ws_services_entry_t global_dccp_services_table[] = {\n")
+    for e in dccp:
+        max_port = write_entry(out, e, max_port)
+    out.write("};\n\n")
+
+    out.write("static const uint16_t _services_max_port = {};\n".format(max_port))
 
     out.close()
 
