@@ -27,8 +27,8 @@
 /*
  * Open the help dialog and show a specific HTML help page.
  */
-gchar *
-user_guide_url(const gchar *page) {
+char *
+user_guide_url(const char *page) {
     GString *url = g_string_new("");
 
 #if defined(_WIN32)
@@ -61,10 +61,10 @@ user_guide_url(const gchar *page) {
     return g_string_free(url, FALSE);
 }
 
-gchar *
+char *
 topic_action_url(topic_action_e action)
 {
-    gchar *url;
+    char *url;
 
     switch(action) {
     /* pages online at www.wireshark.org */
@@ -104,9 +104,6 @@ topic_action_url(topic_action_e action)
     case(ONLINEPAGE_SECURITY):
         url = g_strdup(WS_WIKI_URL("Security"));
         break;
-    case(ONLINEPAGE_CHIMNEY):
-        url = g_strdup(WS_WIKI_URL("CaptureSetup/Offloading#chimney"));
-        break;
 
     /* local manual pages */
     case(LOCALPAGE_MAN_WIRESHARK):
@@ -140,6 +137,11 @@ topic_action_url(topic_action_e action)
         url = doc_file_url("tshark.html");
         break;
 
+    /* Release Notes */
+    case(LOCALPAGE_RELEASE_NOTES):
+        url = doc_file_url("release-notes.html");
+        break;
+
     /* local help pages (User's Guide) */
     case(HELP_CONTENT):
         url = user_guide_url( "index.html");
@@ -153,6 +155,9 @@ topic_action_url(topic_action_e action)
     case(HELP_DISPLAY_FILTERS_DIALOG):
         url = user_guide_url("ChWorkDefineFilterSection.html");
         break;
+    case(HELP_DISPLAY_MACRO_DIALOG):
+        url = user_guide_url("ChWorkDefineFilterMacrosSection.html");
+        break;
     case(HELP_FILTER_EXPRESSION_DIALOG):
         url = user_guide_url("ChWorkFilterAddExpressionSection.html");
         break;
