@@ -1,4 +1,4 @@
-/* help_dlg.h
+/** @file
  *
  * Some content from gtk/help_dlg.h by Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -12,6 +12,8 @@
 #ifndef __HELP_URL_H__
 #define __HELP_URL_H__
 
+#include <ws_attributes.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -35,7 +37,6 @@ typedef enum {
     ONLINEPAGE_NETWORK_MEDIA,
     ONLINEPAGE_SAMPLE_CAPTURES,
     ONLINEPAGE_SECURITY,
-    ONLINEPAGE_CHIMNEY,
     ONLINEPAGE_ASK,
 
     /* local manual pages */
@@ -50,16 +51,19 @@ typedef enum {
     LOCALPAGE_MAN_TEXT2PCAP,
     LOCALPAGE_MAN_TSHARK,
 
-    /* help pages (textfiles or local HTML User's Guide) */
+    /* Release Notes */
+    LOCALPAGE_RELEASE_NOTES,
+
+    /* help pages (textfiles or HTML User's Guide) */
     HELP_CONTENT = 200,
     HELP_GETTING_STARTED,           /* currently unused */
     HELP_CAPTURE_OPTIONS,           /* currently unused */
     HELP_CAPTURE_FILTERS_DIALOG,
     HELP_DISPLAY_FILTERS_DIALOG,
     HELP_FILTER_EXPRESSION_DIALOG,
+    HELP_DISPLAY_MACRO_DIALOG,
     HELP_COLORING_RULES_DIALOG,
     HELP_CONFIG_PROFILES_DIALOG,
-    HELP_MANUAL_ADDR_RESOLVE_DIALOG, /* GTK+ only? */
     HELP_PRINT_DIALOG,
     HELP_FIND_DIALOG,
     HELP_FILESET_DIALOG,
@@ -80,13 +84,11 @@ typedef enum {
     HELP_STATS_ENDPOINTS_DIALOG,
     HELP_STATS_CONVERSATIONS_DIALOG,
     HELP_STATS_IO_GRAPH_DIALOG,
-    HELP_STATS_COMPARE_FILES_DIALOG,
     HELP_STATS_LTE_MAC_TRAFFIC_DIALOG,
     HELP_STATS_LTE_RLC_TRAFFIC_DIALOG,
     HELP_STATS_TCP_STREAM_GRAPHS_DIALOG,
     HELP_STATS_WLAN_TRAFFIC_DIALOG,
     HELP_CAPTURE_INTERFACE_OPTIONS_DIALOG,
-    HELP_CAPTURE_INTERFACES_DETAILS_DIALOG,
     HELP_PREFERENCES_DIALOG,
     HELP_CAPTURE_INFO_DIALOG,
     HELP_EXPORT_FILE_DIALOG,
@@ -101,40 +103,31 @@ typedef enum {
     HELP_MERGE_WIN32_DIALOG,
     HELP_SAVE_WIN32_DIALOG,
     HELP_TIME_SHIFT_DIALOG,
-    HELP_FILTER_SAVE_DIALOG,
     HELP_TELEPHONY_VOIP_CALLS_DIALOG,
-    HELP_RTP_ANALYSIS_DIALOG,
+    HELP_TELEPHONY_RTP_ANALYSIS_DIALOG,
+    HELP_TELEPHONY_RTP_STREAMS_DIALOG,
     HELP_NEW_PACKET_DIALOG,
     HELP_IAX2_ANALYSIS_DIALOG,
-    HELP_TELEPHONY_RTP_PLAYER_DIALOG
+    HELP_TELEPHONY_RTP_PLAYER_DIALOG,
+    HELP_STAT_FLOW_GRAPH
 } topic_action_e;
 
-/** Given a topic action return its online (www.wireshark.org) URL or NULL.
- *
- * @param action Topic action, e.g. ONLINEPAGE_HOME or ONLINEPAGE_ASK.
- * @return A static URL or NULL. MUST NOT be freed.
- */
-const char *topic_online_url(topic_action_e action);
-
-/** Given a page in the Wireshark User's Guide return its URL. On Windows
- *  an attempt will be made to open User Guide URLs with HTML Help. If
- *  the attempt succeeds NULL will be returned.
+/** Given a page in the Wireshark User's Guide return its URL. Returns a
+ *  URL to a local file if present, or to the online guide if the local
+ *  file is unavailable.
  *
  * @param page A page in the User's Guide.
- * @return A static URL or NULL. A non-NULL return value must be freed
- * with g_free().
+ * @return A static URL. The return value must be freed with g_free().
  */
-gchar *user_guide_url(const gchar *page);
+WS_RETNONNULL char *user_guide_url(const char *page);
 
-/** Given a topic action return its URL. On Windows an attempt will be
- *  made to open User Guide URLs with HTML Help. If the attempt succeeds
- *  NULL will be returned.
+/** Given a topic action return its URL. If the attempt fails NULL
+ *  will be returned.
  *
  * @param action Topic action.
- * @return A static URL or NULL. A non-NULL return value must be freed
- * with g_free().
+ * @return A static URL. The return value must be freed with g_free().
  */
-gchar *topic_action_url(topic_action_e action);
+WS_RETNONNULL char *topic_action_url(topic_action_e action);
 
 /** Open a specific topic (create a "Help" dialog box or open a webpage).
  *
@@ -147,16 +140,3 @@ void topic_action(topic_action_e topic);
 #endif /* __cplusplus */
 
 #endif /* __HELP_URL_H__ */
-
-/*
- * Editor modelines
- *
- * Local Variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * ex: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
