@@ -13,8 +13,6 @@
 #include <epan/strutil.h>
 #include <epan/tap.h>
 
-#include <epan/dissectors/packet-rlc-lte.h>
-
 #include <QFormLayout>
 #include <QTreeWidgetItem>
 #include <QPushButton>
@@ -26,6 +24,7 @@
 // TODO: have never tested in a live capture.
 
 enum {
+    col_rat_,
     col_ueid_,
     col_mode_,     // channel only
     col_priority_, // channel only
@@ -49,7 +48,7 @@ enum {
 };
 
 /* Calculate and return a bandwidth figure, in Mbs */
-static double calculate_bw(const nstime_t *start_time, const nstime_t *stop_time, guint32 bytes)
+static double calculate_bw(const nstime_t *start_time, const nstime_t *stop_time, uint32_t bytes)
 {
     /* Can only calculate bandwidth if have time delta */
     if (memcmp(start_time, stop_time, sizeof(nstime_t)) != 0) {
@@ -74,31 +73,31 @@ static double calculate_bw(const nstime_t *start_time, const nstime_t *stop_time
 
 // Stats kept for one channel.
 typedef struct rlc_channel_stats {
-    guint8   rlcMode;
-    guint8   priority;
-    guint16  channelType;
-    guint16  channelId;
+    uint8_t  rlcMode;
+    uint8_t  priority;
+    uint16_t channelType;
+    uint16_t channelId;
 
-    guint32  UL_frames;
-    guint32  UL_bytes;
+    uint32_t UL_frames;
+    uint32_t UL_bytes;
     nstime_t UL_time_start;
     nstime_t UL_time_stop;
-    gboolean UL_has_data; // i.e. not just ACKs for DL.
+    bool UL_has_data; // i.e. not just ACKs for DL.
 
-    guint32  DL_frames;
-    guint32  DL_bytes;
+    uint32_t DL_frames;
+    uint32_t DL_bytes;
     nstime_t DL_time_start;
     nstime_t DL_time_stop;
-    gboolean DL_has_data;  // i.e. not just ACKs for UL.
+    bool DL_has_data;  // i.e. not just ACKs for UL.
 
-    guint32  UL_acks;
-    guint32  UL_nacks;
+    uint32_t UL_acks;
+    uint32_t UL_nacks;
 
-    guint32  DL_acks;
-    guint32  DL_nacks;
+    uint32_t DL_acks;
+    uint32_t DL_nacks;
 
-    guint32  UL_missing;
-    guint32  DL_missing;
+    uint32_t UL_missing;
+    uint32_t DL_missing;
 } rlc_channel_stats;
 
 //-------------------------------------------------------------------
@@ -108,10 +107,12 @@ class RlcChannelTreeWidgetItem : public QTreeWidgetItem
 {
 public:
     RlcChannelTreeWidgetItem(QTreeWidgetItem *parent,
+                             uint8_t  rat,
                              unsigned ueid,
                              unsigned mode,
                              unsigned channelType, unsigned channelId) :
         QTreeWidgetItem(parent, rlc_channel_row_type_),
+        rat_(rat),
         ueid_(ueid),
         channelType_(channelType),
         channelId_(channelId),
@@ -163,7 +164,7 @@ public:
     }
 
     // Update UE/channels from tap info.
-    void update(const rlc_lte_tap_info *tap_info) {
+    void update(const rlc_3gpp_tap_info *tap_info) {
 
         // Copy these fields into UE stats.
         if (tap_info->rlcMode != stats_.rlcMode) {
@@ -183,9 +184,9 @@ public:
         if (tap_info->direction == DIRECTION_UPLINK) {
             // Update time range.
             if (stats_.UL_frames == 0) {
-                stats_.UL_time_start = tap_info->rlc_lte_time;
+                stats_.UL_time_start = tap_info->rlc_time;
             }
-            stats_.UL_time_stop = tap_info->rlc_lte_time;
+            stats_.UL_time_stop = tap_info->rlc_time;
 
             stats_.UL_frames++;
             stats_.UL_bytes += tap_info->pduLength;
@@ -195,15 +196,15 @@ public:
                 stats_.UL_acks++;
             }
             else {
-                stats_.UL_has_data = TRUE;
+                stats_.UL_has_data = true;
             }
         }
         else {
             // Update time range.
             if (stats_.DL_frames == 0) {
-                stats_.DL_time_start = tap_info->rlc_lte_time;
+                stats_.DL_time_start = tap_info->rlc_time;
             }
-            stats_.DL_time_stop = tap_info->rlc_lte_time;
+            stats_.DL_time_stop = tap_info->rlc_time;
 
             stats_.DL_frames++;
             stats_.DL_bytes += tap_info->pduLength;
@@ -213,7 +214,7 @@ public:
                 stats_.DL_acks++;
             }
             else {
-                stats_.DL_has_data = TRUE;
+                stats_.DL_has_data = true;
             }
         }
     }
@@ -269,47 +270,81 @@ public:
         return QTreeWidgetItem::operator< (other);
     }
 
-    // Filter expression for channel.
+    // Filter expression for this bearer.
     const QString filterExpression(bool showSR, bool showRACH) {
         // Create an expression to match with all traffic for this UE.
         QString filter_expr;
 
         // Are we taking RLC PDUs from MAC, or not?
         if (!recent.gui_rlc_use_pdus_from_mac) {
-            filter_expr += QString("not mac-lte and ");
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString("not mac-lte and ");
+            }
+            else {
+                filter_expr += QString("not mac-nr and ");
+            }
         }
         else {
-            filter_expr += QString("mac-lte and ");
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString("mac-lte and ");
+            }
+            else {
+                filter_expr += QString("mac-nr and ");
+            }
         }
 
         if (showSR) {
-            filter_expr += QString("(mac-lte.sr-req and mac-lte.ueid == %1) or (").arg(ueid_);
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString("(mac-lte.sr-req and mac-lte.ueid == %1) or (").arg(ueid_);
+            }
         }
 
         if (showRACH) {
-            filter_expr += QString("(mac-lte.rar or (mac-lte.preamble-sent and mac-lte.ueid == %1)) or (").arg(ueid_);
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString("(mac-lte.rar or (mac-lte.preamble-sent and mac-lte.ueid == %1)) or (").arg(ueid_);
+            }
+            else {
+                filter_expr += QString("(mac-nr.rar or ");
+            }
         }
 
         // Main part of expression.
-        filter_expr += QString("rlc-lte.ueid==%1 and rlc-lte.channel-type == %2").
-                                  arg(ueid_).arg(channelType_);
+        if (rat_ == RLC_RAT_LTE) {
+            filter_expr += QString("rlc-lte.ueid==%1 and rlc-lte.channel-type == %2").
+                                      arg(ueid_).arg(channelType_);
+        }
+        else {
+            filter_expr += QString("rlc-nr.ueid==%1 and rlc-nr.bearer-type == %2").
+                                      arg(ueid_).arg(channelType_);
+        }
+        // Channel/bearer Id
         if ((channelType_ == CHANNEL_TYPE_SRB) || (channelType_ == CHANNEL_TYPE_DRB)) {
-            filter_expr += QString(" and rlc-lte.channel-id == %1").arg(channelId_);
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString(" and rlc-lte.channel-id == %1").arg(channelId_);
+            }
+            else {
+                filter_expr += QString(" and rlc-nr.bearer-id == %1").arg(channelId_);
+            }
         }
 
         // Close () if open because of SR
         if (showSR) {
-            filter_expr += QString(")");
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString(")");
+            }
         }
         // Close () if open because of RACH
         if (showRACH) {
-            filter_expr += QString(")");
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString(")");
+            }
         }
 
         return filter_expr;
     }
 
     // Accessors (queried for launching graph)
+    uint8_t  get_rat() const { return rat_; }
     unsigned get_ueid() const { return ueid_; }
     unsigned get_channelType() const { return channelType_; }
     unsigned get_channelId() const { return channelId_; }
@@ -325,10 +360,11 @@ public:
     }
 
 private:
+    uint8_t  rat_;
     unsigned ueid_;
     unsigned channelType_;
     unsigned channelId_;
-    unsigned mode_;
+    unsigned mode_;          // RLC mode for this bearer
     unsigned priority_;
 
     unsigned channelRank() const
@@ -353,21 +389,21 @@ private:
 // Stats for one UE.  TODO: private to class?
 typedef struct rlc_ue_stats {
 
-    guint32  UL_frames;
-    guint32  UL_total_bytes;
+    uint32_t UL_frames;
+    uint32_t UL_total_bytes;
     nstime_t UL_time_start;
     nstime_t UL_time_stop;
-    guint32  UL_total_acks;
-    guint32  UL_total_nacks;
-    guint32  UL_total_missing;
+    uint32_t UL_total_acks;
+    uint32_t UL_total_nacks;
+    uint32_t UL_total_missing;
 
-    guint32  DL_frames;
-    guint32  DL_total_bytes;
+    uint32_t DL_frames;
+    uint32_t DL_total_bytes;
     nstime_t DL_time_start;
     nstime_t DL_time_stop;
-    guint32  DL_total_acks;
-    guint32  DL_total_nacks;
-    guint32  DL_total_missing;
+    uint32_t DL_total_acks;
+    uint32_t DL_total_nacks;
+    uint32_t DL_total_missing;
 
 } rlc_ue_stats;
 
@@ -377,11 +413,17 @@ typedef struct rlc_ue_stats {
 class RlcUeTreeWidgetItem : public QTreeWidgetItem
 {
 public:
-    RlcUeTreeWidgetItem(QTreeWidget *parent, const rlc_lte_tap_info *rlt_info) :
+    RlcUeTreeWidgetItem(QTreeWidget *parent, const rlc_3gpp_tap_info *rlt_info) :
         QTreeWidgetItem (parent, rlc_ue_row_type_),
         ueid_(0)
     {
         ueid_ = rlt_info->ueid;
+        rat_ = rlt_info->rat;
+
+        // Version matches UE number
+        setText(col_rat_, (rat_ == RLC_RAT_LTE) ?
+                                 QObject::tr("LTE") :
+                                 QObject::tr("NR"));
         setText(col_ueid_, QString::number(ueid_));
 
         // We create RlcChannelTreeWidgetItems when first data on new channel is seen.
@@ -398,20 +440,14 @@ public:
     }
 
     // Does UE match?
-    bool isMatch(const rlc_lte_tap_info *rlt_info) {
-        return ueid_ == rlt_info->ueid;
+    bool isMatch(const rlc_3gpp_tap_info *rlt_info)
+    {
+        return (rat_ == rlt_info->rat) && (ueid_ == rlt_info->ueid);
     }
 
     // Update UE/channels from tap info.
-    void update(const rlc_lte_tap_info *tap_info) {
-
-        // Are we ignoring RLC frames that were found in MAC frames, or only those
-        // that were logged separately?
-        if ((!recent.gui_rlc_use_pdus_from_mac && tap_info->loggedInMACFrame) ||
-            (recent.gui_rlc_use_pdus_from_mac  && !tap_info->loggedInMACFrame)) {
-            return;
-        }
-
+    void update(const rlc_3gpp_tap_info *tap_info)
+    {
         // TODO: update title with number of UEs and frames like MAC does?
 
         // N.B. not really expecting to see common stats - ignoring them.
@@ -430,9 +466,9 @@ public:
         if (tap_info->direction == DIRECTION_UPLINK) {
             // Update time range.
             if (stats_.UL_frames == 0) {
-                stats_.UL_time_start = tap_info->rlc_lte_time;
+                stats_.UL_time_start = tap_info->rlc_time;
             }
-            stats_.UL_time_stop = tap_info->rlc_lte_time;
+            stats_.UL_time_stop = tap_info->rlc_time;
 
             stats_.UL_frames++;
             stats_.UL_total_bytes += tap_info->pduLength;
@@ -448,9 +484,9 @@ public:
         else {
             // Update time range.
             if (stats_.DL_frames == 0) {
-                stats_.DL_time_start = tap_info->rlc_lte_time;
+                stats_.DL_time_start = tap_info->rlc_time;
             }
-            stats_.DL_time_stop = tap_info->rlc_lte_time;
+            stats_.DL_time_stop = tap_info->rlc_time;
 
             stats_.DL_frames++;
             stats_.DL_total_bytes += tap_info->pduLength;
@@ -472,7 +508,7 @@ public:
                 channel_item = CCCH_stats_;
                 if (channel_item == NULL) {
                     channel_item = CCCH_stats_ =
-                            new RlcChannelTreeWidgetItem(this, tap_info->ueid, RLC_TM_MODE,
+                            new RlcChannelTreeWidgetItem(this, tap_info->rat, tap_info->ueid, RLC_TM_MODE,
                                                          tap_info->channelType, tap_info->channelId);
                 }
                 break;
@@ -481,7 +517,7 @@ public:
                 channel_item = srb_stats_[tap_info->channelId-1];
                 if (channel_item == NULL) {
                     channel_item = srb_stats_[tap_info->channelId-1] =
-                            new RlcChannelTreeWidgetItem(this, tap_info->ueid, RLC_AM_MODE,
+                            new RlcChannelTreeWidgetItem(this, tap_info->rat, tap_info->ueid, RLC_AM_MODE,
                                                          tap_info->channelType, tap_info->channelId);
                 }
                 break;
@@ -490,7 +526,7 @@ public:
                 channel_item = drb_stats_[tap_info->channelId-1];
                 if (channel_item == NULL) {
                     channel_item = drb_stats_[tap_info->channelId-1] =
-                            new RlcChannelTreeWidgetItem(this, tap_info->ueid, tap_info->rlcMode,
+                            new RlcChannelTreeWidgetItem(this, tap_info->rat, tap_info->ueid, tap_info->rlcMode,
                                                          tap_info->channelType, tap_info->channelId);
                 }
                 break;
@@ -505,7 +541,8 @@ public:
     }
 
     // Draw UE entry
-    void draw() {
+    void draw()
+    {
         // Fixed fields only drawn once from constructor so don't redraw here.
 
         /* Calculate bandwidths. */
@@ -516,6 +553,8 @@ public:
                                     &stats_.DL_time_stop,
                                     stats_.DL_total_bytes);
 
+        setText(col_rat_,    (rat_ == RLC_RAT_LTE) ? QString("LTE") : QString("NR"));
+
         // Uplink.
         setText(col_ul_frames_,  QString::number(stats_.UL_frames));
         setText(col_ul_bytes_,   QString::number(stats_.UL_total_bytes));
@@ -564,35 +603,63 @@ public:
     }
 
     // Filter expression for UE.
-    const QString filterExpression(bool showSR, bool showRACH) {
+    const QString filterExpression(bool showSR, bool showRACH)
+    {
         // Create an expression to match with all traffic for this UE.
         QString filter_expr;
 
         // Are we taking RLC PDUs from MAC, or not?
         if (!recent.gui_rlc_use_pdus_from_mac) {
-            filter_expr += QString("not mac-lte and ");
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString("not mac-lte and ");
+            }
+            else {
+                filter_expr += QString("not mac-nr and ");
+            }
         }
         else {
-            filter_expr += QString("mac-lte and ");
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString("mac-lte and ");
+            }
+            else {
+                filter_expr += QString("mac-nr and ");
+            }
         }
 
         if (showSR) {
-            filter_expr += QString("(mac-lte.sr-req and mac-lte.ueid == %1) or (").arg(ueid_);
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString("(mac-lte.sr-req and mac-lte.ueid == %1) or (").arg(ueid_);
+            }
         }
 
         if (showRACH) {
-            filter_expr += QString("(mac-lte.rar or (mac-lte.preamble-sent and mac-lte.ueid == %1)) or (").arg(ueid_);
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString("(mac-lte.rar or (mac-lte.preamble-sent and mac-lte.ueid == %1)) or (").arg(ueid_);
+            }
+            else {
+                filter_expr += QString("mac-nr.rar or ");
+            }
         }
 
-        filter_expr += QString("rlc-lte.ueid==%1").arg(ueid_);
+        // Must match UE
+        if (rat_ == RLC_RAT_LTE) {
+            filter_expr += QString("rlc-lte.ueid==%1").arg(ueid_);
+        }
+        else {
+            filter_expr += QString("rlc-nr.ueid==%1").arg(ueid_);
+        }
 
         // Close () if open because of SR
         if (showSR) {
-            filter_expr += QString(")");
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString(")");
+            }
         }
         // Close () if open because of RACH
         if (showRACH) {
-            filter_expr += QString(")");
+            if (rat_ == RLC_RAT_LTE) {
+                filter_expr += QString(")");
+            }
         }
 
         return filter_expr;
@@ -623,6 +690,7 @@ public:
     }
 
 private:
+    uint8_t  rat_;
     unsigned ueid_;
     rlc_ue_stats stats_;
 
@@ -633,15 +701,16 @@ private:
 };
 
 
-// Only the first 3 columns headings differ between UE and channel rows.
-
-static const QString ue_col_0_title_ = QObject::tr("UE Id");
-static const QString ue_col_1_title_ = QObject::tr("");
+// Only the first 4 columns headings differ between UE and channel rows.
+static const QString ue_col_0_title_ = QObject::tr("RAT");
+static const QString ue_col_1_title_ = QObject::tr("UE Id");
 static const QString ue_col_2_title_ = QObject::tr("");
+static const QString ue_col_3_title_ = QObject::tr("");
 
-static const QString channel_col_0_title_ = QObject::tr("Name");
-static const QString channel_col_1_title_ = QObject::tr("Mode");
-static const QString channel_col_2_title_ = QObject::tr("Priority");
+static const QString channel_col_0_title_ = QObject::tr("");
+static const QString channel_col_1_title_ = QObject::tr("Name");
+static const QString channel_col_2_title_ = QObject::tr("Mode");
+static const QString channel_col_3_title_ = QObject::tr("Priority");
 
 
 
@@ -654,7 +723,7 @@ LteRlcStatisticsDialog::LteRlcStatisticsDialog(QWidget &parent, CaptureFile &cf,
     cf_(cf),
     packet_count_(0)
 {
-    setWindowSubtitle(tr("LTE RLC Statistics"));
+    setWindowSubtitle(tr("3GPP RLC Statistics"));
     loadGeometry((parent.width() * 5) / 5, (parent.height() * 3) / 4, "LTERLCStatisticsDialog");
 
     // Create a grid for filtering-related widgetsto also appear in layout.
@@ -692,7 +761,7 @@ LteRlcStatisticsDialog::LteRlcStatisticsDialog(QWidget &parent, CaptureFile &cf,
     filter_controls_grid->addWidget(useRLCFramesFromMacCheckBox_);
 
     QStringList header_labels = QStringList()
-            << "" << "" << ""
+            << "" << "" << "" << ""
             << tr("UL Frames") << tr("UL Bytes") << tr("UL MB/s")
             << tr("UL ACKs") << tr("UL NACKs") << tr("UL Missing")
             << tr("DL Frames") << tr("DL Bytes") << tr("DL MB/s")
@@ -705,6 +774,9 @@ LteRlcStatisticsDialog::LteRlcStatisticsDialog(QWidget &parent, CaptureFile &cf,
     // resizeColumnToContents doesn't work well here, so set sizes manually.
     for (int col = 0; col < statsTreeWidget()->columnCount() - 1; col++) {
         switch (col) {
+            case col_rat_:
+                statsTreeWidget()->setColumnWidth(col, one_em * 3);
+                break;
             case col_ueid_:
                 statsTreeWidget()->setColumnWidth(col, one_em * 7);
                 break;
@@ -770,24 +842,33 @@ void LteRlcStatisticsDialog::tapReset(void *ws_dlg_ptr)
 
 // Process the tap info from a dissected RLC PDU.
 // Returns TAP_PACKET_REDRAW if a redraw is needed, TAP_PACKET_DONT_REDRAW otherwise.
-tap_packet_status LteRlcStatisticsDialog::tapPacket(void *ws_dlg_ptr, struct _packet_info *, epan_dissect *, const void *rlc_lte_tap_info_ptr, tap_flags_t)
+tap_packet_status LteRlcStatisticsDialog::tapPacket(void *ws_dlg_ptr, struct _packet_info *, epan_dissect *, const void *rlc_3gpp_tap_info_ptr, tap_flags_t)
 {
     // Look up dialog.
     LteRlcStatisticsDialog *ws_dlg = static_cast<LteRlcStatisticsDialog *>(ws_dlg_ptr);
-    const rlc_lte_tap_info *rlt_info  = (const rlc_lte_tap_info *) rlc_lte_tap_info_ptr;
+    const rlc_3gpp_tap_info *rlt_info  = (const rlc_3gpp_tap_info *) rlc_3gpp_tap_info_ptr;
     if (!ws_dlg || !rlt_info) {
         return TAP_PACKET_DONT_REDRAW;
     }
 
+    // Are we ignoring RLC frames that were found in MAC frames, or only those
+    // that were logged separately?
+    if ((!recent.gui_rlc_use_pdus_from_mac &&  rlt_info->loggedInMACFrame) ||
+         (recent.gui_rlc_use_pdus_from_mac && !rlt_info->loggedInMACFrame)) {
+        return TAP_PACKET_DONT_REDRAW;
+    }
+
     ws_dlg->incFrameCount();
 
-    // Look for this UE (TODO: avoid linear search if have lots of UEs in capture...)
+    // Look for this UE (TODO: avoid linear search if have lots of UEs in capture?)
     RlcUeTreeWidgetItem *ue_ti = NULL;
     for (int i = 0; i < ws_dlg->statsTreeWidget()->topLevelItemCount(); i++) {
         QTreeWidgetItem *ti = ws_dlg->statsTreeWidget()->topLevelItem(i);
         if (ti->type() != rlc_ue_row_type_) continue;
+        // Get UE object for this entry
         RlcUeTreeWidgetItem *cur_ru_ti = static_cast<RlcUeTreeWidgetItem*>(ti);
 
+        // Does it match this tap?
         if (cur_ru_ti->isMatch(rlt_info)) {
             ue_ti = cur_ru_ti;
             break;
@@ -798,7 +879,10 @@ tap_packet_status LteRlcStatisticsDialog::tapPacket(void *ws_dlg_ptr, struct _pa
         // Existing UE wasn't found so create a new one.
         ue_ti = new RlcUeTreeWidgetItem(ws_dlg->statsTreeWidget(), rlt_info);
         for (int col = 0; col < ws_dlg->statsTreeWidget()->columnCount(); col++) {
-            ue_ti->setTextAlignment(col, ws_dlg->statsTreeWidget()->headerItem()->textAlignment(col));
+            // int QTreeWidgetItem::textAlignment(int column) const
+            // Returns the text alignment for the label in the given column.
+            // Note: This function returns an int for historical reasons. It will be corrected to return Qt::Alignment in Qt 7.
+            ue_ti->setTextAlignment(col, static_cast<Qt::Alignment>(ws_dlg->statsTreeWidget()->headerItem()->textAlignment(col)));
         }
     }
 
@@ -839,6 +923,7 @@ void LteRlcStatisticsDialog::useRLCFramesFromMacCheckBoxToggled(bool state)
     fillTree();
 }
 
+// Return a filter expression for currently selected UE or bearer row
 const QString LteRlcStatisticsDialog::filterExpression()
 {
     QString filter_expr;
@@ -861,7 +946,7 @@ const QString LteRlcStatisticsDialog::filterExpression()
 
 void LteRlcStatisticsDialog::fillTree()
 {
-    if (!registerTapListener("rlc-lte",
+    if (!registerTapListener("rlc-3gpp",
                              this,
                              displayFilter_.toLatin1().data(),
                              TL_REQUIRES_NOTHING,
@@ -901,14 +986,16 @@ void LteRlcStatisticsDialog::updateHeaderLabels()
         statsTreeWidget()->selectedItems()[0]->type() == rlc_channel_row_type_) {
 
         // UE column headings.
-        statsTreeWidget()->headerItem()->setText(col_ueid_, channel_col_0_title_);
-        statsTreeWidget()->headerItem()->setText(col_mode_, channel_col_1_title_);
-        statsTreeWidget()->headerItem()->setText(col_priority_, channel_col_2_title_);
+        statsTreeWidget()->headerItem()->setText(col_rat_, channel_col_0_title_);
+        statsTreeWidget()->headerItem()->setText(col_ueid_, channel_col_1_title_);
+        statsTreeWidget()->headerItem()->setText(col_mode_, channel_col_2_title_);
+        statsTreeWidget()->headerItem()->setText(col_priority_, channel_col_3_title_);
     } else {
         // Channel column headings.
-        statsTreeWidget()->headerItem()->setText(col_ueid_, ue_col_0_title_);
-        statsTreeWidget()->headerItem()->setText(col_mode_, ue_col_1_title_);
-        statsTreeWidget()->headerItem()->setText(col_priority_, ue_col_2_title_);
+        statsTreeWidget()->headerItem()->setText(col_rat_, ue_col_0_title_);
+        statsTreeWidget()->headerItem()->setText(col_ueid_, ue_col_1_title_);
+        statsTreeWidget()->headerItem()->setText(col_mode_, ue_col_2_title_);
+        statsTreeWidget()->headerItem()->setText(col_priority_, ue_col_3_title_);
     }
 }
 
@@ -922,11 +1009,15 @@ void LteRlcStatisticsDialog::captureFileClosing()
 // Launch a UL graph for the currently-selected channel.
 void LteRlcStatisticsDialog::launchULGraphButtonClicked()
 {
-    if (statsTreeWidget()->selectedItems().count() > 0 && statsTreeWidget()->selectedItems()[0]->type() == rlc_channel_row_type_) {
+    if (statsTreeWidget()->selectedItems().count() > 0 &&
+        statsTreeWidget()->selectedItems()[0]->type() == rlc_channel_row_type_) {
+
         // Get the channel item.
         QTreeWidgetItem *ti = statsTreeWidget()->selectedItems()[0];
         RlcChannelTreeWidgetItem *rc_ti = static_cast<RlcChannelTreeWidgetItem*>(ti);
+        // Launch the graph.
         emit launchRLCGraph(true,
+                            rc_ti->get_rat(),
                             rc_ti->get_ueid(),
                             rc_ti->get_mode(),
                             rc_ti->get_channelType(),
@@ -943,6 +1034,7 @@ void LteRlcStatisticsDialog::launchDLGraphButtonClicked()
         QTreeWidgetItem *ti = statsTreeWidget()->selectedItems()[0];
         RlcChannelTreeWidgetItem *rc_ti = static_cast<RlcChannelTreeWidgetItem*>(ti);
         emit launchRLCGraph(true,
+                            rc_ti->get_rat(),
                             rc_ti->get_ueid(),
                             rc_ti->get_mode(),
                             rc_ti->get_channelType(),
@@ -979,7 +1071,8 @@ QList<QVariant> LteRlcStatisticsDialog::treeItemData(QTreeWidgetItem *item) cons
 // Stat command + args
 
 static void
-lte_rlc_statistics_init(const char *args, void*) {
+lte_rlc_statistics_init(const char *args, void*)
+{
     QStringList args_l = QString(args).split(',');
     QByteArray filter;
     if (args_l.length() > 2) {
@@ -989,12 +1082,12 @@ lte_rlc_statistics_init(const char *args, void*) {
 }
 
 static stat_tap_ui lte_rlc_statistics_ui = {
-    REGISTER_STAT_GROUP_TELEPHONY_LTE,
+    REGISTER_TELEPHONY_GROUP_3GPP_UU,
     QT_TRANSLATE_NOOP("LteRlcStatisticsDialog", "RLC Statistics"),
-    "rlc-lte,stat",
+    "rlc-3gpp,stat",            // cli_string
     lte_rlc_statistics_init,
-    0,
-    NULL
+    0,                          // nparams
+    NULL                        // params
 };
 
 extern "C" {
