@@ -7,8 +7,6 @@
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#include <glib.h>
-
 #include <epan/tap.h>
 #include <epan/conversation.h>
 #include <epan/conversation_table.h>
@@ -32,7 +30,7 @@
 
 static QString formatString(qlonglong value)
 {
-    return QLocale::system().formattedDataSize(value, QLocale::DataSizeSIFormat);
+    return QLocale().formattedDataSize(value, 0, QLocale::DataSizeSIFormat);
 }
 
 ATapDataModel::ATapDataModel(dataModelType type, int protoId, QString filter, QObject *parent):
@@ -61,7 +59,14 @@ ATapDataModel::ATapDataModel(dataModelType type, int protoId, QString filter, QO
 
 ATapDataModel::~ATapDataModel()
 {
-    remove_tap_listener(hash());
+    /* Only remove the tap if we come from a enabled model */
+    if (!_disableTap)
+        remove_tap_listener(hash());
+
+    if (_type == ATapDataModel::DATAMODEL_ENDPOINT)
+        reset_endpoint_table_data(&hash_);
+    else if (_type == ATapDataModel::DATAMODEL_CONVERSATION)
+        reset_conversation_table_data(&hash_);
 }
 
 int ATapDataModel::protoId() const
@@ -83,10 +88,12 @@ bool ATapDataModel::hasGeoIPData()
     while (!coordsFound && row < count)
     {
         QModelIndex idx = index(row, 0);
-        if (_type == ATapDataModel::DATAMODEL_ENDPOINT)
-            coordsFound = qobject_cast<EndpointDataModel *>(this)->data(idx, ATapDataModel::GEODATA_AVAILABLE).toBool();
-        else if (_type == ATapDataModel::DATAMODEL_CONVERSATION)
-            coordsFound = qobject_cast<ConversationDataModel *>(this)->data(idx, ATapDataModel::GEODATA_AVAILABLE).toBool();
+        if (!data(idx, ATapDataModel::ROW_IS_FILTERED).toBool()) {
+            if (_type == ATapDataModel::DATAMODEL_ENDPOINT)
+                coordsFound = qobject_cast<EndpointDataModel *>(this)->data(idx, ATapDataModel::GEODATA_AVAILABLE).toBool();
+            else if (_type == ATapDataModel::DATAMODEL_CONVERSATION)
+                coordsFound = qobject_cast<ConversationDataModel *>(this)->data(idx, ATapDataModel::GEODATA_AVAILABLE).toBool();
+        }
         row++;
     }
 
@@ -359,6 +366,10 @@ QVariant EndpointDataModel::headerData(int section, Qt::Orientation orientation,
                 return tr("Country"); break;
             case ENDP_COLUMN_GEO_CITY:
                 return tr("City"); break;
+            case ENDP_COLUMN_GEO_LATITUDE:
+                return tr("Latitude"); break;
+            case ENDP_COLUMN_GEO_LONGITUDE:
+                return tr("Longitude"); break;
             case ENDP_COLUMN_GEO_AS_NUM:
                 return tr("AS Number"); break;
             case ENDP_COLUMN_GEO_AS_ORG:
@@ -443,9 +454,14 @@ QVariant EndpointDataModel::data(const QModelIndex &idx, int role) const
                 qlonglong totalPackets = (qlonglong)(item->tx_frames_total + item->rx_frames_total);
                 qlonglong packets = (qlonglong)(item->tx_frames + item->rx_frames);
                 percent = totalPackets == 0 ? 0 : (double) packets * 100 / (double) totalPackets;
-                return QString::number(percent, 'f', 2) + "%";
             }
-            return role == Qt::DisplayRole ? QString::number(percent, 'f', 2) + "%" : (QVariant)percent;
+            QString rounded = QString::number(percent, 'f', 2);
+            /* Qt guarantees that this roundtrip conversion compares equally,
+             * so filtering with equality will work as expected.
+             * Perhaps the UNFORMATTED_DISPLAYDATA role shoud be split
+             * into one used for raw data export, and one used for comparisons.
+             */
+            return role == Qt::DisplayRole ? rounded + "%" : QVariant(rounded.toDouble());
         }
         case ENDP_COLUMN_PKT_AB:
             return role == Qt::DisplayRole ? QString("%L1").arg((qlonglong)item->tx_frames) : QVariant((qlonglong) item->tx_frames);
@@ -465,6 +481,16 @@ QVariant EndpointDataModel::data(const QModelIndex &idx, int role) const
                 return QVariant(mmdb_lookup->city);
             }
             return QVariant();
+        case ENDP_COLUMN_GEO_LATITUDE:
+            if (mmdb_lookup && mmdb_lookup->found && mmdb_lookup->latitude >= -90.0 && mmdb_lookup->latitude <= 90.0) {
+                return role == Qt::DisplayRole ? QString("%L1" UTF8_DEGREE_SIGN).arg(mmdb_lookup->latitude) : QVariant(mmdb_lookup->latitude);
+            }
+            return QVariant();
+        case ENDP_COLUMN_GEO_LONGITUDE:
+            if (mmdb_lookup && mmdb_lookup->found && mmdb_lookup->longitude >= -180.0 && mmdb_lookup->longitude <= 180.0) {
+                return role == Qt::DisplayRole ? QString("%L1" UTF8_DEGREE_SIGN).arg(mmdb_lookup->longitude) : QVariant(mmdb_lookup->longitude);
+            }
+            return QVariant();
         case ENDP_COLUMN_GEO_AS_NUM:
             if (mmdb_lookup && mmdb_lookup->found && mmdb_lookup->as_number) {
                 return QVariant(mmdb_lookup->as_number);
@@ -503,7 +529,9 @@ QVariant EndpointDataModel::data(const QModelIndex &idx, int role) const
         return ipAddress;
     }
 #endif
-    else if (role == ATapDataModel::DATA_ADDRESS_TYPE) {
+    else if (role == ATapDataModel::PROTO_ID) {
+        return protoId();
+    } else if (role == ATapDataModel::DATA_ADDRESS_TYPE) {
         if (idx.column() == EndpointDataModel::ENDP_COLUMN_ADDR)
             return (int)item->myaddress.type;
         return (int) AT_NONE;
@@ -557,6 +585,9 @@ void ConversationDataModel::doDataUpdate()
 
 int ConversationDataModel::columnCount(const QModelIndex &) const
 {
+    if(tap()=="tcp")
+        return CONV_TCP_EXT_NUM_COLUMNS;
+
     return CONV_NUM_COLUMNS;
 }
 
@@ -602,6 +633,15 @@ QVariant ConversationDataModel::headerData(int section, Qt::Orientation orientat
         case CONV_COLUMN_BPS_BA:
             return tr("Bits/s B " UTF8_RIGHTWARDS_ARROW " A"); break;
         }
+        /* Extended conversations columns, e.g. TCP */
+        if(tap()=="tcp") {
+            switch (section) {
+            case CONV_TCP_EXT_COLUMN_A:
+                return tr("Flows"); break;
+            default :
+                ws_assert_not_reached(); break;
+            }
+        }
     } else if (role == Qt::TextAlignmentRole) {
         if (section == CONV_COLUMN_SRC_ADDR || section == CONV_COLUMN_DST_ADDR)
             return Qt::AlignLeft;
@@ -673,7 +713,10 @@ QVariant ConversationDataModel::data(const QModelIndex &idx, int role) const
             return role == Qt::DisplayRole ? formatString((qlonglong)conv_item->tx_bytes + conv_item->rx_bytes) :
                 QVariant((qlonglong)conv_item->tx_bytes + conv_item->rx_bytes);
         case CONV_COLUMN_CONV_ID:
-            return (int) conv_item->conv_id;
+            if(conv_item->conv_id!=CONV_ID_UNSET) {
+                return (int) conv_item->conv_id;
+            }
+            break;
         case CONV_COLUMN_PACKETS_TOTAL:
         {
             qlonglong packets = 0;
@@ -690,7 +733,14 @@ QVariant ConversationDataModel::data(const QModelIndex &idx, int role) const
                 qlonglong packets = (qlonglong)(conv_item->tx_frames + conv_item->rx_frames);
                 percent = totalPackets == 0 ? 0 : (double) packets * 100 / (double) totalPackets;
             }
-            return role == Qt::DisplayRole ? QString::number(percent, 'f', 2) + "%" : (QVariant)percent;
+            QString rounded = QString::number(percent, 'f', 2);
+            /* Qt guarantees that this roundtrip conversion compares equally,
+             * so filtering with equality will work as expected.
+             * XXX: Perhaps the UNFORMATTED_DISPLAYDATA role shoud be split
+             * into one used for raw data export and comparisons with each
+             * other, and another for comparing with filters?
+             */
+            return role == Qt::DisplayRole ? rounded + "%" : QVariant(rounded.toDouble());
         }
         case CONV_COLUMN_PKT_AB:
         {
@@ -712,8 +762,21 @@ QVariant ConversationDataModel::data(const QModelIndex &idx, int role) const
 
             if (_absoluteTime) {
                 nstime_t *abs_time = &conv_item->start_abs_time;
+                /* XXX: QDateTime only supports millisecond resolution,
+                 * and we have microseconds or nanoseconds.
+                 * Should we use something else, particularly for exporting
+                 * raw data? GDateTime handles microseconds.
+                 */
                 QDateTime abs_dt = QDateTime::fromMSecsSinceEpoch(nstime_to_msec(abs_time));
-                return role == Qt::DisplayRole ? abs_dt.toString("hh:mm:ss.zzzz") : (QVariant)abs_dt;
+                if (role == Qt::DisplayRole) {
+                    if (_maxRelStopTime >= 24*60*60) {
+                        return abs_dt.toString(Qt::ISODateWithMs);
+                    } else {
+                        return abs_dt.time().toString(Qt::ISODateWithMs);
+                    }
+                } else {
+                    return QVariant(abs_dt);
+                }
             } else {
                 return role == Qt::DisplayRole ?
                     QString::number(nstime_to_sec(&conv_item->start_time), 'f', width) :
@@ -726,9 +789,21 @@ QVariant ConversationDataModel::data(const QModelIndex &idx, int role) const
             return role == Qt::DisplayRole ? QString::number(duration, 'f', width) : (QVariant)duration;
         }
         case CONV_COLUMN_BPS_AB:
-            return bpsCalculated ? (role == Qt::DisplayRole ? formatString(bps_ab) : QVariant((qlonglong)bps_ab)): QVariant();
+            return bpsCalculated ? (role == Qt::DisplayRole ? gchar_free_to_qstring(format_size((int64_t)bps_ab, FORMAT_SIZE_UNIT_BITS_S, FORMAT_SIZE_PREFIX_SI)) : QVariant((qlonglong)bps_ab)): QVariant();
         case CONV_COLUMN_BPS_BA:
-            return bpsCalculated ? (role == Qt::DisplayRole ? formatString(bps_ba) : QVariant((qlonglong)bps_ba)): QVariant();
+            return bpsCalculated ? (role == Qt::DisplayRole ? gchar_free_to_qstring(format_size((int64_t)bps_ba, FORMAT_SIZE_UNIT_BITS_S, FORMAT_SIZE_PREFIX_SI)) : QVariant((qlonglong)bps_ba)): QVariant();
+        }
+        /* Extended conversations columns, e.g. TCP */
+        if(tap()=="tcp") {
+            switch(idx.column()) {
+            case CONV_TCP_EXT_COLUMN_A:
+                {
+                qlonglong flows = (qlonglong)conv_item->ext_tcp.flows;
+                return role == Qt::DisplayRole ? QString("%L1").arg(flows) : (QVariant)flows; break;
+                }
+            default :
+                ws_assert_not_reached(); break;
+            }
         }
     } else if (role == Qt::ToolTipRole) {
         if (idx.column() == CONV_COLUMN_START || idx.column() == CONV_COLUMN_DURATION)
@@ -751,6 +826,8 @@ QVariant ConversationDataModel::data(const QModelIndex &idx, int role) const
         }
     } else if (role == ATapDataModel::ENDPOINT_DATATYPE) {
         return (int)(conv_item->ctype);
+    } else if (role == ATapDataModel::PROTO_ID) {
+        return protoId();
     } else if (role == ATapDataModel::CONVERSATION_ID) {
         return (int)(conv_item->conv_id);
     } else if (role == ATapDataModel::ROW_IS_FILTERED) {
@@ -790,11 +867,15 @@ conv_item_t * ConversationDataModel::itemForRow(int row)
 
 bool ConversationDataModel::showConversationId(int row) const
 {
-    if (!storage_ || row >= (int) storage_->len)
+    if (!storage_ || row < 0 || row >= (int) storage_->len)
         return false;
 
     conv_item_t *conv_item = (conv_item_t *)&g_array_index(storage_, conv_item_t, row);
-    if (conv_item && (conv_item->ctype == CONVERSATION_TCP || conv_item->ctype == CONVERSATION_UDP))
+    if (conv_item && (conv_item->ctype == CONVERSATION_TCP ||
+                      conv_item->ctype == CONVERSATION_UDP ||
+                      conv_item->ctype == CONVERSATION_IP  ||
+                      conv_item->ctype == CONVERSATION_IPV6||
+                      conv_item->ctype == CONVERSATION_ETH))
         return true;
     return false;
 }
