@@ -322,19 +322,11 @@ private:
         QFontMetrics fm = QFontMetrics(layout_->regularFont());
 
         painter->setFont(layout_->regularFont());
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
         int label_w = fm.horizontalAdvance(label);
-#else
-        int label_w = fm.width(label);
-#endif
         if (label_w > label_rect.width()) {
             painter->setFont(layout_->smallFont());
             fm = QFontMetrics(layout_->smallFont());
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
             label_w = fm.horizontalAdvance(label);
-#else
-            label_w = fm.width(label);
-#endif
             if (label_w > label_rect.width()) {
                 // XXX Use parent+ItemClipsChildrenToShape or setScale instead?
                 label = fm.elidedText(label, Qt::ElideRight, label_rect.width());
@@ -467,27 +459,28 @@ void PacketDiagram::contextMenuEvent(QContextMenuEvent *event)
     }
 
     QAction *action;
-    QMenu ctx_menu(this);
+    QMenu *ctx_menu = new QMenu(this);
+    ctx_menu->setAttribute(Qt::WA_DeleteOnClose);
 
-    action = ctx_menu.addAction(tr("Show Field Values"));
+    action = ctx_menu->addAction(tr("Show Field Values"));
     action->setCheckable(true);
     action->setChecked(layout_->showFields());
     connect(action, &QAction::toggled, this, &PacketDiagram::showFieldsToggled);
 
-    ctx_menu.addSeparator();
+    ctx_menu->addSeparator();
 
-    action = ctx_menu.addAction(tr("Save Diagram As…"));
+    action = ctx_menu->addAction(tr("Save Diagram As…"));
     connect(action, &QAction::triggered, this, &PacketDiagram::saveAsTriggered);
 
-    action = ctx_menu.addAction(tr("Copy as Raster Image"));
+    action = ctx_menu->addAction(tr("Copy as Raster Image"));
     connect(action, &QAction::triggered, this, &PacketDiagram::copyAsRasterTriggered);
 
 #if defined(QT_SVG_LIB) && !defined(Q_OS_MAC)
-    action = ctx_menu.addAction(tr("…as SVG"));
+    action = ctx_menu->addAction(tr("…as SVG"));
     connect(action, &QAction::triggered, this, &PacketDiagram::copyAsSvgTriggered);
 #endif
 
-    ctx_menu.exec(event->globalPos());
+    ctx_menu->popup(event->globalPos());
 }
 
 void PacketDiagram::connectToMainWindow()
@@ -563,11 +556,7 @@ void PacketDiagram::addDiagram(proto_node *tl_node)
     qreal y_bottom = y_pos_ + bit_width;
     QGraphicsItem *tl_item = scene()->addLine(x, y_bottom, x + diag_w, y_bottom);
     QFontMetrics sfm = QFontMetrics(layout_->smallFont());
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
     int space_w = sfm.horizontalAdvance(' ');
-#else
-    int space_w = sfm.width(' ');
-#endif
 #ifdef Q_OS_WIN
     // t_item->boundingRect() has a pixel of space on the left on my (gcc)
     // Windows VM.
@@ -762,7 +751,7 @@ void PacketDiagram::showFieldsToggled(bool checked)
 void PacketDiagram::saveAsTriggered()
 {
     QString file_name, extension;
-    QDir path(mainApp->lastOpenDir());
+    QDir path(mainApp->openDialogInitialDir());
     QString png_filter = tr("Portable Network Graphics (*.png)");
     QString bmp_filter = tr("Windows Bitmap (*.bmp)");
     // Gaze upon my beautiful graph with lossy artifacts!
