@@ -9,13 +9,11 @@
 
 #include <config.h>
 
-#include <glib.h>
-
 #include <ui/qt/widgets/additional_toolbar.h>
 #include <ui/qt/widgets/apply_line_edit.h>
 #include <ui/qt/utils/qt_ui_utils.h>
 #include <ui/qt/utils/variant_pointer.h>
-#include <ui/qt/wireshark_application.h>
+#include <ui/qt/main_application.h>
 
 #include <QLabel>
 #include <QLineEdit>
@@ -40,42 +38,42 @@ AdditionalToolBar::~AdditionalToolBar()
 
 AdditionalToolBar * AdditionalToolBar::create(QWidget * parent, ext_toolbar_t * toolbar)
 {
-    if ( g_list_length( toolbar->children ) == 0 )
+    if (g_list_length(toolbar->children) == 0)
         return NULL;
 
     AdditionalToolBar * result = new AdditionalToolBar(toolbar, parent);
     result->setMovable(false);
     result->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
-    result->layout()->setMargin(0);
+    result->layout()->setContentsMargins(0, 0, 0, 0);
     result->layout()->setSpacing(4);
 
     GList * walker = toolbar->children;
     bool spacerNeeded = true;
 
-    while ( walker && walker->data )
+    while (walker && walker->data)
     {
-        ext_toolbar_t * item = (ext_toolbar_t *)walker->data;
-        if ( item->type == EXT_TOOLBAR_ITEM )
+        ext_toolbar_t * item = gxx_list_data(ext_toolbar_t *, walker);
+        if (item->type == EXT_TOOLBAR_ITEM)
         {
-            if ( item->item_type == EXT_TOOLBAR_STRING )
+            if (item->item_type == EXT_TOOLBAR_STRING)
                 spacerNeeded = false;
 
             QAction * newAction = new AdditionalToolbarWidgetAction(item, result);
-            if ( newAction )
+            if (newAction)
             {
                 result->addAction(newAction);
-                /* Necessary, because enable state is resetted upon adding the action */
+                /* Necessary, because enable state is reset upon adding the action */
                 result->actions()[result->actions().count() - 1]->setEnabled(!item->capture_only);
             }
         }
 
-        walker = g_list_next ( walker );
+        walker = gxx_list_next (walker);
     }
 
-    if ( result->children().count() == 0 )
-        return NULL;
+    if (result->children().count() == 0)
+        return Q_NULLPTR;
 
-    if ( spacerNeeded )
+    if (spacerNeeded)
     {
         QWidget * empty = new QWidget();
         empty->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Preferred);
@@ -100,20 +98,20 @@ AdditionalToolbarWidgetAction::AdditionalToolbarWidgetAction(ext_toolbar_t * ite
 : QWidgetAction(parent),
   toolbar_item(item)
 {
-    connect(wsApp, SIGNAL(captureActive(int)), this, SLOT(captureActive(int)));
+    connect(mainApp, &MainApplication::captureActive, this, &AdditionalToolbarWidgetAction::captureActive);
 }
 
 AdditionalToolbarWidgetAction::AdditionalToolbarWidgetAction(const AdditionalToolbarWidgetAction & copy_object)
 :  QWidgetAction(copy_object.parent()),
    toolbar_item(copy_object.toolbar_item)
 {
-    connect(wsApp, SIGNAL(captureActive(int)), this, SLOT(captureActive(int)));
+    connect(mainApp, &MainApplication::captureActive, this, &AdditionalToolbarWidgetAction::captureActive);
 }
 
 
 void AdditionalToolbarWidgetAction::captureActive(int activeCaptures)
 {
-    if ( toolbar_item && toolbar_item->capture_only )
+    if (toolbar_item && toolbar_item->capture_only)
     {
         setEnabled(activeCaptures != 0);
     }
@@ -126,10 +124,10 @@ QWidget * AdditionalToolbarWidgetAction::createWidget(QWidget * parent)
 {
     QWidget * barItem = 0;
 
-    if ( toolbar_item->type != EXT_TOOLBAR_ITEM )
+    if (toolbar_item->type != EXT_TOOLBAR_ITEM)
         return barItem;
 
-    switch ( toolbar_item->item_type )
+    switch (toolbar_item->item_type)
     {
     case EXT_TOOLBAR_BUTTON:
         barItem = createButton(toolbar_item, parent);
@@ -145,7 +143,7 @@ QWidget * AdditionalToolbarWidgetAction::createWidget(QWidget * parent)
         break;
     }
 
-    if ( ! barItem )
+    if (! barItem)
         return 0;
 
     barItem->setToolTip(toolbar_item->tooltip);
@@ -159,19 +157,19 @@ QWidget * AdditionalToolbarWidgetAction::createWidget(QWidget * parent)
 }
 
 static void
-toolbar_button_cb(gpointer item, gpointer item_data, gpointer user_data)
+toolbar_button_cb(void *item, void *item_data, void *user_data)
 {
-    if ( ! item || ! item_data || ! user_data )
+    if (! item || ! item_data || ! user_data)
         return;
 
     QPushButton * widget = (QPushButton *)(item_data);
     ext_toolbar_update_t * update_entry = (ext_toolbar_update_t *)user_data;
 
-    if ( widget )
+    if (widget)
     {
-        if ( update_entry->type == EXT_TOOLBAR_UPDATE_VALUE )
-            widget->setText((gchar *)update_entry->user_data);
-        else if ( update_entry->type == EXT_TOOLBAR_SET_ACTIVE )
+        if (update_entry->type == EXT_TOOLBAR_UPDATE_VALUE)
+            widget->setText((char *)update_entry->user_data);
+        else if (update_entry->type == EXT_TOOLBAR_SET_ACTIVE)
         {
             bool enableState = GPOINTER_TO_INT(update_entry->user_data) == 1;
             widget->setEnabled(enableState);
@@ -182,12 +180,12 @@ toolbar_button_cb(gpointer item, gpointer item_data, gpointer user_data)
 
 QWidget * AdditionalToolbarWidgetAction::createButton(ext_toolbar_t * item, QWidget * parent)
 {
-    if ( ! item || item->type != EXT_TOOLBAR_ITEM || item->item_type != EXT_TOOLBAR_BUTTON )
+    if (! item || item->type != EXT_TOOLBAR_ITEM || item->item_type != EXT_TOOLBAR_BUTTON)
         return 0;
 
     QPushButton * button = new QPushButton(item->name, parent);
     button->setText(item->name);
-    connect(button, SIGNAL(clicked()), this, SLOT(onButtonClicked()));
+    connect(button, &QPushButton::clicked, this, &AdditionalToolbarWidgetAction::onButtonClicked);
 
     ext_toolbar_register_update_cb(item, (ext_toolbar_action_cb)&toolbar_button_cb, (void *)button);
 
@@ -195,27 +193,27 @@ QWidget * AdditionalToolbarWidgetAction::createButton(ext_toolbar_t * item, QWid
 }
 
 static void
-toolbar_boolean_cb(gpointer item, gpointer item_data, gpointer user_data)
+toolbar_boolean_cb(void *item, void *item_data, void *user_data)
 {
-    if ( ! item || ! item_data || ! user_data )
+    if (! item || ! item_data || ! user_data)
         return;
 
     QCheckBox * widget = (QCheckBox *)(item_data);
 
     ext_toolbar_update_t * update_entry = (ext_toolbar_update_t *)user_data;
 
-    if ( update_entry->type == EXT_TOOLBAR_UPDATE_VALUE )
+    if (update_entry->type == EXT_TOOLBAR_UPDATE_VALUE)
     {
         bool oldState = false;
-        if ( update_entry->silent )
+        if (update_entry->silent)
             oldState = widget->blockSignals(true);
 
         widget->setCheckState(GPOINTER_TO_INT(update_entry->user_data) == 1 ? Qt::Checked : Qt::Unchecked);
 
-        if ( update_entry->silent )
+        if (update_entry->silent)
             widget->blockSignals(oldState);
     }
-    else if ( update_entry->type == EXT_TOOLBAR_SET_ACTIVE )
+    else if (update_entry->type == EXT_TOOLBAR_SET_ACTIVE)
     {
         bool enableState = GPOINTER_TO_INT(update_entry->user_data) == 1;
         widget->setEnabled(enableState);
@@ -224,7 +222,7 @@ toolbar_boolean_cb(gpointer item, gpointer item_data, gpointer user_data)
 
 QWidget * AdditionalToolbarWidgetAction::createBoolean(ext_toolbar_t * item, QWidget * parent)
 {
-    if ( ! item || item->type != EXT_TOOLBAR_ITEM || item->item_type != EXT_TOOLBAR_BOOLEAN )
+    if (! item || item->type != EXT_TOOLBAR_ITEM || item->item_type != EXT_TOOLBAR_BOOLEAN)
         return 0;
 
     QString defValue = toolbar_item->defvalue;
@@ -233,7 +231,7 @@ QWidget * AdditionalToolbarWidgetAction::createBoolean(ext_toolbar_t * item, QWi
     checkbox->setText(item->name);
     setCheckable(true);
     checkbox->setCheckState(defValue.compare("true", Qt::CaseInsensitive) == 0 ? Qt::Checked : Qt::Unchecked);
-    connect(checkbox, SIGNAL(stateChanged(int)), this, SLOT(onCheckBoxChecked(int)));
+    connect(checkbox, &QCheckBox::stateChanged, this, &AdditionalToolbarWidgetAction::onCheckBoxChecked);
 
     ext_toolbar_register_update_cb(item, (ext_toolbar_action_cb)&toolbar_boolean_cb, (void *)checkbox);
 
@@ -242,13 +240,13 @@ QWidget * AdditionalToolbarWidgetAction::createBoolean(ext_toolbar_t * item, QWi
 
 QWidget * AdditionalToolbarWidgetAction::createLabelFrame(ext_toolbar_t * item, QWidget * parent)
 {
-    if ( ! item )
+    if (! item)
         return new QWidget();
 
     QWidget * frame = new QWidget(parent);
 
     QHBoxLayout * frameLayout = new QHBoxLayout(frame);
-    frameLayout->setMargin(0);
+    frameLayout->setContentsMargins(0, 0, 0, 0);
     frameLayout->setSpacing(0);
 
     QLabel * strLabel = new QLabel(item->name, frame);
@@ -267,27 +265,27 @@ QWidget * AdditionalToolbarWidgetAction::createLabelFrame(ext_toolbar_t * item,
 }
 
 static void
-toolbar_string_cb(gpointer item, gpointer item_data, gpointer user_data)
+toolbar_string_cb(void *item, void *item_data, void *user_data)
 {
-    if ( ! item || ! item_data || ! user_data )
+    if (! item || ! item_data || ! user_data)
         return;
 
     ApplyLineEdit * edit = (ApplyLineEdit *)(item_data);
 
     ext_toolbar_update_t * update_entry = (ext_toolbar_update_t *)user_data;
 
-    if ( update_entry->type == EXT_TOOLBAR_UPDATE_VALUE )
+    if (update_entry->type == EXT_TOOLBAR_UPDATE_VALUE)
     {
         bool oldState = false;
-        if ( update_entry->silent )
+        if (update_entry->silent)
             oldState = edit->blockSignals(true);
 
-        edit->setText((gchar *)update_entry->user_data);
+        edit->setText((char *)update_entry->user_data);
 
-        if ( update_entry->silent )
+        if (update_entry->silent)
             edit->blockSignals(oldState);
     }
-    else if ( update_entry->type == EXT_TOOLBAR_SET_ACTIVE )
+    else if (update_entry->type == EXT_TOOLBAR_SET_ACTIVE)
     {
         bool enableState = GPOINTER_TO_INT(update_entry->user_data) == 1;
         edit->setEnabled(enableState);
@@ -296,7 +294,7 @@ toolbar_string_cb(gpointer item, gpointer item_data, gpointer user_data)
 
 QWidget * AdditionalToolbarWidgetAction::createTextEditor(ext_toolbar_t * item, QWidget * parent)
 {
-    if ( ! item || item->type != EXT_TOOLBAR_ITEM || item->item_type != EXT_TOOLBAR_STRING )
+    if (! item || item->type != EXT_TOOLBAR_ITEM || item->item_type != EXT_TOOLBAR_STRING)
         return 0;
 
     QWidget * frame = createLabelFrame(toolbar_item, parent);
@@ -313,7 +311,7 @@ QWidget * AdditionalToolbarWidgetAction::createTextEditor(ext_toolbar_t * item,
 
     frame->layout()->addWidget(strEdit);
 
-    connect(strEdit, SIGNAL(textApplied()), this, SLOT(sendTextToCallback()));
+    connect(strEdit, &ApplyLineEdit::textApplied, this, &AdditionalToolbarWidgetAction::sendTextToCallback);
 
     ext_toolbar_register_update_cb(item, (ext_toolbar_action_cb)&toolbar_string_cb, (void *)strEdit);
 
@@ -321,9 +319,9 @@ QWidget * AdditionalToolbarWidgetAction::createTextEditor(ext_toolbar_t * item,
 }
 
 static void
-toolbar_selector_cb(gpointer item, gpointer item_data, gpointer user_data)
+toolbar_selector_cb(void *item, void *item_data, void *user_data)
 {
-    if ( ! item || ! item_data || ! user_data )
+    if (! item || ! item_data || ! user_data)
         return;
 
     QComboBox * comboBox = (QComboBox *)(item_data);
@@ -331,70 +329,70 @@ toolbar_selector_cb(gpointer item, gpointer item_data, gpointer user_data)
 
     bool oldState = false;
 
-    if ( update_entry->silent )
+    if (update_entry->silent)
         oldState = comboBox->blockSignals(true);
 
     QStandardItemModel * sourceModel = (QStandardItemModel *)comboBox->model();
 
-    if ( update_entry->type == EXT_TOOLBAR_SET_ACTIVE )
+    if (update_entry->type == EXT_TOOLBAR_SET_ACTIVE)
     {
         bool enableState = GPOINTER_TO_INT(update_entry->user_data) == 1;
         comboBox->setEnabled(enableState);
     }
-    else if ( update_entry->type != EXT_TOOLBAR_UPDATE_DATA_REMOVE && ! update_entry->user_data )
+    else if (update_entry->type != EXT_TOOLBAR_UPDATE_DATA_REMOVE && ! update_entry->user_data)
         return;
 
-    if ( update_entry->type == EXT_TOOLBAR_UPDATE_VALUE )
+    if (update_entry->type == EXT_TOOLBAR_UPDATE_VALUE)
     {
-        QString data = QString((gchar *)update_entry->user_data);
+        QString data = QString((char *)update_entry->user_data);
 
-        for(int i = 0; i < sourceModel->rowCount(); i++)
+        for (int i = 0; i < sourceModel->rowCount(); i++)
         {
             QStandardItem * dataValue = ((QStandardItemModel *)sourceModel)->item(i, 0);
             ext_toolbar_value_t * tbValue = VariantPointer<ext_toolbar_value_t>::asPtr(dataValue->data(Qt::UserRole));
-            if ( tbValue && data.compare(QString(tbValue->value)) == 0 )
+            if (tbValue && data.compare(QString(tbValue->value)) == 0)
             {
                 comboBox->setCurrentIndex(i);
                 break;
             }
         }
     }
-    else if ( update_entry->type == EXT_TOOLBAR_UPDATE_DATA )
+    else if (update_entry->type == EXT_TOOLBAR_UPDATE_DATA)
     {
         GList * walker = (GList *)update_entry->user_data;
-        if ( g_list_length(walker) == 0 )
+        if (g_list_length(walker) == 0)
             return;
 
         sourceModel->clear();
 
-        while ( walker && walker->data )
+        while (walker && walker->data)
         {
-            ext_toolbar_value_t * listvalue = (ext_toolbar_value_t *)walker->data;
+            ext_toolbar_value_t * listvalue = gxx_list_data(ext_toolbar_value_t *, walker);
 
             QStandardItem * si = new QStandardItem(listvalue->display);
             si->setData(VariantPointer<ext_toolbar_value_t>::asQVariant(listvalue), Qt::UserRole);
             sourceModel->appendRow(si);
 
-            walker = g_list_next(walker);
+            walker = gxx_list_next(walker);
         }
     }
-    else if ( update_entry->type == EXT_TOOLBAR_UPDATE_DATABYINDEX ||
+    else if (update_entry->type == EXT_TOOLBAR_UPDATE_DATABYINDEX ||
             update_entry->type == EXT_TOOLBAR_UPDATE_DATA_ADD ||
-            update_entry->type == EXT_TOOLBAR_UPDATE_DATA_REMOVE )
+            update_entry->type == EXT_TOOLBAR_UPDATE_DATA_REMOVE)
     {
-        if ( ! update_entry->data_index )
+        if (! update_entry->data_index)
             return;
 
-        gchar * idx = (gchar *)update_entry->data_index;
-        gchar * display = (gchar *)update_entry->user_data;
+        char * idx = (char *)update_entry->data_index;
+        char * display = (char *)update_entry->user_data;
 
-        if ( update_entry->type == EXT_TOOLBAR_UPDATE_DATABYINDEX )
+        if (update_entry->type == EXT_TOOLBAR_UPDATE_DATABYINDEX)
         {
-            for ( int i = 0; i < sourceModel->rowCount(); i++ )
+            for (int i = 0; i < sourceModel->rowCount(); i++)
             {
                 QStandardItem * dataValue = sourceModel->item(i, 0);
                 ext_toolbar_value_t * entry = VariantPointer<ext_toolbar_value_t>::asPtr(dataValue->data(Qt::UserRole));
-                if ( entry && g_strcmp0( entry->value, idx) == 0 )
+                if (entry && g_strcmp0(entry->value, idx) == 0)
                 {
                     g_free(entry->display);
                     entry->display = g_strdup(display);
@@ -404,7 +402,7 @@ toolbar_selector_cb(gpointer item, gpointer item_data, gpointer user_data)
                 }
             }
         }
-        else if ( update_entry->type == EXT_TOOLBAR_UPDATE_DATA_ADD )
+        else if (update_entry->type == EXT_TOOLBAR_UPDATE_DATA_ADD)
         {
             ext_toolbar_value_t * listvalue = g_new0(ext_toolbar_value_t, 1);
             listvalue->display = g_strdup(display);
@@ -414,33 +412,33 @@ toolbar_selector_cb(gpointer item, gpointer item_data, gpointer user_data)
             si->setData(VariantPointer<ext_toolbar_value_t>::asQVariant(listvalue), Qt::UserRole);
             sourceModel->appendRow(si);
         }
-        else if ( update_entry->type == EXT_TOOLBAR_UPDATE_DATA_REMOVE )
+        else if (update_entry->type == EXT_TOOLBAR_UPDATE_DATA_REMOVE)
         {
             QList<QStandardItem *> entryList = sourceModel->findItems(display);
             /* Search for index if display did not find anything */
-            if ( entryList.size() == 0 )
+            if (entryList.size() == 0)
                 entryList = sourceModel->findItems(idx);
 
             foreach(QStandardItem *entry, entryList)
             {
                 QModelIndex index = sourceModel->indexFromItem(entry);
-                if ( index.isValid() )
+                if (index.isValid())
                     sourceModel->removeRow(index.row());
             }
         }
     }
 
-    if ( update_entry->silent )
+    if (update_entry->silent)
         comboBox->blockSignals(oldState);
 
 }
 
 QWidget * AdditionalToolbarWidgetAction::createSelector(ext_toolbar_t * item, QWidget * parent)
 {
-    if ( ! item || item->type != EXT_TOOLBAR_ITEM || item->item_type != EXT_TOOLBAR_SELECTOR )
+    if (! item || item->type != EXT_TOOLBAR_ITEM || item->item_type != EXT_TOOLBAR_SELECTOR)
         return 0;
 
-    if ( g_list_length(item->values) == 0 )
+    if (g_list_length(item->values) == 0)
         return 0;
 
     QWidget * frame = createLabelFrame(item, parent);
@@ -452,18 +450,18 @@ QWidget * AdditionalToolbarWidgetAction::createSelector(ext_toolbar_t * item, QW
 
     GList * walker = item->values;
     int selIndex = 0;
-    while ( walker && walker->data )
+    while (walker && walker->data)
     {
-        ext_toolbar_value_t * listvalue = (ext_toolbar_value_t *)walker->data;
+        ext_toolbar_value_t * listvalue = gxx_list_data(ext_toolbar_value_t *, walker);
 
         QStandardItem * si = new QStandardItem(listvalue->display);
         si->setData(VariantPointer<ext_toolbar_value_t>::asQVariant(listvalue), Qt::UserRole);
         sourceModel->appendRow(si);
 
-        if ( listvalue->is_default )
+        if (listvalue->is_default)
             selIndex = sourceModel->rowCount();
 
-        walker = g_list_next(walker);
+        walker = gxx_list_next(walker);
     }
 
     myBox->setModel(sourceModel);
@@ -475,7 +473,8 @@ QWidget * AdditionalToolbarWidgetAction::createSelector(ext_toolbar_t * item, QW
 
     frame->layout()->addWidget(myBox);
 
-    connect(myBox, SIGNAL(currentIndexChanged(int)), this, SLOT(onSelectionInWidgetChanged(int)));
+    connect(myBox, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
+            this, &AdditionalToolbarWidgetAction::onSelectionInWidgetChanged);
 
     ext_toolbar_register_update_cb(item, (ext_toolbar_action_cb)&toolbar_selector_cb, (void *)myBox);
 
@@ -485,22 +484,22 @@ QWidget * AdditionalToolbarWidgetAction::createSelector(ext_toolbar_t * item, QW
 ext_toolbar_t * AdditionalToolbarWidgetAction::extractToolbarItemFromObject(QObject * object)
 {
     QWidget * widget = dynamic_cast<QWidget *>(object);
-    if ( ! widget )
+    if (! widget)
         return 0;
 
     QVariant propValue = widget->property(propertyName);
 
     /* If property is invalid, look if our parent has this property */
-    if ( ! propValue.isValid() )
+    if (! propValue.isValid())
     {
         QWidget * frame = dynamic_cast<QWidget *>(widget->parent());
-        if ( ! frame )
+        if (! frame)
             return 0;
 
         propValue = frame->property(propertyName);
     }
 
-    if ( ! propValue.isValid() )
+    if (! propValue.isValid())
         return 0;
 
     return VariantPointer<ext_toolbar_t>::asPtr(propValue);
@@ -509,7 +508,7 @@ ext_toolbar_t * AdditionalToolbarWidgetAction::extractToolbarItemFromObject(QObj
 void AdditionalToolbarWidgetAction::onButtonClicked()
 {
     ext_toolbar_t * item = extractToolbarItemFromObject(sender());
-    if ( ! item )
+    if (! item)
         return;
 
     item->callback(item, 0, item->user_data);
@@ -518,10 +517,10 @@ void AdditionalToolbarWidgetAction::onButtonClicked()
 void AdditionalToolbarWidgetAction::onCheckBoxChecked(int checkState)
 {
     ext_toolbar_t * item = extractToolbarItemFromObject(sender());
-    if ( ! item )
+    if (! item)
         return;
 
-    gboolean value = checkState == Qt::Checked ? true : false;
+    bool value = checkState == Qt::Checked ? true : false;
 
     item->callback(item, &value, item->user_data);
 }
@@ -529,26 +528,26 @@ void AdditionalToolbarWidgetAction::onCheckBoxChecked(int checkState)
 void AdditionalToolbarWidgetAction::sendTextToCallback()
 {
     ext_toolbar_t * item = extractToolbarItemFromObject(sender());
-    if ( ! item )
+    if (! item)
         return;
 
-    if (item->item_type != EXT_TOOLBAR_STRING )
+    if (item->item_type != EXT_TOOLBAR_STRING)
         return;
 
     ApplyLineEdit * editor = dynamic_cast<ApplyLineEdit *>(sender());
-    if ( ! editor )
+    if (! editor)
     {
         /* Called from button, searching for acompanying line edit */
         QWidget * parent = dynamic_cast<QWidget *>(sender()->parent());
-        if ( parent )
+        if (parent)
         {
             QList<ApplyLineEdit *> children = parent->findChildren<ApplyLineEdit *>();
-            if ( children.count() >= 0 )
+            if (children.count() >= 0)
                 editor = children.at(0);
         }
     }
 
-    if ( editor )
+    if (editor)
         item->callback(item, qstring_strdup(editor->text()), item->user_data);
 }
 
@@ -556,31 +555,18 @@ void AdditionalToolbarWidgetAction::onSelectionInWidgetChanged(int idx)
 {
     QComboBox * editor = dynamic_cast<QComboBox *>(sender());
     ext_toolbar_t * item = extractToolbarItemFromObject(editor);
-    if ( ! item || item->item_type != EXT_TOOLBAR_SELECTOR )
+    if (! item || item->item_type != EXT_TOOLBAR_SELECTOR)
         return;
 
     QStandardItemModel * sourceModel = (QStandardItemModel *) editor->model();
-    if ( sourceModel->rowCount() <= idx )
+    if (sourceModel->rowCount() <= idx)
         return;
 
     QModelIndex mdIdx = sourceModel->index(idx, 0);
     QVariant dataSet = sourceModel->data(mdIdx, Qt::UserRole);
-    if ( dataSet.isValid() )
+    if (dataSet.isValid())
     {
         ext_toolbar_value_t * value_entry = VariantPointer<ext_toolbar_value_t>::asPtr(dataSet);
         item->callback(item, value_entry, item->user_data);
     }
 }
-
-/*
- * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
- *
- * Local variables:
- * c-basic-offset: 4
- * tab-width: 8
- * indent-tabs-mode: nil
- * End:
- *
- * vi: set shiftwidth=4 tabstop=8 expandtab:
- * :indentSize=4:tabSize=8:noTabs=true:
- */
