@@ -17,6 +17,8 @@
 
 #include <QHelpEvent>
 #include <QStyleOptionComboBox>
+#include <QStandardItemModel>
+#include <QDateTime>
 
 #include <ui/qt/widgets/display_filter_edit.h>
 #include <ui/qt/widgets/display_filter_combo.h>
@@ -24,7 +26,7 @@
 #include "main_application.h"
 
 // If we ever add support for multiple windows this will need to be replaced.
-static DisplayFilterCombo *cur_display_filter_combo = NULL;
+static DisplayFilterCombo *cur_display_filter_combo;
 
 DisplayFilterCombo::DisplayFilterCombo(QWidget *parent) :
     QComboBox(parent)
@@ -48,7 +50,13 @@ DisplayFilterCombo::DisplayFilterCombo(QWidget *parent) :
     updateStyleSheet();
     setToolTip(tr("Select from previously used filters."));
 
+    QStandardItemModel *model = qobject_cast<QStandardItemModel*>(this->model());
+    model->setSortRole(Qt::UserRole);
+
     connect(mainApp, &MainApplication::preferencesChanged, this, &DisplayFilterCombo::updateMaxCount);
+    // Ugly cast required (?)
+    // https://stackoverflow.com/questions/16794695/connecting-overloaded-signals-and-slots-in-qt-5
+    connect(this, static_cast<void (DisplayFilterCombo::*)(int)>(&DisplayFilterCombo::activated), this, &DisplayFilterCombo::onActivated);
 }
 
 extern "C" void dfilter_recent_combo_write_all(FILE *rf) {
@@ -69,6 +77,15 @@ void DisplayFilterCombo::writeRecent(FILE *rf) {
     }
 }
 
+void DisplayFilterCombo::onActivated(int row)
+{
+    /* Update the row timestamp and resort list. */
+    QStandardItemModel *m = qobject_cast<QStandardItemModel*>(this->model());
+    QModelIndex idx = m->index(row, 0);
+    m->setData(idx, QVariant(QDateTime::currentMSecsSinceEpoch()), Qt::UserRole);
+    m->sort(0, Qt::DescendingOrder);
+}
+
 bool DisplayFilterCombo::event(QEvent *event)
 {
     switch (event->type()) {
@@ -156,17 +173,17 @@ void DisplayFilterCombo::updateMaxCount()
     setMaxCount(prefs.gui_recent_df_entries_max);
 }
 
-extern "C" gboolean dfilter_combo_add_recent(const gchar *filter) {
+extern "C" bool dfilter_combo_add_recent(const char *filter) {
     if (!cur_display_filter_combo)
-        return FALSE;
+        return false;
 
     // Adding an item to a QComboBox also sets its lineEdit. In our case
     // that means we might trigger a temporary status message so we block
     // the lineEdit's signals.
     // Another approach would be to update QComboBox->model directly.
     bool block_state = cur_display_filter_combo->lineEdit()->blockSignals(true);
-    cur_display_filter_combo->addItem(filter);
+    cur_display_filter_combo->addItem(filter, QVariant(QDateTime::currentMSecsSinceEpoch()));
     cur_display_filter_combo->clearEditText();
     cur_display_filter_combo->lineEdit()->blockSignals(block_state);
-    return TRUE;
+    return true;
 }
