@@ -9,10 +9,10 @@
  */
 
 #include "config.h"
-#include "filesystem.h"
-
 #define WS_LOG_DOMAIN LOG_DOMAIN_WSUTIL
 
+#include "filesystem.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -73,18 +73,18 @@ enum configuration_namespace_e configuration_namespace = CONFIGURATION_NAMESPACE
 #define CONFIGURATION_NAMESPACE_LOWER (configuration_namespace == CONFIGURATION_NAMESPACE_WIRESHARK ? "wireshark" : "logray")
 #define CONFIGURATION_ENVIRONMENT_VARIABLE(suffix) (configuration_namespace == CONFIGURATION_NAMESPACE_WIRESHARK ? "WIRESHARK_" suffix : "LOGRAY_" suffix)
 
-char *persconffile_dir = NULL;
-char *datafile_dir = NULL;
-char *persdatafile_dir = NULL;
-char *persconfprofile = NULL;
-char *doc_dir = NULL;
+char *persconffile_dir;
+char *datafile_dir;
+char *persdatafile_dir;
+char *persconfprofile;
+char *doc_dir;
 
 /* Directory from which the executable came. */
-static char *progfile_dir = NULL;
-static char *install_prefix = NULL;
+static char *progfile_dir;
+static char *install_prefix;
 
-static gboolean do_store_persconffiles = FALSE;
-static GHashTable *profile_files = NULL;
+static bool do_store_persconffiles;
+static GHashTable *profile_files;
 
 /*
  * Given a pathname, return a pointer to the last pathname separator
@@ -219,6 +219,21 @@ test_for_fifo(const char *path)
         return 0;
 }
 
+bool
+test_for_regular_file(const char *path)
+{
+    ws_statb64 statb;
+
+    if (!path) {
+        return false;
+    }
+
+    if (ws_stat64(path, &statb) != 0)
+        return false;
+
+    return S_ISREG(statb.st_mode);
+}
+
 #ifdef ENABLE_APPLICATION_BUNDLE
 /*
  * Directory of the application bundle in which we're contained,
@@ -275,10 +290,10 @@ static char *appbundle_dir;
 #endif
 
 /*
- * TRUE if we're running from the build directory and we aren't running
+ * true if we're running from the build directory and we aren't running
  * with special privileges.
  */
-static gboolean running_in_build_directory_flag = FALSE;
+static bool running_in_build_directory_flag;
 
 /*
  * Set our configuration namespace. This will be used for top-level
@@ -524,6 +539,13 @@ get_current_executable_path(void)
 
 static void trim_progfile_dir(void)
 {
+#ifdef _WIN32
+    char *namespace_last_dir = find_last_pathname_separator(progfile_dir);
+    if (namespace_last_dir && strncmp(namespace_last_dir + 1, CONFIGURATION_NAMESPACE_LOWER, sizeof(CONFIGURATION_NAMESPACE_LOWER)) == 0) {
+        *namespace_last_dir = '\0';
+    }
+#endif
+
     char *progfile_last_dir = find_last_pathname_separator(progfile_dir);
 
     if (! (progfile_last_dir && strncmp(progfile_last_dir + 1, "extcap", sizeof("extcap")) == 0)) {
@@ -581,14 +603,14 @@ get_executable_path(const char *program_name)
  * g_mallocated string containing an error on failure.
  */
 #ifdef _WIN32
-char *
+static char *
 configuration_init_w32(const char* arg0 _U_)
 {
     TCHAR prog_pathname_w[_MAX_PATH+2];
     char *prog_pathname;
     DWORD error;
     TCHAR *msg_w;
-    guchar *msg;
+    unsigned char *msg;
     size_t msglen;
 
     /*
@@ -657,7 +679,7 @@ configuration_init_w32(const char* arg0 _U_)
     }
     else {
         install_prefix = g_strdup(progfile_dir);
-        running_in_build_directory_flag = TRUE;
+        running_in_build_directory_flag = true;
     }
 #endif /* HAVE_MSYSTEM */
 
@@ -666,7 +688,7 @@ configuration_init_w32(const char* arg0 _U_)
 
 #else /* !_WIN32 */
 
-char *
+static char *
 configuration_init_posix(const char* arg0)
 {
     const char *execname;
@@ -695,7 +717,7 @@ configuration_init_posix(const char* arg0)
     const char *run_from_envar = CONFIGURATION_ENVIRONMENT_VARIABLE("RUN_FROM_BUILD_DIRECTORY");
     if (g_getenv(run_from_envar) != NULL
         && !started_with_special_privs()) {
-        running_in_build_directory_flag = TRUE;
+        running_in_build_directory_flag = true;
     }
 
     execname = get_current_executable_path();
@@ -831,12 +853,12 @@ configuration_init_posix(const char* arg0)
                  * CMakeCache.txt file before assuming a CMake output dir.
                  */
                 if (strcmp(dir_end, "/run") == 0) {
-                    gchar *cmake_file;
+                    char *cmake_file;
                     cmake_file = ws_strdup_printf("%.*s/CMakeCache.txt",
                                                  (int)(dir_end - prog_pathname),
                                                  prog_pathname);
                     if (file_exists(cmake_file))
-                        running_in_build_directory_flag = TRUE;
+                        running_in_build_directory_flag = true;
                     g_free(cmake_file);
                 }
 #ifdef ENABLE_APPLICATION_BUNDLE
@@ -915,7 +937,7 @@ configuration_init_posix(const char* arg0)
     }
     else {
         install_prefix = g_strdup(progfile_dir);
-        running_in_build_directory_flag = TRUE;
+        running_in_build_directory_flag = true;
     }
 
     return NULL;
@@ -1000,7 +1022,7 @@ get_datafile_dir(void)
     if (running_in_build_directory_flag) {
         datafile_dir = g_strdup(install_prefix);
     } else {
-        datafile_dir = g_build_filename(install_prefix, DATA_DIR, (gchar *)NULL);
+        datafile_dir = g_build_filename(install_prefix, DATA_DIR, CONFIGURATION_NAMESPACE_LOWER, (char *)NULL);
     }
 #elif defined(_WIN32)
     /*
@@ -1047,7 +1069,7 @@ get_datafile_dir(void)
          * We're (probably) being run from the build directory and
          * weren't started with special privileges.
          *
-         * (running_in_build_directory_flag is never set to TRUE
+         * (running_in_build_directory_flag is never set to true
          * if we're started with special privileges, so we need
          * only check it; we don't need to call started_with_special_privs().)
          *
@@ -1057,7 +1079,7 @@ get_datafile_dir(void)
          */
         datafile_dir = g_strdup(progfile_dir);
     } else {
-        datafile_dir = g_build_filename(install_prefix, DATA_DIR, (char *)NULL);
+        datafile_dir = g_build_filename(install_prefix, DATA_DIR, CONFIGURATION_NAMESPACE_LOWER, (char *)NULL);
     }
 #endif
     return datafile_dir;
@@ -1078,7 +1100,7 @@ get_doc_dir(void)
     if (running_in_build_directory_flag) {
         doc_dir = g_strdup(install_prefix);
     } else {
-        doc_dir = g_build_filename(install_prefix, DOC_DIR, (gchar *)NULL);
+        doc_dir = g_build_filename(install_prefix, DOC_DIR, (char *)NULL);
     }
 #elif defined(_WIN32)
     if (progfile_dir != NULL) {
@@ -1099,8 +1121,7 @@ get_doc_dir(void)
      * it; we don't need to call started_with_special_privs().)
      */
     else if (appbundle_dir != NULL) {
-        doc_dir = ws_strdup_printf("%s/Contents/Resources/%s",
-                                        appbundle_dir, DOC_DIR);
+        doc_dir = g_strdup(get_datafile_dir());
     }
 #endif
     else if (running_in_build_directory_flag && progfile_dir != NULL) {
@@ -1138,11 +1159,11 @@ get_doc_dir(void)
  *    otherwise, we use the PLUGIN_DIR value supplied by the
  *    configure script.
  */
-static char *plugin_dir = NULL;
-static char *plugin_dir_with_version = NULL;
-static char *plugin_pers_dir = NULL;
-static char *plugin_pers_dir_with_version = NULL;
-static char *extcap_pers_dir = NULL;
+static char *plugin_dir;
+static char *plugin_dir_with_version;
+static char *plugin_pers_dir;
+static char *plugin_pers_dir_with_version;
+static char *extcap_pers_dir;
 
 static void
 init_plugin_dir(void)
@@ -1155,47 +1176,22 @@ init_plugin_dir(void)
          * Let {WIRESHARK,LOGRAY}_PLUGIN_DIR take precedence.
          */
         plugin_dir = g_strdup(g_getenv(plugin_dir_envar));
-        return;
     }
 
 #if defined(HAVE_PLUGINS) || defined(HAVE_LUA)
 #if defined(HAVE_MSYSTEM)
-    if (running_in_build_directory_flag) {
-        plugin_dir = g_build_filename(install_prefix, "plugins", (gchar *)NULL);
+    else if (running_in_build_directory_flag) {
+        plugin_dir = g_build_filename(install_prefix, "plugins", (char *)NULL);
     } else {
-        plugin_dir = g_build_filename(install_prefix, PLUGIN_DIR, (gchar *)NULL);
+        plugin_dir = g_build_filename(install_prefix, PLUGIN_DIR, (char *)NULL);
     }
 #elif defined(_WIN32)
-    /*
-     * On Windows, the data file directory is the installation
-     * directory; the plugins are stored under it.
-     *
-     * Assume we're running the installed version of Wireshark;
-     * on Windows, the data file directory is the directory
-     * in which the Wireshark binary resides.
-     */
-    plugin_dir = g_build_filename(get_datafile_dir(), "plugins", (gchar *)NULL);
-
-    /*
-     * Make sure that pathname refers to a directory.
-     */
-    if (test_for_directory(plugin_dir) != EISDIR) {
+    else {
         /*
-         * Either it doesn't refer to a directory or it
-         * refers to something that doesn't exist.
-         *
-         * Assume that means we're running a version of
-         * Wireshark we've built in a build directory,
-         * in which case {datafile dir}\plugins is the
-         * top-level plugins source directory, and use
-         * that directory and set the "we're running in
-         * a build directory" flag, so the plugin
-         * scanner will check all subdirectories of that
-         * directory for plugins.
+         * On Windows, plugins are stored under the program file directory
+         * in both the build and the installation directories.
          */
-        g_free(plugin_dir);
-        plugin_dir = g_build_filename(get_datafile_dir(), "plugins", (gchar *)NULL);
-        running_in_build_directory_flag = TRUE;
+        plugin_dir = g_build_filename(get_progfile_dir(), "plugins", (char *)NULL);
     }
 #else
 #ifdef ENABLE_APPLICATION_BUNDLE
@@ -1210,9 +1206,9 @@ init_plugin_dir(void)
      */
     else if (appbundle_dir != NULL) {
         plugin_dir = g_build_filename(appbundle_dir, "Contents/PlugIns",
-                                        CONFIGURATION_NAMESPACE_LOWER, (gchar *)NULL);
+                                        CONFIGURATION_NAMESPACE_LOWER, (char *)NULL);
     }
-#endif
+#endif // ENABLE_APPLICATION_BUNDLE
     else if (running_in_build_directory_flag) {
         /*
          * We're (probably) being run from the build directory and
@@ -1220,11 +1216,11 @@ init_plugin_dir(void)
          * the "plugins" subdirectory of the directory where the program
          * we're running is (that's the build directory).
          */
-        plugin_dir = g_build_filename(get_progfile_dir(), "plugins", (gchar *)NULL);
+        plugin_dir = g_build_filename(get_progfile_dir(), "plugins", (char *)NULL);
     } else {
         plugin_dir = g_build_filename(install_prefix, PLUGIN_DIR, (char *)NULL);
     }
-#endif
+#endif // HAVE_MSYSTEM / _WIN32
 #endif /* defined(HAVE_PLUGINS) || defined(HAVE_LUA) */
 }
 
@@ -1233,10 +1229,10 @@ init_plugin_pers_dir(void)
 {
 #if defined(HAVE_PLUGINS) || defined(HAVE_LUA)
 #ifdef _WIN32
-    plugin_pers_dir = get_persconffile_path(PLUGINS_DIR_NAME, FALSE);
+    plugin_pers_dir = get_persconffile_path(PLUGINS_DIR_NAME, false);
 #else
     plugin_pers_dir = g_build_filename(g_get_home_dir(), ".local/lib",
-                                       CONFIGURATION_NAMESPACE_LOWER, PLUGINS_DIR_NAME, (gchar *)NULL);
+                                       CONFIGURATION_NAMESPACE_LOWER, PLUGINS_DIR_NAME, (char *)NULL);
 #endif
 #endif /* defined(HAVE_PLUGINS) || defined(HAVE_LUA) */
 }
@@ -1258,7 +1254,7 @@ get_plugins_dir_with_version(void)
     if (!plugin_dir)
         init_plugin_dir();
     if (plugin_dir && !plugin_dir_with_version)
-        plugin_dir_with_version = g_build_filename(plugin_dir, PLUGIN_PATH_ID, (gchar *)NULL);
+        plugin_dir_with_version = g_build_filename(plugin_dir, PLUGIN_PATH_ID, (char *)NULL);
     return plugin_dir_with_version;
 }
 
@@ -1277,7 +1273,7 @@ get_plugins_pers_dir_with_version(void)
     if (!plugin_pers_dir)
         init_plugin_pers_dir();
     if (plugin_pers_dir && !plugin_pers_dir_with_version)
-        plugin_pers_dir_with_version = g_build_filename(plugin_pers_dir, PLUGIN_PATH_ID, (gchar *)NULL);
+        plugin_pers_dir_with_version = g_build_filename(plugin_pers_dir, PLUGIN_PATH_ID, (char *)NULL);
     return plugin_pers_dir_with_version;
 }
 
@@ -1287,7 +1283,7 @@ get_plugins_pers_dir_with_version(void)
  * If the WIRESHARK_EXTCAP_DIR environment variable is set and we are not
  * running with special privileges, use that. Otherwise:
  *
- * On Windows, we use the "extcap" subdirectory of the datafile directory.
+ * On Windows, we use the "extcap" subdirectory of the program directory.
  *
  * On UN*X:
  *
@@ -1299,7 +1295,7 @@ get_plugins_pers_dir_with_version(void)
  *
  *    otherwise, we use the EXTCAP_DIR value supplied by CMake.
  */
-static char *extcap_dir = NULL;
+static char *extcap_dir;
 
 static void
 init_extcap_dir(void)
@@ -1315,32 +1311,21 @@ init_extcap_dir(void)
 
 #if defined(HAVE_MSYSTEM)
     else if (running_in_build_directory_flag) {
-        extcap_dir = g_build_filename(install_prefix, "extcap", (gchar *)NULL);
+        extcap_dir = g_build_filename(install_prefix, "extcap", (char *)NULL);
     } else {
-        extcap_dir = g_build_filename(install_prefix, EXTCAP_DIR, (gchar *)NULL);
+        extcap_dir = g_build_filename(install_prefix, EXTCAP_DIR, (char *)NULL);
     }
 #elif defined(_WIN32)
     else {
         /*
-         * On Windows, the data file directory is the installation
-         * directory; the extcap hooks are stored under it.
-         *
-         * Assume we're running the installed version of Wireshark;
-         * on Windows, the data file directory is the directory
-         * in which the Wireshark binary resides.
+         * On Windows, extcap utilities are stored in "extcap/<program name>"
+         * in the program file directory in both the build and installation
+         * directories.
          */
-        extcap_dir = g_build_filename(get_datafile_dir(), "extcap", (gchar *)NULL);
+        extcap_dir = g_build_filename(get_progfile_dir(), EXTCAP_DIR_NAME,
+            CONFIGURATION_NAMESPACE_LOWER, (char *)NULL);
     }
 #else
-    else if (running_in_build_directory_flag) {
-        /*
-         * We're (probably) being run from the build directory and
-         * weren't started with special privileges, so we'll use
-         * the "extcap hooks" subdirectory of the directory where the program
-         * we're running is (that's the build directory).
-         */
-        extcap_dir = g_build_filename(get_progfile_dir(), "extcap", (gchar *)NULL);
-    }
 #ifdef ENABLE_APPLICATION_BUNDLE
     else if (appbundle_dir != NULL) {
         /*
@@ -1352,23 +1337,34 @@ init_extcap_dir(void)
          * started with special privileges, so we need only check
          * it; we don't need to call started_with_special_privs().)
          */
-        extcap_dir = g_build_filename(appbundle_dir, "Contents/MacOS/extcap", (gchar *)NULL);
+        extcap_dir = g_build_filename(appbundle_dir, "Contents/MacOS/extcap", (char *)NULL);
+    }
+#endif // ENABLE_APPLICATION_BUNDLE
+    else if (running_in_build_directory_flag) {
+        /*
+         * We're (probably) being run from the build directory and
+         * weren't started with special privileges, so we'll use
+         * the "extcap hooks" subdirectory of the directory where the program
+         * we're running is (that's the build directory).
+         */
+        extcap_dir = g_build_filename(get_progfile_dir(), EXTCAP_DIR_NAME,
+            CONFIGURATION_NAMESPACE_LOWER, (char *)NULL);
     }
-#endif
     else {
-        extcap_dir = g_build_filename(install_prefix, EXTCAP_DIR, (char *)NULL);
+        extcap_dir = g_build_filename(install_prefix,
+            is_packet_configuration_namespace() ? EXTCAP_DIR : LOG_EXTCAP_DIR, (char *)NULL);
     }
-#endif
+#endif // HAVE_MSYSTEM / _WIN32
 }
 
 static void
 init_extcap_pers_dir(void)
 {
 #ifdef _WIN32
-    extcap_pers_dir = get_persconffile_path(EXTCAP_DIR_NAME, FALSE);
+    extcap_pers_dir = get_persconffile_path(EXTCAP_DIR_NAME, false);
 #else
     extcap_pers_dir = g_build_filename(g_get_home_dir(), ".local/lib",
-                                       CONFIGURATION_NAMESPACE_LOWER, EXTCAP_DIR_NAME, (gchar *)NULL);
+                                       CONFIGURATION_NAMESPACE_LOWER, EXTCAP_DIR_NAME, (char *)NULL);
 #endif
 }
 
@@ -1397,7 +1393,7 @@ get_extcap_pers_dir(void)
  * Get the flag indicating whether we're running from a build
  * directory.
  */
-gboolean
+bool
 running_in_build_directory(void)
 {
     return running_in_build_directory_flag;
@@ -1420,7 +1416,7 @@ get_systemfile_dir(void)
 }
 
 void
-set_profile_name(const gchar *profilename)
+set_profile_name(const char *profilename)
 {
     g_free (persconfprofile);
 
@@ -1443,20 +1439,20 @@ get_profile_name(void)
     }
 }
 
-gboolean
+bool
 is_default_profile(void)
 {
-    return (!persconfprofile || strcmp(persconfprofile, DEFAULT_PROFILE) == 0) ? TRUE : FALSE;
+    return (!persconfprofile || strcmp(persconfprofile, DEFAULT_PROFILE) == 0) ? true : false;
 }
 
-gboolean
+bool
 has_global_profiles(void)
 {
     WS_DIR *dir;
     WS_DIRENT *file;
-    gchar *global_dir = get_global_profiles_dir();
-    gchar *filename;
-    gboolean has_global = FALSE;
+    char *global_dir = get_global_profiles_dir();
+    char *filename;
+    bool has_global = false;
 
     if ((test_for_directory(global_dir) == EISDIR) &&
         ((dir = ws_dir_open(global_dir, 0, NULL)) != NULL))
@@ -1465,7 +1461,7 @@ has_global_profiles(void)
             filename = ws_strdup_printf ("%s%s%s", global_dir, G_DIR_SEPARATOR_S,
                             ws_dir_get_name(file));
             if (test_for_directory(filename) == EISDIR) {
-                has_global = TRUE;
+                has_global = true;
                 g_free (filename);
                 break;
             }
@@ -1478,7 +1474,7 @@ has_global_profiles(void)
 }
 
 void
-profile_store_persconffiles(gboolean store)
+profile_store_persconffiles(bool store)
 {
     if (store) {
         profile_files = g_hash_table_new (g_str_hash, g_str_equal);
@@ -1692,7 +1688,7 @@ get_global_profiles_dir(void)
 }
 
 static char *
-get_persconffile_dir(const gchar *profilename)
+get_persconffile_dir(const char *profilename)
 {
     char *persconffile_profile_dir = NULL, *profile_dir;
 
@@ -1710,15 +1706,15 @@ get_persconffile_dir(const gchar *profilename)
 }
 
 char *
-get_profile_dir(const char *profilename, gboolean is_global)
+get_profile_dir(const char *profilename, bool is_global)
 {
-    gchar *profile_dir;
+    char *profile_dir;
 
     if (is_global) {
         if (profilename && strlen(profilename) > 0 &&
             strcmp(profilename, DEFAULT_PROFILE) != 0)
         {
-            gchar *global_path = get_global_profiles_dir();
+            char *global_path = get_global_profiles_dir();
             profile_dir = g_build_filename(global_path, profilename, NULL);
             g_free(global_path);
         } else {
@@ -1735,21 +1731,21 @@ get_profile_dir(const char *profilename, gboolean is_global)
     return profile_dir;
 }
 
-gboolean
-profile_exists(const gchar *profilename, gboolean global)
+bool
+profile_exists(const char *profilename, bool global)
 {
-    gchar *path = NULL;
-    gboolean exists;
+    char *path = NULL;
+    bool exists;
 
     /*
      * If we're looking up a global profile, we must have a
      * profile name.
      */
     if (global && !profilename)
-        return FALSE;
+        return false;
 
     path = get_profile_dir(profilename, global);
-    exists = (test_for_directory(path) == EISDIR) ? TRUE : FALSE;
+    exists = (test_for_directory(path) == EISDIR) ? true : false;
 
     g_free(path);
     return exists;
@@ -1760,7 +1756,7 @@ delete_directory (const char *directory, char **pf_dir_path_return)
 {
     WS_DIR *dir;
     WS_DIRENT *file;
-    gchar *filename;
+    char *filename;
     int ret = 0;
 
     if ((dir = ws_dir_open(directory, 0, NULL)) != NULL) {
@@ -1797,7 +1793,7 @@ static int
 copy_directory(const char *from_dir, const char *to_dir, char **pf_filename_return)
 {
     int ret = 0;
-    gchar *from_file, *to_file;
+    char *from_file, *to_file;
     const char *filename;
     WS_DIR *dir;
     WS_DIRENT *file;
@@ -1835,14 +1831,14 @@ static int
 reset_default_profile(char **pf_dir_path_return)
 {
     char *profile_dir = get_persconffile_dir(NULL);
-    gchar *filename, *del_file;
+    char *filename, *del_file;
     GList *files, *file;
     int ret = 0;
 
     files = g_hash_table_get_keys(profile_files);
     file = g_list_first(files);
     while (file) {
-        filename = (gchar *)file->data;
+        filename = (char *)file->data;
         del_file = ws_strdup_printf("%s%s%s", profile_dir, G_DIR_SEPARATOR_S, filename);
 
         if (file_exists(del_file)) {
@@ -2013,16 +2009,16 @@ create_persconffile_dir(char **pf_dir_path_return)
 }
 
 int
-copy_persconffile_profile(const char *toname, const char *fromname, gboolean from_global,
+copy_persconffile_profile(const char *toname, const char *fromname, bool from_global,
               char **pf_filename_return, char **pf_to_dir_path_return, char **pf_from_dir_path_return)
 {
     int ret = 0;
-    gchar *from_dir;
-    gchar *to_dir = get_persconffile_dir(toname);
-    gchar *from_file, *to_file;
+    char *from_dir;
+    char *to_dir = get_persconffile_dir(toname);
+    char *from_file, *to_file;
     const char *filename;
     GHashTableIter files;
-    gpointer file;
+    void * file;
 
     from_dir = get_profile_dir(fromname, from_global);
 
@@ -2040,7 +2036,7 @@ copy_persconffile_profile(const char *toname, const char *fromname, gboolean fro
             from_file = ws_strdup_printf ("%s%s%s", from_dir, G_DIR_SEPARATOR_S, filename);
             to_file = ws_strdup_printf ("%s%s%s", to_dir, G_DIR_SEPARATOR_S, filename);
 
-            if (file_exists(from_file) && !copy_file_binary_mode(from_file, to_file)) {
+            if (test_for_regular_file(from_file) && !copy_file_binary_mode(from_file, to_file)) {
                 *pf_filename_return = g_strdup(filename);
                 g_free (from_file);
                 g_free (to_file);
@@ -2068,31 +2064,51 @@ copy_persconffile_profile(const char *toname, const char *fromname, gboolean fro
  * Get the (default) directory in which personal data is stored.
  *
  * On Win32, this is the "My Documents" folder in the personal profile.
- * On UNIX this is simply the current directory.
+ * On UNIX this is simply the current directory, unless that's "/",
+ * which it will be, for example, when Wireshark is run from the
+ * Finder in macOS, in which case we use the user's home directory.
  */
 /* XXX - should this and the get_home_dir() be merged? */
 extern const char *
 get_persdatafile_dir(void)
 {
-#ifdef _WIN32
-    TCHAR tszPath[MAX_PATH];
-
     /* Return the cached value, if available */
     if (persdatafile_dir != NULL)
         return persdatafile_dir;
 
+#ifdef _WIN32
+    TCHAR tszPath[MAX_PATH];
+
     /*
      * Hint: SHGetFolderPath is not available on MSVC 6 - without
      * Platform SDK
      */
-    if (SHGetSpecialFolderPath(NULL, tszPath, CSIDL_PERSONAL, FALSE)) {
+    if (SHGetSpecialFolderPath(NULL, tszPath, CSIDL_PERSONAL, false)) {
         persdatafile_dir = g_utf16_to_utf8(tszPath, -1, NULL, NULL, NULL);
         return persdatafile_dir;
     } else {
         return "";
     }
 #else
-    return "";
+    /*
+     * Get the current directory.
+     */
+    persdatafile_dir = g_get_current_dir();
+    if (persdatafile_dir == NULL) {
+      /* XXX - can this fail? */
+      /*
+       * g_get_home_dir() returns a const gchar *; g_strdup() it
+       * so that it's something that can be freed.
+       */
+      persdatafile_dir = g_strdup(g_get_home_dir());
+    } else if (strcmp(persdatafile_dir, "/") == 0) {
+        g_free(persdatafile_dir);
+        /*
+         * See above.
+         */
+        persdatafile_dir = g_strdup(g_get_home_dir());
+    }
+    return persdatafile_dir;
 #endif
 }
 
@@ -2107,7 +2123,7 @@ set_persdatafile_dir(const char *p)
  * Construct the path name of a personal configuration file, given the
  * file name.
  *
- * On Win32, if "for_writing" is FALSE, we check whether the file exists
+ * On Win32, if "for_writing" is false, we check whether the file exists
  * and, if not, construct a path name relative to the ".wireshark"
  * subdirectory of the user's home directory, and check whether that
  * exists; if it does, we return that, so that configuration files
@@ -2117,7 +2133,7 @@ set_persdatafile_dir(const char *p)
  * caller is done with it.
  */
 char *
-get_persconffile_path(const char *filename, gboolean from_profile)
+get_persconffile_path(const char *filename, bool from_profile)
 {
     char *path, *dir = NULL;
 
@@ -2184,7 +2200,7 @@ get_docfile_path(const char *filename)
  * create operations.
  */
 const char *
-file_open_error_message(int err, gboolean for_writing)
+file_open_error_message(int err, bool for_writing)
 {
     const char *errmsg;
     static char errmsg_errno[1024+1];
@@ -2317,41 +2333,41 @@ file_write_error_message(int err)
 }
 
 
-gboolean
+bool
 file_exists(const char *fname)
 {
     ws_statb64 file_stat;
 
     if (!fname) {
-        return FALSE;
+        return false;
     }
 
     if (ws_stat64(fname, &file_stat) != 0 && errno == ENOENT) {
-        return FALSE;
+        return false;
     } else {
-        return TRUE;
+        return true;
     }
 }
 
-gboolean config_file_exists_with_entries(const char *fname, char comment_char)
+bool config_file_exists_with_entries(const char *fname, char comment_char)
 {
-    gboolean start_of_line = TRUE;
-    gboolean has_entries = FALSE;
+    bool start_of_line = true;
+    bool has_entries = false;
     FILE *file;
     int c;
 
     if (!fname) {
-        return FALSE;
+        return false;
     }
 
     if ((file = ws_fopen(fname, "r")) == NULL) {
-        return FALSE;
+        return false;
     }
 
     do {
         c = ws_getc_unlocked(file);
         if (start_of_line && c != comment_char && !g_ascii_isspace(c) && g_ascii_isprint(c)) {
-            has_entries = TRUE;
+            has_entries = true;
             break;
         }
         if (c == '\n' || !g_ascii_isspace(c)) {
@@ -2370,40 +2386,51 @@ gboolean config_file_exists_with_entries(const char *fname, char comment_char)
  * name and the read file name may be relative (if supplied on
  * the command line), so we can't just compare paths. From Joerg Mayer.
  */
-gboolean
+bool
 files_identical(const char *fname1, const char *fname2)
 {
-    /* Two different implementations, because:
-     *
-     * - _fullpath is not available on UN*X, so we can't get full
-     *   paths and compare them (which wouldn't work with hard links
-     *   in any case);
-     *
-     * - st_ino isn't filled in with a meaningful value on Windows.
+    /* Two different implementations, because st_ino isn't filled in with
+     * a meaningful value on Windows. Use the Windows API and FILE_ID_INFO
+     * instead.
      */
 #ifdef _WIN32
-    char full1[MAX_PATH], full2[MAX_PATH];
+
+    FILE_ID_INFO filestat1, filestat2;
 
     /*
-     * Get the absolute full paths of the file and compare them.
-     * That won't work if you have hard links, but those aren't
-     * much used on Windows, even though NTFS supports them.
-     *
-     * XXX - will _fullpath work with UNC?
+     * Compare VolumeSerialNumber and FileId.
      */
-    if( _fullpath( full1, fname1, MAX_PATH ) == NULL ) {
-        return FALSE;
+
+    HANDLE h1 = CreateFile(utf_8to16(fname1), 0,
+        FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
+        NULL, OPEN_EXISTING, 0, NULL);
+
+    if (h1 == INVALID_HANDLE_VALUE) {
+        return false;
     }
 
-    if( _fullpath( full2, fname2, MAX_PATH ) == NULL ) {
-        return FALSE;
+    if (!GetFileInformationByHandleEx(h1, FileIdInfo, &filestat1, sizeof(FILE_ID_INFO))) {
+        CloseHandle(h1);
+        return false;
+    }
+    CloseHandle(h1);
+
+    HANDLE h2 = CreateFile(utf_8to16(fname2), 0,
+        FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
+        NULL, OPEN_EXISTING, 0, NULL);
+
+    if (h2 == INVALID_HANDLE_VALUE) {
+        return false;
     }
 
-    if(strcmp(full1, full2) == 0) {
-        return TRUE;
-    } else {
-        return FALSE;
+    if (!GetFileInformationByHandleEx(h2, FileIdInfo, &filestat2, sizeof(FILE_ID_INFO))) {
+        CloseHandle(h2);
+        return false;
     }
+    CloseHandle(h2);
+
+    return ((memcmp(&filestat1.FileId, &filestat2.FileId, sizeof(FILE_ID_128)) == 0) &&
+        filestat1.VolumeSerialNumber == filestat2.VolumeSerialNumber);
 #else
     ws_statb64 filestat1, filestat2;
 
@@ -2411,15 +2438,15 @@ files_identical(const char *fname1, const char *fname2)
      * Compare st_dev and st_ino.
      */
     if (ws_stat64(fname1, &filestat1) == -1)
-        return FALSE;   /* can't get info about the first file */
+        return false;   /* can't get info about the first file */
     if (ws_stat64(fname2, &filestat2) == -1)
-        return FALSE;   /* can't get info about the second file */
+        return false;   /* can't get info about the second file */
     return (filestat1.st_dev == filestat2.st_dev &&
         filestat1.st_ino == filestat2.st_ino);
 #endif
 }
 
-gboolean
+bool
 file_needs_reopen(int fd, const char* filename)
 {
 #ifdef _WIN32
@@ -2442,7 +2469,7 @@ file_needs_reopen(int fd, const char* filename)
     BY_HANDLE_FILE_INFORMATION open_info, current_info;
 
     if (current_handle == INVALID_HANDLE_VALUE) {
-        return TRUE;
+        return true;
     }
 
 #if (_WIN32_WINNT >= _WIN32_WINNT_WIN8)
@@ -2459,24 +2486,24 @@ file_needs_reopen(int fd, const char* filename)
         GetFileInformationByHandle(current_handle, &current_info)) {
         /* Fallback to 64-bit identifier */
         CloseHandle(current_handle);
-        guint64 open_size = (((guint64)open_info.nFileSizeHigh) << 32) | open_info.nFileSizeLow;
-        guint64 current_size = (((guint64)current_info.nFileSizeHigh) << 32) | current_info.nFileSizeLow;
+        uint64_t open_size = (((uint64_t)open_info.nFileSizeHigh) << 32) | open_info.nFileSizeLow;
+        uint64_t current_size = (((uint64_t)current_info.nFileSizeHigh) << 32) | current_info.nFileSizeLow;
         return open_info.dwVolumeSerialNumber != current_info.dwVolumeSerialNumber ||
                open_info.nFileIndexHigh != current_info.nFileIndexHigh ||
                open_info.nFileIndexLow != current_info.nFileIndexLow ||
                open_size > current_size;
     }
     CloseHandle(current_handle);
-    return TRUE;
+    return true;
 #else
     ws_statb64 open_stat, current_stat;
 
     /* consider a file deleted when stat fails for either file,
      * or when the residing device / inode has changed. */
     if (0 != ws_fstat64(fd, &open_stat))
-        return TRUE;
+        return true;
     if (0 != ws_stat64(filename, &current_stat))
-        return TRUE;
+        return true;
 
     return open_stat.st_dev != current_stat.st_dev ||
            open_stat.st_ino != current_stat.st_ino ||
@@ -2484,20 +2511,20 @@ file_needs_reopen(int fd, const char* filename)
 #endif
 }
 
-gboolean
+bool
 write_file_binary_mode(const char *filename, const void *content, size_t content_len)
 {
     int fd;
     size_t bytes_left;
     unsigned int bytes_to_write;
     ssize_t bytes_written;
-    const guint8 *ptr;
+    const uint8_t *ptr;
     int err;
 
     fd = ws_open(filename, O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0644);
     if (fd == -1) {
-        report_open_failure(filename, errno, TRUE);
-        return FALSE;
+        report_open_failure(filename, errno, true);
+        return false;
     }
 
     /*
@@ -2514,7 +2541,7 @@ write_file_binary_mode(const char *filename, const void *content, size_t content
      * chunks of at most 2^31 bytes.
      */
 
-    ptr = (const guint8 *)content;
+    ptr = (const uint8_t *)content;
     bytes_left = content_len;
     while (bytes_left != 0) {
         if (bytes_left > 0x40000000) {
@@ -2531,14 +2558,14 @@ write_file_binary_mode(const char *filename, const void *content, size_t content
             }
             report_write_failure(filename, err);
             ws_close(fd);
-            return FALSE;
+            return false;
         }
         bytes_left -= bytes_written;
         ptr += bytes_written;
     }
 
     ws_close(fd);
-    return TRUE;
+    return true;
 }
 
 /*
@@ -2547,20 +2574,20 @@ write_file_binary_mode(const char *filename, const void *content, size_t content
  * we'll copy the raw bytes, and we don't look at the bytes as we copy
  * them.
  *
- * Returns TRUE on success, FALSE on failure. If a failure, it also
+ * Returns true on success, false on failure. If a failure, it also
  * displays a simple dialog window with the error message.
  */
-gboolean
+bool
 copy_file_binary_mode(const char *from_filename, const char *to_filename)
 {
     int           from_fd, to_fd, err;
     ws_file_ssize_t nread, nwritten;
-    guint8        *pd = NULL;
+    uint8_t       *pd = NULL;
 
     /* Copy the raw bytes of the file. */
     from_fd = ws_open(from_filename, O_RDONLY | O_BINARY, 0000 /* no creation so don't matter */);
     if (from_fd < 0) {
-        report_open_failure(from_filename, errno, FALSE);
+        report_open_failure(from_filename, errno, false);
         goto done;
     }
 
@@ -2571,13 +2598,13 @@ copy_file_binary_mode(const char *from_filename, const char *to_filename)
        to be open in binary mode. */
     to_fd = ws_open(to_filename, O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0644);
     if (to_fd < 0) {
-        report_open_failure(to_filename, errno, TRUE);
+        report_open_failure(to_filename, errno, true);
         ws_close(from_fd);
         goto done;
     }
 
 #define FS_READ_SIZE 65536
-    pd = (guint8 *)g_malloc(FS_READ_SIZE);
+    pd = (uint8_t *)g_malloc(FS_READ_SIZE);
     while ((nread = ws_read(from_fd, pd, FS_READ_SIZE)) > 0) {
         nwritten = ws_write(to_fd, pd, nread);
         if (nwritten < nread) {
@@ -2606,18 +2633,18 @@ copy_file_binary_mode(const char *from_filename, const char *to_filename)
 
     g_free(pd);
     pd = NULL;
-    return TRUE;
+    return true;
 
 done:
     g_free(pd);
-    return FALSE;
+    return false;
 }
 
-gchar *
-data_file_url(const gchar *filename)
+char *
+data_file_url(const char *filename)
 {
-    gchar *file_path;
-    gchar *uri;
+    char *file_path;
+    char *uri;
 
     /* Absolute path? */
     if(g_path_is_absolute(filename)) {
@@ -2634,11 +2661,11 @@ data_file_url(const gchar *filename)
     return uri;
 }
 
-gchar *
-doc_file_url(const gchar *filename)
+char *
+doc_file_url(const char *filename)
 {
-    gchar *file_path;
-    gchar *uri;
+    char *file_path;
+    char *uri;
 
     /* Absolute path? */
     if(g_path_is_absolute(filename)) {
